#define CASE_CFN_ACOS \
  case CFN_ACOS: \
  case CFN_BUILT_IN_ACOSF: \
  case CFN_BUILT_IN_ACOS: \
  case CFN_BUILT_IN_ACOSL
#define CASE_CFN_ACOS_FN \
  case CFN_BUILT_IN_ACOSF16: \
  case CFN_BUILT_IN_ACOSF32: \
  case CFN_BUILT_IN_ACOSF64: \
  case CFN_BUILT_IN_ACOSF128: \
  case CFN_BUILT_IN_ACOSF32X: \
  case CFN_BUILT_IN_ACOSF64X: \
  case CFN_BUILT_IN_ACOSF128X
#define CASE_CFN_ACOS_ALL \
  case CFN_BUILT_IN_ACOSF: \
  case CFN_BUILT_IN_ACOS: \
  case CFN_BUILT_IN_ACOSL: \
  case CFN_BUILT_IN_ACOSF16: \
  case CFN_BUILT_IN_ACOSF32: \
  case CFN_BUILT_IN_ACOSF64: \
  case CFN_BUILT_IN_ACOSF128: \
  case CFN_BUILT_IN_ACOSF32X: \
  case CFN_BUILT_IN_ACOSF64X: \
  case CFN_BUILT_IN_ACOSF128X
#define CASE_CFN_ACOSH \
  case CFN_ACOSH: \
  case CFN_BUILT_IN_ACOSHF: \
  case CFN_BUILT_IN_ACOSH: \
  case CFN_BUILT_IN_ACOSHL
#define CASE_CFN_ACOSH_FN \
  case CFN_BUILT_IN_ACOSHF16: \
  case CFN_BUILT_IN_ACOSHF32: \
  case CFN_BUILT_IN_ACOSHF64: \
  case CFN_BUILT_IN_ACOSHF128: \
  case CFN_BUILT_IN_ACOSHF32X: \
  case CFN_BUILT_IN_ACOSHF64X: \
  case CFN_BUILT_IN_ACOSHF128X
#define CASE_CFN_ACOSH_ALL \
  case CFN_BUILT_IN_ACOSHF: \
  case CFN_BUILT_IN_ACOSH: \
  case CFN_BUILT_IN_ACOSHL: \
  case CFN_BUILT_IN_ACOSHF16: \
  case CFN_BUILT_IN_ACOSHF32: \
  case CFN_BUILT_IN_ACOSHF64: \
  case CFN_BUILT_IN_ACOSHF128: \
  case CFN_BUILT_IN_ACOSHF32X: \
  case CFN_BUILT_IN_ACOSHF64X: \
  case CFN_BUILT_IN_ACOSHF128X
#define CASE_CFN_ASIN \
  case CFN_ASIN: \
  case CFN_BUILT_IN_ASINF: \
  case CFN_BUILT_IN_ASIN: \
  case CFN_BUILT_IN_ASINL
#define CASE_CFN_ASIN_FN \
  case CFN_BUILT_IN_ASINF16: \
  case CFN_BUILT_IN_ASINF32: \
  case CFN_BUILT_IN_ASINF64: \
  case CFN_BUILT_IN_ASINF128: \
  case CFN_BUILT_IN_ASINF32X: \
  case CFN_BUILT_IN_ASINF64X: \
  case CFN_BUILT_IN_ASINF128X
#define CASE_CFN_ASIN_ALL \
  case CFN_BUILT_IN_ASINF: \
  case CFN_BUILT_IN_ASIN: \
  case CFN_BUILT_IN_ASINL: \
  case CFN_BUILT_IN_ASINF16: \
  case CFN_BUILT_IN_ASINF32: \
  case CFN_BUILT_IN_ASINF64: \
  case CFN_BUILT_IN_ASINF128: \
  case CFN_BUILT_IN_ASINF32X: \
  case CFN_BUILT_IN_ASINF64X: \
  case CFN_BUILT_IN_ASINF128X
#define CASE_CFN_ASINH \
  case CFN_ASINH: \
  case CFN_BUILT_IN_ASINHF: \
  case CFN_BUILT_IN_ASINH: \
  case CFN_BUILT_IN_ASINHL
#define CASE_CFN_ASINH_FN \
  case CFN_BUILT_IN_ASINHF16: \
  case CFN_BUILT_IN_ASINHF32: \
  case CFN_BUILT_IN_ASINHF64: \
  case CFN_BUILT_IN_ASINHF128: \
  case CFN_BUILT_IN_ASINHF32X: \
  case CFN_BUILT_IN_ASINHF64X: \
  case CFN_BUILT_IN_ASINHF128X
#define CASE_CFN_ASINH_ALL \
  case CFN_BUILT_IN_ASINHF: \
  case CFN_BUILT_IN_ASINH: \
  case CFN_BUILT_IN_ASINHL: \
  case CFN_BUILT_IN_ASINHF16: \
  case CFN_BUILT_IN_ASINHF32: \
  case CFN_BUILT_IN_ASINHF64: \
  case CFN_BUILT_IN_ASINHF128: \
  case CFN_BUILT_IN_ASINHF32X: \
  case CFN_BUILT_IN_ASINHF64X: \
  case CFN_BUILT_IN_ASINHF128X
#define CASE_CFN_ATAN \
  case CFN_ATAN: \
  case CFN_BUILT_IN_ATANF: \
  case CFN_BUILT_IN_ATAN: \
  case CFN_BUILT_IN_ATANL
#define CASE_CFN_ATAN_FN \
  case CFN_BUILT_IN_ATANF16: \
  case CFN_BUILT_IN_ATANF32: \
  case CFN_BUILT_IN_ATANF64: \
  case CFN_BUILT_IN_ATANF128: \
  case CFN_BUILT_IN_ATANF32X: \
  case CFN_BUILT_IN_ATANF64X: \
  case CFN_BUILT_IN_ATANF128X
#define CASE_CFN_ATAN_ALL \
  case CFN_BUILT_IN_ATANF: \
  case CFN_BUILT_IN_ATAN: \
  case CFN_BUILT_IN_ATANL: \
  case CFN_BUILT_IN_ATANF16: \
  case CFN_BUILT_IN_ATANF32: \
  case CFN_BUILT_IN_ATANF64: \
  case CFN_BUILT_IN_ATANF128: \
  case CFN_BUILT_IN_ATANF32X: \
  case CFN_BUILT_IN_ATANF64X: \
  case CFN_BUILT_IN_ATANF128X
#define CASE_CFN_ATAN2 \
  case CFN_ATAN2: \
  case CFN_BUILT_IN_ATAN2F: \
  case CFN_BUILT_IN_ATAN2: \
  case CFN_BUILT_IN_ATAN2L
#define CASE_CFN_ATAN2_FN \
  case CFN_BUILT_IN_ATAN2F16: \
  case CFN_BUILT_IN_ATAN2F32: \
  case CFN_BUILT_IN_ATAN2F64: \
  case CFN_BUILT_IN_ATAN2F128: \
  case CFN_BUILT_IN_ATAN2F32X: \
  case CFN_BUILT_IN_ATAN2F64X: \
  case CFN_BUILT_IN_ATAN2F128X
#define CASE_CFN_ATAN2_ALL \
  case CFN_BUILT_IN_ATAN2F: \
  case CFN_BUILT_IN_ATAN2: \
  case CFN_BUILT_IN_ATAN2L: \
  case CFN_BUILT_IN_ATAN2F16: \
  case CFN_BUILT_IN_ATAN2F32: \
  case CFN_BUILT_IN_ATAN2F64: \
  case CFN_BUILT_IN_ATAN2F128: \
  case CFN_BUILT_IN_ATAN2F32X: \
  case CFN_BUILT_IN_ATAN2F64X: \
  case CFN_BUILT_IN_ATAN2F128X
#define CASE_CFN_ATANH \
  case CFN_ATANH: \
  case CFN_BUILT_IN_ATANHF: \
  case CFN_BUILT_IN_ATANH: \
  case CFN_BUILT_IN_ATANHL
#define CASE_CFN_ATANH_FN \
  case CFN_BUILT_IN_ATANHF16: \
  case CFN_BUILT_IN_ATANHF32: \
  case CFN_BUILT_IN_ATANHF64: \
  case CFN_BUILT_IN_ATANHF128: \
  case CFN_BUILT_IN_ATANHF32X: \
  case CFN_BUILT_IN_ATANHF64X: \
  case CFN_BUILT_IN_ATANHF128X
#define CASE_CFN_ATANH_ALL \
  case CFN_BUILT_IN_ATANHF: \
  case CFN_BUILT_IN_ATANH: \
  case CFN_BUILT_IN_ATANHL: \
  case CFN_BUILT_IN_ATANHF16: \
  case CFN_BUILT_IN_ATANHF32: \
  case CFN_BUILT_IN_ATANHF64: \
  case CFN_BUILT_IN_ATANHF128: \
  case CFN_BUILT_IN_ATANHF32X: \
  case CFN_BUILT_IN_ATANHF64X: \
  case CFN_BUILT_IN_ATANHF128X
#define CASE_CFN_CBRT \
  case CFN_BUILT_IN_CBRTF: \
  case CFN_BUILT_IN_CBRT: \
  case CFN_BUILT_IN_CBRTL
#define CASE_CFN_CBRT_FN \
  case CFN_BUILT_IN_CBRTF16: \
  case CFN_BUILT_IN_CBRTF32: \
  case CFN_BUILT_IN_CBRTF64: \
  case CFN_BUILT_IN_CBRTF128: \
  case CFN_BUILT_IN_CBRTF32X: \
  case CFN_BUILT_IN_CBRTF64X: \
  case CFN_BUILT_IN_CBRTF128X
#define CASE_CFN_CBRT_ALL \
  case CFN_BUILT_IN_CBRTF: \
  case CFN_BUILT_IN_CBRT: \
  case CFN_BUILT_IN_CBRTL: \
  case CFN_BUILT_IN_CBRTF16: \
  case CFN_BUILT_IN_CBRTF32: \
  case CFN_BUILT_IN_CBRTF64: \
  case CFN_BUILT_IN_CBRTF128: \
  case CFN_BUILT_IN_CBRTF32X: \
  case CFN_BUILT_IN_CBRTF64X: \
  case CFN_BUILT_IN_CBRTF128X
#define CASE_CFN_CEIL \
  case CFN_CEIL: \
  case CFN_BUILT_IN_CEILF: \
  case CFN_BUILT_IN_CEIL: \
  case CFN_BUILT_IN_CEILL
#define CASE_CFN_CEIL_FN \
  case CFN_BUILT_IN_CEILF16: \
  case CFN_BUILT_IN_CEILF32: \
  case CFN_BUILT_IN_CEILF64: \
  case CFN_BUILT_IN_CEILF128: \
  case CFN_BUILT_IN_CEILF32X: \
  case CFN_BUILT_IN_CEILF64X: \
  case CFN_BUILT_IN_CEILF128X
#define CASE_CFN_CEIL_ALL \
  case CFN_BUILT_IN_CEILF: \
  case CFN_BUILT_IN_CEIL: \
  case CFN_BUILT_IN_CEILL: \
  case CFN_BUILT_IN_CEILF16: \
  case CFN_BUILT_IN_CEILF32: \
  case CFN_BUILT_IN_CEILF64: \
  case CFN_BUILT_IN_CEILF128: \
  case CFN_BUILT_IN_CEILF32X: \
  case CFN_BUILT_IN_CEILF64X: \
  case CFN_BUILT_IN_CEILF128X
#define CASE_CFN_COPYSIGN \
  case CFN_COPYSIGN: \
  case CFN_BUILT_IN_COPYSIGNF: \
  case CFN_BUILT_IN_COPYSIGN: \
  case CFN_BUILT_IN_COPYSIGNL
#define CASE_CFN_COPYSIGN_FN \
  case CFN_BUILT_IN_COPYSIGNF16: \
  case CFN_BUILT_IN_COPYSIGNF32: \
  case CFN_BUILT_IN_COPYSIGNF64: \
  case CFN_BUILT_IN_COPYSIGNF128: \
  case CFN_BUILT_IN_COPYSIGNF32X: \
  case CFN_BUILT_IN_COPYSIGNF64X: \
  case CFN_BUILT_IN_COPYSIGNF128X
#define CASE_CFN_COPYSIGN_ALL \
  case CFN_BUILT_IN_COPYSIGNF: \
  case CFN_BUILT_IN_COPYSIGN: \
  case CFN_BUILT_IN_COPYSIGNL: \
  case CFN_BUILT_IN_COPYSIGNF16: \
  case CFN_BUILT_IN_COPYSIGNF32: \
  case CFN_BUILT_IN_COPYSIGNF64: \
  case CFN_BUILT_IN_COPYSIGNF128: \
  case CFN_BUILT_IN_COPYSIGNF32X: \
  case CFN_BUILT_IN_COPYSIGNF64X: \
  case CFN_BUILT_IN_COPYSIGNF128X
#define CASE_CFN_COS \
  case CFN_COS: \
  case CFN_BUILT_IN_COSF: \
  case CFN_BUILT_IN_COS: \
  case CFN_BUILT_IN_COSL
#define CASE_CFN_COS_FN \
  case CFN_BUILT_IN_COSF16: \
  case CFN_BUILT_IN_COSF32: \
  case CFN_BUILT_IN_COSF64: \
  case CFN_BUILT_IN_COSF128: \
  case CFN_BUILT_IN_COSF32X: \
  case CFN_BUILT_IN_COSF64X: \
  case CFN_BUILT_IN_COSF128X
#define CASE_CFN_COS_ALL \
  case CFN_BUILT_IN_COSF: \
  case CFN_BUILT_IN_COS: \
  case CFN_BUILT_IN_COSL: \
  case CFN_BUILT_IN_COSF16: \
  case CFN_BUILT_IN_COSF32: \
  case CFN_BUILT_IN_COSF64: \
  case CFN_BUILT_IN_COSF128: \
  case CFN_BUILT_IN_COSF32X: \
  case CFN_BUILT_IN_COSF64X: \
  case CFN_BUILT_IN_COSF128X
#define CASE_CFN_COSH \
  case CFN_COSH: \
  case CFN_BUILT_IN_COSHF: \
  case CFN_BUILT_IN_COSH: \
  case CFN_BUILT_IN_COSHL
#define CASE_CFN_COSH_FN \
  case CFN_BUILT_IN_COSHF16: \
  case CFN_BUILT_IN_COSHF32: \
  case CFN_BUILT_IN_COSHF64: \
  case CFN_BUILT_IN_COSHF128: \
  case CFN_BUILT_IN_COSHF32X: \
  case CFN_BUILT_IN_COSHF64X: \
  case CFN_BUILT_IN_COSHF128X
#define CASE_CFN_COSH_ALL \
  case CFN_BUILT_IN_COSHF: \
  case CFN_BUILT_IN_COSH: \
  case CFN_BUILT_IN_COSHL: \
  case CFN_BUILT_IN_COSHF16: \
  case CFN_BUILT_IN_COSHF32: \
  case CFN_BUILT_IN_COSHF64: \
  case CFN_BUILT_IN_COSHF128: \
  case CFN_BUILT_IN_COSHF32X: \
  case CFN_BUILT_IN_COSHF64X: \
  case CFN_BUILT_IN_COSHF128X
#define CASE_CFN_DREM \
  case CFN_BUILT_IN_DREMF: \
  case CFN_BUILT_IN_DREM: \
  case CFN_BUILT_IN_DREML
#define CASE_CFN_ERF \
  case CFN_BUILT_IN_ERFF: \
  case CFN_BUILT_IN_ERF: \
  case CFN_BUILT_IN_ERFL
#define CASE_CFN_ERF_FN \
  case CFN_BUILT_IN_ERFF16: \
  case CFN_BUILT_IN_ERFF32: \
  case CFN_BUILT_IN_ERFF64: \
  case CFN_BUILT_IN_ERFF128: \
  case CFN_BUILT_IN_ERFF32X: \
  case CFN_BUILT_IN_ERFF64X: \
  case CFN_BUILT_IN_ERFF128X
#define CASE_CFN_ERF_ALL \
  case CFN_BUILT_IN_ERFF: \
  case CFN_BUILT_IN_ERF: \
  case CFN_BUILT_IN_ERFL: \
  case CFN_BUILT_IN_ERFF16: \
  case CFN_BUILT_IN_ERFF32: \
  case CFN_BUILT_IN_ERFF64: \
  case CFN_BUILT_IN_ERFF128: \
  case CFN_BUILT_IN_ERFF32X: \
  case CFN_BUILT_IN_ERFF64X: \
  case CFN_BUILT_IN_ERFF128X
#define CASE_CFN_ERFC \
  case CFN_BUILT_IN_ERFCF: \
  case CFN_BUILT_IN_ERFC: \
  case CFN_BUILT_IN_ERFCL
#define CASE_CFN_ERFC_FN \
  case CFN_BUILT_IN_ERFCF16: \
  case CFN_BUILT_IN_ERFCF32: \
  case CFN_BUILT_IN_ERFCF64: \
  case CFN_BUILT_IN_ERFCF128: \
  case CFN_BUILT_IN_ERFCF32X: \
  case CFN_BUILT_IN_ERFCF64X: \
  case CFN_BUILT_IN_ERFCF128X
#define CASE_CFN_ERFC_ALL \
  case CFN_BUILT_IN_ERFCF: \
  case CFN_BUILT_IN_ERFC: \
  case CFN_BUILT_IN_ERFCL: \
  case CFN_BUILT_IN_ERFCF16: \
  case CFN_BUILT_IN_ERFCF32: \
  case CFN_BUILT_IN_ERFCF64: \
  case CFN_BUILT_IN_ERFCF128: \
  case CFN_BUILT_IN_ERFCF32X: \
  case CFN_BUILT_IN_ERFCF64X: \
  case CFN_BUILT_IN_ERFCF128X
#define CASE_CFN_EXP \
  case CFN_EXP: \
  case CFN_BUILT_IN_EXPF: \
  case CFN_BUILT_IN_EXP: \
  case CFN_BUILT_IN_EXPL
#define CASE_CFN_EXP_FN \
  case CFN_BUILT_IN_EXPF16: \
  case CFN_BUILT_IN_EXPF32: \
  case CFN_BUILT_IN_EXPF64: \
  case CFN_BUILT_IN_EXPF128: \
  case CFN_BUILT_IN_EXPF32X: \
  case CFN_BUILT_IN_EXPF64X: \
  case CFN_BUILT_IN_EXPF128X
#define CASE_CFN_EXP_ALL \
  case CFN_BUILT_IN_EXPF: \
  case CFN_BUILT_IN_EXP: \
  case CFN_BUILT_IN_EXPL: \
  case CFN_BUILT_IN_EXPF16: \
  case CFN_BUILT_IN_EXPF32: \
  case CFN_BUILT_IN_EXPF64: \
  case CFN_BUILT_IN_EXPF128: \
  case CFN_BUILT_IN_EXPF32X: \
  case CFN_BUILT_IN_EXPF64X: \
  case CFN_BUILT_IN_EXPF128X
#define CASE_CFN_EXP10 \
  case CFN_EXP10: \
  case CFN_BUILT_IN_EXP10F: \
  case CFN_BUILT_IN_EXP10: \
  case CFN_BUILT_IN_EXP10L
#define CASE_CFN_EXP2 \
  case CFN_EXP2: \
  case CFN_BUILT_IN_EXP2F: \
  case CFN_BUILT_IN_EXP2: \
  case CFN_BUILT_IN_EXP2L
#define CASE_CFN_EXP2_FN \
  case CFN_BUILT_IN_EXP2F16: \
  case CFN_BUILT_IN_EXP2F32: \
  case CFN_BUILT_IN_EXP2F64: \
  case CFN_BUILT_IN_EXP2F128: \
  case CFN_BUILT_IN_EXP2F32X: \
  case CFN_BUILT_IN_EXP2F64X: \
  case CFN_BUILT_IN_EXP2F128X
#define CASE_CFN_EXP2_ALL \
  case CFN_BUILT_IN_EXP2F: \
  case CFN_BUILT_IN_EXP2: \
  case CFN_BUILT_IN_EXP2L: \
  case CFN_BUILT_IN_EXP2F16: \
  case CFN_BUILT_IN_EXP2F32: \
  case CFN_BUILT_IN_EXP2F64: \
  case CFN_BUILT_IN_EXP2F128: \
  case CFN_BUILT_IN_EXP2F32X: \
  case CFN_BUILT_IN_EXP2F64X: \
  case CFN_BUILT_IN_EXP2F128X
#define CASE_CFN_EXPM1 \
  case CFN_EXPM1: \
  case CFN_BUILT_IN_EXPM1F: \
  case CFN_BUILT_IN_EXPM1: \
  case CFN_BUILT_IN_EXPM1L
#define CASE_CFN_EXPM1_FN \
  case CFN_BUILT_IN_EXPM1F16: \
  case CFN_BUILT_IN_EXPM1F32: \
  case CFN_BUILT_IN_EXPM1F64: \
  case CFN_BUILT_IN_EXPM1F128: \
  case CFN_BUILT_IN_EXPM1F32X: \
  case CFN_BUILT_IN_EXPM1F64X: \
  case CFN_BUILT_IN_EXPM1F128X
#define CASE_CFN_EXPM1_ALL \
  case CFN_BUILT_IN_EXPM1F: \
  case CFN_BUILT_IN_EXPM1: \
  case CFN_BUILT_IN_EXPM1L: \
  case CFN_BUILT_IN_EXPM1F16: \
  case CFN_BUILT_IN_EXPM1F32: \
  case CFN_BUILT_IN_EXPM1F64: \
  case CFN_BUILT_IN_EXPM1F128: \
  case CFN_BUILT_IN_EXPM1F32X: \
  case CFN_BUILT_IN_EXPM1F64X: \
  case CFN_BUILT_IN_EXPM1F128X
#define CASE_CFN_FABS \
  case CFN_BUILT_IN_FABSF: \
  case CFN_BUILT_IN_FABS: \
  case CFN_BUILT_IN_FABSL
#define CASE_CFN_FABS_FN \
  case CFN_BUILT_IN_FABSF16: \
  case CFN_BUILT_IN_FABSF32: \
  case CFN_BUILT_IN_FABSF64: \
  case CFN_BUILT_IN_FABSF128: \
  case CFN_BUILT_IN_FABSF32X: \
  case CFN_BUILT_IN_FABSF64X: \
  case CFN_BUILT_IN_FABSF128X
#define CASE_CFN_FABS_ALL \
  case CFN_BUILT_IN_FABSF: \
  case CFN_BUILT_IN_FABS: \
  case CFN_BUILT_IN_FABSL: \
  case CFN_BUILT_IN_FABSF16: \
  case CFN_BUILT_IN_FABSF32: \
  case CFN_BUILT_IN_FABSF64: \
  case CFN_BUILT_IN_FABSF128: \
  case CFN_BUILT_IN_FABSF32X: \
  case CFN_BUILT_IN_FABSF64X: \
  case CFN_BUILT_IN_FABSF128X
#define CASE_CFN_FDIM \
  case CFN_BUILT_IN_FDIMF: \
  case CFN_BUILT_IN_FDIM: \
  case CFN_BUILT_IN_FDIML
#define CASE_CFN_FDIM_FN \
  case CFN_BUILT_IN_FDIMF16: \
  case CFN_BUILT_IN_FDIMF32: \
  case CFN_BUILT_IN_FDIMF64: \
  case CFN_BUILT_IN_FDIMF128: \
  case CFN_BUILT_IN_FDIMF32X: \
  case CFN_BUILT_IN_FDIMF64X: \
  case CFN_BUILT_IN_FDIMF128X
#define CASE_CFN_FDIM_ALL \
  case CFN_BUILT_IN_FDIMF: \
  case CFN_BUILT_IN_FDIM: \
  case CFN_BUILT_IN_FDIML: \
  case CFN_BUILT_IN_FDIMF16: \
  case CFN_BUILT_IN_FDIMF32: \
  case CFN_BUILT_IN_FDIMF64: \
  case CFN_BUILT_IN_FDIMF128: \
  case CFN_BUILT_IN_FDIMF32X: \
  case CFN_BUILT_IN_FDIMF64X: \
  case CFN_BUILT_IN_FDIMF128X
#define CASE_CFN_FLOOR \
  case CFN_FLOOR: \
  case CFN_BUILT_IN_FLOORF: \
  case CFN_BUILT_IN_FLOOR: \
  case CFN_BUILT_IN_FLOORL
#define CASE_CFN_FLOOR_FN \
  case CFN_BUILT_IN_FLOORF16: \
  case CFN_BUILT_IN_FLOORF32: \
  case CFN_BUILT_IN_FLOORF64: \
  case CFN_BUILT_IN_FLOORF128: \
  case CFN_BUILT_IN_FLOORF32X: \
  case CFN_BUILT_IN_FLOORF64X: \
  case CFN_BUILT_IN_FLOORF128X
#define CASE_CFN_FLOOR_ALL \
  case CFN_BUILT_IN_FLOORF: \
  case CFN_BUILT_IN_FLOOR: \
  case CFN_BUILT_IN_FLOORL: \
  case CFN_BUILT_IN_FLOORF16: \
  case CFN_BUILT_IN_FLOORF32: \
  case CFN_BUILT_IN_FLOORF64: \
  case CFN_BUILT_IN_FLOORF128: \
  case CFN_BUILT_IN_FLOORF32X: \
  case CFN_BUILT_IN_FLOORF64X: \
  case CFN_BUILT_IN_FLOORF128X
#define CASE_CFN_FMA \
  case CFN_FMA: \
  case CFN_BUILT_IN_FMAF: \
  case CFN_BUILT_IN_FMA: \
  case CFN_BUILT_IN_FMAL
#define CASE_CFN_FMA_FN \
  case CFN_BUILT_IN_FMAF16: \
  case CFN_BUILT_IN_FMAF32: \
  case CFN_BUILT_IN_FMAF64: \
  case CFN_BUILT_IN_FMAF128: \
  case CFN_BUILT_IN_FMAF32X: \
  case CFN_BUILT_IN_FMAF64X: \
  case CFN_BUILT_IN_FMAF128X
#define CASE_CFN_FMA_ALL \
  case CFN_BUILT_IN_FMAF: \
  case CFN_BUILT_IN_FMA: \
  case CFN_BUILT_IN_FMAL: \
  case CFN_BUILT_IN_FMAF16: \
  case CFN_BUILT_IN_FMAF32: \
  case CFN_BUILT_IN_FMAF64: \
  case CFN_BUILT_IN_FMAF128: \
  case CFN_BUILT_IN_FMAF32X: \
  case CFN_BUILT_IN_FMAF64X: \
  case CFN_BUILT_IN_FMAF128X
#define CASE_CFN_FMAX \
  case CFN_FMAX: \
  case CFN_BUILT_IN_FMAXF: \
  case CFN_BUILT_IN_FMAX: \
  case CFN_BUILT_IN_FMAXL
#define CASE_CFN_FMAX_FN \
  case CFN_BUILT_IN_FMAXF16: \
  case CFN_BUILT_IN_FMAXF32: \
  case CFN_BUILT_IN_FMAXF64: \
  case CFN_BUILT_IN_FMAXF128: \
  case CFN_BUILT_IN_FMAXF32X: \
  case CFN_BUILT_IN_FMAXF64X: \
  case CFN_BUILT_IN_FMAXF128X
#define CASE_CFN_FMAX_ALL \
  case CFN_BUILT_IN_FMAXF: \
  case CFN_BUILT_IN_FMAX: \
  case CFN_BUILT_IN_FMAXL: \
  case CFN_BUILT_IN_FMAXF16: \
  case CFN_BUILT_IN_FMAXF32: \
  case CFN_BUILT_IN_FMAXF64: \
  case CFN_BUILT_IN_FMAXF128: \
  case CFN_BUILT_IN_FMAXF32X: \
  case CFN_BUILT_IN_FMAXF64X: \
  case CFN_BUILT_IN_FMAXF128X
#define CASE_CFN_FMIN \
  case CFN_FMIN: \
  case CFN_BUILT_IN_FMINF: \
  case CFN_BUILT_IN_FMIN: \
  case CFN_BUILT_IN_FMINL
#define CASE_CFN_FMIN_FN \
  case CFN_BUILT_IN_FMINF16: \
  case CFN_BUILT_IN_FMINF32: \
  case CFN_BUILT_IN_FMINF64: \
  case CFN_BUILT_IN_FMINF128: \
  case CFN_BUILT_IN_FMINF32X: \
  case CFN_BUILT_IN_FMINF64X: \
  case CFN_BUILT_IN_FMINF128X
#define CASE_CFN_FMIN_ALL \
  case CFN_BUILT_IN_FMINF: \
  case CFN_BUILT_IN_FMIN: \
  case CFN_BUILT_IN_FMINL: \
  case CFN_BUILT_IN_FMINF16: \
  case CFN_BUILT_IN_FMINF32: \
  case CFN_BUILT_IN_FMINF64: \
  case CFN_BUILT_IN_FMINF128: \
  case CFN_BUILT_IN_FMINF32X: \
  case CFN_BUILT_IN_FMINF64X: \
  case CFN_BUILT_IN_FMINF128X
#define CASE_CFN_FMOD \
  case CFN_FMOD: \
  case CFN_BUILT_IN_FMODF: \
  case CFN_BUILT_IN_FMOD: \
  case CFN_BUILT_IN_FMODL
#define CASE_CFN_FMOD_FN \
  case CFN_BUILT_IN_FMODF16: \
  case CFN_BUILT_IN_FMODF32: \
  case CFN_BUILT_IN_FMODF64: \
  case CFN_BUILT_IN_FMODF128: \
  case CFN_BUILT_IN_FMODF32X: \
  case CFN_BUILT_IN_FMODF64X: \
  case CFN_BUILT_IN_FMODF128X
#define CASE_CFN_FMOD_ALL \
  case CFN_BUILT_IN_FMODF: \
  case CFN_BUILT_IN_FMOD: \
  case CFN_BUILT_IN_FMODL: \
  case CFN_BUILT_IN_FMODF16: \
  case CFN_BUILT_IN_FMODF32: \
  case CFN_BUILT_IN_FMODF64: \
  case CFN_BUILT_IN_FMODF128: \
  case CFN_BUILT_IN_FMODF32X: \
  case CFN_BUILT_IN_FMODF64X: \
  case CFN_BUILT_IN_FMODF128X
#define CASE_CFN_FREXP \
  case CFN_BUILT_IN_FREXPF: \
  case CFN_BUILT_IN_FREXP: \
  case CFN_BUILT_IN_FREXPL
#define CASE_CFN_FREXP_FN \
  case CFN_BUILT_IN_FREXPF16: \
  case CFN_BUILT_IN_FREXPF32: \
  case CFN_BUILT_IN_FREXPF64: \
  case CFN_BUILT_IN_FREXPF128: \
  case CFN_BUILT_IN_FREXPF32X: \
  case CFN_BUILT_IN_FREXPF64X: \
  case CFN_BUILT_IN_FREXPF128X
#define CASE_CFN_FREXP_ALL \
  case CFN_BUILT_IN_FREXPF: \
  case CFN_BUILT_IN_FREXP: \
  case CFN_BUILT_IN_FREXPL: \
  case CFN_BUILT_IN_FREXPF16: \
  case CFN_BUILT_IN_FREXPF32: \
  case CFN_BUILT_IN_FREXPF64: \
  case CFN_BUILT_IN_FREXPF128: \
  case CFN_BUILT_IN_FREXPF32X: \
  case CFN_BUILT_IN_FREXPF64X: \
  case CFN_BUILT_IN_FREXPF128X
#define CASE_CFN_GAMMA \
  case CFN_BUILT_IN_GAMMAF: \
  case CFN_BUILT_IN_GAMMA: \
  case CFN_BUILT_IN_GAMMAL
#define CASE_CFN_HUGE_VAL \
  case CFN_BUILT_IN_HUGE_VALF: \
  case CFN_BUILT_IN_HUGE_VAL: \
  case CFN_BUILT_IN_HUGE_VALL
#define CASE_CFN_HUGE_VAL_FN \
  case CFN_BUILT_IN_HUGE_VALF16: \
  case CFN_BUILT_IN_HUGE_VALF32: \
  case CFN_BUILT_IN_HUGE_VALF64: \
  case CFN_BUILT_IN_HUGE_VALF128: \
  case CFN_BUILT_IN_HUGE_VALF32X: \
  case CFN_BUILT_IN_HUGE_VALF64X: \
  case CFN_BUILT_IN_HUGE_VALF128X
#define CASE_CFN_HUGE_VAL_ALL \
  case CFN_BUILT_IN_HUGE_VALF: \
  case CFN_BUILT_IN_HUGE_VAL: \
  case CFN_BUILT_IN_HUGE_VALL: \
  case CFN_BUILT_IN_HUGE_VALF16: \
  case CFN_BUILT_IN_HUGE_VALF32: \
  case CFN_BUILT_IN_HUGE_VALF64: \
  case CFN_BUILT_IN_HUGE_VALF128: \
  case CFN_BUILT_IN_HUGE_VALF32X: \
  case CFN_BUILT_IN_HUGE_VALF64X: \
  case CFN_BUILT_IN_HUGE_VALF128X
#define CASE_CFN_HYPOT \
  case CFN_HYPOT: \
  case CFN_BUILT_IN_HYPOTF: \
  case CFN_BUILT_IN_HYPOT: \
  case CFN_BUILT_IN_HYPOTL
#define CASE_CFN_HYPOT_FN \
  case CFN_BUILT_IN_HYPOTF16: \
  case CFN_BUILT_IN_HYPOTF32: \
  case CFN_BUILT_IN_HYPOTF64: \
  case CFN_BUILT_IN_HYPOTF128: \
  case CFN_BUILT_IN_HYPOTF32X: \
  case CFN_BUILT_IN_HYPOTF64X: \
  case CFN_BUILT_IN_HYPOTF128X
#define CASE_CFN_HYPOT_ALL \
  case CFN_BUILT_IN_HYPOTF: \
  case CFN_BUILT_IN_HYPOT: \
  case CFN_BUILT_IN_HYPOTL: \
  case CFN_BUILT_IN_HYPOTF16: \
  case CFN_BUILT_IN_HYPOTF32: \
  case CFN_BUILT_IN_HYPOTF64: \
  case CFN_BUILT_IN_HYPOTF128: \
  case CFN_BUILT_IN_HYPOTF32X: \
  case CFN_BUILT_IN_HYPOTF64X: \
  case CFN_BUILT_IN_HYPOTF128X
#define CASE_CFN_ICEIL \
  case CFN_ICEIL: \
  case CFN_BUILT_IN_ICEILF: \
  case CFN_BUILT_IN_ICEIL: \
  case CFN_BUILT_IN_ICEILL
#define CASE_CFN_IFLOOR \
  case CFN_IFLOOR: \
  case CFN_BUILT_IN_IFLOORF: \
  case CFN_BUILT_IN_IFLOOR: \
  case CFN_BUILT_IN_IFLOORL
#define CASE_CFN_ILOGB \
  case CFN_BUILT_IN_ILOGBF: \
  case CFN_BUILT_IN_ILOGB: \
  case CFN_BUILT_IN_ILOGBL
#define CASE_CFN_ILOGB_FN \
  case CFN_BUILT_IN_ILOGBF16: \
  case CFN_BUILT_IN_ILOGBF32: \
  case CFN_BUILT_IN_ILOGBF64: \
  case CFN_BUILT_IN_ILOGBF128: \
  case CFN_BUILT_IN_ILOGBF32X: \
  case CFN_BUILT_IN_ILOGBF64X: \
  case CFN_BUILT_IN_ILOGBF128X
#define CASE_CFN_ILOGB_ALL \
  case CFN_BUILT_IN_ILOGBF: \
  case CFN_BUILT_IN_ILOGB: \
  case CFN_BUILT_IN_ILOGBL: \
  case CFN_BUILT_IN_ILOGBF16: \
  case CFN_BUILT_IN_ILOGBF32: \
  case CFN_BUILT_IN_ILOGBF64: \
  case CFN_BUILT_IN_ILOGBF128: \
  case CFN_BUILT_IN_ILOGBF32X: \
  case CFN_BUILT_IN_ILOGBF64X: \
  case CFN_BUILT_IN_ILOGBF128X
#define CASE_CFN_INF \
  case CFN_BUILT_IN_INFF: \
  case CFN_BUILT_IN_INF: \
  case CFN_BUILT_IN_INFL
#define CASE_CFN_INF_FN \
  case CFN_BUILT_IN_INFF16: \
  case CFN_BUILT_IN_INFF32: \
  case CFN_BUILT_IN_INFF64: \
  case CFN_BUILT_IN_INFF128: \
  case CFN_BUILT_IN_INFF32X: \
  case CFN_BUILT_IN_INFF64X: \
  case CFN_BUILT_IN_INFF128X
#define CASE_CFN_INF_ALL \
  case CFN_BUILT_IN_INFF: \
  case CFN_BUILT_IN_INF: \
  case CFN_BUILT_IN_INFL: \
  case CFN_BUILT_IN_INFF16: \
  case CFN_BUILT_IN_INFF32: \
  case CFN_BUILT_IN_INFF64: \
  case CFN_BUILT_IN_INFF128: \
  case CFN_BUILT_IN_INFF32X: \
  case CFN_BUILT_IN_INFF64X: \
  case CFN_BUILT_IN_INFF128X
#define CASE_CFN_IRINT \
  case CFN_IRINT: \
  case CFN_BUILT_IN_IRINTF: \
  case CFN_BUILT_IN_IRINT: \
  case CFN_BUILT_IN_IRINTL
#define CASE_CFN_IROUND \
  case CFN_IROUND: \
  case CFN_BUILT_IN_IROUNDF: \
  case CFN_BUILT_IN_IROUND: \
  case CFN_BUILT_IN_IROUNDL
#define CASE_CFN_J0 \
  case CFN_BUILT_IN_J0F: \
  case CFN_BUILT_IN_J0: \
  case CFN_BUILT_IN_J0L
#define CASE_CFN_J1 \
  case CFN_BUILT_IN_J1F: \
  case CFN_BUILT_IN_J1: \
  case CFN_BUILT_IN_J1L
#define CASE_CFN_JN \
  case CFN_BUILT_IN_JNF: \
  case CFN_BUILT_IN_JN: \
  case CFN_BUILT_IN_JNL
#define CASE_CFN_LCEIL \
  case CFN_LCEIL: \
  case CFN_BUILT_IN_LCEILF: \
  case CFN_BUILT_IN_LCEIL: \
  case CFN_BUILT_IN_LCEILL
#define CASE_CFN_LDEXP \
  case CFN_LDEXP: \
  case CFN_BUILT_IN_LDEXPF: \
  case CFN_BUILT_IN_LDEXP: \
  case CFN_BUILT_IN_LDEXPL
#define CASE_CFN_LDEXP_FN \
  case CFN_BUILT_IN_LDEXPF16: \
  case CFN_BUILT_IN_LDEXPF32: \
  case CFN_BUILT_IN_LDEXPF64: \
  case CFN_BUILT_IN_LDEXPF128: \
  case CFN_BUILT_IN_LDEXPF32X: \
  case CFN_BUILT_IN_LDEXPF64X: \
  case CFN_BUILT_IN_LDEXPF128X
#define CASE_CFN_LDEXP_ALL \
  case CFN_BUILT_IN_LDEXPF: \
  case CFN_BUILT_IN_LDEXP: \
  case CFN_BUILT_IN_LDEXPL: \
  case CFN_BUILT_IN_LDEXPF16: \
  case CFN_BUILT_IN_LDEXPF32: \
  case CFN_BUILT_IN_LDEXPF64: \
  case CFN_BUILT_IN_LDEXPF128: \
  case CFN_BUILT_IN_LDEXPF32X: \
  case CFN_BUILT_IN_LDEXPF64X: \
  case CFN_BUILT_IN_LDEXPF128X
#define CASE_CFN_LFLOOR \
  case CFN_LFLOOR: \
  case CFN_BUILT_IN_LFLOORF: \
  case CFN_BUILT_IN_LFLOOR: \
  case CFN_BUILT_IN_LFLOORL
#define CASE_CFN_LGAMMA \
  case CFN_BUILT_IN_LGAMMAF: \
  case CFN_BUILT_IN_LGAMMA: \
  case CFN_BUILT_IN_LGAMMAL
#define CASE_CFN_LGAMMA_FN \
  case CFN_BUILT_IN_LGAMMAF16: \
  case CFN_BUILT_IN_LGAMMAF32: \
  case CFN_BUILT_IN_LGAMMAF64: \
  case CFN_BUILT_IN_LGAMMAF128: \
  case CFN_BUILT_IN_LGAMMAF32X: \
  case CFN_BUILT_IN_LGAMMAF64X: \
  case CFN_BUILT_IN_LGAMMAF128X
#define CASE_CFN_LGAMMA_ALL \
  case CFN_BUILT_IN_LGAMMAF: \
  case CFN_BUILT_IN_LGAMMA: \
  case CFN_BUILT_IN_LGAMMAL: \
  case CFN_BUILT_IN_LGAMMAF16: \
  case CFN_BUILT_IN_LGAMMAF32: \
  case CFN_BUILT_IN_LGAMMAF64: \
  case CFN_BUILT_IN_LGAMMAF128: \
  case CFN_BUILT_IN_LGAMMAF32X: \
  case CFN_BUILT_IN_LGAMMAF64X: \
  case CFN_BUILT_IN_LGAMMAF128X
#define CASE_CFN_LLCEIL \
  case CFN_LLCEIL: \
  case CFN_BUILT_IN_LLCEILF: \
  case CFN_BUILT_IN_LLCEIL: \
  case CFN_BUILT_IN_LLCEILL
#define CASE_CFN_LLFLOOR \
  case CFN_LLFLOOR: \
  case CFN_BUILT_IN_LLFLOORF: \
  case CFN_BUILT_IN_LLFLOOR: \
  case CFN_BUILT_IN_LLFLOORL
#define CASE_CFN_LLRINT \
  case CFN_LLRINT: \
  case CFN_BUILT_IN_LLRINTF: \
  case CFN_BUILT_IN_LLRINT: \
  case CFN_BUILT_IN_LLRINTL
#define CASE_CFN_LLRINT_FN \
  case CFN_BUILT_IN_LLRINTF16: \
  case CFN_BUILT_IN_LLRINTF32: \
  case CFN_BUILT_IN_LLRINTF64: \
  case CFN_BUILT_IN_LLRINTF128: \
  case CFN_BUILT_IN_LLRINTF32X: \
  case CFN_BUILT_IN_LLRINTF64X: \
  case CFN_BUILT_IN_LLRINTF128X
#define CASE_CFN_LLRINT_ALL \
  case CFN_BUILT_IN_LLRINTF: \
  case CFN_BUILT_IN_LLRINT: \
  case CFN_BUILT_IN_LLRINTL: \
  case CFN_BUILT_IN_LLRINTF16: \
  case CFN_BUILT_IN_LLRINTF32: \
  case CFN_BUILT_IN_LLRINTF64: \
  case CFN_BUILT_IN_LLRINTF128: \
  case CFN_BUILT_IN_LLRINTF32X: \
  case CFN_BUILT_IN_LLRINTF64X: \
  case CFN_BUILT_IN_LLRINTF128X
#define CASE_CFN_LLROUND \
  case CFN_LLROUND: \
  case CFN_BUILT_IN_LLROUNDF: \
  case CFN_BUILT_IN_LLROUND: \
  case CFN_BUILT_IN_LLROUNDL
#define CASE_CFN_LLROUND_FN \
  case CFN_BUILT_IN_LLROUNDF16: \
  case CFN_BUILT_IN_LLROUNDF32: \
  case CFN_BUILT_IN_LLROUNDF64: \
  case CFN_BUILT_IN_LLROUNDF128: \
  case CFN_BUILT_IN_LLROUNDF32X: \
  case CFN_BUILT_IN_LLROUNDF64X: \
  case CFN_BUILT_IN_LLROUNDF128X
#define CASE_CFN_LLROUND_ALL \
  case CFN_BUILT_IN_LLROUNDF: \
  case CFN_BUILT_IN_LLROUND: \
  case CFN_BUILT_IN_LLROUNDL: \
  case CFN_BUILT_IN_LLROUNDF16: \
  case CFN_BUILT_IN_LLROUNDF32: \
  case CFN_BUILT_IN_LLROUNDF64: \
  case CFN_BUILT_IN_LLROUNDF128: \
  case CFN_BUILT_IN_LLROUNDF32X: \
  case CFN_BUILT_IN_LLROUNDF64X: \
  case CFN_BUILT_IN_LLROUNDF128X
#define CASE_CFN_LOG \
  case CFN_LOG: \
  case CFN_BUILT_IN_LOGF: \
  case CFN_BUILT_IN_LOG: \
  case CFN_BUILT_IN_LOGL
#define CASE_CFN_LOG_FN \
  case CFN_BUILT_IN_LOGF16: \
  case CFN_BUILT_IN_LOGF32: \
  case CFN_BUILT_IN_LOGF64: \
  case CFN_BUILT_IN_LOGF128: \
  case CFN_BUILT_IN_LOGF32X: \
  case CFN_BUILT_IN_LOGF64X: \
  case CFN_BUILT_IN_LOGF128X
#define CASE_CFN_LOG_ALL \
  case CFN_BUILT_IN_LOGF: \
  case CFN_BUILT_IN_LOG: \
  case CFN_BUILT_IN_LOGL: \
  case CFN_BUILT_IN_LOGF16: \
  case CFN_BUILT_IN_LOGF32: \
  case CFN_BUILT_IN_LOGF64: \
  case CFN_BUILT_IN_LOGF128: \
  case CFN_BUILT_IN_LOGF32X: \
  case CFN_BUILT_IN_LOGF64X: \
  case CFN_BUILT_IN_LOGF128X
#define CASE_CFN_LOG10 \
  case CFN_LOG10: \
  case CFN_BUILT_IN_LOG10F: \
  case CFN_BUILT_IN_LOG10: \
  case CFN_BUILT_IN_LOG10L
#define CASE_CFN_LOG10_FN \
  case CFN_BUILT_IN_LOG10F16: \
  case CFN_BUILT_IN_LOG10F32: \
  case CFN_BUILT_IN_LOG10F64: \
  case CFN_BUILT_IN_LOG10F128: \
  case CFN_BUILT_IN_LOG10F32X: \
  case CFN_BUILT_IN_LOG10F64X: \
  case CFN_BUILT_IN_LOG10F128X
#define CASE_CFN_LOG10_ALL \
  case CFN_BUILT_IN_LOG10F: \
  case CFN_BUILT_IN_LOG10: \
  case CFN_BUILT_IN_LOG10L: \
  case CFN_BUILT_IN_LOG10F16: \
  case CFN_BUILT_IN_LOG10F32: \
  case CFN_BUILT_IN_LOG10F64: \
  case CFN_BUILT_IN_LOG10F128: \
  case CFN_BUILT_IN_LOG10F32X: \
  case CFN_BUILT_IN_LOG10F64X: \
  case CFN_BUILT_IN_LOG10F128X
#define CASE_CFN_LOG1P \
  case CFN_LOG1P: \
  case CFN_BUILT_IN_LOG1PF: \
  case CFN_BUILT_IN_LOG1P: \
  case CFN_BUILT_IN_LOG1PL
#define CASE_CFN_LOG1P_FN \
  case CFN_BUILT_IN_LOG1PF16: \
  case CFN_BUILT_IN_LOG1PF32: \
  case CFN_BUILT_IN_LOG1PF64: \
  case CFN_BUILT_IN_LOG1PF128: \
  case CFN_BUILT_IN_LOG1PF32X: \
  case CFN_BUILT_IN_LOG1PF64X: \
  case CFN_BUILT_IN_LOG1PF128X
#define CASE_CFN_LOG1P_ALL \
  case CFN_BUILT_IN_LOG1PF: \
  case CFN_BUILT_IN_LOG1P: \
  case CFN_BUILT_IN_LOG1PL: \
  case CFN_BUILT_IN_LOG1PF16: \
  case CFN_BUILT_IN_LOG1PF32: \
  case CFN_BUILT_IN_LOG1PF64: \
  case CFN_BUILT_IN_LOG1PF128: \
  case CFN_BUILT_IN_LOG1PF32X: \
  case CFN_BUILT_IN_LOG1PF64X: \
  case CFN_BUILT_IN_LOG1PF128X
#define CASE_CFN_LOG2 \
  case CFN_LOG2: \
  case CFN_BUILT_IN_LOG2F: \
  case CFN_BUILT_IN_LOG2: \
  case CFN_BUILT_IN_LOG2L
#define CASE_CFN_LOG2_FN \
  case CFN_BUILT_IN_LOG2F16: \
  case CFN_BUILT_IN_LOG2F32: \
  case CFN_BUILT_IN_LOG2F64: \
  case CFN_BUILT_IN_LOG2F128: \
  case CFN_BUILT_IN_LOG2F32X: \
  case CFN_BUILT_IN_LOG2F64X: \
  case CFN_BUILT_IN_LOG2F128X
#define CASE_CFN_LOG2_ALL \
  case CFN_BUILT_IN_LOG2F: \
  case CFN_BUILT_IN_LOG2: \
  case CFN_BUILT_IN_LOG2L: \
  case CFN_BUILT_IN_LOG2F16: \
  case CFN_BUILT_IN_LOG2F32: \
  case CFN_BUILT_IN_LOG2F64: \
  case CFN_BUILT_IN_LOG2F128: \
  case CFN_BUILT_IN_LOG2F32X: \
  case CFN_BUILT_IN_LOG2F64X: \
  case CFN_BUILT_IN_LOG2F128X
#define CASE_CFN_LOGB \
  case CFN_LOGB: \
  case CFN_BUILT_IN_LOGBF: \
  case CFN_BUILT_IN_LOGB: \
  case CFN_BUILT_IN_LOGBL
#define CASE_CFN_LOGB_FN \
  case CFN_BUILT_IN_LOGBF16: \
  case CFN_BUILT_IN_LOGBF32: \
  case CFN_BUILT_IN_LOGBF64: \
  case CFN_BUILT_IN_LOGBF128: \
  case CFN_BUILT_IN_LOGBF32X: \
  case CFN_BUILT_IN_LOGBF64X: \
  case CFN_BUILT_IN_LOGBF128X
#define CASE_CFN_LOGB_ALL \
  case CFN_BUILT_IN_LOGBF: \
  case CFN_BUILT_IN_LOGB: \
  case CFN_BUILT_IN_LOGBL: \
  case CFN_BUILT_IN_LOGBF16: \
  case CFN_BUILT_IN_LOGBF32: \
  case CFN_BUILT_IN_LOGBF64: \
  case CFN_BUILT_IN_LOGBF128: \
  case CFN_BUILT_IN_LOGBF32X: \
  case CFN_BUILT_IN_LOGBF64X: \
  case CFN_BUILT_IN_LOGBF128X
#define CASE_CFN_LRINT \
  case CFN_LRINT: \
  case CFN_BUILT_IN_LRINTF: \
  case CFN_BUILT_IN_LRINT: \
  case CFN_BUILT_IN_LRINTL
#define CASE_CFN_LRINT_FN \
  case CFN_BUILT_IN_LRINTF16: \
  case CFN_BUILT_IN_LRINTF32: \
  case CFN_BUILT_IN_LRINTF64: \
  case CFN_BUILT_IN_LRINTF128: \
  case CFN_BUILT_IN_LRINTF32X: \
  case CFN_BUILT_IN_LRINTF64X: \
  case CFN_BUILT_IN_LRINTF128X
#define CASE_CFN_LRINT_ALL \
  case CFN_BUILT_IN_LRINTF: \
  case CFN_BUILT_IN_LRINT: \
  case CFN_BUILT_IN_LRINTL: \
  case CFN_BUILT_IN_LRINTF16: \
  case CFN_BUILT_IN_LRINTF32: \
  case CFN_BUILT_IN_LRINTF64: \
  case CFN_BUILT_IN_LRINTF128: \
  case CFN_BUILT_IN_LRINTF32X: \
  case CFN_BUILT_IN_LRINTF64X: \
  case CFN_BUILT_IN_LRINTF128X
#define CASE_CFN_LROUND \
  case CFN_LROUND: \
  case CFN_BUILT_IN_LROUNDF: \
  case CFN_BUILT_IN_LROUND: \
  case CFN_BUILT_IN_LROUNDL
#define CASE_CFN_LROUND_FN \
  case CFN_BUILT_IN_LROUNDF16: \
  case CFN_BUILT_IN_LROUNDF32: \
  case CFN_BUILT_IN_LROUNDF64: \
  case CFN_BUILT_IN_LROUNDF128: \
  case CFN_BUILT_IN_LROUNDF32X: \
  case CFN_BUILT_IN_LROUNDF64X: \
  case CFN_BUILT_IN_LROUNDF128X
#define CASE_CFN_LROUND_ALL \
  case CFN_BUILT_IN_LROUNDF: \
  case CFN_BUILT_IN_LROUND: \
  case CFN_BUILT_IN_LROUNDL: \
  case CFN_BUILT_IN_LROUNDF16: \
  case CFN_BUILT_IN_LROUNDF32: \
  case CFN_BUILT_IN_LROUNDF64: \
  case CFN_BUILT_IN_LROUNDF128: \
  case CFN_BUILT_IN_LROUNDF32X: \
  case CFN_BUILT_IN_LROUNDF64X: \
  case CFN_BUILT_IN_LROUNDF128X
#define CASE_CFN_MODF \
  case CFN_BUILT_IN_MODFF: \
  case CFN_BUILT_IN_MODF: \
  case CFN_BUILT_IN_MODFL
#define CASE_CFN_MODF_FN \
  case CFN_BUILT_IN_MODFF16: \
  case CFN_BUILT_IN_MODFF32: \
  case CFN_BUILT_IN_MODFF64: \
  case CFN_BUILT_IN_MODFF128: \
  case CFN_BUILT_IN_MODFF32X: \
  case CFN_BUILT_IN_MODFF64X: \
  case CFN_BUILT_IN_MODFF128X
#define CASE_CFN_MODF_ALL \
  case CFN_BUILT_IN_MODFF: \
  case CFN_BUILT_IN_MODF: \
  case CFN_BUILT_IN_MODFL: \
  case CFN_BUILT_IN_MODFF16: \
  case CFN_BUILT_IN_MODFF32: \
  case CFN_BUILT_IN_MODFF64: \
  case CFN_BUILT_IN_MODFF128: \
  case CFN_BUILT_IN_MODFF32X: \
  case CFN_BUILT_IN_MODFF64X: \
  case CFN_BUILT_IN_MODFF128X
#define CASE_CFN_NAN \
  case CFN_BUILT_IN_NANF: \
  case CFN_BUILT_IN_NAN: \
  case CFN_BUILT_IN_NANL
#define CASE_CFN_NAN_FN \
  case CFN_BUILT_IN_NANF16: \
  case CFN_BUILT_IN_NANF32: \
  case CFN_BUILT_IN_NANF64: \
  case CFN_BUILT_IN_NANF128: \
  case CFN_BUILT_IN_NANF32X: \
  case CFN_BUILT_IN_NANF64X: \
  case CFN_BUILT_IN_NANF128X
#define CASE_CFN_NAN_ALL \
  case CFN_BUILT_IN_NANF: \
  case CFN_BUILT_IN_NAN: \
  case CFN_BUILT_IN_NANL: \
  case CFN_BUILT_IN_NANF16: \
  case CFN_BUILT_IN_NANF32: \
  case CFN_BUILT_IN_NANF64: \
  case CFN_BUILT_IN_NANF128: \
  case CFN_BUILT_IN_NANF32X: \
  case CFN_BUILT_IN_NANF64X: \
  case CFN_BUILT_IN_NANF128X
#define CASE_CFN_NANS \
  case CFN_BUILT_IN_NANSF: \
  case CFN_BUILT_IN_NANS: \
  case CFN_BUILT_IN_NANSL
#define CASE_CFN_NANS_FN \
  case CFN_BUILT_IN_NANSF16: \
  case CFN_BUILT_IN_NANSF32: \
  case CFN_BUILT_IN_NANSF64: \
  case CFN_BUILT_IN_NANSF128: \
  case CFN_BUILT_IN_NANSF32X: \
  case CFN_BUILT_IN_NANSF64X: \
  case CFN_BUILT_IN_NANSF128X
#define CASE_CFN_NANS_ALL \
  case CFN_BUILT_IN_NANSF: \
  case CFN_BUILT_IN_NANS: \
  case CFN_BUILT_IN_NANSL: \
  case CFN_BUILT_IN_NANSF16: \
  case CFN_BUILT_IN_NANSF32: \
  case CFN_BUILT_IN_NANSF64: \
  case CFN_BUILT_IN_NANSF128: \
  case CFN_BUILT_IN_NANSF32X: \
  case CFN_BUILT_IN_NANSF64X: \
  case CFN_BUILT_IN_NANSF128X
#define CASE_CFN_NEARBYINT \
  case CFN_NEARBYINT: \
  case CFN_BUILT_IN_NEARBYINTF: \
  case CFN_BUILT_IN_NEARBYINT: \
  case CFN_BUILT_IN_NEARBYINTL
#define CASE_CFN_NEARBYINT_FN \
  case CFN_BUILT_IN_NEARBYINTF16: \
  case CFN_BUILT_IN_NEARBYINTF32: \
  case CFN_BUILT_IN_NEARBYINTF64: \
  case CFN_BUILT_IN_NEARBYINTF128: \
  case CFN_BUILT_IN_NEARBYINTF32X: \
  case CFN_BUILT_IN_NEARBYINTF64X: \
  case CFN_BUILT_IN_NEARBYINTF128X
#define CASE_CFN_NEARBYINT_ALL \
  case CFN_BUILT_IN_NEARBYINTF: \
  case CFN_BUILT_IN_NEARBYINT: \
  case CFN_BUILT_IN_NEARBYINTL: \
  case CFN_BUILT_IN_NEARBYINTF16: \
  case CFN_BUILT_IN_NEARBYINTF32: \
  case CFN_BUILT_IN_NEARBYINTF64: \
  case CFN_BUILT_IN_NEARBYINTF128: \
  case CFN_BUILT_IN_NEARBYINTF32X: \
  case CFN_BUILT_IN_NEARBYINTF64X: \
  case CFN_BUILT_IN_NEARBYINTF128X
#define CASE_CFN_NEXTAFTER \
  case CFN_BUILT_IN_NEXTAFTERF: \
  case CFN_BUILT_IN_NEXTAFTER: \
  case CFN_BUILT_IN_NEXTAFTERL
#define CASE_CFN_NEXTAFTER_FN \
  case CFN_BUILT_IN_NEXTAFTERF16: \
  case CFN_BUILT_IN_NEXTAFTERF32: \
  case CFN_BUILT_IN_NEXTAFTERF64: \
  case CFN_BUILT_IN_NEXTAFTERF128: \
  case CFN_BUILT_IN_NEXTAFTERF32X: \
  case CFN_BUILT_IN_NEXTAFTERF64X: \
  case CFN_BUILT_IN_NEXTAFTERF128X
#define CASE_CFN_NEXTAFTER_ALL \
  case CFN_BUILT_IN_NEXTAFTERF: \
  case CFN_BUILT_IN_NEXTAFTER: \
  case CFN_BUILT_IN_NEXTAFTERL: \
  case CFN_BUILT_IN_NEXTAFTERF16: \
  case CFN_BUILT_IN_NEXTAFTERF32: \
  case CFN_BUILT_IN_NEXTAFTERF64: \
  case CFN_BUILT_IN_NEXTAFTERF128: \
  case CFN_BUILT_IN_NEXTAFTERF32X: \
  case CFN_BUILT_IN_NEXTAFTERF64X: \
  case CFN_BUILT_IN_NEXTAFTERF128X
#define CASE_CFN_NEXTTOWARD \
  case CFN_BUILT_IN_NEXTTOWARDF: \
  case CFN_BUILT_IN_NEXTTOWARD: \
  case CFN_BUILT_IN_NEXTTOWARDL
#define CASE_CFN_POW \
  case CFN_POW: \
  case CFN_BUILT_IN_POWF: \
  case CFN_BUILT_IN_POW: \
  case CFN_BUILT_IN_POWL
#define CASE_CFN_POW_FN \
  case CFN_BUILT_IN_POWF16: \
  case CFN_BUILT_IN_POWF32: \
  case CFN_BUILT_IN_POWF64: \
  case CFN_BUILT_IN_POWF128: \
  case CFN_BUILT_IN_POWF32X: \
  case CFN_BUILT_IN_POWF64X: \
  case CFN_BUILT_IN_POWF128X
#define CASE_CFN_POW_ALL \
  case CFN_BUILT_IN_POWF: \
  case CFN_BUILT_IN_POW: \
  case CFN_BUILT_IN_POWL: \
  case CFN_BUILT_IN_POWF16: \
  case CFN_BUILT_IN_POWF32: \
  case CFN_BUILT_IN_POWF64: \
  case CFN_BUILT_IN_POWF128: \
  case CFN_BUILT_IN_POWF32X: \
  case CFN_BUILT_IN_POWF64X: \
  case CFN_BUILT_IN_POWF128X
#define CASE_CFN_POW10 \
  case CFN_BUILT_IN_POW10F: \
  case CFN_BUILT_IN_POW10: \
  case CFN_BUILT_IN_POW10L
#define CASE_CFN_POWI \
  case CFN_BUILT_IN_POWIF: \
  case CFN_BUILT_IN_POWI: \
  case CFN_BUILT_IN_POWIL
#define CASE_CFN_REMAINDER \
  case CFN_REMAINDER: \
  case CFN_BUILT_IN_REMAINDERF: \
  case CFN_BUILT_IN_REMAINDER: \
  case CFN_BUILT_IN_REMAINDERL
#define CASE_CFN_REMAINDER_FN \
  case CFN_BUILT_IN_REMAINDERF16: \
  case CFN_BUILT_IN_REMAINDERF32: \
  case CFN_BUILT_IN_REMAINDERF64: \
  case CFN_BUILT_IN_REMAINDERF128: \
  case CFN_BUILT_IN_REMAINDERF32X: \
  case CFN_BUILT_IN_REMAINDERF64X: \
  case CFN_BUILT_IN_REMAINDERF128X
#define CASE_CFN_REMAINDER_ALL \
  case CFN_BUILT_IN_REMAINDERF: \
  case CFN_BUILT_IN_REMAINDER: \
  case CFN_BUILT_IN_REMAINDERL: \
  case CFN_BUILT_IN_REMAINDERF16: \
  case CFN_BUILT_IN_REMAINDERF32: \
  case CFN_BUILT_IN_REMAINDERF64: \
  case CFN_BUILT_IN_REMAINDERF128: \
  case CFN_BUILT_IN_REMAINDERF32X: \
  case CFN_BUILT_IN_REMAINDERF64X: \
  case CFN_BUILT_IN_REMAINDERF128X
#define CASE_CFN_REMQUO \
  case CFN_BUILT_IN_REMQUOF: \
  case CFN_BUILT_IN_REMQUO: \
  case CFN_BUILT_IN_REMQUOL
#define CASE_CFN_REMQUO_FN \
  case CFN_BUILT_IN_REMQUOF16: \
  case CFN_BUILT_IN_REMQUOF32: \
  case CFN_BUILT_IN_REMQUOF64: \
  case CFN_BUILT_IN_REMQUOF128: \
  case CFN_BUILT_IN_REMQUOF32X: \
  case CFN_BUILT_IN_REMQUOF64X: \
  case CFN_BUILT_IN_REMQUOF128X
#define CASE_CFN_REMQUO_ALL \
  case CFN_BUILT_IN_REMQUOF: \
  case CFN_BUILT_IN_REMQUO: \
  case CFN_BUILT_IN_REMQUOL: \
  case CFN_BUILT_IN_REMQUOF16: \
  case CFN_BUILT_IN_REMQUOF32: \
  case CFN_BUILT_IN_REMQUOF64: \
  case CFN_BUILT_IN_REMQUOF128: \
  case CFN_BUILT_IN_REMQUOF32X: \
  case CFN_BUILT_IN_REMQUOF64X: \
  case CFN_BUILT_IN_REMQUOF128X
#define CASE_CFN_RINT \
  case CFN_RINT: \
  case CFN_BUILT_IN_RINTF: \
  case CFN_BUILT_IN_RINT: \
  case CFN_BUILT_IN_RINTL
#define CASE_CFN_RINT_FN \
  case CFN_BUILT_IN_RINTF16: \
  case CFN_BUILT_IN_RINTF32: \
  case CFN_BUILT_IN_RINTF64: \
  case CFN_BUILT_IN_RINTF128: \
  case CFN_BUILT_IN_RINTF32X: \
  case CFN_BUILT_IN_RINTF64X: \
  case CFN_BUILT_IN_RINTF128X
#define CASE_CFN_RINT_ALL \
  case CFN_BUILT_IN_RINTF: \
  case CFN_BUILT_IN_RINT: \
  case CFN_BUILT_IN_RINTL: \
  case CFN_BUILT_IN_RINTF16: \
  case CFN_BUILT_IN_RINTF32: \
  case CFN_BUILT_IN_RINTF64: \
  case CFN_BUILT_IN_RINTF128: \
  case CFN_BUILT_IN_RINTF32X: \
  case CFN_BUILT_IN_RINTF64X: \
  case CFN_BUILT_IN_RINTF128X
#define CASE_CFN_ROUNDEVEN \
  case CFN_ROUNDEVEN: \
  case CFN_BUILT_IN_ROUNDEVENF: \
  case CFN_BUILT_IN_ROUNDEVEN: \
  case CFN_BUILT_IN_ROUNDEVENL
#define CASE_CFN_ROUNDEVEN_FN \
  case CFN_BUILT_IN_ROUNDEVENF16: \
  case CFN_BUILT_IN_ROUNDEVENF32: \
  case CFN_BUILT_IN_ROUNDEVENF64: \
  case CFN_BUILT_IN_ROUNDEVENF128: \
  case CFN_BUILT_IN_ROUNDEVENF32X: \
  case CFN_BUILT_IN_ROUNDEVENF64X: \
  case CFN_BUILT_IN_ROUNDEVENF128X
#define CASE_CFN_ROUNDEVEN_ALL \
  case CFN_BUILT_IN_ROUNDEVENF: \
  case CFN_BUILT_IN_ROUNDEVEN: \
  case CFN_BUILT_IN_ROUNDEVENL: \
  case CFN_BUILT_IN_ROUNDEVENF16: \
  case CFN_BUILT_IN_ROUNDEVENF32: \
  case CFN_BUILT_IN_ROUNDEVENF64: \
  case CFN_BUILT_IN_ROUNDEVENF128: \
  case CFN_BUILT_IN_ROUNDEVENF32X: \
  case CFN_BUILT_IN_ROUNDEVENF64X: \
  case CFN_BUILT_IN_ROUNDEVENF128X
#define CASE_CFN_ROUND \
  case CFN_ROUND: \
  case CFN_BUILT_IN_ROUNDF: \
  case CFN_BUILT_IN_ROUND: \
  case CFN_BUILT_IN_ROUNDL
#define CASE_CFN_ROUND_FN \
  case CFN_BUILT_IN_ROUNDF16: \
  case CFN_BUILT_IN_ROUNDF32: \
  case CFN_BUILT_IN_ROUNDF64: \
  case CFN_BUILT_IN_ROUNDF128: \
  case CFN_BUILT_IN_ROUNDF32X: \
  case CFN_BUILT_IN_ROUNDF64X: \
  case CFN_BUILT_IN_ROUNDF128X
#define CASE_CFN_ROUND_ALL \
  case CFN_BUILT_IN_ROUNDF: \
  case CFN_BUILT_IN_ROUND: \
  case CFN_BUILT_IN_ROUNDL: \
  case CFN_BUILT_IN_ROUNDF16: \
  case CFN_BUILT_IN_ROUNDF32: \
  case CFN_BUILT_IN_ROUNDF64: \
  case CFN_BUILT_IN_ROUNDF128: \
  case CFN_BUILT_IN_ROUNDF32X: \
  case CFN_BUILT_IN_ROUNDF64X: \
  case CFN_BUILT_IN_ROUNDF128X
#define CASE_CFN_SCALB \
  case CFN_SCALB: \
  case CFN_BUILT_IN_SCALBF: \
  case CFN_BUILT_IN_SCALB: \
  case CFN_BUILT_IN_SCALBL
#define CASE_CFN_SCALBLN \
  case CFN_BUILT_IN_SCALBLNF: \
  case CFN_BUILT_IN_SCALBLN: \
  case CFN_BUILT_IN_SCALBLNL
#define CASE_CFN_SCALBLN_FN \
  case CFN_BUILT_IN_SCALBLNF16: \
  case CFN_BUILT_IN_SCALBLNF32: \
  case CFN_BUILT_IN_SCALBLNF64: \
  case CFN_BUILT_IN_SCALBLNF128: \
  case CFN_BUILT_IN_SCALBLNF32X: \
  case CFN_BUILT_IN_SCALBLNF64X: \
  case CFN_BUILT_IN_SCALBLNF128X
#define CASE_CFN_SCALBLN_ALL \
  case CFN_BUILT_IN_SCALBLNF: \
  case CFN_BUILT_IN_SCALBLN: \
  case CFN_BUILT_IN_SCALBLNL: \
  case CFN_BUILT_IN_SCALBLNF16: \
  case CFN_BUILT_IN_SCALBLNF32: \
  case CFN_BUILT_IN_SCALBLNF64: \
  case CFN_BUILT_IN_SCALBLNF128: \
  case CFN_BUILT_IN_SCALBLNF32X: \
  case CFN_BUILT_IN_SCALBLNF64X: \
  case CFN_BUILT_IN_SCALBLNF128X
#define CASE_CFN_SCALBN \
  case CFN_BUILT_IN_SCALBNF: \
  case CFN_BUILT_IN_SCALBN: \
  case CFN_BUILT_IN_SCALBNL
#define CASE_CFN_SCALBN_FN \
  case CFN_BUILT_IN_SCALBNF16: \
  case CFN_BUILT_IN_SCALBNF32: \
  case CFN_BUILT_IN_SCALBNF64: \
  case CFN_BUILT_IN_SCALBNF128: \
  case CFN_BUILT_IN_SCALBNF32X: \
  case CFN_BUILT_IN_SCALBNF64X: \
  case CFN_BUILT_IN_SCALBNF128X
#define CASE_CFN_SCALBN_ALL \
  case CFN_BUILT_IN_SCALBNF: \
  case CFN_BUILT_IN_SCALBN: \
  case CFN_BUILT_IN_SCALBNL: \
  case CFN_BUILT_IN_SCALBNF16: \
  case CFN_BUILT_IN_SCALBNF32: \
  case CFN_BUILT_IN_SCALBNF64: \
  case CFN_BUILT_IN_SCALBNF128: \
  case CFN_BUILT_IN_SCALBNF32X: \
  case CFN_BUILT_IN_SCALBNF64X: \
  case CFN_BUILT_IN_SCALBNF128X
#define CASE_CFN_SIGNBIT \
  case CFN_SIGNBIT: \
  case CFN_BUILT_IN_SIGNBITF: \
  case CFN_BUILT_IN_SIGNBIT: \
  case CFN_BUILT_IN_SIGNBITL
#define CASE_CFN_SIGNIFICAND \
  case CFN_SIGNIFICAND: \
  case CFN_BUILT_IN_SIGNIFICANDF: \
  case CFN_BUILT_IN_SIGNIFICAND: \
  case CFN_BUILT_IN_SIGNIFICANDL
#define CASE_CFN_SIN \
  case CFN_SIN: \
  case CFN_BUILT_IN_SINF: \
  case CFN_BUILT_IN_SIN: \
  case CFN_BUILT_IN_SINL
#define CASE_CFN_SIN_FN \
  case CFN_BUILT_IN_SINF16: \
  case CFN_BUILT_IN_SINF32: \
  case CFN_BUILT_IN_SINF64: \
  case CFN_BUILT_IN_SINF128: \
  case CFN_BUILT_IN_SINF32X: \
  case CFN_BUILT_IN_SINF64X: \
  case CFN_BUILT_IN_SINF128X
#define CASE_CFN_SIN_ALL \
  case CFN_BUILT_IN_SINF: \
  case CFN_BUILT_IN_SIN: \
  case CFN_BUILT_IN_SINL: \
  case CFN_BUILT_IN_SINF16: \
  case CFN_BUILT_IN_SINF32: \
  case CFN_BUILT_IN_SINF64: \
  case CFN_BUILT_IN_SINF128: \
  case CFN_BUILT_IN_SINF32X: \
  case CFN_BUILT_IN_SINF64X: \
  case CFN_BUILT_IN_SINF128X
#define CASE_CFN_SINCOS \
  case CFN_BUILT_IN_SINCOSF: \
  case CFN_BUILT_IN_SINCOS: \
  case CFN_BUILT_IN_SINCOSL
#define CASE_CFN_SINH \
  case CFN_SINH: \
  case CFN_BUILT_IN_SINHF: \
  case CFN_BUILT_IN_SINH: \
  case CFN_BUILT_IN_SINHL
#define CASE_CFN_SINH_FN \
  case CFN_BUILT_IN_SINHF16: \
  case CFN_BUILT_IN_SINHF32: \
  case CFN_BUILT_IN_SINHF64: \
  case CFN_BUILT_IN_SINHF128: \
  case CFN_BUILT_IN_SINHF32X: \
  case CFN_BUILT_IN_SINHF64X: \
  case CFN_BUILT_IN_SINHF128X
#define CASE_CFN_SINH_ALL \
  case CFN_BUILT_IN_SINHF: \
  case CFN_BUILT_IN_SINH: \
  case CFN_BUILT_IN_SINHL: \
  case CFN_BUILT_IN_SINHF16: \
  case CFN_BUILT_IN_SINHF32: \
  case CFN_BUILT_IN_SINHF64: \
  case CFN_BUILT_IN_SINHF128: \
  case CFN_BUILT_IN_SINHF32X: \
  case CFN_BUILT_IN_SINHF64X: \
  case CFN_BUILT_IN_SINHF128X
#define CASE_CFN_SQRT \
  case CFN_SQRT: \
  case CFN_BUILT_IN_SQRTF: \
  case CFN_BUILT_IN_SQRT: \
  case CFN_BUILT_IN_SQRTL
#define CASE_CFN_SQRT_FN \
  case CFN_BUILT_IN_SQRTF16: \
  case CFN_BUILT_IN_SQRTF32: \
  case CFN_BUILT_IN_SQRTF64: \
  case CFN_BUILT_IN_SQRTF128: \
  case CFN_BUILT_IN_SQRTF32X: \
  case CFN_BUILT_IN_SQRTF64X: \
  case CFN_BUILT_IN_SQRTF128X
#define CASE_CFN_SQRT_ALL \
  case CFN_BUILT_IN_SQRTF: \
  case CFN_BUILT_IN_SQRT: \
  case CFN_BUILT_IN_SQRTL: \
  case CFN_BUILT_IN_SQRTF16: \
  case CFN_BUILT_IN_SQRTF32: \
  case CFN_BUILT_IN_SQRTF64: \
  case CFN_BUILT_IN_SQRTF128: \
  case CFN_BUILT_IN_SQRTF32X: \
  case CFN_BUILT_IN_SQRTF64X: \
  case CFN_BUILT_IN_SQRTF128X
#define CASE_CFN_TAN \
  case CFN_TAN: \
  case CFN_BUILT_IN_TANF: \
  case CFN_BUILT_IN_TAN: \
  case CFN_BUILT_IN_TANL
#define CASE_CFN_TAN_FN \
  case CFN_BUILT_IN_TANF16: \
  case CFN_BUILT_IN_TANF32: \
  case CFN_BUILT_IN_TANF64: \
  case CFN_BUILT_IN_TANF128: \
  case CFN_BUILT_IN_TANF32X: \
  case CFN_BUILT_IN_TANF64X: \
  case CFN_BUILT_IN_TANF128X
#define CASE_CFN_TAN_ALL \
  case CFN_BUILT_IN_TANF: \
  case CFN_BUILT_IN_TAN: \
  case CFN_BUILT_IN_TANL: \
  case CFN_BUILT_IN_TANF16: \
  case CFN_BUILT_IN_TANF32: \
  case CFN_BUILT_IN_TANF64: \
  case CFN_BUILT_IN_TANF128: \
  case CFN_BUILT_IN_TANF32X: \
  case CFN_BUILT_IN_TANF64X: \
  case CFN_BUILT_IN_TANF128X
#define CASE_CFN_TANH \
  case CFN_TANH: \
  case CFN_BUILT_IN_TANHF: \
  case CFN_BUILT_IN_TANH: \
  case CFN_BUILT_IN_TANHL
#define CASE_CFN_TANH_FN \
  case CFN_BUILT_IN_TANHF16: \
  case CFN_BUILT_IN_TANHF32: \
  case CFN_BUILT_IN_TANHF64: \
  case CFN_BUILT_IN_TANHF128: \
  case CFN_BUILT_IN_TANHF32X: \
  case CFN_BUILT_IN_TANHF64X: \
  case CFN_BUILT_IN_TANHF128X
#define CASE_CFN_TANH_ALL \
  case CFN_BUILT_IN_TANHF: \
  case CFN_BUILT_IN_TANH: \
  case CFN_BUILT_IN_TANHL: \
  case CFN_BUILT_IN_TANHF16: \
  case CFN_BUILT_IN_TANHF32: \
  case CFN_BUILT_IN_TANHF64: \
  case CFN_BUILT_IN_TANHF128: \
  case CFN_BUILT_IN_TANHF32X: \
  case CFN_BUILT_IN_TANHF64X: \
  case CFN_BUILT_IN_TANHF128X
#define CASE_CFN_TGAMMA \
  case CFN_BUILT_IN_TGAMMAF: \
  case CFN_BUILT_IN_TGAMMA: \
  case CFN_BUILT_IN_TGAMMAL
#define CASE_CFN_TGAMMA_FN \
  case CFN_BUILT_IN_TGAMMAF16: \
  case CFN_BUILT_IN_TGAMMAF32: \
  case CFN_BUILT_IN_TGAMMAF64: \
  case CFN_BUILT_IN_TGAMMAF128: \
  case CFN_BUILT_IN_TGAMMAF32X: \
  case CFN_BUILT_IN_TGAMMAF64X: \
  case CFN_BUILT_IN_TGAMMAF128X
#define CASE_CFN_TGAMMA_ALL \
  case CFN_BUILT_IN_TGAMMAF: \
  case CFN_BUILT_IN_TGAMMA: \
  case CFN_BUILT_IN_TGAMMAL: \
  case CFN_BUILT_IN_TGAMMAF16: \
  case CFN_BUILT_IN_TGAMMAF32: \
  case CFN_BUILT_IN_TGAMMAF64: \
  case CFN_BUILT_IN_TGAMMAF128: \
  case CFN_BUILT_IN_TGAMMAF32X: \
  case CFN_BUILT_IN_TGAMMAF64X: \
  case CFN_BUILT_IN_TGAMMAF128X
#define CASE_CFN_TRUNC \
  case CFN_TRUNC: \
  case CFN_BUILT_IN_TRUNCF: \
  case CFN_BUILT_IN_TRUNC: \
  case CFN_BUILT_IN_TRUNCL
#define CASE_CFN_TRUNC_FN \
  case CFN_BUILT_IN_TRUNCF16: \
  case CFN_BUILT_IN_TRUNCF32: \
  case CFN_BUILT_IN_TRUNCF64: \
  case CFN_BUILT_IN_TRUNCF128: \
  case CFN_BUILT_IN_TRUNCF32X: \
  case CFN_BUILT_IN_TRUNCF64X: \
  case CFN_BUILT_IN_TRUNCF128X
#define CASE_CFN_TRUNC_ALL \
  case CFN_BUILT_IN_TRUNCF: \
  case CFN_BUILT_IN_TRUNC: \
  case CFN_BUILT_IN_TRUNCL: \
  case CFN_BUILT_IN_TRUNCF16: \
  case CFN_BUILT_IN_TRUNCF32: \
  case CFN_BUILT_IN_TRUNCF64: \
  case CFN_BUILT_IN_TRUNCF128: \
  case CFN_BUILT_IN_TRUNCF32X: \
  case CFN_BUILT_IN_TRUNCF64X: \
  case CFN_BUILT_IN_TRUNCF128X
#define CASE_CFN_Y0 \
  case CFN_BUILT_IN_Y0F: \
  case CFN_BUILT_IN_Y0: \
  case CFN_BUILT_IN_Y0L
#define CASE_CFN_Y1 \
  case CFN_BUILT_IN_Y1F: \
  case CFN_BUILT_IN_Y1: \
  case CFN_BUILT_IN_Y1L
#define CASE_CFN_YN \
  case CFN_BUILT_IN_YNF: \
  case CFN_BUILT_IN_YN: \
  case CFN_BUILT_IN_YNL
#define CASE_CFN_CABS \
  case CFN_BUILT_IN_CABSF: \
  case CFN_BUILT_IN_CABS: \
  case CFN_BUILT_IN_CABSL
#define CASE_CFN_CABS_FN \
  case CFN_BUILT_IN_CABSF16: \
  case CFN_BUILT_IN_CABSF32: \
  case CFN_BUILT_IN_CABSF64: \
  case CFN_BUILT_IN_CABSF128: \
  case CFN_BUILT_IN_CABSF32X: \
  case CFN_BUILT_IN_CABSF64X: \
  case CFN_BUILT_IN_CABSF128X
#define CASE_CFN_CABS_ALL \
  case CFN_BUILT_IN_CABSF: \
  case CFN_BUILT_IN_CABS: \
  case CFN_BUILT_IN_CABSL: \
  case CFN_BUILT_IN_CABSF16: \
  case CFN_BUILT_IN_CABSF32: \
  case CFN_BUILT_IN_CABSF64: \
  case CFN_BUILT_IN_CABSF128: \
  case CFN_BUILT_IN_CABSF32X: \
  case CFN_BUILT_IN_CABSF64X: \
  case CFN_BUILT_IN_CABSF128X
#define CASE_CFN_CACOS \
  case CFN_BUILT_IN_CACOSF: \
  case CFN_BUILT_IN_CACOS: \
  case CFN_BUILT_IN_CACOSL
#define CASE_CFN_CACOS_FN \
  case CFN_BUILT_IN_CACOSF16: \
  case CFN_BUILT_IN_CACOSF32: \
  case CFN_BUILT_IN_CACOSF64: \
  case CFN_BUILT_IN_CACOSF128: \
  case CFN_BUILT_IN_CACOSF32X: \
  case CFN_BUILT_IN_CACOSF64X: \
  case CFN_BUILT_IN_CACOSF128X
#define CASE_CFN_CACOS_ALL \
  case CFN_BUILT_IN_CACOSF: \
  case CFN_BUILT_IN_CACOS: \
  case CFN_BUILT_IN_CACOSL: \
  case CFN_BUILT_IN_CACOSF16: \
  case CFN_BUILT_IN_CACOSF32: \
  case CFN_BUILT_IN_CACOSF64: \
  case CFN_BUILT_IN_CACOSF128: \
  case CFN_BUILT_IN_CACOSF32X: \
  case CFN_BUILT_IN_CACOSF64X: \
  case CFN_BUILT_IN_CACOSF128X
#define CASE_CFN_CACOSH \
  case CFN_BUILT_IN_CACOSHF: \
  case CFN_BUILT_IN_CACOSH: \
  case CFN_BUILT_IN_CACOSHL
#define CASE_CFN_CACOSH_FN \
  case CFN_BUILT_IN_CACOSHF16: \
  case CFN_BUILT_IN_CACOSHF32: \
  case CFN_BUILT_IN_CACOSHF64: \
  case CFN_BUILT_IN_CACOSHF128: \
  case CFN_BUILT_IN_CACOSHF32X: \
  case CFN_BUILT_IN_CACOSHF64X: \
  case CFN_BUILT_IN_CACOSHF128X
#define CASE_CFN_CACOSH_ALL \
  case CFN_BUILT_IN_CACOSHF: \
  case CFN_BUILT_IN_CACOSH: \
  case CFN_BUILT_IN_CACOSHL: \
  case CFN_BUILT_IN_CACOSHF16: \
  case CFN_BUILT_IN_CACOSHF32: \
  case CFN_BUILT_IN_CACOSHF64: \
  case CFN_BUILT_IN_CACOSHF128: \
  case CFN_BUILT_IN_CACOSHF32X: \
  case CFN_BUILT_IN_CACOSHF64X: \
  case CFN_BUILT_IN_CACOSHF128X
#define CASE_CFN_CARG \
  case CFN_BUILT_IN_CARGF: \
  case CFN_BUILT_IN_CARG: \
  case CFN_BUILT_IN_CARGL
#define CASE_CFN_CARG_FN \
  case CFN_BUILT_IN_CARGF16: \
  case CFN_BUILT_IN_CARGF32: \
  case CFN_BUILT_IN_CARGF64: \
  case CFN_BUILT_IN_CARGF128: \
  case CFN_BUILT_IN_CARGF32X: \
  case CFN_BUILT_IN_CARGF64X: \
  case CFN_BUILT_IN_CARGF128X
#define CASE_CFN_CARG_ALL \
  case CFN_BUILT_IN_CARGF: \
  case CFN_BUILT_IN_CARG: \
  case CFN_BUILT_IN_CARGL: \
  case CFN_BUILT_IN_CARGF16: \
  case CFN_BUILT_IN_CARGF32: \
  case CFN_BUILT_IN_CARGF64: \
  case CFN_BUILT_IN_CARGF128: \
  case CFN_BUILT_IN_CARGF32X: \
  case CFN_BUILT_IN_CARGF64X: \
  case CFN_BUILT_IN_CARGF128X
#define CASE_CFN_CASIN \
  case CFN_BUILT_IN_CASINF: \
  case CFN_BUILT_IN_CASIN: \
  case CFN_BUILT_IN_CASINL
#define CASE_CFN_CASIN_FN \
  case CFN_BUILT_IN_CASINF16: \
  case CFN_BUILT_IN_CASINF32: \
  case CFN_BUILT_IN_CASINF64: \
  case CFN_BUILT_IN_CASINF128: \
  case CFN_BUILT_IN_CASINF32X: \
  case CFN_BUILT_IN_CASINF64X: \
  case CFN_BUILT_IN_CASINF128X
#define CASE_CFN_CASIN_ALL \
  case CFN_BUILT_IN_CASINF: \
  case CFN_BUILT_IN_CASIN: \
  case CFN_BUILT_IN_CASINL: \
  case CFN_BUILT_IN_CASINF16: \
  case CFN_BUILT_IN_CASINF32: \
  case CFN_BUILT_IN_CASINF64: \
  case CFN_BUILT_IN_CASINF128: \
  case CFN_BUILT_IN_CASINF32X: \
  case CFN_BUILT_IN_CASINF64X: \
  case CFN_BUILT_IN_CASINF128X
#define CASE_CFN_CASINH \
  case CFN_BUILT_IN_CASINHF: \
  case CFN_BUILT_IN_CASINH: \
  case CFN_BUILT_IN_CASINHL
#define CASE_CFN_CASINH_FN \
  case CFN_BUILT_IN_CASINHF16: \
  case CFN_BUILT_IN_CASINHF32: \
  case CFN_BUILT_IN_CASINHF64: \
  case CFN_BUILT_IN_CASINHF128: \
  case CFN_BUILT_IN_CASINHF32X: \
  case CFN_BUILT_IN_CASINHF64X: \
  case CFN_BUILT_IN_CASINHF128X
#define CASE_CFN_CASINH_ALL \
  case CFN_BUILT_IN_CASINHF: \
  case CFN_BUILT_IN_CASINH: \
  case CFN_BUILT_IN_CASINHL: \
  case CFN_BUILT_IN_CASINHF16: \
  case CFN_BUILT_IN_CASINHF32: \
  case CFN_BUILT_IN_CASINHF64: \
  case CFN_BUILT_IN_CASINHF128: \
  case CFN_BUILT_IN_CASINHF32X: \
  case CFN_BUILT_IN_CASINHF64X: \
  case CFN_BUILT_IN_CASINHF128X
#define CASE_CFN_CATAN \
  case CFN_BUILT_IN_CATANF: \
  case CFN_BUILT_IN_CATAN: \
  case CFN_BUILT_IN_CATANL
#define CASE_CFN_CATAN_FN \
  case CFN_BUILT_IN_CATANF16: \
  case CFN_BUILT_IN_CATANF32: \
  case CFN_BUILT_IN_CATANF64: \
  case CFN_BUILT_IN_CATANF128: \
  case CFN_BUILT_IN_CATANF32X: \
  case CFN_BUILT_IN_CATANF64X: \
  case CFN_BUILT_IN_CATANF128X
#define CASE_CFN_CATAN_ALL \
  case CFN_BUILT_IN_CATANF: \
  case CFN_BUILT_IN_CATAN: \
  case CFN_BUILT_IN_CATANL: \
  case CFN_BUILT_IN_CATANF16: \
  case CFN_BUILT_IN_CATANF32: \
  case CFN_BUILT_IN_CATANF64: \
  case CFN_BUILT_IN_CATANF128: \
  case CFN_BUILT_IN_CATANF32X: \
  case CFN_BUILT_IN_CATANF64X: \
  case CFN_BUILT_IN_CATANF128X
#define CASE_CFN_CATANH \
  case CFN_BUILT_IN_CATANHF: \
  case CFN_BUILT_IN_CATANH: \
  case CFN_BUILT_IN_CATANHL
#define CASE_CFN_CATANH_FN \
  case CFN_BUILT_IN_CATANHF16: \
  case CFN_BUILT_IN_CATANHF32: \
  case CFN_BUILT_IN_CATANHF64: \
  case CFN_BUILT_IN_CATANHF128: \
  case CFN_BUILT_IN_CATANHF32X: \
  case CFN_BUILT_IN_CATANHF64X: \
  case CFN_BUILT_IN_CATANHF128X
#define CASE_CFN_CATANH_ALL \
  case CFN_BUILT_IN_CATANHF: \
  case CFN_BUILT_IN_CATANH: \
  case CFN_BUILT_IN_CATANHL: \
  case CFN_BUILT_IN_CATANHF16: \
  case CFN_BUILT_IN_CATANHF32: \
  case CFN_BUILT_IN_CATANHF64: \
  case CFN_BUILT_IN_CATANHF128: \
  case CFN_BUILT_IN_CATANHF32X: \
  case CFN_BUILT_IN_CATANHF64X: \
  case CFN_BUILT_IN_CATANHF128X
#define CASE_CFN_CCOS \
  case CFN_BUILT_IN_CCOSF: \
  case CFN_BUILT_IN_CCOS: \
  case CFN_BUILT_IN_CCOSL
#define CASE_CFN_CCOS_FN \
  case CFN_BUILT_IN_CCOSF16: \
  case CFN_BUILT_IN_CCOSF32: \
  case CFN_BUILT_IN_CCOSF64: \
  case CFN_BUILT_IN_CCOSF128: \
  case CFN_BUILT_IN_CCOSF32X: \
  case CFN_BUILT_IN_CCOSF64X: \
  case CFN_BUILT_IN_CCOSF128X
#define CASE_CFN_CCOS_ALL \
  case CFN_BUILT_IN_CCOSF: \
  case CFN_BUILT_IN_CCOS: \
  case CFN_BUILT_IN_CCOSL: \
  case CFN_BUILT_IN_CCOSF16: \
  case CFN_BUILT_IN_CCOSF32: \
  case CFN_BUILT_IN_CCOSF64: \
  case CFN_BUILT_IN_CCOSF128: \
  case CFN_BUILT_IN_CCOSF32X: \
  case CFN_BUILT_IN_CCOSF64X: \
  case CFN_BUILT_IN_CCOSF128X
#define CASE_CFN_CCOSH \
  case CFN_BUILT_IN_CCOSHF: \
  case CFN_BUILT_IN_CCOSH: \
  case CFN_BUILT_IN_CCOSHL
#define CASE_CFN_CCOSH_FN \
  case CFN_BUILT_IN_CCOSHF16: \
  case CFN_BUILT_IN_CCOSHF32: \
  case CFN_BUILT_IN_CCOSHF64: \
  case CFN_BUILT_IN_CCOSHF128: \
  case CFN_BUILT_IN_CCOSHF32X: \
  case CFN_BUILT_IN_CCOSHF64X: \
  case CFN_BUILT_IN_CCOSHF128X
#define CASE_CFN_CCOSH_ALL \
  case CFN_BUILT_IN_CCOSHF: \
  case CFN_BUILT_IN_CCOSH: \
  case CFN_BUILT_IN_CCOSHL: \
  case CFN_BUILT_IN_CCOSHF16: \
  case CFN_BUILT_IN_CCOSHF32: \
  case CFN_BUILT_IN_CCOSHF64: \
  case CFN_BUILT_IN_CCOSHF128: \
  case CFN_BUILT_IN_CCOSHF32X: \
  case CFN_BUILT_IN_CCOSHF64X: \
  case CFN_BUILT_IN_CCOSHF128X
#define CASE_CFN_CEXP \
  case CFN_BUILT_IN_CEXPF: \
  case CFN_BUILT_IN_CEXP: \
  case CFN_BUILT_IN_CEXPL
#define CASE_CFN_CEXP_FN \
  case CFN_BUILT_IN_CEXPF16: \
  case CFN_BUILT_IN_CEXPF32: \
  case CFN_BUILT_IN_CEXPF64: \
  case CFN_BUILT_IN_CEXPF128: \
  case CFN_BUILT_IN_CEXPF32X: \
  case CFN_BUILT_IN_CEXPF64X: \
  case CFN_BUILT_IN_CEXPF128X
#define CASE_CFN_CEXP_ALL \
  case CFN_BUILT_IN_CEXPF: \
  case CFN_BUILT_IN_CEXP: \
  case CFN_BUILT_IN_CEXPL: \
  case CFN_BUILT_IN_CEXPF16: \
  case CFN_BUILT_IN_CEXPF32: \
  case CFN_BUILT_IN_CEXPF64: \
  case CFN_BUILT_IN_CEXPF128: \
  case CFN_BUILT_IN_CEXPF32X: \
  case CFN_BUILT_IN_CEXPF64X: \
  case CFN_BUILT_IN_CEXPF128X
#define CASE_CFN_CEXPI \
  case CFN_BUILT_IN_CEXPIF: \
  case CFN_BUILT_IN_CEXPI: \
  case CFN_BUILT_IN_CEXPIL
#define CASE_CFN_CIMAG \
  case CFN_BUILT_IN_CIMAGF: \
  case CFN_BUILT_IN_CIMAG: \
  case CFN_BUILT_IN_CIMAGL
#define CASE_CFN_CLOG \
  case CFN_BUILT_IN_CLOGF: \
  case CFN_BUILT_IN_CLOG: \
  case CFN_BUILT_IN_CLOGL
#define CASE_CFN_CLOG_FN \
  case CFN_BUILT_IN_CLOGF16: \
  case CFN_BUILT_IN_CLOGF32: \
  case CFN_BUILT_IN_CLOGF64: \
  case CFN_BUILT_IN_CLOGF128: \
  case CFN_BUILT_IN_CLOGF32X: \
  case CFN_BUILT_IN_CLOGF64X: \
  case CFN_BUILT_IN_CLOGF128X
#define CASE_CFN_CLOG_ALL \
  case CFN_BUILT_IN_CLOGF: \
  case CFN_BUILT_IN_CLOG: \
  case CFN_BUILT_IN_CLOGL: \
  case CFN_BUILT_IN_CLOGF16: \
  case CFN_BUILT_IN_CLOGF32: \
  case CFN_BUILT_IN_CLOGF64: \
  case CFN_BUILT_IN_CLOGF128: \
  case CFN_BUILT_IN_CLOGF32X: \
  case CFN_BUILT_IN_CLOGF64X: \
  case CFN_BUILT_IN_CLOGF128X
#define CASE_CFN_CLOG10 \
  case CFN_BUILT_IN_CLOG10F: \
  case CFN_BUILT_IN_CLOG10: \
  case CFN_BUILT_IN_CLOG10L
#define CASE_CFN_CONJ \
  case CFN_BUILT_IN_CONJF: \
  case CFN_BUILT_IN_CONJ: \
  case CFN_BUILT_IN_CONJL
#define CASE_CFN_CPOW \
  case CFN_BUILT_IN_CPOWF: \
  case CFN_BUILT_IN_CPOW: \
  case CFN_BUILT_IN_CPOWL
#define CASE_CFN_CPOW_FN \
  case CFN_BUILT_IN_CPOWF16: \
  case CFN_BUILT_IN_CPOWF32: \
  case CFN_BUILT_IN_CPOWF64: \
  case CFN_BUILT_IN_CPOWF128: \
  case CFN_BUILT_IN_CPOWF32X: \
  case CFN_BUILT_IN_CPOWF64X: \
  case CFN_BUILT_IN_CPOWF128X
#define CASE_CFN_CPOW_ALL \
  case CFN_BUILT_IN_CPOWF: \
  case CFN_BUILT_IN_CPOW: \
  case CFN_BUILT_IN_CPOWL: \
  case CFN_BUILT_IN_CPOWF16: \
  case CFN_BUILT_IN_CPOWF32: \
  case CFN_BUILT_IN_CPOWF64: \
  case CFN_BUILT_IN_CPOWF128: \
  case CFN_BUILT_IN_CPOWF32X: \
  case CFN_BUILT_IN_CPOWF64X: \
  case CFN_BUILT_IN_CPOWF128X
#define CASE_CFN_CPROJ \
  case CFN_BUILT_IN_CPROJF: \
  case CFN_BUILT_IN_CPROJ: \
  case CFN_BUILT_IN_CPROJL
#define CASE_CFN_CPROJ_FN \
  case CFN_BUILT_IN_CPROJF16: \
  case CFN_BUILT_IN_CPROJF32: \
  case CFN_BUILT_IN_CPROJF64: \
  case CFN_BUILT_IN_CPROJF128: \
  case CFN_BUILT_IN_CPROJF32X: \
  case CFN_BUILT_IN_CPROJF64X: \
  case CFN_BUILT_IN_CPROJF128X
#define CASE_CFN_CPROJ_ALL \
  case CFN_BUILT_IN_CPROJF: \
  case CFN_BUILT_IN_CPROJ: \
  case CFN_BUILT_IN_CPROJL: \
  case CFN_BUILT_IN_CPROJF16: \
  case CFN_BUILT_IN_CPROJF32: \
  case CFN_BUILT_IN_CPROJF64: \
  case CFN_BUILT_IN_CPROJF128: \
  case CFN_BUILT_IN_CPROJF32X: \
  case CFN_BUILT_IN_CPROJF64X: \
  case CFN_BUILT_IN_CPROJF128X
#define CASE_CFN_CREAL \
  case CFN_BUILT_IN_CREALF: \
  case CFN_BUILT_IN_CREAL: \
  case CFN_BUILT_IN_CREALL
#define CASE_CFN_CSIN \
  case CFN_BUILT_IN_CSINF: \
  case CFN_BUILT_IN_CSIN: \
  case CFN_BUILT_IN_CSINL
#define CASE_CFN_CSIN_FN \
  case CFN_BUILT_IN_CSINF16: \
  case CFN_BUILT_IN_CSINF32: \
  case CFN_BUILT_IN_CSINF64: \
  case CFN_BUILT_IN_CSINF128: \
  case CFN_BUILT_IN_CSINF32X: \
  case CFN_BUILT_IN_CSINF64X: \
  case CFN_BUILT_IN_CSINF128X
#define CASE_CFN_CSIN_ALL \
  case CFN_BUILT_IN_CSINF: \
  case CFN_BUILT_IN_CSIN: \
  case CFN_BUILT_IN_CSINL: \
  case CFN_BUILT_IN_CSINF16: \
  case CFN_BUILT_IN_CSINF32: \
  case CFN_BUILT_IN_CSINF64: \
  case CFN_BUILT_IN_CSINF128: \
  case CFN_BUILT_IN_CSINF32X: \
  case CFN_BUILT_IN_CSINF64X: \
  case CFN_BUILT_IN_CSINF128X
#define CASE_CFN_CSINH \
  case CFN_BUILT_IN_CSINHF: \
  case CFN_BUILT_IN_CSINH: \
  case CFN_BUILT_IN_CSINHL
#define CASE_CFN_CSINH_FN \
  case CFN_BUILT_IN_CSINHF16: \
  case CFN_BUILT_IN_CSINHF32: \
  case CFN_BUILT_IN_CSINHF64: \
  case CFN_BUILT_IN_CSINHF128: \
  case CFN_BUILT_IN_CSINHF32X: \
  case CFN_BUILT_IN_CSINHF64X: \
  case CFN_BUILT_IN_CSINHF128X
#define CASE_CFN_CSINH_ALL \
  case CFN_BUILT_IN_CSINHF: \
  case CFN_BUILT_IN_CSINH: \
  case CFN_BUILT_IN_CSINHL: \
  case CFN_BUILT_IN_CSINHF16: \
  case CFN_BUILT_IN_CSINHF32: \
  case CFN_BUILT_IN_CSINHF64: \
  case CFN_BUILT_IN_CSINHF128: \
  case CFN_BUILT_IN_CSINHF32X: \
  case CFN_BUILT_IN_CSINHF64X: \
  case CFN_BUILT_IN_CSINHF128X
#define CASE_CFN_CSQRT \
  case CFN_BUILT_IN_CSQRTF: \
  case CFN_BUILT_IN_CSQRT: \
  case CFN_BUILT_IN_CSQRTL
#define CASE_CFN_CSQRT_FN \
  case CFN_BUILT_IN_CSQRTF16: \
  case CFN_BUILT_IN_CSQRTF32: \
  case CFN_BUILT_IN_CSQRTF64: \
  case CFN_BUILT_IN_CSQRTF128: \
  case CFN_BUILT_IN_CSQRTF32X: \
  case CFN_BUILT_IN_CSQRTF64X: \
  case CFN_BUILT_IN_CSQRTF128X
#define CASE_CFN_CSQRT_ALL \
  case CFN_BUILT_IN_CSQRTF: \
  case CFN_BUILT_IN_CSQRT: \
  case CFN_BUILT_IN_CSQRTL: \
  case CFN_BUILT_IN_CSQRTF16: \
  case CFN_BUILT_IN_CSQRTF32: \
  case CFN_BUILT_IN_CSQRTF64: \
  case CFN_BUILT_IN_CSQRTF128: \
  case CFN_BUILT_IN_CSQRTF32X: \
  case CFN_BUILT_IN_CSQRTF64X: \
  case CFN_BUILT_IN_CSQRTF128X
#define CASE_CFN_CTAN \
  case CFN_BUILT_IN_CTANF: \
  case CFN_BUILT_IN_CTAN: \
  case CFN_BUILT_IN_CTANL
#define CASE_CFN_CTAN_FN \
  case CFN_BUILT_IN_CTANF16: \
  case CFN_BUILT_IN_CTANF32: \
  case CFN_BUILT_IN_CTANF64: \
  case CFN_BUILT_IN_CTANF128: \
  case CFN_BUILT_IN_CTANF32X: \
  case CFN_BUILT_IN_CTANF64X: \
  case CFN_BUILT_IN_CTANF128X
#define CASE_CFN_CTAN_ALL \
  case CFN_BUILT_IN_CTANF: \
  case CFN_BUILT_IN_CTAN: \
  case CFN_BUILT_IN_CTANL: \
  case CFN_BUILT_IN_CTANF16: \
  case CFN_BUILT_IN_CTANF32: \
  case CFN_BUILT_IN_CTANF64: \
  case CFN_BUILT_IN_CTANF128: \
  case CFN_BUILT_IN_CTANF32X: \
  case CFN_BUILT_IN_CTANF64X: \
  case CFN_BUILT_IN_CTANF128X
#define CASE_CFN_CTANH \
  case CFN_BUILT_IN_CTANHF: \
  case CFN_BUILT_IN_CTANH: \
  case CFN_BUILT_IN_CTANHL
#define CASE_CFN_CTANH_FN \
  case CFN_BUILT_IN_CTANHF16: \
  case CFN_BUILT_IN_CTANHF32: \
  case CFN_BUILT_IN_CTANHF64: \
  case CFN_BUILT_IN_CTANHF128: \
  case CFN_BUILT_IN_CTANHF32X: \
  case CFN_BUILT_IN_CTANHF64X: \
  case CFN_BUILT_IN_CTANHF128X
#define CASE_CFN_CTANH_ALL \
  case CFN_BUILT_IN_CTANHF: \
  case CFN_BUILT_IN_CTANH: \
  case CFN_BUILT_IN_CTANHL: \
  case CFN_BUILT_IN_CTANHF16: \
  case CFN_BUILT_IN_CTANHF32: \
  case CFN_BUILT_IN_CTANHF64: \
  case CFN_BUILT_IN_CTANHF128: \
  case CFN_BUILT_IN_CTANHF32X: \
  case CFN_BUILT_IN_CTANHF64X: \
  case CFN_BUILT_IN_CTANHF128X
#define CASE_CFN_CLZ \
  case CFN_CLZ: \
  case CFN_BUILT_IN_CLZ: \
  case CFN_BUILT_IN_CLZL: \
  case CFN_BUILT_IN_CLZLL: \
  case CFN_BUILT_IN_CLZIMAX
#define CASE_CFN_CTZ \
  case CFN_CTZ: \
  case CFN_BUILT_IN_CTZ: \
  case CFN_BUILT_IN_CTZL: \
  case CFN_BUILT_IN_CTZLL: \
  case CFN_BUILT_IN_CTZIMAX
#define CASE_CFN_CLRSB \
  case CFN_CLRSB: \
  case CFN_BUILT_IN_CLRSB: \
  case CFN_BUILT_IN_CLRSBL: \
  case CFN_BUILT_IN_CLRSBLL: \
  case CFN_BUILT_IN_CLRSBIMAX
#define CASE_CFN_FFS \
  case CFN_FFS: \
  case CFN_BUILT_IN_FFS: \
  case CFN_BUILT_IN_FFSL: \
  case CFN_BUILT_IN_FFSLL: \
  case CFN_BUILT_IN_FFSIMAX
#define CASE_CFN_FINITE \
  case CFN_BUILT_IN_FINITEF: \
  case CFN_BUILT_IN_FINITE: \
  case CFN_BUILT_IN_FINITEL
#define CASE_CFN_ISINF \
  case CFN_BUILT_IN_ISINFF: \
  case CFN_BUILT_IN_ISINF: \
  case CFN_BUILT_IN_ISINFL
#define CASE_CFN_ISNAN \
  case CFN_BUILT_IN_ISNANF: \
  case CFN_BUILT_IN_ISNAN: \
  case CFN_BUILT_IN_ISNANL
#define CASE_CFN_PARITY \
  case CFN_PARITY: \
  case CFN_BUILT_IN_PARITY: \
  case CFN_BUILT_IN_PARITYL: \
  case CFN_BUILT_IN_PARITYLL: \
  case CFN_BUILT_IN_PARITYIMAX
#define CASE_CFN_POPCOUNT \
  case CFN_POPCOUNT: \
  case CFN_BUILT_IN_POPCOUNT: \
  case CFN_BUILT_IN_POPCOUNTL: \
  case CFN_BUILT_IN_POPCOUNTLL: \
  case CFN_BUILT_IN_POPCOUNTIMAX
