/* Generated automatically by the program `genattrtab'
   from the machine description file `md'.  */

#define IN_TARGET_CODE 1
#include "config.h"
#include "system.h"
#include "coretypes.h"
#include "backend.h"
#include "predict.h"
#include "tree.h"
#include "rtl.h"
#include "alias.h"
#include "options.h"
#include "varasm.h"
#include "stor-layout.h"
#include "calls.h"
#include "insn-attr.h"
#include "memmodel.h"
#include "tm_p.h"
#include "insn-config.h"
#include "recog.h"
#include "regs.h"
#include "real.h"
#include "output.h"
#include "toplev.h"
#include "flags.h"
#include "emit-rtl.h"

#define operands recog_data.operand

int
insn_current_length (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 6532:  /* *p *arm_jump */
    case 288:  /* *arm_jump */
      extract_constrain_insn_cached (insn);
      if ((
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) >= (-2044)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 1068:  /* *doloop_end_internal */
      extract_insn_cached (insn);
      if ((unsigned) ((insn_current_reference_address (insn)) - (INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0)) < (unsigned) (1024))
        {
	  return 4;
        }
      else
        {
	  return 6;
        }

    case 1058:  /* *thumb2_cbnz */
      extract_constrain_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[1]) == LABEL_REF ? XEXP (operands[1], 0) : operands[1])) : 0) - (insn_current_reference_address (insn))) >= (2)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[1]) == LABEL_REF ? XEXP (operands[1], 0) : operands[1])) : 0) - (insn_current_reference_address (insn))) <= (128)) && (! (
#line 1502 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb2.md"
(which_alternative))))
        {
	  return 2;
        }
      else
        {
	  return 8;
        }

    case 1057:  /* *thumb2_cbz */
      extract_constrain_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[1]) == LABEL_REF ? XEXP (operands[1], 0) : operands[1])) : 0) - (insn_current_reference_address (insn))) >= (2)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[1]) == LABEL_REF ? XEXP (operands[1], 0) : operands[1])) : 0) - (insn_current_reference_address (insn))) <= (128)) && (! (
#line 1502 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb2.md"
(which_alternative))))
        {
	  return 2;
        }
      else
        {
	  return 8;
        }

    case 983:  /* *thumb_jump */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) >= (-2044)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 976:  /* *addsi3_cbranch_scratch */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (256)))
        {
	  return 4;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	    {
	      return 6;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 975:  /* *addsi3_cbranch */
      extract_constrain_insn_cached (insn);
      if ((
#line 1591 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb1.md"
(which_alternative)) < (2))
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[5]) == LABEL_REF ? XEXP (operands[5], 0) : operands[5])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[5]) == LABEL_REF ? XEXP (operands[5], 0) : operands[5])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 4;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[5]) == LABEL_REF ? XEXP (operands[5], 0) : operands[5])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[5]) == LABEL_REF ? XEXP (operands[5], 0) : operands[5])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	        {
		  return 6;
	        }
	      else
	        {
		  return 8;
	        }
	    }
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[5]) == LABEL_REF ? XEXP (operands[5], 0) : operands[5])) : 0) - (insn_current_reference_address (insn))) >= (-248)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[5]) == LABEL_REF ? XEXP (operands[5], 0) : operands[5])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 6;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[5]) == LABEL_REF ? XEXP (operands[5], 0) : operands[5])) : 0) - (insn_current_reference_address (insn))) >= (-2038)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[5]) == LABEL_REF ? XEXP (operands[5], 0) : operands[5])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	        {
		  return 8;
	        }
	      else
	        {
		  return 10 /* 0xa */;
	        }
	    }
        }

    case 974:  /* *cbranchne_decr1 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 4;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	        {
		  return 6;
	        }
	      else
	        {
		  return 8;
	        }
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-248)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 6;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-2038)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	        {
		  return 8;
	        }
	      else
	        {
		  return 10 /* 0xa */;
	        }
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-248)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 6;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-2038)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	        {
		  return 8;
	        }
	      else
	        {
		  return 10 /* 0xa */;
	        }
	    }
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-248)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 6;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) >= (-2038)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[4]) == LABEL_REF ? XEXP (operands[4], 0) : operands[4])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	        {
		  return 8;
	        }
	      else
	        {
		  return 10 /* 0xa */;
	        }
	    }
        }

    case 973:  /* *tstsi3_cbranch */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) <= (256)))
        {
	  return 4;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	    {
	      return 6;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 972:  /* *tlobits_cbranch */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (256)))
        {
	  return 4;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	    {
	      return 6;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 971:  /* *tbit_cbranch */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (256)))
        {
	  return 4;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	    {
	      return 6;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 970:  /* *negated_cbranchsi4 */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (256)))
        {
	  return 4;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	    {
	      return 6;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 969:  /* cbranchsi4_scratch */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (256)))
        {
	  return 4;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	    {
	      return 6;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 968:  /* cbranchsi4_insn */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (256)))
        {
	  return 4;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[3]) == LABEL_REF ? XEXP (operands[3], 0) : operands[3])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	    {
	      return 6;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 967:  /* thumb1_cbz */
      extract_insn_cached (insn);
      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) >= (2)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) <= (128)))
        {
	  return 2;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 4;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) >= (-2040)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[2]) == LABEL_REF ? XEXP (operands[2], 0) : operands[2])) : 0) - (insn_current_reference_address (insn))) <= (2048)))
	        {
		  return 6;
	        }
	      else
	        {
		  return 8;
	        }
	    }
        }

    case 278:  /* *arm_cond_branch_reversed */
      extract_constrain_insn_cached (insn);
      if (
#line 8035 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(!TARGET_THUMB2))
        {
	  return 0;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 2;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) >= (-1048568)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) <= (1048576)))
	        {
		  return 4;
	        }
	      else
	        {
		  return 6;
	        }
	    }
        }

    case 277:  /* arm_cond_branch */
      extract_constrain_insn_cached (insn);
      if (
#line 8035 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(!TARGET_THUMB2))
        {
	  return 0;
        }
      else
        {
	  if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) >= (-250)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) <= (256)))
	    {
	      return 2;
	    }
	  else
	    {
	      if ((((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) >= (-1048568)) && (((INSN_ADDRESSES_SET_P () ? INSN_ADDRESSES (INSN_UID (GET_CODE (operands[0]) == LABEL_REF ? XEXP (operands[0], 0) : operands[0])) : 0) - (insn_current_reference_address (insn))) <= (1048576)))
	        {
		  return 4;
	        }
	      else
	        {
		  return 6;
	        }
	    }
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

int
insn_variable_length_p (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 6532:  /* *p *arm_jump */
    case 288:  /* *arm_jump */
    case 1068:  /* *doloop_end_internal */
    case 1058:  /* *thumb2_cbnz */
    case 1057:  /* *thumb2_cbz */
    case 983:  /* *thumb_jump */
    case 976:  /* *addsi3_cbranch_scratch */
    case 975:  /* *addsi3_cbranch */
    case 974:  /* *cbranchne_decr1 */
    case 973:  /* *tstsi3_cbranch */
    case 972:  /* *tlobits_cbranch */
    case 971:  /* *tbit_cbranch */
    case 970:  /* *negated_cbranchsi4 */
    case 969:  /* cbranchsi4_scratch */
    case 968:  /* cbranchsi4_insn */
    case 967:  /* thumb1_cbz */
      return 1;

    case 278:  /* *arm_cond_branch_reversed */
    case 277:  /* arm_cond_branch */
      extract_constrain_insn_cached (insn);
      if (
#line 8035 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(!TARGET_THUMB2))
        {
	  return 0;
        }
      else
        {
	  return 1;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

int
insn_min_length (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 3045:  /* *mve_movv2df */
    case 3044:  /* *mve_movv4sf */
    case 3043:  /* *mve_movv8hf */
    case 3042:  /* *mve_movti */
    case 3041:  /* *mve_movv2di */
    case 3040:  /* *mve_movv4si */
    case 3039:  /* *mve_movv8hi */
    case 3038:  /* *mve_movv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return 4;
        }
      else if (which_alternative == 5)
        {
	  return 8;
        }
      else if (which_alternative == 6)
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else if (which_alternative == 1)
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x70ULL))
        {
	  return 8;
        }
      else if (which_alternative == 7)
        {
	  return 16 /* 0x10 */;
        }
      else if (which_alternative == 8)
        {
	  return 8;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7fULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 1036:  /* *thumb2_movcond */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 10 /* 0xa */;
        }
      else
        {
	  return 14 /* 0xe */;
        }

    case 1016:  /* *thumb2_movsicc_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x3cULL))
        {
	  return 6;
        }
      else if (which_alternative == 6)
        {
	  return 10 /* 0xa */;
        }
      else if (which_alternative == 7)
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0x700ULL))
        {
	  return 10 /* 0xa */;
        }
      else
        {
	  return 6;
        }

    case 1008:  /* tls_load_dot_plus_four */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else
        {
	  return 6;
        }

    case 1028:  /* *thumb2_cond_move */
    case 1003:  /* *thumb2_uminsi3 */
    case 1002:  /* *thumb32_umaxsi3 */
    case 1001:  /* *thumb2_sminsi3 */
    case 1000:  /* *thumb2_smaxsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 6;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 974:  /* *cbranchne_decr1 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else
        {
	  return 6;
        }

    case 964:  /* *thumb_movdf_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return 2;
        }
      else if (which_alternative == 3)
        {
	  return 6;
        }
      else
        {
	  return 4;
        }

    case 962:  /* *thumb1_movhf */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 2;
        }
      else if (which_alternative == 2)
        {
	  return 6;
        }
      else
        {
	  return 2;
        }

    case 960:  /* *thumb1_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else if (which_alternative == 1)
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x3cULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 2;
        }
      else if (((1ULL << which_alternative) & 0x1cULL))
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return 2;
        }
      else if (which_alternative == 7)
        {
	  return 14 /* 0xe */;
        }
      else
        {
	  return 2;
        }

    case 958:  /* *thumb1_movdi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return 6;
        }
      else if (((1ULL << which_alternative) & 0x30ULL))
        {
	  return 2;
        }
      else if (which_alternative == 6)
        {
	  return 6;
        }
      else
        {
	  return 4;
        }

    case 938:  /* *thumb_mulsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else
        {
	  return 2;
        }

    case 935:  /* *thumb1_addsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7fULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 774:  /* *thumb2_movdfcc_vfp */
    case 772:  /* *thumb2_movsfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 6;
        }
      else if (which_alternative == 2)
        {
	  return 10 /* 0xa */;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return 6;
        }
      else if (which_alternative == 5)
        {
	  return 10 /* 0xa */;
        }
      else if (((1ULL << which_alternative) & 0xc0ULL))
        {
	  return 6;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 773:  /* *movdfcc_vfp */
    case 771:  /* *movsfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else if (which_alternative == 2)
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return 4;
        }
      else if (which_alternative == 5)
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0xc0ULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 766:  /* *movbf_vfp */
    case 765:  /* *movhf_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3fULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xffULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1ffULL))
        {
	  return 4;
        }
      else
        {
	  if (
#line 471 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(arm_arch_thumb2))
	    {
	      return 4;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 531:  /* *iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xffULL))
        {
	  return 4;
        }
      else if (which_alternative == 8)
        {
	  return 16 /* 0x10 */;
        }
      else
        {
	  return 4;
        }

    case 343:  /* *cmp_ior */
    case 342:  /* *cmp_and */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 6;
        }
      else if (((1ULL << which_alternative) & 0x1eULL))
        {
	  return 8;
        }
      else if (which_alternative == 5)
        {
	  return 6;
        }
      else
        {
	  if ((! (
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB))))
	    {
	      return 8;
	    }
	  else
	    {
	      return 10 /* 0xa */;
	    }
        }

    case 341:  /* *cmp_ite1 */
    case 340:  /* *cmp_ite0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 6;
        }
      else if (((1ULL << which_alternative) & 0x1eULL))
        {
	  return 8;
        }
      else
        {
	  if ((! (
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB))))
	    {
	      return 8;
	    }
	  else
	    {
	      return 10 /* 0xa */;
	    }
        }

    case 6859:  /* *p *negdf2_vfp */
    case 778:  /* *negdf2_vfp */
    case 355:  /* *if_move_plus */
    case 353:  /* *if_plus_move */
    case 337:  /* *cond_move */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 286:  /* *movsicc_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 6528:  /* *p *arm32_movbf */
    case 6527:  /* *p *arm32_movhf */
    case 269:  /* *arm32_movbf */
    case 268:  /* *arm32_movhf */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 6526:  /* *p *arm_movqi_insn */
    case 267:  /* *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return 4;
        }
      else if (which_alternative == 3)
        {
	  return 2;
        }
      else if (which_alternative == 4)
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 6927:  /* *p *thumb2_movhi_insn */
    case 6926:  /* *p *thumb2_movsi_insn */
    case 6849:  /* *p *thumb2_movsi_vfp */
    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 1009:  /* *thumb2_movhi_insn */
    case 1007:  /* *thumb2_movsi_insn */
    case 759:  /* *thumb2_movsi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
    case 264:  /* *movsi_compare0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else if (which_alternative == 1)
        {
	  return 4;
        }
      else if (which_alternative == 2)
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 271:  /* *movdf_soft_insn */
    case 255:  /* *arm_movdi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 12 /* 0xc */;
        }
      else if (which_alternative == 2)
        {
	  return 16 /* 0x10 */;
        }
      else
        {
	  return 8;
        }

    case 351:  /* movcond */
    case 123:  /* *arm_uminsi3 */
    case 122:  /* *arm_umaxsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 8;
        }
      else
        {
	  return 12 /* 0xc */;
        }

    case 6410:  /* *p *arm_xorsi3 */
    case 113:  /* *arm_xorsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 6409:  /* *p *iorsi3_insn */
    case 110:  /* *iorsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 6397:  /* *p *arm_andsi3_insn */
    case 90:  /* *arm_andsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 6370:  /* *p *arm_subsi3_insn */
    case 45:  /* *arm_subsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xffULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 18:  /* *addsi3_compare_op2 */
    case 17:  /* addsi3_compare_op1 */
    case 11:  /* addsi3_compareV_imm */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 6558:  /* *p *arm_rev */
    case 6530:  /* *p *arm_cmpsi_insn */
    case 6433:  /* *p unaligned_storehi */
    case 6432:  /* *p unaligned_storesi */
    case 6431:  /* *p unaligned_loadhiu */
    case 6429:  /* *p unaligned_loadsi */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 1052:  /* thumb2_addsi3_compare0 */
    case 415:  /* arm_rev16si2_alt */
    case 414:  /* arm_rev16si2 */
    case 413:  /* *arm_rev16 */
    case 412:  /* *arm_revsh */
    case 411:  /* *arm_rev */
    case 272:  /* *arm_cmpsi_insn */
    case 163:  /* unaligned_storehi */
    case 162:  /* unaligned_storesi */
    case 160:  /* unaligned_loadhiu */
    case 158:  /* unaligned_loadsi */
    case 20:  /* *compare_addsi2_op1 */
    case 19:  /* *compare_addsi2_op0 */
    case 8:  /* addsi3_compareV_reg */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 6353:  /* *p *arm_addsi3 */
    case 7:  /* *arm_addsi3 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else if (((1ULL << which_alternative) & 0x7ffeULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 6924:  /* *p *thumb2_neg_abssi2 */
    case 6923:  /* *p *thumb2_abssi2 */
    case 1005:  /* *thumb2_neg_abssi2 */
    case 1004:  /* *thumb2_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 6;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 6915:  /* *p *combine_vcvt_f64_s32 */
    case 6914:  /* *p *combine_vcvt_f64_u32 */
    case 6440:  /* *p *arm_neg_abssi2 */
    case 6439:  /* *p *arm_abssi2 */
    case 6411:  /* *p *andsi_iorsi3_notsi */
    case 4953:  /* arm_vcx3qa_p_v16qi */
    case 4952:  /* arm_vcx3q_p_v16qi */
    case 4951:  /* arm_vcx2qa_p_v16qi */
    case 4950:  /* arm_vcx2q_p_v16qi */
    case 4949:  /* arm_vcx1qa_p_v16qi */
    case 4948:  /* arm_vcx1q_p_v16qi */
    case 4941:  /* mve_vshlcq_m_uv4si */
    case 4940:  /* mve_vshlcq_m_sv4si */
    case 4939:  /* mve_vshlcq_m_uv8hi */
    case 4938:  /* mve_vshlcq_m_sv8hi */
    case 4937:  /* mve_vshlcq_m_uv16qi */
    case 4936:  /* mve_vshlcq_m_sv16qi */
    case 4898:  /* mve_vld2qv4sf */
    case 4897:  /* mve_vld2qv8hf */
    case 4896:  /* mve_vld2qv4si */
    case 4895:  /* mve_vld2qv8hi */
    case 4894:  /* mve_vld2qv16qi */
    case 4893:  /* mve_vst2qv4sf */
    case 4892:  /* mve_vst2qv8hf */
    case 4891:  /* mve_vst2qv4si */
    case 4890:  /* mve_vst2qv8hi */
    case 4889:  /* mve_vst2qv16qi */
    case 4886:  /* mve_vsbcq_m_sv4si */
    case 4885:  /* mve_vsbcq_m_uv4si */
    case 4882:  /* mve_vsbciq_m_sv4si */
    case 4881:  /* mve_vsbciq_m_uv4si */
    case 4878:  /* mve_vadcq_m_sv4si */
    case 4877:  /* mve_vadcq_m_uv4si */
    case 4874:  /* mve_vadciq_m_sv4si */
    case 4873:  /* mve_vadciq_m_uv4si */
    case 4872:  /* mve_vldrdq_gather_base_wb_z_uv2di_insn */
    case 4871:  /* mve_vldrdq_gather_base_wb_z_sv2di_insn */
    case 4866:  /* mve_vldrwq_gather_base_wb_z_fv4sf_insn */
    case 4864:  /* mve_vldrwq_gather_base_wb_z_uv4si_insn */
    case 4863:  /* mve_vldrwq_gather_base_wb_z_sv4si_insn */
    case 4860:  /* mve_vstrdq_scatter_base_wb_p_uv2di */
    case 4859:  /* mve_vstrdq_scatter_base_wb_p_sv2di */
    case 4856:  /* mve_vstrwq_scatter_base_wb_p_fv4sf */
    case 4854:  /* mve_vstrwq_scatter_base_wb_p_uv4si */
    case 4853:  /* mve_vstrwq_scatter_base_wb_p_sv4si */
    case 4850:  /* mve_viwdupq_m_wb_uv4si_insn */
    case 4849:  /* mve_viwdupq_m_wb_uv8hi_insn */
    case 4848:  /* mve_viwdupq_m_wb_uv16qi_insn */
    case 4844:  /* mve_vdwdupq_m_wb_uv4si_insn */
    case 4843:  /* mve_vdwdupq_m_wb_uv8hi_insn */
    case 4842:  /* mve_vdwdupq_m_wb_uv16qi_insn */
    case 4838:  /* mve_vddupq_m_wb_uv4si_insn */
    case 4837:  /* mve_vddupq_m_wb_uv8hi_insn */
    case 4836:  /* mve_vddupq_m_wb_uv16qi_insn */
    case 4832:  /* mve_vidupq_m_wb_uv4si_insn */
    case 4831:  /* mve_vidupq_m_wb_uv8hi_insn */
    case 4830:  /* mve_vidupq_m_wb_uv16qi_insn */
    case 4819:  /* mve_vstrwq_scatter_shifted_offset_p_uv4si_insn */
    case 4818:  /* mve_vstrwq_scatter_shifted_offset_p_sv4si_insn */
    case 4817:  /* mve_vstrwq_scatter_shifted_offset_p_fv4sf_insn */
    case 4816:  /* mve_vstrwq_scatter_shifted_offset_fv4sf_insn */
    case 4813:  /* mve_vstrwq_scatter_offset_p_uv4si_insn */
    case 4812:  /* mve_vstrwq_scatter_offset_p_sv4si_insn */
    case 4811:  /* mve_vstrwq_scatter_offset_p_fv4sf_insn */
    case 4809:  /* mve_vstrwq_scatter_base_p_fv4sf */
    case 4807:  /* mve_vstrhq_scatter_shifted_offset_p_fv8hf_insn */
    case 4805:  /* mve_vstrhq_scatter_offset_p_fv8hf_insn */
    case 4801:  /* mve_vstrdq_scatter_shifted_offset_p_uv2di_insn */
    case 4800:  /* mve_vstrdq_scatter_shifted_offset_p_sv2di_insn */
    case 4797:  /* mve_vstrdq_scatter_offset_p_uv2di_insn */
    case 4796:  /* mve_vstrdq_scatter_offset_p_sv2di_insn */
    case 4793:  /* mve_vstrdq_scatter_base_p_uv2di */
    case 4792:  /* mve_vstrdq_scatter_base_p_sv2di */
    case 4789:  /* mve_vstrwq_p_uv4si */
    case 4788:  /* mve_vstrwq_p_sv4si */
    case 4787:  /* mve_vstrwq_p_fv4sf */
    case 4777:  /* mve_vstrhq_scatter_shifted_offset_p_uv4si_insn */
    case 4776:  /* mve_vstrhq_scatter_shifted_offset_p_sv4si_insn */
    case 4775:  /* mve_vstrhq_scatter_shifted_offset_p_uv8hi_insn */
    case 4774:  /* mve_vstrhq_scatter_shifted_offset_p_sv8hi_insn */
    case 4769:  /* mve_vstrhq_scatter_offset_p_uv4si_insn */
    case 4768:  /* mve_vstrhq_scatter_offset_p_sv4si_insn */
    case 4767:  /* mve_vstrhq_scatter_offset_p_uv8hi_insn */
    case 4766:  /* mve_vstrhq_scatter_offset_p_sv8hi_insn */
    case 4765:  /* mve_vstrhq_p_uv4si */
    case 4764:  /* mve_vstrhq_p_sv4si */
    case 4763:  /* mve_vstrhq_p_uv8hi */
    case 4762:  /* mve_vstrhq_p_sv8hi */
    case 4761:  /* mve_vstrhq_p_fv8hf */
    case 4759:  /* mve_vldrwq_gather_shifted_offset_z_uv4si */
    case 4758:  /* mve_vldrwq_gather_shifted_offset_z_sv4si */
    case 4757:  /* mve_vldrwq_gather_shifted_offset_z_fv4sf */
    case 4753:  /* mve_vldrwq_gather_offset_z_uv4si */
    case 4752:  /* mve_vldrwq_gather_offset_z_sv4si */
    case 4751:  /* mve_vldrwq_gather_offset_z_fv4sf */
    case 4747:  /* mve_vldrwq_gather_base_z_fv4sf */
    case 4745:  /* mve_vldrhq_gather_shifted_offset_z_fv8hf */
    case 4743:  /* mve_vldrhq_gather_offset_z_fv8hf */
    case 4741:  /* mve_vldrdq_gather_shifted_offset_z_uv2di */
    case 4740:  /* mve_vldrdq_gather_shifted_offset_z_sv2di */
    case 4737:  /* mve_vldrdq_gather_offset_z_uv2di */
    case 4736:  /* mve_vldrdq_gather_offset_z_sv2di */
    case 4733:  /* mve_vldrdq_gather_base_z_uv2di */
    case 4732:  /* mve_vldrdq_gather_base_z_sv2di */
    case 4729:  /* mve_vldrwq_z_uv4si */
    case 4728:  /* mve_vldrwq_z_sv4si */
    case 4727:  /* mve_vldrwq_z_fv4sf */
    case 4723:  /* mve_vldrhq_z_uv4si */
    case 4722:  /* mve_vldrhq_z_sv4si */
    case 4721:  /* mve_vldrhq_z_uv8hi */
    case 4720:  /* mve_vldrhq_z_sv8hi */
    case 4719:  /* mve_vldrhq_z_fv8hf */
    case 4714:  /* mve_vldrhq_gather_shifted_offset_z_uv4si */
    case 4713:  /* mve_vldrhq_gather_shifted_offset_z_sv4si */
    case 4712:  /* mve_vldrhq_gather_shifted_offset_z_uv8hi */
    case 4711:  /* mve_vldrhq_gather_shifted_offset_z_sv8hi */
    case 4706:  /* mve_vldrhq_gather_offset_z_uv4si */
    case 4705:  /* mve_vldrhq_gather_offset_z_sv4si */
    case 4704:  /* mve_vldrhq_gather_offset_z_uv8hi */
    case 4703:  /* mve_vldrhq_gather_offset_z_sv8hi */
    case 4697:  /* mve_vldrwq_gather_base_z_uv4si */
    case 4696:  /* mve_vldrwq_gather_base_z_sv4si */
    case 4695:  /* mve_vldrbq_z_uv4si */
    case 4694:  /* mve_vldrbq_z_sv4si */
    case 4693:  /* mve_vldrbq_z_uv8hi */
    case 4692:  /* mve_vldrbq_z_sv8hi */
    case 4691:  /* mve_vldrbq_z_uv16qi */
    case 4690:  /* mve_vldrbq_z_sv16qi */
    case 4689:  /* mve_vldrbq_gather_offset_z_uv4si */
    case 4688:  /* mve_vldrbq_gather_offset_z_sv4si */
    case 4687:  /* mve_vldrbq_gather_offset_z_uv8hi */
    case 4686:  /* mve_vldrbq_gather_offset_z_sv8hi */
    case 4685:  /* mve_vldrbq_gather_offset_z_uv16qi */
    case 4684:  /* mve_vldrbq_gather_offset_z_sv16qi */
    case 4683:  /* mve_vstrbq_p_uv4si */
    case 4682:  /* mve_vstrbq_p_sv4si */
    case 4681:  /* mve_vstrbq_p_uv8hi */
    case 4680:  /* mve_vstrbq_p_sv8hi */
    case 4679:  /* mve_vstrbq_p_uv16qi */
    case 4678:  /* mve_vstrbq_p_sv16qi */
    case 4677:  /* mve_vstrwq_scatter_base_p_uv4si */
    case 4676:  /* mve_vstrwq_scatter_base_p_sv4si */
    case 4675:  /* mve_vstrbq_scatter_offset_p_uv4si_insn */
    case 4674:  /* mve_vstrbq_scatter_offset_p_sv4si_insn */
    case 4673:  /* mve_vstrbq_scatter_offset_p_uv8hi_insn */
    case 4672:  /* mve_vstrbq_scatter_offset_p_sv8hi_insn */
    case 4671:  /* mve_vstrbq_scatter_offset_p_uv16qi_insn */
    case 4670:  /* mve_vstrbq_scatter_offset_p_sv16qi_insn */
    case 4641:  /* mve_vsubq_m_n_fv4sf */
    case 4640:  /* mve_vsubq_m_n_fv8hf */
    case 4639:  /* mve_vsubq_m_fv4sf */
    case 4638:  /* mve_vsubq_m_fv8hf */
    case 4637:  /* mve_vorrq_m_fv4sf */
    case 4636:  /* mve_vorrq_m_fv8hf */
    case 4635:  /* mve_vornq_m_fv4sf */
    case 4634:  /* mve_vornq_m_fv8hf */
    case 4633:  /* mve_vmulq_m_n_fv4sf */
    case 4632:  /* mve_vmulq_m_n_fv8hf */
    case 4631:  /* mve_vmulq_m_fv4sf */
    case 4630:  /* mve_vmulq_m_fv8hf */
    case 4629:  /* mve_vminnmq_m_fv4sf */
    case 4628:  /* mve_vminnmq_m_fv8hf */
    case 4627:  /* mve_vmaxnmq_m_fv4sf */
    case 4626:  /* mve_vmaxnmq_m_fv8hf */
    case 4625:  /* mve_vfmsq_m_fv4sf */
    case 4624:  /* mve_vfmsq_m_fv8hf */
    case 4623:  /* mve_vfmasq_m_n_fv4sf */
    case 4622:  /* mve_vfmasq_m_n_fv8hf */
    case 4621:  /* mve_vfmaq_m_n_fv4sf */
    case 4620:  /* mve_vfmaq_m_n_fv8hf */
    case 4619:  /* mve_vfmaq_m_fv4sf */
    case 4618:  /* mve_vfmaq_m_fv8hf */
    case 4617:  /* mve_veorq_m_fv4sf */
    case 4616:  /* mve_veorq_m_fv8hf */
    case 4615:  /* mve_vcmulq_rot90_m_fv4sf */
    case 4614:  /* mve_vcmulq_rot90_m_fv8hf */
    case 4613:  /* mve_vcmulq_rot270_m_fv4sf */
    case 4612:  /* mve_vcmulq_rot270_m_fv8hf */
    case 4611:  /* mve_vcmulq_rot180_m_fv4sf */
    case 4610:  /* mve_vcmulq_rot180_m_fv8hf */
    case 4609:  /* mve_vcmulq_m_fv4sf */
    case 4608:  /* mve_vcmulq_m_fv8hf */
    case 4607:  /* mve_vcmlaq_rot90_m_fv4sf */
    case 4606:  /* mve_vcmlaq_rot90_m_fv8hf */
    case 4605:  /* mve_vcmlaq_rot270_m_fv4sf */
    case 4604:  /* mve_vcmlaq_rot270_m_fv8hf */
    case 4603:  /* mve_vcmlaq_rot180_m_fv4sf */
    case 4602:  /* mve_vcmlaq_rot180_m_fv8hf */
    case 4601:  /* mve_vcmlaq_m_fv4sf */
    case 4600:  /* mve_vcmlaq_m_fv8hf */
    case 4599:  /* mve_vcaddq_rot90_m_fv4sf */
    case 4598:  /* mve_vcaddq_rot90_m_fv8hf */
    case 4597:  /* mve_vcaddq_rot270_m_fv4sf */
    case 4596:  /* mve_vcaddq_rot270_m_fv8hf */
    case 4595:  /* mve_vbrsrq_m_n_fv4sf */
    case 4594:  /* mve_vbrsrq_m_n_fv8hf */
    case 4593:  /* mve_vbicq_m_fv4sf */
    case 4592:  /* mve_vbicq_m_fv8hf */
    case 4591:  /* mve_vandq_m_fv4sf */
    case 4590:  /* mve_vandq_m_fv8hf */
    case 4589:  /* mve_vaddq_m_n_fv4sf */
    case 4588:  /* mve_vaddq_m_n_fv8hf */
    case 4587:  /* mve_vaddq_m_fv4sf */
    case 4586:  /* mve_vaddq_m_fv8hf */
    case 4585:  /* mve_vabdq_m_fv4sf */
    case 4584:  /* mve_vabdq_m_fv8hf */
    case 4583:  /* mve_vrmlsldavhaxq_p_sv4si */
    case 4582:  /* mve_vrmlsldavhaq_p_sv4si */
    case 4581:  /* mve_vrmlaldavhaxq_p_sv4si */
    case 4580:  /* mve_vrmlaldavhaq_p_uv4si */
    case 4579:  /* mve_vqshruntq_m_n_sv4si */
    case 4578:  /* mve_vqshruntq_m_n_sv8hi */
    case 4577:  /* mve_vqshrunbq_m_n_sv4si */
    case 4576:  /* mve_vqshrunbq_m_n_sv8hi */
    case 4575:  /* mve_vqrshruntq_m_n_sv4si */
    case 4574:  /* mve_vqrshruntq_m_n_sv8hi */
    case 4573:  /* mve_vqrshrunbq_m_n_sv4si */
    case 4572:  /* mve_vqrshrunbq_m_n_sv8hi */
    case 4571:  /* mve_vqdmulltq_m_sv4si */
    case 4570:  /* mve_vqdmulltq_m_sv8hi */
    case 4569:  /* mve_vqdmulltq_m_n_sv4si */
    case 4568:  /* mve_vqdmulltq_m_n_sv8hi */
    case 4567:  /* mve_vqdmullbq_m_sv4si */
    case 4566:  /* mve_vqdmullbq_m_sv8hi */
    case 4565:  /* mve_vqdmullbq_m_n_sv4si */
    case 4564:  /* mve_vqdmullbq_m_n_sv8hi */
    case 4563:  /* mve_vmulltq_poly_m_pv8hi */
    case 4562:  /* mve_vmulltq_poly_m_pv16qi */
    case 4561:  /* mve_vmullbq_poly_m_pv8hi */
    case 4560:  /* mve_vmullbq_poly_m_pv16qi */
    case 4559:  /* mve_vmlsldavaxq_p_sv4si */
    case 4558:  /* mve_vmlsldavaxq_p_sv8hi */
    case 4557:  /* mve_vmlsldavaq_p_sv4si */
    case 4556:  /* mve_vmlsldavaq_p_sv8hi */
    case 4555:  /* mve_vshrntq_m_n_uv4si */
    case 4554:  /* mve_vshrntq_m_n_sv4si */
    case 4553:  /* mve_vshrntq_m_n_uv8hi */
    case 4552:  /* mve_vshrntq_m_n_sv8hi */
    case 4551:  /* mve_vshrnbq_m_n_uv4si */
    case 4550:  /* mve_vshrnbq_m_n_sv4si */
    case 4549:  /* mve_vshrnbq_m_n_uv8hi */
    case 4548:  /* mve_vshrnbq_m_n_sv8hi */
    case 4547:  /* mve_vshlltq_m_n_sv8hi */
    case 4546:  /* mve_vshlltq_m_n_uv8hi */
    case 4545:  /* mve_vshlltq_m_n_sv16qi */
    case 4544:  /* mve_vshlltq_m_n_uv16qi */
    case 4543:  /* mve_vshllbq_m_n_sv8hi */
    case 4542:  /* mve_vshllbq_m_n_uv8hi */
    case 4541:  /* mve_vshllbq_m_n_sv16qi */
    case 4540:  /* mve_vshllbq_m_n_uv16qi */
    case 4539:  /* mve_vrshrntq_m_n_sv4si */
    case 4538:  /* mve_vrshrntq_m_n_uv4si */
    case 4537:  /* mve_vrshrntq_m_n_sv8hi */
    case 4536:  /* mve_vrshrntq_m_n_uv8hi */
    case 4535:  /* mve_vrshrnbq_m_n_sv4si */
    case 4534:  /* mve_vrshrnbq_m_n_uv4si */
    case 4533:  /* mve_vrshrnbq_m_n_sv8hi */
    case 4532:  /* mve_vrshrnbq_m_n_uv8hi */
    case 4531:  /* mve_vrmlaldavhaq_p_sv4si */
    case 4530:  /* mve_vqshrntq_m_n_uv4si */
    case 4529:  /* mve_vqshrntq_m_n_sv4si */
    case 4528:  /* mve_vqshrntq_m_n_uv8hi */
    case 4527:  /* mve_vqshrntq_m_n_sv8hi */
    case 4526:  /* mve_vqshrnbq_m_n_sv4si */
    case 4525:  /* mve_vqshrnbq_m_n_uv4si */
    case 4524:  /* mve_vqshrnbq_m_n_sv8hi */
    case 4523:  /* mve_vqshrnbq_m_n_uv8hi */
    case 4522:  /* mve_vqrshrntq_m_n_uv4si */
    case 4521:  /* mve_vqrshrntq_m_n_sv4si */
    case 4520:  /* mve_vqrshrntq_m_n_uv8hi */
    case 4519:  /* mve_vqrshrntq_m_n_sv8hi */
    case 4518:  /* mve_vqrshrnbq_m_n_sv4si */
    case 4517:  /* mve_vqrshrnbq_m_n_uv4si */
    case 4516:  /* mve_vqrshrnbq_m_n_sv8hi */
    case 4515:  /* mve_vqrshrnbq_m_n_uv8hi */
    case 4514:  /* mve_vmlaldavaxq_p_sv4si */
    case 4513:  /* mve_vmlaldavaxq_p_sv8hi */
    case 4512:  /* mve_vmlaldavaq_p_sv4si */
    case 4511:  /* mve_vmlaldavaq_p_uv4si */
    case 4510:  /* mve_vmlaldavaq_p_sv8hi */
    case 4509:  /* mve_vmlaldavaq_p_uv8hi */
    case 4508:  /* mve_vqrdmulhq_m_sv4si */
    case 4507:  /* mve_vqrdmulhq_m_sv8hi */
    case 4506:  /* mve_vqrdmulhq_m_sv16qi */
    case 4505:  /* mve_vqrdmulhq_m_n_sv4si */
    case 4504:  /* mve_vqrdmulhq_m_n_sv8hi */
    case 4503:  /* mve_vqrdmulhq_m_n_sv16qi */
    case 4502:  /* mve_vqrdmlsdhxq_m_sv4si */
    case 4501:  /* mve_vqrdmlsdhxq_m_sv8hi */
    case 4500:  /* mve_vqrdmlsdhxq_m_sv16qi */
    case 4499:  /* mve_vqrdmlsdhq_m_sv4si */
    case 4498:  /* mve_vqrdmlsdhq_m_sv8hi */
    case 4497:  /* mve_vqrdmlsdhq_m_sv16qi */
    case 4496:  /* mve_vqrdmladhxq_m_sv4si */
    case 4495:  /* mve_vqrdmladhxq_m_sv8hi */
    case 4494:  /* mve_vqrdmladhxq_m_sv16qi */
    case 4493:  /* mve_vqrdmladhq_m_sv4si */
    case 4492:  /* mve_vqrdmladhq_m_sv8hi */
    case 4491:  /* mve_vqrdmladhq_m_sv16qi */
    case 4490:  /* mve_vqdmulhq_m_sv4si */
    case 4489:  /* mve_vqdmulhq_m_sv8hi */
    case 4488:  /* mve_vqdmulhq_m_sv16qi */
    case 4487:  /* mve_vqdmulhq_m_n_sv4si */
    case 4486:  /* mve_vqdmulhq_m_n_sv8hi */
    case 4485:  /* mve_vqdmulhq_m_n_sv16qi */
    case 4484:  /* mve_vqdmlsdhxq_m_sv4si */
    case 4483:  /* mve_vqdmlsdhxq_m_sv8hi */
    case 4482:  /* mve_vqdmlsdhxq_m_sv16qi */
    case 4481:  /* mve_vqdmlsdhq_m_sv4si */
    case 4480:  /* mve_vqdmlsdhq_m_sv8hi */
    case 4479:  /* mve_vqdmlsdhq_m_sv16qi */
    case 4478:  /* mve_vqdmladhxq_m_sv4si */
    case 4477:  /* mve_vqdmladhxq_m_sv8hi */
    case 4476:  /* mve_vqdmladhxq_m_sv16qi */
    case 4475:  /* mve_vqdmladhq_m_sv4si */
    case 4474:  /* mve_vqdmladhq_m_sv8hi */
    case 4473:  /* mve_vqdmladhq_m_sv16qi */
    case 4472:  /* mve_vmlsdavaxq_p_sv4si */
    case 4471:  /* mve_vmlsdavaxq_p_sv8hi */
    case 4470:  /* mve_vmlsdavaxq_p_sv16qi */
    case 4469:  /* mve_vmlsdavaq_p_sv4si */
    case 4468:  /* mve_vmlsdavaq_p_sv8hi */
    case 4467:  /* mve_vmlsdavaq_p_sv16qi */
    case 4466:  /* mve_vmladavaxq_p_sv4si */
    case 4465:  /* mve_vmladavaxq_p_sv8hi */
    case 4464:  /* mve_vmladavaxq_p_sv16qi */
    case 4463:  /* mve_vhcaddq_rot90_m_sv4si */
    case 4462:  /* mve_vhcaddq_rot90_m_sv8hi */
    case 4461:  /* mve_vhcaddq_rot90_m_sv16qi */
    case 4460:  /* mve_vhcaddq_rot270_m_sv4si */
    case 4459:  /* mve_vhcaddq_rot270_m_sv8hi */
    case 4458:  /* mve_vhcaddq_rot270_m_sv16qi */
    case 4457:  /* mve_vsubq_m_n_uv4si */
    case 4456:  /* mve_vsubq_m_n_sv4si */
    case 4455:  /* mve_vsubq_m_n_uv8hi */
    case 4454:  /* mve_vsubq_m_n_sv8hi */
    case 4453:  /* mve_vsubq_m_n_uv16qi */
    case 4452:  /* mve_vsubq_m_n_sv16qi */
    case 4451:  /* mve_vsliq_m_n_sv4si */
    case 4450:  /* mve_vsliq_m_n_uv4si */
    case 4449:  /* mve_vsliq_m_n_sv8hi */
    case 4448:  /* mve_vsliq_m_n_uv8hi */
    case 4447:  /* mve_vsliq_m_n_sv16qi */
    case 4446:  /* mve_vsliq_m_n_uv16qi */
    case 4445:  /* mve_vshrq_m_n_uv4si */
    case 4444:  /* mve_vshrq_m_n_sv4si */
    case 4443:  /* mve_vshrq_m_n_uv8hi */
    case 4442:  /* mve_vshrq_m_n_sv8hi */
    case 4441:  /* mve_vshrq_m_n_uv16qi */
    case 4440:  /* mve_vshrq_m_n_sv16qi */
    case 4439:  /* mve_vshlq_m_n_uv4si */
    case 4438:  /* mve_vshlq_m_n_sv4si */
    case 4437:  /* mve_vshlq_m_n_uv8hi */
    case 4436:  /* mve_vshlq_m_n_sv8hi */
    case 4435:  /* mve_vshlq_m_n_uv16qi */
    case 4434:  /* mve_vshlq_m_n_sv16qi */
    case 4433:  /* mve_vrshrq_m_n_uv4si */
    case 4432:  /* mve_vrshrq_m_n_sv4si */
    case 4431:  /* mve_vrshrq_m_n_uv8hi */
    case 4430:  /* mve_vrshrq_m_n_sv8hi */
    case 4429:  /* mve_vrshrq_m_n_uv16qi */
    case 4428:  /* mve_vrshrq_m_n_sv16qi */
    case 4427:  /* mve_vrshlq_m_uv4si */
    case 4426:  /* mve_vrshlq_m_sv4si */
    case 4425:  /* mve_vrshlq_m_uv8hi */
    case 4424:  /* mve_vrshlq_m_sv8hi */
    case 4423:  /* mve_vrshlq_m_uv16qi */
    case 4422:  /* mve_vrshlq_m_sv16qi */
    case 4421:  /* mve_vrmulhq_m_sv4si */
    case 4420:  /* mve_vrmulhq_m_uv4si */
    case 4419:  /* mve_vrmulhq_m_sv8hi */
    case 4418:  /* mve_vrmulhq_m_uv8hi */
    case 4417:  /* mve_vrmulhq_m_sv16qi */
    case 4416:  /* mve_vrmulhq_m_uv16qi */
    case 4415:  /* mve_vrhaddq_m_sv4si */
    case 4414:  /* mve_vrhaddq_m_uv4si */
    case 4413:  /* mve_vrhaddq_m_sv8hi */
    case 4412:  /* mve_vrhaddq_m_uv8hi */
    case 4411:  /* mve_vrhaddq_m_sv16qi */
    case 4410:  /* mve_vrhaddq_m_uv16qi */
    case 4409:  /* mve_vqsubq_m_sv4si */
    case 4408:  /* mve_vqsubq_m_uv4si */
    case 4407:  /* mve_vqsubq_m_sv8hi */
    case 4406:  /* mve_vqsubq_m_uv8hi */
    case 4405:  /* mve_vqsubq_m_sv16qi */
    case 4404:  /* mve_vqsubq_m_uv16qi */
    case 4403:  /* mve_vqsubq_m_n_sv4si */
    case 4402:  /* mve_vqsubq_m_n_uv4si */
    case 4401:  /* mve_vqsubq_m_n_sv8hi */
    case 4400:  /* mve_vqsubq_m_n_uv8hi */
    case 4399:  /* mve_vqsubq_m_n_sv16qi */
    case 4398:  /* mve_vqsubq_m_n_uv16qi */
    case 4397:  /* mve_vqshlq_m_sv4si */
    case 4396:  /* mve_vqshlq_m_uv4si */
    case 4395:  /* mve_vqshlq_m_sv8hi */
    case 4394:  /* mve_vqshlq_m_uv8hi */
    case 4393:  /* mve_vqshlq_m_sv16qi */
    case 4392:  /* mve_vqshlq_m_uv16qi */
    case 4391:  /* mve_vqshlq_m_n_uv4si */
    case 4390:  /* mve_vqshlq_m_n_sv4si */
    case 4389:  /* mve_vqshlq_m_n_uv8hi */
    case 4388:  /* mve_vqshlq_m_n_sv8hi */
    case 4387:  /* mve_vqshlq_m_n_uv16qi */
    case 4386:  /* mve_vqshlq_m_n_sv16qi */
    case 4385:  /* mve_vqrshlq_m_sv4si */
    case 4384:  /* mve_vqrshlq_m_uv4si */
    case 4383:  /* mve_vqrshlq_m_sv8hi */
    case 4382:  /* mve_vqrshlq_m_uv8hi */
    case 4381:  /* mve_vqrshlq_m_sv16qi */
    case 4380:  /* mve_vqrshlq_m_uv16qi */
    case 4379:  /* mve_vqrdmlashq_m_n_sv4si */
    case 4378:  /* mve_vqrdmlashq_m_n_sv8hi */
    case 4377:  /* mve_vqrdmlashq_m_n_sv16qi */
    case 4376:  /* mve_vqrdmlahq_m_n_sv4si */
    case 4375:  /* mve_vqrdmlahq_m_n_sv8hi */
    case 4374:  /* mve_vqrdmlahq_m_n_sv16qi */
    case 4373:  /* mve_vqdmlashq_m_n_sv4si */
    case 4372:  /* mve_vqdmlashq_m_n_sv8hi */
    case 4371:  /* mve_vqdmlashq_m_n_sv16qi */
    case 4370:  /* mve_vqdmlahq_m_n_sv4si */
    case 4369:  /* mve_vqdmlahq_m_n_sv8hi */
    case 4368:  /* mve_vqdmlahq_m_n_sv16qi */
    case 4367:  /* mve_vqaddq_m_sv4si */
    case 4366:  /* mve_vqaddq_m_uv4si */
    case 4365:  /* mve_vqaddq_m_sv8hi */
    case 4364:  /* mve_vqaddq_m_uv8hi */
    case 4363:  /* mve_vqaddq_m_sv16qi */
    case 4362:  /* mve_vqaddq_m_uv16qi */
    case 4361:  /* mve_vqaddq_m_n_sv4si */
    case 4360:  /* mve_vqaddq_m_n_uv4si */
    case 4359:  /* mve_vqaddq_m_n_sv8hi */
    case 4358:  /* mve_vqaddq_m_n_uv8hi */
    case 4357:  /* mve_vqaddq_m_n_sv16qi */
    case 4356:  /* mve_vqaddq_m_n_uv16qi */
    case 4355:  /* mve_vorrq_m_uv4si */
    case 4354:  /* mve_vorrq_m_sv4si */
    case 4353:  /* mve_vorrq_m_uv8hi */
    case 4352:  /* mve_vorrq_m_sv8hi */
    case 4351:  /* mve_vorrq_m_uv16qi */
    case 4350:  /* mve_vorrq_m_sv16qi */
    case 4349:  /* mve_vornq_m_sv4si */
    case 4348:  /* mve_vornq_m_uv4si */
    case 4347:  /* mve_vornq_m_sv8hi */
    case 4346:  /* mve_vornq_m_uv8hi */
    case 4345:  /* mve_vornq_m_sv16qi */
    case 4344:  /* mve_vornq_m_uv16qi */
    case 4343:  /* mve_vmulq_m_uv4si */
    case 4342:  /* mve_vmulq_m_sv4si */
    case 4341:  /* mve_vmulq_m_uv8hi */
    case 4340:  /* mve_vmulq_m_sv8hi */
    case 4339:  /* mve_vmulq_m_uv16qi */
    case 4338:  /* mve_vmulq_m_sv16qi */
    case 4337:  /* mve_vmulq_m_n_sv4si */
    case 4336:  /* mve_vmulq_m_n_uv4si */
    case 4335:  /* mve_vmulq_m_n_sv8hi */
    case 4334:  /* mve_vmulq_m_n_uv8hi */
    case 4333:  /* mve_vmulq_m_n_sv16qi */
    case 4332:  /* mve_vmulq_m_n_uv16qi */
    case 4331:  /* mve_vmulltq_int_m_uv4si */
    case 4330:  /* mve_vmulltq_int_m_sv4si */
    case 4329:  /* mve_vmulltq_int_m_uv8hi */
    case 4328:  /* mve_vmulltq_int_m_sv8hi */
    case 4327:  /* mve_vmulltq_int_m_uv16qi */
    case 4326:  /* mve_vmulltq_int_m_sv16qi */
    case 4325:  /* mve_vmullbq_int_m_sv4si */
    case 4324:  /* mve_vmullbq_int_m_uv4si */
    case 4323:  /* mve_vmullbq_int_m_sv8hi */
    case 4322:  /* mve_vmullbq_int_m_uv8hi */
    case 4321:  /* mve_vmullbq_int_m_sv16qi */
    case 4320:  /* mve_vmullbq_int_m_uv16qi */
    case 4319:  /* mve_vmulhq_m_uv4si */
    case 4318:  /* mve_vmulhq_m_sv4si */
    case 4317:  /* mve_vmulhq_m_uv8hi */
    case 4316:  /* mve_vmulhq_m_sv8hi */
    case 4315:  /* mve_vmulhq_m_uv16qi */
    case 4314:  /* mve_vmulhq_m_sv16qi */
    case 4313:  /* mve_vmlasq_m_n_sv4si */
    case 4312:  /* mve_vmlasq_m_n_uv4si */
    case 4311:  /* mve_vmlasq_m_n_sv8hi */
    case 4310:  /* mve_vmlasq_m_n_uv8hi */
    case 4309:  /* mve_vmlasq_m_n_sv16qi */
    case 4308:  /* mve_vmlasq_m_n_uv16qi */
    case 4307:  /* mve_vmlaq_m_n_uv4si */
    case 4306:  /* mve_vmlaq_m_n_sv4si */
    case 4305:  /* mve_vmlaq_m_n_uv8hi */
    case 4304:  /* mve_vmlaq_m_n_sv8hi */
    case 4303:  /* mve_vmlaq_m_n_uv16qi */
    case 4302:  /* mve_vmlaq_m_n_sv16qi */
    case 4301:  /* mve_vmladavaq_p_sv4si */
    case 4300:  /* mve_vmladavaq_p_uv4si */
    case 4299:  /* mve_vmladavaq_p_sv8hi */
    case 4298:  /* mve_vmladavaq_p_uv8hi */
    case 4297:  /* mve_vmladavaq_p_sv16qi */
    case 4296:  /* mve_vmladavaq_p_uv16qi */
    case 4295:  /* mve_vminq_m_uv4si */
    case 4294:  /* mve_vminq_m_sv4si */
    case 4293:  /* mve_vminq_m_uv8hi */
    case 4292:  /* mve_vminq_m_sv8hi */
    case 4291:  /* mve_vminq_m_uv16qi */
    case 4290:  /* mve_vminq_m_sv16qi */
    case 4289:  /* mve_vmaxq_m_uv4si */
    case 4288:  /* mve_vmaxq_m_sv4si */
    case 4287:  /* mve_vmaxq_m_uv8hi */
    case 4286:  /* mve_vmaxq_m_sv8hi */
    case 4285:  /* mve_vmaxq_m_uv16qi */
    case 4284:  /* mve_vmaxq_m_sv16qi */
    case 4283:  /* mve_vhsubq_m_uv4si */
    case 4282:  /* mve_vhsubq_m_sv4si */
    case 4281:  /* mve_vhsubq_m_uv8hi */
    case 4280:  /* mve_vhsubq_m_sv8hi */
    case 4279:  /* mve_vhsubq_m_uv16qi */
    case 4278:  /* mve_vhsubq_m_sv16qi */
    case 4277:  /* mve_vhsubq_m_n_uv4si */
    case 4276:  /* mve_vhsubq_m_n_sv4si */
    case 4275:  /* mve_vhsubq_m_n_uv8hi */
    case 4274:  /* mve_vhsubq_m_n_sv8hi */
    case 4273:  /* mve_vhsubq_m_n_uv16qi */
    case 4272:  /* mve_vhsubq_m_n_sv16qi */
    case 4271:  /* mve_vhaddq_m_uv4si */
    case 4270:  /* mve_vhaddq_m_sv4si */
    case 4269:  /* mve_vhaddq_m_uv8hi */
    case 4268:  /* mve_vhaddq_m_sv8hi */
    case 4267:  /* mve_vhaddq_m_uv16qi */
    case 4266:  /* mve_vhaddq_m_sv16qi */
    case 4265:  /* mve_vhaddq_m_n_uv4si */
    case 4264:  /* mve_vhaddq_m_n_sv4si */
    case 4263:  /* mve_vhaddq_m_n_uv8hi */
    case 4262:  /* mve_vhaddq_m_n_sv8hi */
    case 4261:  /* mve_vhaddq_m_n_uv16qi */
    case 4260:  /* mve_vhaddq_m_n_sv16qi */
    case 4259:  /* mve_veorq_m_uv4si */
    case 4258:  /* mve_veorq_m_sv4si */
    case 4257:  /* mve_veorq_m_uv8hi */
    case 4256:  /* mve_veorq_m_sv8hi */
    case 4255:  /* mve_veorq_m_uv16qi */
    case 4254:  /* mve_veorq_m_sv16qi */
    case 4253:  /* mve_vcaddq_rot90_m_sv4si */
    case 4252:  /* mve_vcaddq_rot90_m_uv4si */
    case 4251:  /* mve_vcaddq_rot90_m_sv8hi */
    case 4250:  /* mve_vcaddq_rot90_m_uv8hi */
    case 4249:  /* mve_vcaddq_rot90_m_sv16qi */
    case 4248:  /* mve_vcaddq_rot90_m_uv16qi */
    case 4247:  /* mve_vcaddq_rot270_m_sv4si */
    case 4246:  /* mve_vcaddq_rot270_m_uv4si */
    case 4245:  /* mve_vcaddq_rot270_m_sv8hi */
    case 4244:  /* mve_vcaddq_rot270_m_uv8hi */
    case 4243:  /* mve_vcaddq_rot270_m_sv16qi */
    case 4242:  /* mve_vcaddq_rot270_m_uv16qi */
    case 4241:  /* mve_vbrsrq_m_n_sv4si */
    case 4240:  /* mve_vbrsrq_m_n_uv4si */
    case 4239:  /* mve_vbrsrq_m_n_sv8hi */
    case 4238:  /* mve_vbrsrq_m_n_uv8hi */
    case 4237:  /* mve_vbrsrq_m_n_sv16qi */
    case 4236:  /* mve_vbrsrq_m_n_uv16qi */
    case 4235:  /* mve_vbicq_m_sv4si */
    case 4234:  /* mve_vbicq_m_uv4si */
    case 4233:  /* mve_vbicq_m_sv8hi */
    case 4232:  /* mve_vbicq_m_uv8hi */
    case 4231:  /* mve_vbicq_m_sv16qi */
    case 4230:  /* mve_vbicq_m_uv16qi */
    case 4229:  /* mve_vandq_m_sv4si */
    case 4228:  /* mve_vandq_m_uv4si */
    case 4227:  /* mve_vandq_m_sv8hi */
    case 4226:  /* mve_vandq_m_uv8hi */
    case 4225:  /* mve_vandq_m_sv16qi */
    case 4224:  /* mve_vandq_m_uv16qi */
    case 4223:  /* mve_vaddq_m_sv4si */
    case 4222:  /* mve_vaddq_m_uv4si */
    case 4221:  /* mve_vaddq_m_sv8hi */
    case 4220:  /* mve_vaddq_m_uv8hi */
    case 4219:  /* mve_vaddq_m_sv16qi */
    case 4218:  /* mve_vaddq_m_uv16qi */
    case 4217:  /* mve_vaddq_m_n_uv4si */
    case 4216:  /* mve_vaddq_m_n_sv4si */
    case 4215:  /* mve_vaddq_m_n_uv8hi */
    case 4214:  /* mve_vaddq_m_n_sv8hi */
    case 4213:  /* mve_vaddq_m_n_uv16qi */
    case 4212:  /* mve_vaddq_m_n_sv16qi */
    case 4211:  /* mve_vabdq_m_uv4si */
    case 4210:  /* mve_vabdq_m_sv4si */
    case 4209:  /* mve_vabdq_m_uv8hi */
    case 4208:  /* mve_vabdq_m_sv8hi */
    case 4207:  /* mve_vabdq_m_uv16qi */
    case 4206:  /* mve_vabdq_m_sv16qi */
    case 4205:  /* mve_vcvtq_m_n_to_f_sv4sf */
    case 4204:  /* mve_vcvtq_m_n_to_f_uv4sf */
    case 4203:  /* mve_vcvtq_m_n_to_f_sv8hf */
    case 4202:  /* mve_vcvtq_m_n_to_f_uv8hf */
    case 4201:  /* mve_vsubq_m_sv4si */
    case 4200:  /* mve_vsubq_m_uv4si */
    case 4199:  /* mve_vsubq_m_sv8hi */
    case 4198:  /* mve_vsubq_m_uv8hi */
    case 4197:  /* mve_vsubq_m_sv16qi */
    case 4196:  /* mve_vsubq_m_uv16qi */
    case 4195:  /* mve_vsriq_m_n_uv4si */
    case 4194:  /* mve_vsriq_m_n_sv4si */
    case 4193:  /* mve_vsriq_m_n_uv8hi */
    case 4192:  /* mve_vsriq_m_n_sv8hi */
    case 4191:  /* mve_vsriq_m_n_uv16qi */
    case 4190:  /* mve_vsriq_m_n_sv16qi */
    case 4189:  /* mve_vshlq_m_uv4si */
    case 4188:  /* mve_vshlq_m_sv4si */
    case 4187:  /* mve_vshlq_m_uv8hi */
    case 4186:  /* mve_vshlq_m_sv8hi */
    case 4185:  /* mve_vshlq_m_uv16qi */
    case 4184:  /* mve_vshlq_m_sv16qi */
    case 4183:  /* mve_vqshluq_m_n_sv4si */
    case 4182:  /* mve_vqshluq_m_n_sv8hi */
    case 4181:  /* mve_vqshluq_m_n_sv16qi */
    case 4180:  /* mve_vabavq_p_uv4si */
    case 4179:  /* mve_vabavq_p_sv4si */
    case 4178:  /* mve_vabavq_p_uv8hi */
    case 4177:  /* mve_vabavq_p_sv8hi */
    case 4176:  /* mve_vabavq_p_uv16qi */
    case 4175:  /* mve_vabavq_p_sv16qi */
    case 4173:  /* mve_vrmlaldavhq_p_uv4si */
    case 4172:  /* mve_vrmlaldavhq_p_sv4si */
    case 4171:  /* mve_vcvtq_m_from_f_sv4si */
    case 4170:  /* mve_vcvtq_m_from_f_uv4si */
    case 4169:  /* mve_vcvtq_m_from_f_sv8hi */
    case 4168:  /* mve_vcvtq_m_from_f_uv8hi */
    case 4167:  /* mve_vrev16q_m_uv16qi */
    case 4166:  /* mve_vrev16q_m_sv16qi */
    case 4165:  /* mve_vcvtq_m_n_from_f_uv4si */
    case 4164:  /* mve_vcvtq_m_n_from_f_sv4si */
    case 4163:  /* mve_vcvtq_m_n_from_f_uv8hi */
    case 4162:  /* mve_vcvtq_m_n_from_f_sv8hi */
    case 4161:  /* mve_vcvtnq_m_uv4si */
    case 4160:  /* mve_vcvtnq_m_sv4si */
    case 4159:  /* mve_vcvtnq_m_uv8hi */
    case 4158:  /* mve_vcvtnq_m_sv8hi */
    case 4157:  /* mve_vcvtpq_m_uv4si */
    case 4156:  /* mve_vcvtpq_m_sv4si */
    case 4155:  /* mve_vcvtpq_m_uv8hi */
    case 4154:  /* mve_vcvtpq_m_sv8hi */
    case 4153:  /* mve_vcvtmq_m_uv4si */
    case 4152:  /* mve_vcvtmq_m_sv4si */
    case 4151:  /* mve_vcvtmq_m_uv8hi */
    case 4150:  /* mve_vcvtmq_m_sv8hi */
    case 4133:  /* mve_vrndxq_m_fv4sf */
    case 4132:  /* mve_vrndxq_m_fv8hf */
    case 4131:  /* mve_vrndpq_m_fv4sf */
    case 4130:  /* mve_vrndpq_m_fv8hf */
    case 4129:  /* mve_vrndnq_m_fv4sf */
    case 4128:  /* mve_vrndnq_m_fv8hf */
    case 4127:  /* mve_vrndmq_m_fv4sf */
    case 4126:  /* mve_vrndmq_m_fv8hf */
    case 4125:  /* mve_vrndaq_m_fv4sf */
    case 4124:  /* mve_vrndaq_m_fv8hf */
    case 4123:  /* mve_vrmlsldavhxq_p_sv4si */
    case 4122:  /* mve_vrmlsldavhq_p_sv4si */
    case 4120:  /* mve_vrmlaldavhxq_p_sv4si */
    case 4118:  /* mve_vrev64q_m_fv4sf */
    case 4117:  /* mve_vrev64q_m_fv8hf */
    case 4116:  /* mve_vrev32q_m_uv8hi */
    case 4115:  /* mve_vrev32q_m_sv8hi */
    case 4114:  /* mve_vrev32q_m_uv16qi */
    case 4113:  /* mve_vrev32q_m_sv16qi */
    case 4112:  /* mve_vrev32q_m_fv8hf */
    case 4093:  /* mve_vqmovuntq_m_sv4si */
    case 4092:  /* mve_vqmovuntq_m_sv8hi */
    case 4091:  /* mve_vqmovunbq_m_sv4si */
    case 4090:  /* mve_vqmovunbq_m_sv8hi */
    case 4089:  /* mve_vqmovntq_m_sv4si */
    case 4088:  /* mve_vqmovntq_m_uv4si */
    case 4087:  /* mve_vqmovntq_m_sv8hi */
    case 4086:  /* mve_vqmovntq_m_uv8hi */
    case 4085:  /* mve_vqmovnbq_m_uv4si */
    case 4084:  /* mve_vqmovnbq_m_sv4si */
    case 4083:  /* mve_vqmovnbq_m_uv8hi */
    case 4082:  /* mve_vqmovnbq_m_sv8hi */
    case 4079:  /* mve_vorrq_m_n_uv4si */
    case 4078:  /* mve_vorrq_m_n_sv4si */
    case 4077:  /* mve_vorrq_m_n_uv8hi */
    case 4076:  /* mve_vorrq_m_n_sv8hi */
    case 4075:  /* mve_vnegq_m_fv4sf */
    case 4074:  /* mve_vnegq_m_fv8hf */
    case 4073:  /* mve_vmvnq_m_n_sv4si */
    case 4072:  /* mve_vmvnq_m_n_uv4si */
    case 4071:  /* mve_vmvnq_m_n_sv8hi */
    case 4070:  /* mve_vmvnq_m_n_uv8hi */
    case 4069:  /* mve_vmovntq_m_sv4si */
    case 4068:  /* mve_vmovntq_m_uv4si */
    case 4067:  /* mve_vmovntq_m_sv8hi */
    case 4066:  /* mve_vmovntq_m_uv8hi */
    case 4065:  /* mve_vmovnbq_m_sv4si */
    case 4064:  /* mve_vmovnbq_m_uv4si */
    case 4063:  /* mve_vmovnbq_m_sv8hi */
    case 4062:  /* mve_vmovnbq_m_uv8hi */
    case 4061:  /* mve_vmovltq_m_sv8hi */
    case 4060:  /* mve_vmovltq_m_uv8hi */
    case 4059:  /* mve_vmovltq_m_sv16qi */
    case 4058:  /* mve_vmovltq_m_uv16qi */
    case 4057:  /* mve_vmovlbq_m_sv8hi */
    case 4056:  /* mve_vmovlbq_m_uv8hi */
    case 4055:  /* mve_vmovlbq_m_sv16qi */
    case 4054:  /* mve_vmovlbq_m_uv16qi */
    case 4053:  /* mve_vmlsldavxq_p_sv4si */
    case 4052:  /* mve_vmlsldavxq_p_sv8hi */
    case 4051:  /* mve_vmlsldavq_p_sv4si */
    case 4050:  /* mve_vmlsldavq_p_sv8hi */
    case 4045:  /* mve_vmlaldavxq_p_sv4si */
    case 4044:  /* mve_vmlaldavxq_p_sv8hi */
    case 4043:  /* mve_vmlaldavq_p_sv4si */
    case 4042:  /* mve_vmlaldavq_p_uv4si */
    case 4041:  /* mve_vmlaldavq_p_sv8hi */
    case 4040:  /* mve_vmlaldavq_p_uv8hi */
    case 4033:  /* mve_vminnmvq_p_fv4sf */
    case 4032:  /* mve_vminnmvq_p_fv8hf */
    case 4031:  /* mve_vminnmavq_p_fv4sf */
    case 4030:  /* mve_vminnmavq_p_fv8hf */
    case 4029:  /* mve_vminnmaq_m_fv4sf */
    case 4028:  /* mve_vminnmaq_m_fv8hf */
    case 4027:  /* mve_vmaxnmvq_p_fv4sf */
    case 4026:  /* mve_vmaxnmvq_p_fv8hf */
    case 4025:  /* mve_vmaxnmavq_p_fv4sf */
    case 4024:  /* mve_vmaxnmavq_p_fv8hf */
    case 4023:  /* mve_vmaxnmaq_m_fv4sf */
    case 4022:  /* mve_vmaxnmaq_m_fv8hf */
    case 4013:  /* mve_vdupq_m_n_fv4sf */
    case 4012:  /* mve_vdupq_m_n_fv8hf */
    case 4011:  /* mve_vcvttq_m_f32_f16v4sf */
    case 4010:  /* mve_vcvttq_m_f16_f32v8hf */
    case 4009:  /* mve_vcvtbq_m_f32_f16v4sf */
    case 4008:  /* mve_vcvtbq_m_f16_f32v8hf */
    case 4007:  /* mve_vcmpneq_m_n_fv4sf */
    case 4006:  /* mve_vcmpneq_m_n_fv8hf */
    case 4005:  /* mve_vcmpneq_m_fv4sf */
    case 4004:  /* mve_vcmpneq_m_fv8hf */
    case 4003:  /* mve_vcmpltq_m_n_fv4sf */
    case 4002:  /* mve_vcmpltq_m_n_fv8hf */
    case 4001:  /* mve_vcmpltq_m_fv4sf */
    case 4000:  /* mve_vcmpltq_m_fv8hf */
    case 3999:  /* mve_vcmpleq_m_n_fv4sf */
    case 3998:  /* mve_vcmpleq_m_n_fv8hf */
    case 3997:  /* mve_vcmpleq_m_fv4sf */
    case 3996:  /* mve_vcmpleq_m_fv8hf */
    case 3995:  /* mve_vcmpgtq_m_n_fv4sf */
    case 3994:  /* mve_vcmpgtq_m_n_fv8hf */
    case 3993:  /* mve_vcmpgtq_m_fv4sf */
    case 3992:  /* mve_vcmpgtq_m_fv8hf */
    case 3991:  /* mve_vcmpgeq_m_n_fv4sf */
    case 3990:  /* mve_vcmpgeq_m_n_fv8hf */
    case 3989:  /* mve_vcmpgeq_m_fv4sf */
    case 3988:  /* mve_vcmpgeq_m_fv8hf */
    case 3987:  /* mve_vcmpeqq_m_n_fv4sf */
    case 3986:  /* mve_vcmpeqq_m_n_fv8hf */
    case 3977:  /* mve_vaddlvaq_p_sv4si */
    case 3976:  /* mve_vaddlvaq_p_uv4si */
    case 3975:  /* mve_vabsq_m_fv4sf */
    case 3974:  /* mve_vabsq_m_fv8hf */
    case 3940:  /* mve_vshlq_m_r_uv4si */
    case 3939:  /* mve_vshlq_m_r_sv4si */
    case 3938:  /* mve_vshlq_m_r_uv8hi */
    case 3937:  /* mve_vshlq_m_r_sv8hi */
    case 3936:  /* mve_vshlq_m_r_uv16qi */
    case 3935:  /* mve_vshlq_m_r_sv16qi */
    case 3934:  /* mve_vrshlq_m_n_uv4si */
    case 3933:  /* mve_vrshlq_m_n_sv4si */
    case 3932:  /* mve_vrshlq_m_n_uv8hi */
    case 3931:  /* mve_vrshlq_m_n_sv8hi */
    case 3930:  /* mve_vrshlq_m_n_uv16qi */
    case 3929:  /* mve_vrshlq_m_n_sv16qi */
    case 3928:  /* mve_vrev64q_m_uv4si */
    case 3927:  /* mve_vrev64q_m_sv4si */
    case 3926:  /* mve_vrev64q_m_uv8hi */
    case 3925:  /* mve_vrev64q_m_sv8hi */
    case 3924:  /* mve_vrev64q_m_uv16qi */
    case 3923:  /* mve_vrev64q_m_sv16qi */
    case 3922:  /* mve_vqshlq_m_r_uv4si */
    case 3921:  /* mve_vqshlq_m_r_sv4si */
    case 3920:  /* mve_vqshlq_m_r_uv8hi */
    case 3919:  /* mve_vqshlq_m_r_sv8hi */
    case 3918:  /* mve_vqshlq_m_r_uv16qi */
    case 3917:  /* mve_vqshlq_m_r_sv16qi */
    case 3916:  /* mve_vqrshlq_m_n_uv4si */
    case 3915:  /* mve_vqrshlq_m_n_sv4si */
    case 3914:  /* mve_vqrshlq_m_n_uv8hi */
    case 3913:  /* mve_vqrshlq_m_n_sv8hi */
    case 3912:  /* mve_vqrshlq_m_n_uv16qi */
    case 3911:  /* mve_vqrshlq_m_n_sv16qi */
    case 3892:  /* mve_vqnegq_m_sv4si */
    case 3891:  /* mve_vqnegq_m_sv8hi */
    case 3890:  /* mve_vqnegq_m_sv16qi */
    case 3883:  /* mve_vqabsq_m_sv4si */
    case 3882:  /* mve_vqabsq_m_sv8hi */
    case 3881:  /* mve_vqabsq_m_sv16qi */
    case 3872:  /* mve_vnegq_m_sv4si */
    case 3871:  /* mve_vnegq_m_sv8hi */
    case 3870:  /* mve_vnegq_m_sv16qi */
    case 3869:  /* mve_vmvnq_m_uv4si */
    case 3868:  /* mve_vmvnq_m_sv4si */
    case 3867:  /* mve_vmvnq_m_uv8hi */
    case 3866:  /* mve_vmvnq_m_sv8hi */
    case 3865:  /* mve_vmvnq_m_uv16qi */
    case 3864:  /* mve_vmvnq_m_sv16qi */
    case 3863:  /* mve_vmlsdavxq_p_sv4si */
    case 3862:  /* mve_vmlsdavxq_p_sv8hi */
    case 3861:  /* mve_vmlsdavxq_p_sv16qi */
    case 3860:  /* mve_vmlsdavq_p_sv4si */
    case 3859:  /* mve_vmlsdavq_p_sv8hi */
    case 3858:  /* mve_vmlsdavq_p_sv16qi */
    case 3845:  /* mve_vmladavxq_p_sv4si */
    case 3844:  /* mve_vmladavxq_p_sv8hi */
    case 3843:  /* mve_vmladavxq_p_sv16qi */
    case 3842:  /* mve_vmladavq_p_uv4si */
    case 3841:  /* mve_vmladavq_p_sv4si */
    case 3840:  /* mve_vmladavq_p_uv8hi */
    case 3839:  /* mve_vmladavq_p_sv8hi */
    case 3838:  /* mve_vmladavq_p_uv16qi */
    case 3837:  /* mve_vmladavq_p_sv16qi */
    case 3830:  /* mve_vminvq_p_uv4si */
    case 3829:  /* mve_vminvq_p_sv4si */
    case 3828:  /* mve_vminvq_p_uv8hi */
    case 3827:  /* mve_vminvq_p_sv8hi */
    case 3826:  /* mve_vminvq_p_uv16qi */
    case 3825:  /* mve_vminvq_p_sv16qi */
    case 3824:  /* mve_vminavq_p_sv4si */
    case 3823:  /* mve_vminavq_p_sv8hi */
    case 3822:  /* mve_vminavq_p_sv16qi */
    case 3821:  /* mve_vminaq_m_sv4si */
    case 3820:  /* mve_vminaq_m_sv8hi */
    case 3819:  /* mve_vminaq_m_sv16qi */
    case 3818:  /* mve_vmaxvq_p_uv4si */
    case 3817:  /* mve_vmaxvq_p_sv4si */
    case 3816:  /* mve_vmaxvq_p_uv8hi */
    case 3815:  /* mve_vmaxvq_p_sv8hi */
    case 3814:  /* mve_vmaxvq_p_uv16qi */
    case 3813:  /* mve_vmaxvq_p_sv16qi */
    case 3812:  /* mve_vmaxavq_p_sv4si */
    case 3811:  /* mve_vmaxavq_p_sv8hi */
    case 3810:  /* mve_vmaxavq_p_sv16qi */
    case 3809:  /* mve_vmaxaq_m_sv4si */
    case 3808:  /* mve_vmaxaq_m_sv8hi */
    case 3807:  /* mve_vmaxaq_m_sv16qi */
    case 3806:  /* mve_vdupq_m_n_uv4si */
    case 3805:  /* mve_vdupq_m_n_sv4si */
    case 3804:  /* mve_vdupq_m_n_uv8hi */
    case 3803:  /* mve_vdupq_m_n_sv8hi */
    case 3802:  /* mve_vdupq_m_n_uv16qi */
    case 3801:  /* mve_vdupq_m_n_sv16qi */
    case 3800:  /* mve_vcmpneq_m_uv4si */
    case 3799:  /* mve_vcmpneq_m_sv4si */
    case 3798:  /* mve_vcmpneq_m_uv8hi */
    case 3797:  /* mve_vcmpneq_m_sv8hi */
    case 3796:  /* mve_vcmpneq_m_uv16qi */
    case 3795:  /* mve_vcmpneq_m_sv16qi */
    case 3794:  /* mve_vcmpneq_m_n_uv4si */
    case 3793:  /* mve_vcmpneq_m_n_sv4si */
    case 3792:  /* mve_vcmpneq_m_n_uv8hi */
    case 3791:  /* mve_vcmpneq_m_n_sv8hi */
    case 3790:  /* mve_vcmpneq_m_n_uv16qi */
    case 3789:  /* mve_vcmpneq_m_n_sv16qi */
    case 3788:  /* mve_vcmpltq_m_sv4si */
    case 3787:  /* mve_vcmpltq_m_sv8hi */
    case 3786:  /* mve_vcmpltq_m_sv16qi */
    case 3785:  /* mve_vcmpltq_m_n_sv4si */
    case 3784:  /* mve_vcmpltq_m_n_sv8hi */
    case 3783:  /* mve_vcmpltq_m_n_sv16qi */
    case 3782:  /* mve_vcmpleq_m_sv4si */
    case 3781:  /* mve_vcmpleq_m_sv8hi */
    case 3780:  /* mve_vcmpleq_m_sv16qi */
    case 3779:  /* mve_vcmpleq_m_n_sv4si */
    case 3778:  /* mve_vcmpleq_m_n_sv8hi */
    case 3777:  /* mve_vcmpleq_m_n_sv16qi */
    case 3776:  /* mve_vcmphiq_m_uv4si */
    case 3775:  /* mve_vcmphiq_m_uv8hi */
    case 3774:  /* mve_vcmphiq_m_uv16qi */
    case 3773:  /* mve_vcmphiq_m_n_uv4si */
    case 3772:  /* mve_vcmphiq_m_n_uv8hi */
    case 3771:  /* mve_vcmphiq_m_n_uv16qi */
    case 3770:  /* mve_vcmpgtq_m_sv4si */
    case 3769:  /* mve_vcmpgtq_m_sv8hi */
    case 3768:  /* mve_vcmpgtq_m_sv16qi */
    case 3767:  /* mve_vcmpgtq_m_n_sv4si */
    case 3766:  /* mve_vcmpgtq_m_n_sv8hi */
    case 3765:  /* mve_vcmpgtq_m_n_sv16qi */
    case 3764:  /* mve_vcmpgeq_m_sv4si */
    case 3763:  /* mve_vcmpgeq_m_sv8hi */
    case 3762:  /* mve_vcmpgeq_m_sv16qi */
    case 3761:  /* mve_vcmpgeq_m_n_sv4si */
    case 3760:  /* mve_vcmpgeq_m_n_sv8hi */
    case 3759:  /* mve_vcmpgeq_m_n_sv16qi */
    case 3758:  /* mve_vcmpeqq_m_uv4si */
    case 3757:  /* mve_vcmpeqq_m_sv4si */
    case 3756:  /* mve_vcmpeqq_m_uv8hi */
    case 3755:  /* mve_vcmpeqq_m_sv8hi */
    case 3754:  /* mve_vcmpeqq_m_uv16qi */
    case 3753:  /* mve_vcmpeqq_m_sv16qi */
    case 3752:  /* mve_vcmpeqq_m_n_uv4si */
    case 3751:  /* mve_vcmpeqq_m_n_sv4si */
    case 3750:  /* mve_vcmpeqq_m_n_uv8hi */
    case 3749:  /* mve_vcmpeqq_m_n_sv8hi */
    case 3748:  /* mve_vcmpeqq_m_n_uv16qi */
    case 3747:  /* mve_vcmpeqq_m_n_sv16qi */
    case 3746:  /* mve_vcmpcsq_m_uv4si */
    case 3745:  /* mve_vcmpcsq_m_uv8hi */
    case 3744:  /* mve_vcmpcsq_m_uv16qi */
    case 3743:  /* mve_vcmpcsq_m_n_uv4si */
    case 3742:  /* mve_vcmpcsq_m_n_uv8hi */
    case 3741:  /* mve_vcmpcsq_m_n_uv16qi */
    case 3740:  /* mve_vclzq_m_uv4si */
    case 3739:  /* mve_vclzq_m_sv4si */
    case 3738:  /* mve_vclzq_m_uv8hi */
    case 3737:  /* mve_vclzq_m_sv8hi */
    case 3736:  /* mve_vclzq_m_uv16qi */
    case 3735:  /* mve_vclzq_m_sv16qi */
    case 3734:  /* mve_vclsq_m_sv4si */
    case 3733:  /* mve_vclsq_m_sv8hi */
    case 3732:  /* mve_vclsq_m_sv16qi */
    case 3731:  /* mve_vaddvaq_p_uv4si */
    case 3730:  /* mve_vaddvaq_p_sv4si */
    case 3729:  /* mve_vaddvaq_p_uv8hi */
    case 3728:  /* mve_vaddvaq_p_sv8hi */
    case 3727:  /* mve_vaddvaq_p_uv16qi */
    case 3726:  /* mve_vaddvaq_p_sv16qi */
    case 3725:  /* mve_vabsq_m_sv4si */
    case 3724:  /* mve_vabsq_m_sv8hi */
    case 3723:  /* mve_vabsq_m_sv16qi */
    case 3702:  /* mve_vcvtq_m_to_f_uv4sf */
    case 3701:  /* mve_vcvtq_m_to_f_sv4sf */
    case 3700:  /* mve_vcvtq_m_to_f_uv8hf */
    case 3699:  /* mve_vcvtq_m_to_f_sv8hf */
    case 3698:  /* mve_vcvtaq_m_uv4si */
    case 3697:  /* mve_vcvtaq_m_sv4si */
    case 3696:  /* mve_vcvtaq_m_uv8hi */
    case 3695:  /* mve_vcvtaq_m_sv8hi */
    case 3694:  /* mve_vcmpeqq_m_fv4sf */
    case 3693:  /* mve_vcmpeqq_m_fv8hf */
    case 3692:  /* mve_vbicq_m_n_uv4si */
    case 3691:  /* mve_vbicq_m_n_sv4si */
    case 3690:  /* mve_vbicq_m_n_uv8hi */
    case 3689:  /* mve_vbicq_m_n_sv8hi */
    case 3599:  /* mve_vctp64q_mv2qi */
    case 3598:  /* mve_vctp32q_mv4bi */
    case 3597:  /* mve_vctp16q_mv8bi */
    case 3596:  /* mve_vctp8q_mv16bi */
    case 3278:  /* mve_vaddvq_p_sv4si */
    case 3277:  /* mve_vaddvq_p_uv4si */
    case 3276:  /* mve_vaddvq_p_sv8hi */
    case 3275:  /* mve_vaddvq_p_uv8hi */
    case 3274:  /* mve_vaddvq_p_sv16qi */
    case 3273:  /* mve_vaddvq_p_uv16qi */
    case 3206:  /* mve_vaddlvq_p_uv4si */
    case 3205:  /* mve_vaddlvq_p_sv4si */
    case 3188:  /* mve_vcreateq_sv2di */
    case 3187:  /* mve_vcreateq_uv2di */
    case 3186:  /* mve_vcreateq_sv4si */
    case 3185:  /* mve_vcreateq_uv4si */
    case 3184:  /* mve_vcreateq_sv8hi */
    case 3183:  /* mve_vcreateq_uv8hi */
    case 3182:  /* mve_vcreateq_sv16qi */
    case 3181:  /* mve_vcreateq_uv16qi */
    case 3180:  /* mve_vcreateq_fv4sf */
    case 3179:  /* mve_vcreateq_fv8hf */
    case 3059:  /* mve_vrndq_m_fv4sf */
    case 3058:  /* mve_vrndq_m_fv8hf */
    case 2860:  /* *aarch32_crypto_aesd_fused_protected */
    case 2859:  /* *aarch32_crypto_aesd_fused */
    case 2858:  /* *aarch32_crypto_aese_fused_protected */
    case 2857:  /* *aarch32_crypto_aese_fused */
    case 2813:  /* vec_pack_trunc_v2di */
    case 2812:  /* vec_pack_trunc_v4si */
    case 2811:  /* vec_pack_trunc_v8hi */
    case 2548:  /* neon_vld1_dupv2di */
    case 2053:  /* neon_vdup_nv2di */
    case 1027:  /* *thumb2_ior_scc_strict_it */
    case 1015:  /* *thumb2_mov_notscc_strict_it */
    case 1013:  /* *thumb2_mov_negscc_strict_it */
    case 994:  /* prologue_thumb1_interwork */
    case 865:  /* *combine_vcvt_f64_s32 */
    case 864:  /* *combine_vcvt_f64_u32 */
    case 506:  /* *speculation_barrier_insn */
    case 397:  /* consttable_8 */
    case 382:  /* *sign_extract_onebit */
    case 375:  /* *if_arith_not */
    case 373:  /* *if_not_arith */
    case 371:  /* *if_shift_shift */
    case 357:  /* *if_arith_arith */
    case 334:  /* *and_scc */
    case 304:  /* *check_arch2 */
    case 282:  /* *mov_notscc */
    case 281:  /* *mov_negscc */
    case 279:  /* *mov_scc */
    case 172:  /* *arm_neg_abssi2 */
    case 171:  /* *arm_abssi2 */
    case 161:  /* unaligned_storedi */
    case 157:  /* unaligned_loaddi */
    case 116:  /* *andsi_iorsi3_notsi */
    case 97:  /* *ite_ne_zeroextractsi_shifted */
    case 96:  /* *ite_ne_zeroextractsi */
    case 95:  /* *ne_zeroextractsi_shifted */
      return 8;

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x2c0ULL))
        {
	  return 8;
        }
      else if (which_alternative == 8)
        {
	  if (
#line 712 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(TARGET_VFP_SINGLE))
	    {
	      return 8;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else
        {
	  return 4;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 1)
        {
	  return 8;
        }
      else if (which_alternative == 2)
        {
	  return 12 /* 0xc */;
        }
      else if (which_alternative == 3)
        {
	  return 16 /* 0x10 */;
        }
      else if (((1ULL << which_alternative) & 0x70ULL))
        {
	  return 
#line 385 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(arm_count_output_move_double_insns (operands) * 4);
        }
      else if (which_alternative == 9)
        {
	  if (
#line 712 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(TARGET_VFP_SINGLE))
	    {
	      return 8;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else
        {
	  return 4;
        }

    case 6566:  /* *p *arm_strd */
    case 429:  /* *arm_strd */
      extract_constrain_insn_cached (insn);
      return 
#line 193 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/ldrdstrd.md"
(arm_count_ldrdstrd_insns (operands, false) * 4);

    case 6565:  /* *p *arm_ldrd */
    case 428:  /* *arm_ldrd */
      extract_constrain_insn_cached (insn);
      return 
#line 173 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/ldrdstrd.md"
(arm_count_ldrdstrd_insns (operands, true) * 4);

    case 6552:  /* *p *pop_multiple_with_return */
    case 388:  /* *pop_multiple_with_return */
      extract_constrain_insn_cached (insn);
      return 
#line 11992 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_attr_length_pop_multi (operands, /*return_pc=*/true,
						/*write_back_p=*/false));

    case 6551:  /* *p *pop_multiple_with_writeback_and_return */
    case 387:  /* *pop_multiple_with_writeback_and_return */
      extract_constrain_insn_cached (insn);
      return 
#line 11969 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_attr_length_pop_multi (operands, /*return_pc=*/true,
						/*write_back_p=*/true));

    case 6550:  /* *p *load_multiple_with_writeback */
    case 386:  /* *load_multiple_with_writeback */
      extract_constrain_insn_cached (insn);
      return 
#line 11936 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_attr_length_pop_multi (operands,
						/*return_pc=*/false,
						/*write_back_p=*/true));

    case 6549:  /* *p *arith_adjacentmem */
    case 6533:  /* *p *arm_return */
    case 1030:  /* *thumb2_cond_arith_strict_it */
    case 383:  /* *not_signextract_onebit */
    case 380:  /* *arith_adjacentmem */
    case 374:  /* *ifcompare_arith_not */
    case 372:  /* *ifcompare_not_arith */
    case 370:  /* *ifcompare_shift_shift */
    case 356:  /* *ifcompare_arith_arith */
    case 349:  /* *negscc */
    case 338:  /* *cond_arith */
    case 314:  /* *arm_casesi_internal */
    case 312:  /* stack_protect_set_tls */
    case 302:  /* *cond_simple_return_inverted */
    case 301:  /* *cond_return_inverted */
    case 300:  /* *cond_simple_return */
    case 299:  /* *cond_return */
    case 298:  /* *arm_return */
    case 293:  /* *call_value_reg_arm */
    case 291:  /* *call_reg_arm */
      return 12 /* 0xc */;

    case 6452:  /* *p *arm_extendqisi */
    case 6449:  /* *p *arm_extendhisi2 */
    case 6445:  /* *p *arm_zero_extendqisi2 */
    case 853:  /* lazy_load_multiple_insn */
    case 187:  /* *arm_extendqisi */
    case 183:  /* *arm_extendhisi2 */
    case 179:  /* *arm_zero_extendqisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else
        {
	  return 4;
        }

    case 12:  /* addsi3_compareV_imm_nosum */
    case 6355:  /* *p *compare_negsi_si */
    case 1053:  /* *thumb2_addsi3_compare0_scratch */
    case 169:  /* negsi2_0compare */
    case 54:  /* subvsi3_borrow */
    case 52:  /* usubvsi3_borrow */
    case 34:  /* cmpsi3_carryin_CC_Bout */
    case 33:  /* cmpsi3_carryin_CC_NVout */
    case 27:  /* subvsi3 */
    case 15:  /* *compare_negsi_si */
    case 9:  /* *addsi3_compareV_reg_nosum */
    case 4:  /* *addsi3_cin_cout_reg_insn */
    case 1:  /* *addsi3_cin_vout_reg_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 4903:  /* mve_vld4qv4sf */
    case 4902:  /* mve_vld4qv8hf */
    case 4901:  /* mve_vld4qv4si */
    case 4900:  /* mve_vld4qv8hi */
    case 4899:  /* mve_vld4qv16qi */
    case 3057:  /* mve_vst4qv4sf */
    case 3056:  /* mve_vst4qv8hf */
    case 3055:  /* mve_vst4qv4si */
    case 3054:  /* mve_vst4qv8hi */
    case 3053:  /* mve_vst4qv16qi */
    case 1040:  /* *thumb2_casesi_internal */
    case 398:  /* consttable_16 */
    case 347:  /* *and_scc_scc_cmp */
    case 346:  /* *and_scc_scc */
    case 345:  /* *ior_scc_scc_cmp */
    case 344:  /* *ior_scc_scc */
    case 313:  /* stack_protect_test_tls */
      return 16 /* 0x10 */;

    case 3035:  /* *arm_usmulusa3 */
    case 3034:  /* *arm_ssmulsa3 */
      extract_constrain_insn_cached (insn);
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  if (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))
	    {
	      return 40 /* 0x28 */;
	    }
	  else
	    {
	      return 38 /* 0x26 */;
	    }
        }
      else
        {
	  return 32 /* 0x20 */;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      return 
#line 196 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(arm_attr_length_move_neon (insn));

    case 1043:  /* *thumb2_cmse_entry_return */
      extract_constrain_insn_cached (insn);
      if (
#line 1225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb2.md"
(TARGET_HARD_FLOAT))
        {
	  return 34 /* 0x22 */;
        }
      else
        {
	  return 8;
        }

    case 1041:  /* *thumb2_casesi_internal_pic */
    case 348:  /* *and_scc_scc_nodom */
      return 20 /* 0x14 */;

    case 1032:  /* *thumb2_negscc */
    case 1029:  /* *thumb2_cond_arith */
      return 14 /* 0xe */;

    case 1031:  /* *thumb2_cond_sub */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 10 /* 0xa */;
        }
      else
        {
	  return 14 /* 0xe */;
        }

    case 1026:  /* *thumb2_ior_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 6;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 1025:  /* *thumb2_and_scc */
      extract_constrain_insn_cached (insn);
      if (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))
        {
	  return 8;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 1017:  /* *thumb2_movsfcc_soft_insn */
    case 951:  /* *thumb1_neg_abssi2 */
    case 950:  /* *thumb1_abssi2 */
    case 948:  /* *thumb1_negdi2 */
      return 6;

    case 1014:  /* *thumb2_mov_notscc */
    case 1012:  /* *thumb2_mov_negscc */
    case 999:  /* thumb1_stack_protect_test_insn */
      return 10 /* 0xa */;

    case 1011:  /* *thumb2_mov_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 995:  /* *epilogue_insns */
      extract_constrain_insn_cached (insn);
      if (
#line 1980 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb1.md"
(IS_CMSE_ENTRY (arm_current_func_type ())))
        {
	  return 48 /* 0x30 */;
        }
      else
        {
	  return 44 /* 0x2c */;
        }

    case 975:  /* *addsi3_cbranch */
      extract_constrain_insn_cached (insn);
      if ((
#line 1591 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb1.md"
(which_alternative)) < (2))
        {
	  return 4;
        }
      else
        {
	  return 6;
        }

    case 6940:  /* *p *thumb2_negsi2_short */
    case 6939:  /* *p *thumb2_one_cmplsi2_short */
    case 6938:  /* *p *thumb2_mulsi_short */
    case 6937:  /* *p *thumb2_subsi_short */
    case 6936:  /* *p *thumb2_addsi_short */
    case 6935:  /* *p *thumb2_movsi_shortim */
    case 6934:  /* *p *thumb2_movhi_shortim */
    case 6933:  /* *p *thumb2_movqi_shortim */
    case 6932:  /* *p *thumb2_shiftsi3_short */
    case 6931:  /* *p *thumb2_alusi3_short */
    case 6925:  /* *p *thumb2_pop_single */
    case 1060:  /* *thumb2_negsi2_short */
    case 1059:  /* *thumb2_one_cmplsi2_short */
    case 1056:  /* *thumb2_mulsi_short_compare0_scratch */
    case 1055:  /* *thumb2_mulsi_short_compare0 */
    case 1054:  /* *thumb2_mulsi_short */
    case 1051:  /* *thumb2_subsi_short */
    case 1050:  /* *thumb2_addsi_short */
    case 1049:  /* *thumb2_movsi_shortim */
    case 1048:  /* *thumb2_movhi_shortim */
    case 1047:  /* *thumb2_movqi_shortim */
    case 1046:  /* *thumb2_shiftsi3_short */
    case 1045:  /* *thumb2_alusi3_short */
    case 1006:  /* *thumb2_pop_single */
    case 997:  /* *thumb1_tablejump */
    case 996:  /* *thumb1_movpc_insn */
    case 993:  /* *thumb1_indirect_jump */
    case 987:  /* *call_value_reg_thumb1_v5 */
    case 984:  /* *call_reg_thumb1_v5 */
    case 977:  /* *thumb_cmpdi_zero */
    case 963:  /* *thumb1_movsf_insn */
    case 961:  /* *thumb1_movqi_insn */
    case 955:  /* *thumb1_zero_extendqisi2_v6 */
    case 952:  /* *thumb1_one_cmplsi2 */
    case 949:  /* *thumb1_negsi2 */
    case 947:  /* *thumb1_rotrsi3 */
    case 946:  /* *thumb1_lshrsi3 */
    case 945:  /* *thumb1_ashrsi3 */
    case 944:  /* *thumb1_ashlsi3 */
    case 943:  /* *thumb1_xorsi3_insn */
    case 942:  /* *thumb1_iorsi3_insn */
    case 941:  /* thumb1_bicsi3 */
    case 940:  /* *thumb1_andsi3_insn */
    case 939:  /* *thumb_mulsi3_v6 */
    case 937:  /* thumb1_subsi3_insn */
    case 261:  /* pic_add_dot_plus_four */
    case 6532:  /* *p *arm_jump */
    case 288:  /* *arm_jump */
    case 1058:  /* *thumb2_cbnz */
    case 1057:  /* *thumb2_cbz */
    case 983:  /* *thumb_jump */
    case 967:  /* thumb1_cbz */
      return 2;

    case 957:  /* thumb1_extendqisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (((
#line 83 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6)) == (
(IS_ARCH6_YES))))
	    {
	      return 2;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else if (which_alternative == 1)
        {
	  return 2;
        }
      else
        {
	  if (((
#line 83 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6)) == (
(IS_ARCH6_YES))))
	    {
	      return 4;
	    }
	  else
	    {
	      return 6;
	    }
        }

    case 956:  /* thumb1_extendhisi2 */
    case 953:  /* *thumb1_zero_extendhisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (((
#line 83 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6)) == (
(IS_ARCH6_YES))))
	    {
	      return 2;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else
        {
	  return 4;
        }

    case 954:  /* *thumb1_zero_extendqisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else
        {
	  return 2;
        }

    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x19ULL))
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 12 /* 0xc */;
        }
      else if (which_alternative == 2)
        {
	  return 16 /* 0x10 */;
        }
      else if (which_alternative == 12)
        {
	  if ((
#line 145 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/iwmmxt.md"
(TARGET_VFP_SINGLE)) == (1))
	    {
	      return 8;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else
        {
	  return 4;
        }

    case 403:  /* force_register_use */
    case 385:  /* stack_tie */
    case 305:  /* blockage */
    case 276:  /* *deleted_compare */
      return 0;

    case 384:  /* *push_multi */
      extract_constrain_insn_cached (insn);
      return 
#line 11899 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_attr_length_push_multi (operands[2], operands[1]));

    case 2852:  /* aes_op_protect */
    case 369:  /* *if_move_shift */
    case 367:  /* *if_shift_move */
    case 365:  /* *if_not_move */
    case 363:  /* *if_move_not */
    case 381:  /* *cond_move_not */
    case 361:  /* *if_move_arith */
    case 359:  /* *if_arith_move */
    case 335:  /* *ior_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 378:  /* *ifcompare_move_neg */
    case 376:  /* *ifcompare_neg_move */
    case 368:  /* *ifcompare_move_shift */
    case 366:  /* *ifcompare_shift_move */
    case 364:  /* *ifcompare_not_move */
    case 362:  /* *ifcompare_move_not */
    case 360:  /* *ifcompare_move_arith */
    case 358:  /* *ifcompare_arith_move */
    case 354:  /* *ifcompare_move_plus */
    case 352:  /* *ifcompare_plus_move */
    case 339:  /* *cond_sub */
    case 309:  /* *stack_protect_set_insn */
    case 121:  /* *arm_smin_insn */
    case 119:  /* *arm_smax_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else
        {
	  return 12 /* 0xc */;
        }

    case 318:  /* trap */
    case 317:  /* nop */
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 311:  /* arm_stack_protect_test_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 12 /* 0xc */;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 278:  /* *arm_cond_branch_reversed */
    case 277:  /* arm_cond_branch */
      extract_constrain_insn_cached (insn);
      if (
#line 8035 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(!TARGET_THUMB2))
        {
	  return 4;
        }
      else
        {
	  return 2;
        }

    case 258:  /* pic_load_addr_unified */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 6;
        }
      else
        {
	  return 4;
        }

    case 126:  /* *minmax_arithsi_non_canon */
    case 125:  /* *minmax_arithsi */
    case 124:  /* *store_minmaxsi */
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return 14 /* 0xe */;
        }
      else
        {
	  return 12 /* 0xc */;
        }

    case 112:  /* *iorsi3_compare0_scratch */
    case 111:  /* *iorsi3_compare0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else if (which_alternative == 1)
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 94:  /* *ne_zeroextractsi */
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return 12 /* 0xc */;
        }
      else
        {
	  return 8;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 4;

    }
}

int
insn_default_length (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 3045:  /* *mve_movv2df */
    case 3044:  /* *mve_movv4sf */
    case 3043:  /* *mve_movv8hf */
    case 3042:  /* *mve_movti */
    case 3041:  /* *mve_movv2di */
    case 3040:  /* *mve_movv4si */
    case 3039:  /* *mve_movv8hi */
    case 3038:  /* *mve_movv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return 4;
        }
      else if (which_alternative == 5)
        {
	  return 8;
        }
      else if (which_alternative == 6)
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else if (which_alternative == 1)
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x70ULL))
        {
	  return 8;
        }
      else if (which_alternative == 7)
        {
	  return 16 /* 0x10 */;
        }
      else if (which_alternative == 8)
        {
	  return 8;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7fULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 1036:  /* *thumb2_movcond */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 10 /* 0xa */;
        }
      else
        {
	  return 14 /* 0xe */;
        }

    case 1016:  /* *thumb2_movsicc_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x3cULL))
        {
	  return 6;
        }
      else if (which_alternative == 6)
        {
	  return 10 /* 0xa */;
        }
      else if (which_alternative == 7)
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0x700ULL))
        {
	  return 10 /* 0xa */;
        }
      else
        {
	  return 6;
        }

    case 1008:  /* tls_load_dot_plus_four */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else
        {
	  return 6;
        }

    case 1028:  /* *thumb2_cond_move */
    case 1003:  /* *thumb2_uminsi3 */
    case 1002:  /* *thumb32_umaxsi3 */
    case 1001:  /* *thumb2_sminsi3 */
    case 1000:  /* *thumb2_smaxsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 6;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 964:  /* *thumb_movdf_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return 2;
        }
      else if (which_alternative == 3)
        {
	  return 6;
        }
      else
        {
	  return 4;
        }

    case 962:  /* *thumb1_movhf */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 2;
        }
      else if (which_alternative == 2)
        {
	  return 6;
        }
      else
        {
	  return 2;
        }

    case 960:  /* *thumb1_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else if (which_alternative == 1)
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x3cULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 2;
        }
      else if (((1ULL << which_alternative) & 0x1cULL))
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return 2;
        }
      else if (which_alternative == 7)
        {
	  return 14 /* 0xe */;
        }
      else
        {
	  return 2;
        }

    case 958:  /* *thumb1_movdi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return 6;
        }
      else if (((1ULL << which_alternative) & 0x30ULL))
        {
	  return 2;
        }
      else if (which_alternative == 6)
        {
	  return 6;
        }
      else
        {
	  return 4;
        }

    case 938:  /* *thumb_mulsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else
        {
	  return 2;
        }

    case 935:  /* *thumb1_addsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7fULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 774:  /* *thumb2_movdfcc_vfp */
    case 772:  /* *thumb2_movsfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 6;
        }
      else if (which_alternative == 2)
        {
	  return 10 /* 0xa */;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return 6;
        }
      else if (which_alternative == 5)
        {
	  return 10 /* 0xa */;
        }
      else if (((1ULL << which_alternative) & 0xc0ULL))
        {
	  return 6;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 773:  /* *movdfcc_vfp */
    case 771:  /* *movsfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else if (which_alternative == 2)
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return 4;
        }
      else if (which_alternative == 5)
        {
	  return 8;
        }
      else if (((1ULL << which_alternative) & 0xc0ULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 766:  /* *movbf_vfp */
    case 765:  /* *movhf_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3fULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xffULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1ffULL))
        {
	  return 4;
        }
      else
        {
	  if (
#line 471 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(arm_arch_thumb2))
	    {
	      return 4;
	    }
	  else
	    {
	      return 8;
	    }
        }

    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 531:  /* *iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xffULL))
        {
	  return 4;
        }
      else if (which_alternative == 8)
        {
	  return 16 /* 0x10 */;
        }
      else
        {
	  return 4;
        }

    case 343:  /* *cmp_ior */
    case 342:  /* *cmp_and */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 6;
        }
      else if (((1ULL << which_alternative) & 0x1eULL))
        {
	  return 8;
        }
      else if (which_alternative == 5)
        {
	  return 6;
        }
      else
        {
	  if ((! (
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB))))
	    {
	      return 8;
	    }
	  else
	    {
	      return 10 /* 0xa */;
	    }
        }

    case 341:  /* *cmp_ite1 */
    case 340:  /* *cmp_ite0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 6;
        }
      else if (((1ULL << which_alternative) & 0x1eULL))
        {
	  return 8;
        }
      else
        {
	  if ((! (
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB))))
	    {
	      return 8;
	    }
	  else
	    {
	      return 10 /* 0xa */;
	    }
        }

    case 6859:  /* *p *negdf2_vfp */
    case 778:  /* *negdf2_vfp */
    case 355:  /* *if_move_plus */
    case 353:  /* *if_plus_move */
    case 337:  /* *cond_move */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 286:  /* *movsicc_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 6528:  /* *p *arm32_movbf */
    case 6527:  /* *p *arm32_movhf */
    case 269:  /* *arm32_movbf */
    case 268:  /* *arm32_movhf */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 6526:  /* *p *arm_movqi_insn */
    case 267:  /* *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return 4;
        }
      else if (which_alternative == 3)
        {
	  return 2;
        }
      else if (which_alternative == 4)
        {
	  return 4;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 6927:  /* *p *thumb2_movhi_insn */
    case 6926:  /* *p *thumb2_movsi_insn */
    case 6849:  /* *p *thumb2_movsi_vfp */
    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 1009:  /* *thumb2_movhi_insn */
    case 1007:  /* *thumb2_movsi_insn */
    case 759:  /* *thumb2_movsi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
    case 264:  /* *movsi_compare0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else if (which_alternative == 1)
        {
	  return 4;
        }
      else if (which_alternative == 2)
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 271:  /* *movdf_soft_insn */
    case 255:  /* *arm_movdi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 12 /* 0xc */;
        }
      else if (which_alternative == 2)
        {
	  return 16 /* 0x10 */;
        }
      else
        {
	  return 8;
        }

    case 351:  /* movcond */
    case 123:  /* *arm_uminsi3 */
    case 122:  /* *arm_umaxsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 8;
        }
      else
        {
	  return 12 /* 0xc */;
        }

    case 6410:  /* *p *arm_xorsi3 */
    case 113:  /* *arm_xorsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 6409:  /* *p *iorsi3_insn */
    case 110:  /* *iorsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 6397:  /* *p *arm_andsi3_insn */
    case 90:  /* *arm_andsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 6370:  /* *p *arm_subsi3_insn */
    case 45:  /* *arm_subsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xffULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 18:  /* *addsi3_compare_op2 */
    case 17:  /* addsi3_compare_op1 */
    case 11:  /* addsi3_compareV_imm */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 6558:  /* *p *arm_rev */
    case 6530:  /* *p *arm_cmpsi_insn */
    case 6433:  /* *p unaligned_storehi */
    case 6432:  /* *p unaligned_storesi */
    case 6431:  /* *p unaligned_loadhiu */
    case 6429:  /* *p unaligned_loadsi */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 1052:  /* thumb2_addsi3_compare0 */
    case 415:  /* arm_rev16si2_alt */
    case 414:  /* arm_rev16si2 */
    case 413:  /* *arm_rev16 */
    case 412:  /* *arm_revsh */
    case 411:  /* *arm_rev */
    case 272:  /* *arm_cmpsi_insn */
    case 163:  /* unaligned_storehi */
    case 162:  /* unaligned_storesi */
    case 160:  /* unaligned_loadhiu */
    case 158:  /* unaligned_loadsi */
    case 20:  /* *compare_addsi2_op1 */
    case 19:  /* *compare_addsi2_op0 */
    case 8:  /* addsi3_compareV_reg */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 6353:  /* *p *arm_addsi3 */
    case 7:  /* *arm_addsi3 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else if (((1ULL << which_alternative) & 0x7ffeULL))
        {
	  return 4;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 6940:  /* *p *thumb2_negsi2_short */
    case 6939:  /* *p *thumb2_one_cmplsi2_short */
    case 6938:  /* *p *thumb2_mulsi_short */
    case 6937:  /* *p *thumb2_subsi_short */
    case 6936:  /* *p *thumb2_addsi_short */
    case 6935:  /* *p *thumb2_movsi_shortim */
    case 6934:  /* *p *thumb2_movhi_shortim */
    case 6933:  /* *p *thumb2_movqi_shortim */
    case 6932:  /* *p *thumb2_shiftsi3_short */
    case 6931:  /* *p *thumb2_alusi3_short */
    case 6925:  /* *p *thumb2_pop_single */
    case 1060:  /* *thumb2_negsi2_short */
    case 1059:  /* *thumb2_one_cmplsi2_short */
    case 1056:  /* *thumb2_mulsi_short_compare0_scratch */
    case 1055:  /* *thumb2_mulsi_short_compare0 */
    case 1054:  /* *thumb2_mulsi_short */
    case 1051:  /* *thumb2_subsi_short */
    case 1050:  /* *thumb2_addsi_short */
    case 1049:  /* *thumb2_movsi_shortim */
    case 1048:  /* *thumb2_movhi_shortim */
    case 1047:  /* *thumb2_movqi_shortim */
    case 1046:  /* *thumb2_shiftsi3_short */
    case 1045:  /* *thumb2_alusi3_short */
    case 1006:  /* *thumb2_pop_single */
    case 997:  /* *thumb1_tablejump */
    case 996:  /* *thumb1_movpc_insn */
    case 993:  /* *thumb1_indirect_jump */
    case 987:  /* *call_value_reg_thumb1_v5 */
    case 984:  /* *call_reg_thumb1_v5 */
    case 977:  /* *thumb_cmpdi_zero */
    case 963:  /* *thumb1_movsf_insn */
    case 961:  /* *thumb1_movqi_insn */
    case 955:  /* *thumb1_zero_extendqisi2_v6 */
    case 952:  /* *thumb1_one_cmplsi2 */
    case 949:  /* *thumb1_negsi2 */
    case 947:  /* *thumb1_rotrsi3 */
    case 946:  /* *thumb1_lshrsi3 */
    case 945:  /* *thumb1_ashrsi3 */
    case 944:  /* *thumb1_ashlsi3 */
    case 943:  /* *thumb1_xorsi3_insn */
    case 942:  /* *thumb1_iorsi3_insn */
    case 941:  /* thumb1_bicsi3 */
    case 940:  /* *thumb1_andsi3_insn */
    case 939:  /* *thumb_mulsi3_v6 */
    case 937:  /* thumb1_subsi3_insn */
    case 261:  /* pic_add_dot_plus_four */
      return 2;

    case 6924:  /* *p *thumb2_neg_abssi2 */
    case 6923:  /* *p *thumb2_abssi2 */
    case 1005:  /* *thumb2_neg_abssi2 */
    case 1004:  /* *thumb2_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 6;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x2c0ULL))
        {
	  return 8;
        }
      else if (which_alternative == 8)
        {
	  if (
#line 712 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(TARGET_VFP_SINGLE))
	    {
	      return 8;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else
        {
	  return 4;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 1)
        {
	  return 8;
        }
      else if (which_alternative == 2)
        {
	  return 12 /* 0xc */;
        }
      else if (which_alternative == 3)
        {
	  return 16 /* 0x10 */;
        }
      else if (((1ULL << which_alternative) & 0x70ULL))
        {
	  return 
#line 385 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(arm_count_output_move_double_insns (operands) * 4);
        }
      else if (which_alternative == 9)
        {
	  if (
#line 712 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(TARGET_VFP_SINGLE))
	    {
	      return 8;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else
        {
	  return 4;
        }

    case 6566:  /* *p *arm_strd */
    case 429:  /* *arm_strd */
      extract_constrain_insn_cached (insn);
      return 
#line 193 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/ldrdstrd.md"
(arm_count_ldrdstrd_insns (operands, false) * 4);

    case 6565:  /* *p *arm_ldrd */
    case 428:  /* *arm_ldrd */
      extract_constrain_insn_cached (insn);
      return 
#line 173 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/ldrdstrd.md"
(arm_count_ldrdstrd_insns (operands, true) * 4);

    case 6552:  /* *p *pop_multiple_with_return */
    case 388:  /* *pop_multiple_with_return */
      extract_constrain_insn_cached (insn);
      return 
#line 11992 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_attr_length_pop_multi (operands, /*return_pc=*/true,
						/*write_back_p=*/false));

    case 6551:  /* *p *pop_multiple_with_writeback_and_return */
    case 387:  /* *pop_multiple_with_writeback_and_return */
      extract_constrain_insn_cached (insn);
      return 
#line 11969 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_attr_length_pop_multi (operands, /*return_pc=*/true,
						/*write_back_p=*/true));

    case 6550:  /* *p *load_multiple_with_writeback */
    case 386:  /* *load_multiple_with_writeback */
      extract_constrain_insn_cached (insn);
      return 
#line 11936 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_attr_length_pop_multi (operands,
						/*return_pc=*/false,
						/*write_back_p=*/true));

    case 6549:  /* *p *arith_adjacentmem */
    case 6533:  /* *p *arm_return */
    case 1030:  /* *thumb2_cond_arith_strict_it */
    case 383:  /* *not_signextract_onebit */
    case 380:  /* *arith_adjacentmem */
    case 374:  /* *ifcompare_arith_not */
    case 372:  /* *ifcompare_not_arith */
    case 370:  /* *ifcompare_shift_shift */
    case 356:  /* *ifcompare_arith_arith */
    case 349:  /* *negscc */
    case 338:  /* *cond_arith */
    case 314:  /* *arm_casesi_internal */
    case 312:  /* stack_protect_set_tls */
    case 302:  /* *cond_simple_return_inverted */
    case 301:  /* *cond_return_inverted */
    case 300:  /* *cond_simple_return */
    case 299:  /* *cond_return */
    case 298:  /* *arm_return */
    case 293:  /* *call_value_reg_arm */
    case 291:  /* *call_reg_arm */
      return 12 /* 0xc */;

    case 6452:  /* *p *arm_extendqisi */
    case 6449:  /* *p *arm_extendhisi2 */
    case 6445:  /* *p *arm_zero_extendqisi2 */
    case 853:  /* lazy_load_multiple_insn */
    case 187:  /* *arm_extendqisi */
    case 183:  /* *arm_extendhisi2 */
    case 179:  /* *arm_zero_extendqisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else
        {
	  return 4;
        }

    case 12:  /* addsi3_compareV_imm_nosum */
    case 6355:  /* *p *compare_negsi_si */
    case 1053:  /* *thumb2_addsi3_compare0_scratch */
    case 169:  /* negsi2_0compare */
    case 54:  /* subvsi3_borrow */
    case 52:  /* usubvsi3_borrow */
    case 34:  /* cmpsi3_carryin_CC_Bout */
    case 33:  /* cmpsi3_carryin_CC_NVout */
    case 27:  /* subvsi3 */
    case 15:  /* *compare_negsi_si */
    case 9:  /* *addsi3_compareV_reg_nosum */
    case 4:  /* *addsi3_cin_cout_reg_insn */
    case 1:  /* *addsi3_cin_vout_reg_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 4903:  /* mve_vld4qv4sf */
    case 4902:  /* mve_vld4qv8hf */
    case 4901:  /* mve_vld4qv4si */
    case 4900:  /* mve_vld4qv8hi */
    case 4899:  /* mve_vld4qv16qi */
    case 3057:  /* mve_vst4qv4sf */
    case 3056:  /* mve_vst4qv8hf */
    case 3055:  /* mve_vst4qv4si */
    case 3054:  /* mve_vst4qv8hi */
    case 3053:  /* mve_vst4qv16qi */
    case 1040:  /* *thumb2_casesi_internal */
    case 398:  /* consttable_16 */
    case 347:  /* *and_scc_scc_cmp */
    case 346:  /* *and_scc_scc */
    case 345:  /* *ior_scc_scc_cmp */
    case 344:  /* *ior_scc_scc */
    case 313:  /* stack_protect_test_tls */
      return 16 /* 0x10 */;

    case 3035:  /* *arm_usmulusa3 */
    case 3034:  /* *arm_ssmulsa3 */
      extract_constrain_insn_cached (insn);
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  if (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))
	    {
	      return 40 /* 0x28 */;
	    }
	  else
	    {
	      return 38 /* 0x26 */;
	    }
        }
      else
        {
	  return 32 /* 0x20 */;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      return 
#line 196 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(arm_attr_length_move_neon (insn));

    case 1043:  /* *thumb2_cmse_entry_return */
      extract_constrain_insn_cached (insn);
      if (
#line 1225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb2.md"
(TARGET_HARD_FLOAT))
        {
	  return 34 /* 0x22 */;
        }
      else
        {
	  return 8;
        }

    case 1041:  /* *thumb2_casesi_internal_pic */
    case 348:  /* *and_scc_scc_nodom */
      return 20 /* 0x14 */;

    case 1032:  /* *thumb2_negscc */
    case 1029:  /* *thumb2_cond_arith */
      return 14 /* 0xe */;

    case 1031:  /* *thumb2_cond_sub */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 10 /* 0xa */;
        }
      else
        {
	  return 14 /* 0xe */;
        }

    case 1026:  /* *thumb2_ior_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 6;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 1025:  /* *thumb2_and_scc */
      extract_constrain_insn_cached (insn);
      if (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))
        {
	  return 8;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 1068:  /* *doloop_end_internal */
    case 1017:  /* *thumb2_movsfcc_soft_insn */
    case 951:  /* *thumb1_neg_abssi2 */
    case 950:  /* *thumb1_abssi2 */
    case 948:  /* *thumb1_negdi2 */
      return 6;

    case 1014:  /* *thumb2_mov_notscc */
    case 1012:  /* *thumb2_mov_negscc */
    case 999:  /* thumb1_stack_protect_test_insn */
      return 10 /* 0xa */;

    case 974:  /* *cbranchne_decr1 */
    case 1011:  /* *thumb2_mov_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 995:  /* *epilogue_insns */
      extract_constrain_insn_cached (insn);
      if (
#line 1980 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb1.md"
(IS_CMSE_ENTRY (arm_current_func_type ())))
        {
	  return 48 /* 0x30 */;
        }
      else
        {
	  return 44 /* 0x2c */;
        }

    case 975:  /* *addsi3_cbranch */
      extract_constrain_insn_cached (insn);
      if ((
#line 1591 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb1.md"
(which_alternative)) < (2))
        {
	  return 8;
        }
      else
        {
	  return 10 /* 0xa */;
        }

    case 6915:  /* *p *combine_vcvt_f64_s32 */
    case 6914:  /* *p *combine_vcvt_f64_u32 */
    case 6440:  /* *p *arm_neg_abssi2 */
    case 6439:  /* *p *arm_abssi2 */
    case 6411:  /* *p *andsi_iorsi3_notsi */
    case 4953:  /* arm_vcx3qa_p_v16qi */
    case 4952:  /* arm_vcx3q_p_v16qi */
    case 4951:  /* arm_vcx2qa_p_v16qi */
    case 4950:  /* arm_vcx2q_p_v16qi */
    case 4949:  /* arm_vcx1qa_p_v16qi */
    case 4948:  /* arm_vcx1q_p_v16qi */
    case 4941:  /* mve_vshlcq_m_uv4si */
    case 4940:  /* mve_vshlcq_m_sv4si */
    case 4939:  /* mve_vshlcq_m_uv8hi */
    case 4938:  /* mve_vshlcq_m_sv8hi */
    case 4937:  /* mve_vshlcq_m_uv16qi */
    case 4936:  /* mve_vshlcq_m_sv16qi */
    case 4898:  /* mve_vld2qv4sf */
    case 4897:  /* mve_vld2qv8hf */
    case 4896:  /* mve_vld2qv4si */
    case 4895:  /* mve_vld2qv8hi */
    case 4894:  /* mve_vld2qv16qi */
    case 4893:  /* mve_vst2qv4sf */
    case 4892:  /* mve_vst2qv8hf */
    case 4891:  /* mve_vst2qv4si */
    case 4890:  /* mve_vst2qv8hi */
    case 4889:  /* mve_vst2qv16qi */
    case 4886:  /* mve_vsbcq_m_sv4si */
    case 4885:  /* mve_vsbcq_m_uv4si */
    case 4882:  /* mve_vsbciq_m_sv4si */
    case 4881:  /* mve_vsbciq_m_uv4si */
    case 4878:  /* mve_vadcq_m_sv4si */
    case 4877:  /* mve_vadcq_m_uv4si */
    case 4874:  /* mve_vadciq_m_sv4si */
    case 4873:  /* mve_vadciq_m_uv4si */
    case 4872:  /* mve_vldrdq_gather_base_wb_z_uv2di_insn */
    case 4871:  /* mve_vldrdq_gather_base_wb_z_sv2di_insn */
    case 4866:  /* mve_vldrwq_gather_base_wb_z_fv4sf_insn */
    case 4864:  /* mve_vldrwq_gather_base_wb_z_uv4si_insn */
    case 4863:  /* mve_vldrwq_gather_base_wb_z_sv4si_insn */
    case 4860:  /* mve_vstrdq_scatter_base_wb_p_uv2di */
    case 4859:  /* mve_vstrdq_scatter_base_wb_p_sv2di */
    case 4856:  /* mve_vstrwq_scatter_base_wb_p_fv4sf */
    case 4854:  /* mve_vstrwq_scatter_base_wb_p_uv4si */
    case 4853:  /* mve_vstrwq_scatter_base_wb_p_sv4si */
    case 4850:  /* mve_viwdupq_m_wb_uv4si_insn */
    case 4849:  /* mve_viwdupq_m_wb_uv8hi_insn */
    case 4848:  /* mve_viwdupq_m_wb_uv16qi_insn */
    case 4844:  /* mve_vdwdupq_m_wb_uv4si_insn */
    case 4843:  /* mve_vdwdupq_m_wb_uv8hi_insn */
    case 4842:  /* mve_vdwdupq_m_wb_uv16qi_insn */
    case 4838:  /* mve_vddupq_m_wb_uv4si_insn */
    case 4837:  /* mve_vddupq_m_wb_uv8hi_insn */
    case 4836:  /* mve_vddupq_m_wb_uv16qi_insn */
    case 4832:  /* mve_vidupq_m_wb_uv4si_insn */
    case 4831:  /* mve_vidupq_m_wb_uv8hi_insn */
    case 4830:  /* mve_vidupq_m_wb_uv16qi_insn */
    case 4819:  /* mve_vstrwq_scatter_shifted_offset_p_uv4si_insn */
    case 4818:  /* mve_vstrwq_scatter_shifted_offset_p_sv4si_insn */
    case 4817:  /* mve_vstrwq_scatter_shifted_offset_p_fv4sf_insn */
    case 4816:  /* mve_vstrwq_scatter_shifted_offset_fv4sf_insn */
    case 4813:  /* mve_vstrwq_scatter_offset_p_uv4si_insn */
    case 4812:  /* mve_vstrwq_scatter_offset_p_sv4si_insn */
    case 4811:  /* mve_vstrwq_scatter_offset_p_fv4sf_insn */
    case 4809:  /* mve_vstrwq_scatter_base_p_fv4sf */
    case 4807:  /* mve_vstrhq_scatter_shifted_offset_p_fv8hf_insn */
    case 4805:  /* mve_vstrhq_scatter_offset_p_fv8hf_insn */
    case 4801:  /* mve_vstrdq_scatter_shifted_offset_p_uv2di_insn */
    case 4800:  /* mve_vstrdq_scatter_shifted_offset_p_sv2di_insn */
    case 4797:  /* mve_vstrdq_scatter_offset_p_uv2di_insn */
    case 4796:  /* mve_vstrdq_scatter_offset_p_sv2di_insn */
    case 4793:  /* mve_vstrdq_scatter_base_p_uv2di */
    case 4792:  /* mve_vstrdq_scatter_base_p_sv2di */
    case 4789:  /* mve_vstrwq_p_uv4si */
    case 4788:  /* mve_vstrwq_p_sv4si */
    case 4787:  /* mve_vstrwq_p_fv4sf */
    case 4777:  /* mve_vstrhq_scatter_shifted_offset_p_uv4si_insn */
    case 4776:  /* mve_vstrhq_scatter_shifted_offset_p_sv4si_insn */
    case 4775:  /* mve_vstrhq_scatter_shifted_offset_p_uv8hi_insn */
    case 4774:  /* mve_vstrhq_scatter_shifted_offset_p_sv8hi_insn */
    case 4769:  /* mve_vstrhq_scatter_offset_p_uv4si_insn */
    case 4768:  /* mve_vstrhq_scatter_offset_p_sv4si_insn */
    case 4767:  /* mve_vstrhq_scatter_offset_p_uv8hi_insn */
    case 4766:  /* mve_vstrhq_scatter_offset_p_sv8hi_insn */
    case 4765:  /* mve_vstrhq_p_uv4si */
    case 4764:  /* mve_vstrhq_p_sv4si */
    case 4763:  /* mve_vstrhq_p_uv8hi */
    case 4762:  /* mve_vstrhq_p_sv8hi */
    case 4761:  /* mve_vstrhq_p_fv8hf */
    case 4759:  /* mve_vldrwq_gather_shifted_offset_z_uv4si */
    case 4758:  /* mve_vldrwq_gather_shifted_offset_z_sv4si */
    case 4757:  /* mve_vldrwq_gather_shifted_offset_z_fv4sf */
    case 4753:  /* mve_vldrwq_gather_offset_z_uv4si */
    case 4752:  /* mve_vldrwq_gather_offset_z_sv4si */
    case 4751:  /* mve_vldrwq_gather_offset_z_fv4sf */
    case 4747:  /* mve_vldrwq_gather_base_z_fv4sf */
    case 4745:  /* mve_vldrhq_gather_shifted_offset_z_fv8hf */
    case 4743:  /* mve_vldrhq_gather_offset_z_fv8hf */
    case 4741:  /* mve_vldrdq_gather_shifted_offset_z_uv2di */
    case 4740:  /* mve_vldrdq_gather_shifted_offset_z_sv2di */
    case 4737:  /* mve_vldrdq_gather_offset_z_uv2di */
    case 4736:  /* mve_vldrdq_gather_offset_z_sv2di */
    case 4733:  /* mve_vldrdq_gather_base_z_uv2di */
    case 4732:  /* mve_vldrdq_gather_base_z_sv2di */
    case 4729:  /* mve_vldrwq_z_uv4si */
    case 4728:  /* mve_vldrwq_z_sv4si */
    case 4727:  /* mve_vldrwq_z_fv4sf */
    case 4723:  /* mve_vldrhq_z_uv4si */
    case 4722:  /* mve_vldrhq_z_sv4si */
    case 4721:  /* mve_vldrhq_z_uv8hi */
    case 4720:  /* mve_vldrhq_z_sv8hi */
    case 4719:  /* mve_vldrhq_z_fv8hf */
    case 4714:  /* mve_vldrhq_gather_shifted_offset_z_uv4si */
    case 4713:  /* mve_vldrhq_gather_shifted_offset_z_sv4si */
    case 4712:  /* mve_vldrhq_gather_shifted_offset_z_uv8hi */
    case 4711:  /* mve_vldrhq_gather_shifted_offset_z_sv8hi */
    case 4706:  /* mve_vldrhq_gather_offset_z_uv4si */
    case 4705:  /* mve_vldrhq_gather_offset_z_sv4si */
    case 4704:  /* mve_vldrhq_gather_offset_z_uv8hi */
    case 4703:  /* mve_vldrhq_gather_offset_z_sv8hi */
    case 4697:  /* mve_vldrwq_gather_base_z_uv4si */
    case 4696:  /* mve_vldrwq_gather_base_z_sv4si */
    case 4695:  /* mve_vldrbq_z_uv4si */
    case 4694:  /* mve_vldrbq_z_sv4si */
    case 4693:  /* mve_vldrbq_z_uv8hi */
    case 4692:  /* mve_vldrbq_z_sv8hi */
    case 4691:  /* mve_vldrbq_z_uv16qi */
    case 4690:  /* mve_vldrbq_z_sv16qi */
    case 4689:  /* mve_vldrbq_gather_offset_z_uv4si */
    case 4688:  /* mve_vldrbq_gather_offset_z_sv4si */
    case 4687:  /* mve_vldrbq_gather_offset_z_uv8hi */
    case 4686:  /* mve_vldrbq_gather_offset_z_sv8hi */
    case 4685:  /* mve_vldrbq_gather_offset_z_uv16qi */
    case 4684:  /* mve_vldrbq_gather_offset_z_sv16qi */
    case 4683:  /* mve_vstrbq_p_uv4si */
    case 4682:  /* mve_vstrbq_p_sv4si */
    case 4681:  /* mve_vstrbq_p_uv8hi */
    case 4680:  /* mve_vstrbq_p_sv8hi */
    case 4679:  /* mve_vstrbq_p_uv16qi */
    case 4678:  /* mve_vstrbq_p_sv16qi */
    case 4677:  /* mve_vstrwq_scatter_base_p_uv4si */
    case 4676:  /* mve_vstrwq_scatter_base_p_sv4si */
    case 4675:  /* mve_vstrbq_scatter_offset_p_uv4si_insn */
    case 4674:  /* mve_vstrbq_scatter_offset_p_sv4si_insn */
    case 4673:  /* mve_vstrbq_scatter_offset_p_uv8hi_insn */
    case 4672:  /* mve_vstrbq_scatter_offset_p_sv8hi_insn */
    case 4671:  /* mve_vstrbq_scatter_offset_p_uv16qi_insn */
    case 4670:  /* mve_vstrbq_scatter_offset_p_sv16qi_insn */
    case 4641:  /* mve_vsubq_m_n_fv4sf */
    case 4640:  /* mve_vsubq_m_n_fv8hf */
    case 4639:  /* mve_vsubq_m_fv4sf */
    case 4638:  /* mve_vsubq_m_fv8hf */
    case 4637:  /* mve_vorrq_m_fv4sf */
    case 4636:  /* mve_vorrq_m_fv8hf */
    case 4635:  /* mve_vornq_m_fv4sf */
    case 4634:  /* mve_vornq_m_fv8hf */
    case 4633:  /* mve_vmulq_m_n_fv4sf */
    case 4632:  /* mve_vmulq_m_n_fv8hf */
    case 4631:  /* mve_vmulq_m_fv4sf */
    case 4630:  /* mve_vmulq_m_fv8hf */
    case 4629:  /* mve_vminnmq_m_fv4sf */
    case 4628:  /* mve_vminnmq_m_fv8hf */
    case 4627:  /* mve_vmaxnmq_m_fv4sf */
    case 4626:  /* mve_vmaxnmq_m_fv8hf */
    case 4625:  /* mve_vfmsq_m_fv4sf */
    case 4624:  /* mve_vfmsq_m_fv8hf */
    case 4623:  /* mve_vfmasq_m_n_fv4sf */
    case 4622:  /* mve_vfmasq_m_n_fv8hf */
    case 4621:  /* mve_vfmaq_m_n_fv4sf */
    case 4620:  /* mve_vfmaq_m_n_fv8hf */
    case 4619:  /* mve_vfmaq_m_fv4sf */
    case 4618:  /* mve_vfmaq_m_fv8hf */
    case 4617:  /* mve_veorq_m_fv4sf */
    case 4616:  /* mve_veorq_m_fv8hf */
    case 4615:  /* mve_vcmulq_rot90_m_fv4sf */
    case 4614:  /* mve_vcmulq_rot90_m_fv8hf */
    case 4613:  /* mve_vcmulq_rot270_m_fv4sf */
    case 4612:  /* mve_vcmulq_rot270_m_fv8hf */
    case 4611:  /* mve_vcmulq_rot180_m_fv4sf */
    case 4610:  /* mve_vcmulq_rot180_m_fv8hf */
    case 4609:  /* mve_vcmulq_m_fv4sf */
    case 4608:  /* mve_vcmulq_m_fv8hf */
    case 4607:  /* mve_vcmlaq_rot90_m_fv4sf */
    case 4606:  /* mve_vcmlaq_rot90_m_fv8hf */
    case 4605:  /* mve_vcmlaq_rot270_m_fv4sf */
    case 4604:  /* mve_vcmlaq_rot270_m_fv8hf */
    case 4603:  /* mve_vcmlaq_rot180_m_fv4sf */
    case 4602:  /* mve_vcmlaq_rot180_m_fv8hf */
    case 4601:  /* mve_vcmlaq_m_fv4sf */
    case 4600:  /* mve_vcmlaq_m_fv8hf */
    case 4599:  /* mve_vcaddq_rot90_m_fv4sf */
    case 4598:  /* mve_vcaddq_rot90_m_fv8hf */
    case 4597:  /* mve_vcaddq_rot270_m_fv4sf */
    case 4596:  /* mve_vcaddq_rot270_m_fv8hf */
    case 4595:  /* mve_vbrsrq_m_n_fv4sf */
    case 4594:  /* mve_vbrsrq_m_n_fv8hf */
    case 4593:  /* mve_vbicq_m_fv4sf */
    case 4592:  /* mve_vbicq_m_fv8hf */
    case 4591:  /* mve_vandq_m_fv4sf */
    case 4590:  /* mve_vandq_m_fv8hf */
    case 4589:  /* mve_vaddq_m_n_fv4sf */
    case 4588:  /* mve_vaddq_m_n_fv8hf */
    case 4587:  /* mve_vaddq_m_fv4sf */
    case 4586:  /* mve_vaddq_m_fv8hf */
    case 4585:  /* mve_vabdq_m_fv4sf */
    case 4584:  /* mve_vabdq_m_fv8hf */
    case 4583:  /* mve_vrmlsldavhaxq_p_sv4si */
    case 4582:  /* mve_vrmlsldavhaq_p_sv4si */
    case 4581:  /* mve_vrmlaldavhaxq_p_sv4si */
    case 4580:  /* mve_vrmlaldavhaq_p_uv4si */
    case 4579:  /* mve_vqshruntq_m_n_sv4si */
    case 4578:  /* mve_vqshruntq_m_n_sv8hi */
    case 4577:  /* mve_vqshrunbq_m_n_sv4si */
    case 4576:  /* mve_vqshrunbq_m_n_sv8hi */
    case 4575:  /* mve_vqrshruntq_m_n_sv4si */
    case 4574:  /* mve_vqrshruntq_m_n_sv8hi */
    case 4573:  /* mve_vqrshrunbq_m_n_sv4si */
    case 4572:  /* mve_vqrshrunbq_m_n_sv8hi */
    case 4571:  /* mve_vqdmulltq_m_sv4si */
    case 4570:  /* mve_vqdmulltq_m_sv8hi */
    case 4569:  /* mve_vqdmulltq_m_n_sv4si */
    case 4568:  /* mve_vqdmulltq_m_n_sv8hi */
    case 4567:  /* mve_vqdmullbq_m_sv4si */
    case 4566:  /* mve_vqdmullbq_m_sv8hi */
    case 4565:  /* mve_vqdmullbq_m_n_sv4si */
    case 4564:  /* mve_vqdmullbq_m_n_sv8hi */
    case 4563:  /* mve_vmulltq_poly_m_pv8hi */
    case 4562:  /* mve_vmulltq_poly_m_pv16qi */
    case 4561:  /* mve_vmullbq_poly_m_pv8hi */
    case 4560:  /* mve_vmullbq_poly_m_pv16qi */
    case 4559:  /* mve_vmlsldavaxq_p_sv4si */
    case 4558:  /* mve_vmlsldavaxq_p_sv8hi */
    case 4557:  /* mve_vmlsldavaq_p_sv4si */
    case 4556:  /* mve_vmlsldavaq_p_sv8hi */
    case 4555:  /* mve_vshrntq_m_n_uv4si */
    case 4554:  /* mve_vshrntq_m_n_sv4si */
    case 4553:  /* mve_vshrntq_m_n_uv8hi */
    case 4552:  /* mve_vshrntq_m_n_sv8hi */
    case 4551:  /* mve_vshrnbq_m_n_uv4si */
    case 4550:  /* mve_vshrnbq_m_n_sv4si */
    case 4549:  /* mve_vshrnbq_m_n_uv8hi */
    case 4548:  /* mve_vshrnbq_m_n_sv8hi */
    case 4547:  /* mve_vshlltq_m_n_sv8hi */
    case 4546:  /* mve_vshlltq_m_n_uv8hi */
    case 4545:  /* mve_vshlltq_m_n_sv16qi */
    case 4544:  /* mve_vshlltq_m_n_uv16qi */
    case 4543:  /* mve_vshllbq_m_n_sv8hi */
    case 4542:  /* mve_vshllbq_m_n_uv8hi */
    case 4541:  /* mve_vshllbq_m_n_sv16qi */
    case 4540:  /* mve_vshllbq_m_n_uv16qi */
    case 4539:  /* mve_vrshrntq_m_n_sv4si */
    case 4538:  /* mve_vrshrntq_m_n_uv4si */
    case 4537:  /* mve_vrshrntq_m_n_sv8hi */
    case 4536:  /* mve_vrshrntq_m_n_uv8hi */
    case 4535:  /* mve_vrshrnbq_m_n_sv4si */
    case 4534:  /* mve_vrshrnbq_m_n_uv4si */
    case 4533:  /* mve_vrshrnbq_m_n_sv8hi */
    case 4532:  /* mve_vrshrnbq_m_n_uv8hi */
    case 4531:  /* mve_vrmlaldavhaq_p_sv4si */
    case 4530:  /* mve_vqshrntq_m_n_uv4si */
    case 4529:  /* mve_vqshrntq_m_n_sv4si */
    case 4528:  /* mve_vqshrntq_m_n_uv8hi */
    case 4527:  /* mve_vqshrntq_m_n_sv8hi */
    case 4526:  /* mve_vqshrnbq_m_n_sv4si */
    case 4525:  /* mve_vqshrnbq_m_n_uv4si */
    case 4524:  /* mve_vqshrnbq_m_n_sv8hi */
    case 4523:  /* mve_vqshrnbq_m_n_uv8hi */
    case 4522:  /* mve_vqrshrntq_m_n_uv4si */
    case 4521:  /* mve_vqrshrntq_m_n_sv4si */
    case 4520:  /* mve_vqrshrntq_m_n_uv8hi */
    case 4519:  /* mve_vqrshrntq_m_n_sv8hi */
    case 4518:  /* mve_vqrshrnbq_m_n_sv4si */
    case 4517:  /* mve_vqrshrnbq_m_n_uv4si */
    case 4516:  /* mve_vqrshrnbq_m_n_sv8hi */
    case 4515:  /* mve_vqrshrnbq_m_n_uv8hi */
    case 4514:  /* mve_vmlaldavaxq_p_sv4si */
    case 4513:  /* mve_vmlaldavaxq_p_sv8hi */
    case 4512:  /* mve_vmlaldavaq_p_sv4si */
    case 4511:  /* mve_vmlaldavaq_p_uv4si */
    case 4510:  /* mve_vmlaldavaq_p_sv8hi */
    case 4509:  /* mve_vmlaldavaq_p_uv8hi */
    case 4508:  /* mve_vqrdmulhq_m_sv4si */
    case 4507:  /* mve_vqrdmulhq_m_sv8hi */
    case 4506:  /* mve_vqrdmulhq_m_sv16qi */
    case 4505:  /* mve_vqrdmulhq_m_n_sv4si */
    case 4504:  /* mve_vqrdmulhq_m_n_sv8hi */
    case 4503:  /* mve_vqrdmulhq_m_n_sv16qi */
    case 4502:  /* mve_vqrdmlsdhxq_m_sv4si */
    case 4501:  /* mve_vqrdmlsdhxq_m_sv8hi */
    case 4500:  /* mve_vqrdmlsdhxq_m_sv16qi */
    case 4499:  /* mve_vqrdmlsdhq_m_sv4si */
    case 4498:  /* mve_vqrdmlsdhq_m_sv8hi */
    case 4497:  /* mve_vqrdmlsdhq_m_sv16qi */
    case 4496:  /* mve_vqrdmladhxq_m_sv4si */
    case 4495:  /* mve_vqrdmladhxq_m_sv8hi */
    case 4494:  /* mve_vqrdmladhxq_m_sv16qi */
    case 4493:  /* mve_vqrdmladhq_m_sv4si */
    case 4492:  /* mve_vqrdmladhq_m_sv8hi */
    case 4491:  /* mve_vqrdmladhq_m_sv16qi */
    case 4490:  /* mve_vqdmulhq_m_sv4si */
    case 4489:  /* mve_vqdmulhq_m_sv8hi */
    case 4488:  /* mve_vqdmulhq_m_sv16qi */
    case 4487:  /* mve_vqdmulhq_m_n_sv4si */
    case 4486:  /* mve_vqdmulhq_m_n_sv8hi */
    case 4485:  /* mve_vqdmulhq_m_n_sv16qi */
    case 4484:  /* mve_vqdmlsdhxq_m_sv4si */
    case 4483:  /* mve_vqdmlsdhxq_m_sv8hi */
    case 4482:  /* mve_vqdmlsdhxq_m_sv16qi */
    case 4481:  /* mve_vqdmlsdhq_m_sv4si */
    case 4480:  /* mve_vqdmlsdhq_m_sv8hi */
    case 4479:  /* mve_vqdmlsdhq_m_sv16qi */
    case 4478:  /* mve_vqdmladhxq_m_sv4si */
    case 4477:  /* mve_vqdmladhxq_m_sv8hi */
    case 4476:  /* mve_vqdmladhxq_m_sv16qi */
    case 4475:  /* mve_vqdmladhq_m_sv4si */
    case 4474:  /* mve_vqdmladhq_m_sv8hi */
    case 4473:  /* mve_vqdmladhq_m_sv16qi */
    case 4472:  /* mve_vmlsdavaxq_p_sv4si */
    case 4471:  /* mve_vmlsdavaxq_p_sv8hi */
    case 4470:  /* mve_vmlsdavaxq_p_sv16qi */
    case 4469:  /* mve_vmlsdavaq_p_sv4si */
    case 4468:  /* mve_vmlsdavaq_p_sv8hi */
    case 4467:  /* mve_vmlsdavaq_p_sv16qi */
    case 4466:  /* mve_vmladavaxq_p_sv4si */
    case 4465:  /* mve_vmladavaxq_p_sv8hi */
    case 4464:  /* mve_vmladavaxq_p_sv16qi */
    case 4463:  /* mve_vhcaddq_rot90_m_sv4si */
    case 4462:  /* mve_vhcaddq_rot90_m_sv8hi */
    case 4461:  /* mve_vhcaddq_rot90_m_sv16qi */
    case 4460:  /* mve_vhcaddq_rot270_m_sv4si */
    case 4459:  /* mve_vhcaddq_rot270_m_sv8hi */
    case 4458:  /* mve_vhcaddq_rot270_m_sv16qi */
    case 4457:  /* mve_vsubq_m_n_uv4si */
    case 4456:  /* mve_vsubq_m_n_sv4si */
    case 4455:  /* mve_vsubq_m_n_uv8hi */
    case 4454:  /* mve_vsubq_m_n_sv8hi */
    case 4453:  /* mve_vsubq_m_n_uv16qi */
    case 4452:  /* mve_vsubq_m_n_sv16qi */
    case 4451:  /* mve_vsliq_m_n_sv4si */
    case 4450:  /* mve_vsliq_m_n_uv4si */
    case 4449:  /* mve_vsliq_m_n_sv8hi */
    case 4448:  /* mve_vsliq_m_n_uv8hi */
    case 4447:  /* mve_vsliq_m_n_sv16qi */
    case 4446:  /* mve_vsliq_m_n_uv16qi */
    case 4445:  /* mve_vshrq_m_n_uv4si */
    case 4444:  /* mve_vshrq_m_n_sv4si */
    case 4443:  /* mve_vshrq_m_n_uv8hi */
    case 4442:  /* mve_vshrq_m_n_sv8hi */
    case 4441:  /* mve_vshrq_m_n_uv16qi */
    case 4440:  /* mve_vshrq_m_n_sv16qi */
    case 4439:  /* mve_vshlq_m_n_uv4si */
    case 4438:  /* mve_vshlq_m_n_sv4si */
    case 4437:  /* mve_vshlq_m_n_uv8hi */
    case 4436:  /* mve_vshlq_m_n_sv8hi */
    case 4435:  /* mve_vshlq_m_n_uv16qi */
    case 4434:  /* mve_vshlq_m_n_sv16qi */
    case 4433:  /* mve_vrshrq_m_n_uv4si */
    case 4432:  /* mve_vrshrq_m_n_sv4si */
    case 4431:  /* mve_vrshrq_m_n_uv8hi */
    case 4430:  /* mve_vrshrq_m_n_sv8hi */
    case 4429:  /* mve_vrshrq_m_n_uv16qi */
    case 4428:  /* mve_vrshrq_m_n_sv16qi */
    case 4427:  /* mve_vrshlq_m_uv4si */
    case 4426:  /* mve_vrshlq_m_sv4si */
    case 4425:  /* mve_vrshlq_m_uv8hi */
    case 4424:  /* mve_vrshlq_m_sv8hi */
    case 4423:  /* mve_vrshlq_m_uv16qi */
    case 4422:  /* mve_vrshlq_m_sv16qi */
    case 4421:  /* mve_vrmulhq_m_sv4si */
    case 4420:  /* mve_vrmulhq_m_uv4si */
    case 4419:  /* mve_vrmulhq_m_sv8hi */
    case 4418:  /* mve_vrmulhq_m_uv8hi */
    case 4417:  /* mve_vrmulhq_m_sv16qi */
    case 4416:  /* mve_vrmulhq_m_uv16qi */
    case 4415:  /* mve_vrhaddq_m_sv4si */
    case 4414:  /* mve_vrhaddq_m_uv4si */
    case 4413:  /* mve_vrhaddq_m_sv8hi */
    case 4412:  /* mve_vrhaddq_m_uv8hi */
    case 4411:  /* mve_vrhaddq_m_sv16qi */
    case 4410:  /* mve_vrhaddq_m_uv16qi */
    case 4409:  /* mve_vqsubq_m_sv4si */
    case 4408:  /* mve_vqsubq_m_uv4si */
    case 4407:  /* mve_vqsubq_m_sv8hi */
    case 4406:  /* mve_vqsubq_m_uv8hi */
    case 4405:  /* mve_vqsubq_m_sv16qi */
    case 4404:  /* mve_vqsubq_m_uv16qi */
    case 4403:  /* mve_vqsubq_m_n_sv4si */
    case 4402:  /* mve_vqsubq_m_n_uv4si */
    case 4401:  /* mve_vqsubq_m_n_sv8hi */
    case 4400:  /* mve_vqsubq_m_n_uv8hi */
    case 4399:  /* mve_vqsubq_m_n_sv16qi */
    case 4398:  /* mve_vqsubq_m_n_uv16qi */
    case 4397:  /* mve_vqshlq_m_sv4si */
    case 4396:  /* mve_vqshlq_m_uv4si */
    case 4395:  /* mve_vqshlq_m_sv8hi */
    case 4394:  /* mve_vqshlq_m_uv8hi */
    case 4393:  /* mve_vqshlq_m_sv16qi */
    case 4392:  /* mve_vqshlq_m_uv16qi */
    case 4391:  /* mve_vqshlq_m_n_uv4si */
    case 4390:  /* mve_vqshlq_m_n_sv4si */
    case 4389:  /* mve_vqshlq_m_n_uv8hi */
    case 4388:  /* mve_vqshlq_m_n_sv8hi */
    case 4387:  /* mve_vqshlq_m_n_uv16qi */
    case 4386:  /* mve_vqshlq_m_n_sv16qi */
    case 4385:  /* mve_vqrshlq_m_sv4si */
    case 4384:  /* mve_vqrshlq_m_uv4si */
    case 4383:  /* mve_vqrshlq_m_sv8hi */
    case 4382:  /* mve_vqrshlq_m_uv8hi */
    case 4381:  /* mve_vqrshlq_m_sv16qi */
    case 4380:  /* mve_vqrshlq_m_uv16qi */
    case 4379:  /* mve_vqrdmlashq_m_n_sv4si */
    case 4378:  /* mve_vqrdmlashq_m_n_sv8hi */
    case 4377:  /* mve_vqrdmlashq_m_n_sv16qi */
    case 4376:  /* mve_vqrdmlahq_m_n_sv4si */
    case 4375:  /* mve_vqrdmlahq_m_n_sv8hi */
    case 4374:  /* mve_vqrdmlahq_m_n_sv16qi */
    case 4373:  /* mve_vqdmlashq_m_n_sv4si */
    case 4372:  /* mve_vqdmlashq_m_n_sv8hi */
    case 4371:  /* mve_vqdmlashq_m_n_sv16qi */
    case 4370:  /* mve_vqdmlahq_m_n_sv4si */
    case 4369:  /* mve_vqdmlahq_m_n_sv8hi */
    case 4368:  /* mve_vqdmlahq_m_n_sv16qi */
    case 4367:  /* mve_vqaddq_m_sv4si */
    case 4366:  /* mve_vqaddq_m_uv4si */
    case 4365:  /* mve_vqaddq_m_sv8hi */
    case 4364:  /* mve_vqaddq_m_uv8hi */
    case 4363:  /* mve_vqaddq_m_sv16qi */
    case 4362:  /* mve_vqaddq_m_uv16qi */
    case 4361:  /* mve_vqaddq_m_n_sv4si */
    case 4360:  /* mve_vqaddq_m_n_uv4si */
    case 4359:  /* mve_vqaddq_m_n_sv8hi */
    case 4358:  /* mve_vqaddq_m_n_uv8hi */
    case 4357:  /* mve_vqaddq_m_n_sv16qi */
    case 4356:  /* mve_vqaddq_m_n_uv16qi */
    case 4355:  /* mve_vorrq_m_uv4si */
    case 4354:  /* mve_vorrq_m_sv4si */
    case 4353:  /* mve_vorrq_m_uv8hi */
    case 4352:  /* mve_vorrq_m_sv8hi */
    case 4351:  /* mve_vorrq_m_uv16qi */
    case 4350:  /* mve_vorrq_m_sv16qi */
    case 4349:  /* mve_vornq_m_sv4si */
    case 4348:  /* mve_vornq_m_uv4si */
    case 4347:  /* mve_vornq_m_sv8hi */
    case 4346:  /* mve_vornq_m_uv8hi */
    case 4345:  /* mve_vornq_m_sv16qi */
    case 4344:  /* mve_vornq_m_uv16qi */
    case 4343:  /* mve_vmulq_m_uv4si */
    case 4342:  /* mve_vmulq_m_sv4si */
    case 4341:  /* mve_vmulq_m_uv8hi */
    case 4340:  /* mve_vmulq_m_sv8hi */
    case 4339:  /* mve_vmulq_m_uv16qi */
    case 4338:  /* mve_vmulq_m_sv16qi */
    case 4337:  /* mve_vmulq_m_n_sv4si */
    case 4336:  /* mve_vmulq_m_n_uv4si */
    case 4335:  /* mve_vmulq_m_n_sv8hi */
    case 4334:  /* mve_vmulq_m_n_uv8hi */
    case 4333:  /* mve_vmulq_m_n_sv16qi */
    case 4332:  /* mve_vmulq_m_n_uv16qi */
    case 4331:  /* mve_vmulltq_int_m_uv4si */
    case 4330:  /* mve_vmulltq_int_m_sv4si */
    case 4329:  /* mve_vmulltq_int_m_uv8hi */
    case 4328:  /* mve_vmulltq_int_m_sv8hi */
    case 4327:  /* mve_vmulltq_int_m_uv16qi */
    case 4326:  /* mve_vmulltq_int_m_sv16qi */
    case 4325:  /* mve_vmullbq_int_m_sv4si */
    case 4324:  /* mve_vmullbq_int_m_uv4si */
    case 4323:  /* mve_vmullbq_int_m_sv8hi */
    case 4322:  /* mve_vmullbq_int_m_uv8hi */
    case 4321:  /* mve_vmullbq_int_m_sv16qi */
    case 4320:  /* mve_vmullbq_int_m_uv16qi */
    case 4319:  /* mve_vmulhq_m_uv4si */
    case 4318:  /* mve_vmulhq_m_sv4si */
    case 4317:  /* mve_vmulhq_m_uv8hi */
    case 4316:  /* mve_vmulhq_m_sv8hi */
    case 4315:  /* mve_vmulhq_m_uv16qi */
    case 4314:  /* mve_vmulhq_m_sv16qi */
    case 4313:  /* mve_vmlasq_m_n_sv4si */
    case 4312:  /* mve_vmlasq_m_n_uv4si */
    case 4311:  /* mve_vmlasq_m_n_sv8hi */
    case 4310:  /* mve_vmlasq_m_n_uv8hi */
    case 4309:  /* mve_vmlasq_m_n_sv16qi */
    case 4308:  /* mve_vmlasq_m_n_uv16qi */
    case 4307:  /* mve_vmlaq_m_n_uv4si */
    case 4306:  /* mve_vmlaq_m_n_sv4si */
    case 4305:  /* mve_vmlaq_m_n_uv8hi */
    case 4304:  /* mve_vmlaq_m_n_sv8hi */
    case 4303:  /* mve_vmlaq_m_n_uv16qi */
    case 4302:  /* mve_vmlaq_m_n_sv16qi */
    case 4301:  /* mve_vmladavaq_p_sv4si */
    case 4300:  /* mve_vmladavaq_p_uv4si */
    case 4299:  /* mve_vmladavaq_p_sv8hi */
    case 4298:  /* mve_vmladavaq_p_uv8hi */
    case 4297:  /* mve_vmladavaq_p_sv16qi */
    case 4296:  /* mve_vmladavaq_p_uv16qi */
    case 4295:  /* mve_vminq_m_uv4si */
    case 4294:  /* mve_vminq_m_sv4si */
    case 4293:  /* mve_vminq_m_uv8hi */
    case 4292:  /* mve_vminq_m_sv8hi */
    case 4291:  /* mve_vminq_m_uv16qi */
    case 4290:  /* mve_vminq_m_sv16qi */
    case 4289:  /* mve_vmaxq_m_uv4si */
    case 4288:  /* mve_vmaxq_m_sv4si */
    case 4287:  /* mve_vmaxq_m_uv8hi */
    case 4286:  /* mve_vmaxq_m_sv8hi */
    case 4285:  /* mve_vmaxq_m_uv16qi */
    case 4284:  /* mve_vmaxq_m_sv16qi */
    case 4283:  /* mve_vhsubq_m_uv4si */
    case 4282:  /* mve_vhsubq_m_sv4si */
    case 4281:  /* mve_vhsubq_m_uv8hi */
    case 4280:  /* mve_vhsubq_m_sv8hi */
    case 4279:  /* mve_vhsubq_m_uv16qi */
    case 4278:  /* mve_vhsubq_m_sv16qi */
    case 4277:  /* mve_vhsubq_m_n_uv4si */
    case 4276:  /* mve_vhsubq_m_n_sv4si */
    case 4275:  /* mve_vhsubq_m_n_uv8hi */
    case 4274:  /* mve_vhsubq_m_n_sv8hi */
    case 4273:  /* mve_vhsubq_m_n_uv16qi */
    case 4272:  /* mve_vhsubq_m_n_sv16qi */
    case 4271:  /* mve_vhaddq_m_uv4si */
    case 4270:  /* mve_vhaddq_m_sv4si */
    case 4269:  /* mve_vhaddq_m_uv8hi */
    case 4268:  /* mve_vhaddq_m_sv8hi */
    case 4267:  /* mve_vhaddq_m_uv16qi */
    case 4266:  /* mve_vhaddq_m_sv16qi */
    case 4265:  /* mve_vhaddq_m_n_uv4si */
    case 4264:  /* mve_vhaddq_m_n_sv4si */
    case 4263:  /* mve_vhaddq_m_n_uv8hi */
    case 4262:  /* mve_vhaddq_m_n_sv8hi */
    case 4261:  /* mve_vhaddq_m_n_uv16qi */
    case 4260:  /* mve_vhaddq_m_n_sv16qi */
    case 4259:  /* mve_veorq_m_uv4si */
    case 4258:  /* mve_veorq_m_sv4si */
    case 4257:  /* mve_veorq_m_uv8hi */
    case 4256:  /* mve_veorq_m_sv8hi */
    case 4255:  /* mve_veorq_m_uv16qi */
    case 4254:  /* mve_veorq_m_sv16qi */
    case 4253:  /* mve_vcaddq_rot90_m_sv4si */
    case 4252:  /* mve_vcaddq_rot90_m_uv4si */
    case 4251:  /* mve_vcaddq_rot90_m_sv8hi */
    case 4250:  /* mve_vcaddq_rot90_m_uv8hi */
    case 4249:  /* mve_vcaddq_rot90_m_sv16qi */
    case 4248:  /* mve_vcaddq_rot90_m_uv16qi */
    case 4247:  /* mve_vcaddq_rot270_m_sv4si */
    case 4246:  /* mve_vcaddq_rot270_m_uv4si */
    case 4245:  /* mve_vcaddq_rot270_m_sv8hi */
    case 4244:  /* mve_vcaddq_rot270_m_uv8hi */
    case 4243:  /* mve_vcaddq_rot270_m_sv16qi */
    case 4242:  /* mve_vcaddq_rot270_m_uv16qi */
    case 4241:  /* mve_vbrsrq_m_n_sv4si */
    case 4240:  /* mve_vbrsrq_m_n_uv4si */
    case 4239:  /* mve_vbrsrq_m_n_sv8hi */
    case 4238:  /* mve_vbrsrq_m_n_uv8hi */
    case 4237:  /* mve_vbrsrq_m_n_sv16qi */
    case 4236:  /* mve_vbrsrq_m_n_uv16qi */
    case 4235:  /* mve_vbicq_m_sv4si */
    case 4234:  /* mve_vbicq_m_uv4si */
    case 4233:  /* mve_vbicq_m_sv8hi */
    case 4232:  /* mve_vbicq_m_uv8hi */
    case 4231:  /* mve_vbicq_m_sv16qi */
    case 4230:  /* mve_vbicq_m_uv16qi */
    case 4229:  /* mve_vandq_m_sv4si */
    case 4228:  /* mve_vandq_m_uv4si */
    case 4227:  /* mve_vandq_m_sv8hi */
    case 4226:  /* mve_vandq_m_uv8hi */
    case 4225:  /* mve_vandq_m_sv16qi */
    case 4224:  /* mve_vandq_m_uv16qi */
    case 4223:  /* mve_vaddq_m_sv4si */
    case 4222:  /* mve_vaddq_m_uv4si */
    case 4221:  /* mve_vaddq_m_sv8hi */
    case 4220:  /* mve_vaddq_m_uv8hi */
    case 4219:  /* mve_vaddq_m_sv16qi */
    case 4218:  /* mve_vaddq_m_uv16qi */
    case 4217:  /* mve_vaddq_m_n_uv4si */
    case 4216:  /* mve_vaddq_m_n_sv4si */
    case 4215:  /* mve_vaddq_m_n_uv8hi */
    case 4214:  /* mve_vaddq_m_n_sv8hi */
    case 4213:  /* mve_vaddq_m_n_uv16qi */
    case 4212:  /* mve_vaddq_m_n_sv16qi */
    case 4211:  /* mve_vabdq_m_uv4si */
    case 4210:  /* mve_vabdq_m_sv4si */
    case 4209:  /* mve_vabdq_m_uv8hi */
    case 4208:  /* mve_vabdq_m_sv8hi */
    case 4207:  /* mve_vabdq_m_uv16qi */
    case 4206:  /* mve_vabdq_m_sv16qi */
    case 4205:  /* mve_vcvtq_m_n_to_f_sv4sf */
    case 4204:  /* mve_vcvtq_m_n_to_f_uv4sf */
    case 4203:  /* mve_vcvtq_m_n_to_f_sv8hf */
    case 4202:  /* mve_vcvtq_m_n_to_f_uv8hf */
    case 4201:  /* mve_vsubq_m_sv4si */
    case 4200:  /* mve_vsubq_m_uv4si */
    case 4199:  /* mve_vsubq_m_sv8hi */
    case 4198:  /* mve_vsubq_m_uv8hi */
    case 4197:  /* mve_vsubq_m_sv16qi */
    case 4196:  /* mve_vsubq_m_uv16qi */
    case 4195:  /* mve_vsriq_m_n_uv4si */
    case 4194:  /* mve_vsriq_m_n_sv4si */
    case 4193:  /* mve_vsriq_m_n_uv8hi */
    case 4192:  /* mve_vsriq_m_n_sv8hi */
    case 4191:  /* mve_vsriq_m_n_uv16qi */
    case 4190:  /* mve_vsriq_m_n_sv16qi */
    case 4189:  /* mve_vshlq_m_uv4si */
    case 4188:  /* mve_vshlq_m_sv4si */
    case 4187:  /* mve_vshlq_m_uv8hi */
    case 4186:  /* mve_vshlq_m_sv8hi */
    case 4185:  /* mve_vshlq_m_uv16qi */
    case 4184:  /* mve_vshlq_m_sv16qi */
    case 4183:  /* mve_vqshluq_m_n_sv4si */
    case 4182:  /* mve_vqshluq_m_n_sv8hi */
    case 4181:  /* mve_vqshluq_m_n_sv16qi */
    case 4180:  /* mve_vabavq_p_uv4si */
    case 4179:  /* mve_vabavq_p_sv4si */
    case 4178:  /* mve_vabavq_p_uv8hi */
    case 4177:  /* mve_vabavq_p_sv8hi */
    case 4176:  /* mve_vabavq_p_uv16qi */
    case 4175:  /* mve_vabavq_p_sv16qi */
    case 4173:  /* mve_vrmlaldavhq_p_uv4si */
    case 4172:  /* mve_vrmlaldavhq_p_sv4si */
    case 4171:  /* mve_vcvtq_m_from_f_sv4si */
    case 4170:  /* mve_vcvtq_m_from_f_uv4si */
    case 4169:  /* mve_vcvtq_m_from_f_sv8hi */
    case 4168:  /* mve_vcvtq_m_from_f_uv8hi */
    case 4167:  /* mve_vrev16q_m_uv16qi */
    case 4166:  /* mve_vrev16q_m_sv16qi */
    case 4165:  /* mve_vcvtq_m_n_from_f_uv4si */
    case 4164:  /* mve_vcvtq_m_n_from_f_sv4si */
    case 4163:  /* mve_vcvtq_m_n_from_f_uv8hi */
    case 4162:  /* mve_vcvtq_m_n_from_f_sv8hi */
    case 4161:  /* mve_vcvtnq_m_uv4si */
    case 4160:  /* mve_vcvtnq_m_sv4si */
    case 4159:  /* mve_vcvtnq_m_uv8hi */
    case 4158:  /* mve_vcvtnq_m_sv8hi */
    case 4157:  /* mve_vcvtpq_m_uv4si */
    case 4156:  /* mve_vcvtpq_m_sv4si */
    case 4155:  /* mve_vcvtpq_m_uv8hi */
    case 4154:  /* mve_vcvtpq_m_sv8hi */
    case 4153:  /* mve_vcvtmq_m_uv4si */
    case 4152:  /* mve_vcvtmq_m_sv4si */
    case 4151:  /* mve_vcvtmq_m_uv8hi */
    case 4150:  /* mve_vcvtmq_m_sv8hi */
    case 4133:  /* mve_vrndxq_m_fv4sf */
    case 4132:  /* mve_vrndxq_m_fv8hf */
    case 4131:  /* mve_vrndpq_m_fv4sf */
    case 4130:  /* mve_vrndpq_m_fv8hf */
    case 4129:  /* mve_vrndnq_m_fv4sf */
    case 4128:  /* mve_vrndnq_m_fv8hf */
    case 4127:  /* mve_vrndmq_m_fv4sf */
    case 4126:  /* mve_vrndmq_m_fv8hf */
    case 4125:  /* mve_vrndaq_m_fv4sf */
    case 4124:  /* mve_vrndaq_m_fv8hf */
    case 4123:  /* mve_vrmlsldavhxq_p_sv4si */
    case 4122:  /* mve_vrmlsldavhq_p_sv4si */
    case 4120:  /* mve_vrmlaldavhxq_p_sv4si */
    case 4118:  /* mve_vrev64q_m_fv4sf */
    case 4117:  /* mve_vrev64q_m_fv8hf */
    case 4116:  /* mve_vrev32q_m_uv8hi */
    case 4115:  /* mve_vrev32q_m_sv8hi */
    case 4114:  /* mve_vrev32q_m_uv16qi */
    case 4113:  /* mve_vrev32q_m_sv16qi */
    case 4112:  /* mve_vrev32q_m_fv8hf */
    case 4093:  /* mve_vqmovuntq_m_sv4si */
    case 4092:  /* mve_vqmovuntq_m_sv8hi */
    case 4091:  /* mve_vqmovunbq_m_sv4si */
    case 4090:  /* mve_vqmovunbq_m_sv8hi */
    case 4089:  /* mve_vqmovntq_m_sv4si */
    case 4088:  /* mve_vqmovntq_m_uv4si */
    case 4087:  /* mve_vqmovntq_m_sv8hi */
    case 4086:  /* mve_vqmovntq_m_uv8hi */
    case 4085:  /* mve_vqmovnbq_m_uv4si */
    case 4084:  /* mve_vqmovnbq_m_sv4si */
    case 4083:  /* mve_vqmovnbq_m_uv8hi */
    case 4082:  /* mve_vqmovnbq_m_sv8hi */
    case 4079:  /* mve_vorrq_m_n_uv4si */
    case 4078:  /* mve_vorrq_m_n_sv4si */
    case 4077:  /* mve_vorrq_m_n_uv8hi */
    case 4076:  /* mve_vorrq_m_n_sv8hi */
    case 4075:  /* mve_vnegq_m_fv4sf */
    case 4074:  /* mve_vnegq_m_fv8hf */
    case 4073:  /* mve_vmvnq_m_n_sv4si */
    case 4072:  /* mve_vmvnq_m_n_uv4si */
    case 4071:  /* mve_vmvnq_m_n_sv8hi */
    case 4070:  /* mve_vmvnq_m_n_uv8hi */
    case 4069:  /* mve_vmovntq_m_sv4si */
    case 4068:  /* mve_vmovntq_m_uv4si */
    case 4067:  /* mve_vmovntq_m_sv8hi */
    case 4066:  /* mve_vmovntq_m_uv8hi */
    case 4065:  /* mve_vmovnbq_m_sv4si */
    case 4064:  /* mve_vmovnbq_m_uv4si */
    case 4063:  /* mve_vmovnbq_m_sv8hi */
    case 4062:  /* mve_vmovnbq_m_uv8hi */
    case 4061:  /* mve_vmovltq_m_sv8hi */
    case 4060:  /* mve_vmovltq_m_uv8hi */
    case 4059:  /* mve_vmovltq_m_sv16qi */
    case 4058:  /* mve_vmovltq_m_uv16qi */
    case 4057:  /* mve_vmovlbq_m_sv8hi */
    case 4056:  /* mve_vmovlbq_m_uv8hi */
    case 4055:  /* mve_vmovlbq_m_sv16qi */
    case 4054:  /* mve_vmovlbq_m_uv16qi */
    case 4053:  /* mve_vmlsldavxq_p_sv4si */
    case 4052:  /* mve_vmlsldavxq_p_sv8hi */
    case 4051:  /* mve_vmlsldavq_p_sv4si */
    case 4050:  /* mve_vmlsldavq_p_sv8hi */
    case 4045:  /* mve_vmlaldavxq_p_sv4si */
    case 4044:  /* mve_vmlaldavxq_p_sv8hi */
    case 4043:  /* mve_vmlaldavq_p_sv4si */
    case 4042:  /* mve_vmlaldavq_p_uv4si */
    case 4041:  /* mve_vmlaldavq_p_sv8hi */
    case 4040:  /* mve_vmlaldavq_p_uv8hi */
    case 4033:  /* mve_vminnmvq_p_fv4sf */
    case 4032:  /* mve_vminnmvq_p_fv8hf */
    case 4031:  /* mve_vminnmavq_p_fv4sf */
    case 4030:  /* mve_vminnmavq_p_fv8hf */
    case 4029:  /* mve_vminnmaq_m_fv4sf */
    case 4028:  /* mve_vminnmaq_m_fv8hf */
    case 4027:  /* mve_vmaxnmvq_p_fv4sf */
    case 4026:  /* mve_vmaxnmvq_p_fv8hf */
    case 4025:  /* mve_vmaxnmavq_p_fv4sf */
    case 4024:  /* mve_vmaxnmavq_p_fv8hf */
    case 4023:  /* mve_vmaxnmaq_m_fv4sf */
    case 4022:  /* mve_vmaxnmaq_m_fv8hf */
    case 4013:  /* mve_vdupq_m_n_fv4sf */
    case 4012:  /* mve_vdupq_m_n_fv8hf */
    case 4011:  /* mve_vcvttq_m_f32_f16v4sf */
    case 4010:  /* mve_vcvttq_m_f16_f32v8hf */
    case 4009:  /* mve_vcvtbq_m_f32_f16v4sf */
    case 4008:  /* mve_vcvtbq_m_f16_f32v8hf */
    case 4007:  /* mve_vcmpneq_m_n_fv4sf */
    case 4006:  /* mve_vcmpneq_m_n_fv8hf */
    case 4005:  /* mve_vcmpneq_m_fv4sf */
    case 4004:  /* mve_vcmpneq_m_fv8hf */
    case 4003:  /* mve_vcmpltq_m_n_fv4sf */
    case 4002:  /* mve_vcmpltq_m_n_fv8hf */
    case 4001:  /* mve_vcmpltq_m_fv4sf */
    case 4000:  /* mve_vcmpltq_m_fv8hf */
    case 3999:  /* mve_vcmpleq_m_n_fv4sf */
    case 3998:  /* mve_vcmpleq_m_n_fv8hf */
    case 3997:  /* mve_vcmpleq_m_fv4sf */
    case 3996:  /* mve_vcmpleq_m_fv8hf */
    case 3995:  /* mve_vcmpgtq_m_n_fv4sf */
    case 3994:  /* mve_vcmpgtq_m_n_fv8hf */
    case 3993:  /* mve_vcmpgtq_m_fv4sf */
    case 3992:  /* mve_vcmpgtq_m_fv8hf */
    case 3991:  /* mve_vcmpgeq_m_n_fv4sf */
    case 3990:  /* mve_vcmpgeq_m_n_fv8hf */
    case 3989:  /* mve_vcmpgeq_m_fv4sf */
    case 3988:  /* mve_vcmpgeq_m_fv8hf */
    case 3987:  /* mve_vcmpeqq_m_n_fv4sf */
    case 3986:  /* mve_vcmpeqq_m_n_fv8hf */
    case 3977:  /* mve_vaddlvaq_p_sv4si */
    case 3976:  /* mve_vaddlvaq_p_uv4si */
    case 3975:  /* mve_vabsq_m_fv4sf */
    case 3974:  /* mve_vabsq_m_fv8hf */
    case 3940:  /* mve_vshlq_m_r_uv4si */
    case 3939:  /* mve_vshlq_m_r_sv4si */
    case 3938:  /* mve_vshlq_m_r_uv8hi */
    case 3937:  /* mve_vshlq_m_r_sv8hi */
    case 3936:  /* mve_vshlq_m_r_uv16qi */
    case 3935:  /* mve_vshlq_m_r_sv16qi */
    case 3934:  /* mve_vrshlq_m_n_uv4si */
    case 3933:  /* mve_vrshlq_m_n_sv4si */
    case 3932:  /* mve_vrshlq_m_n_uv8hi */
    case 3931:  /* mve_vrshlq_m_n_sv8hi */
    case 3930:  /* mve_vrshlq_m_n_uv16qi */
    case 3929:  /* mve_vrshlq_m_n_sv16qi */
    case 3928:  /* mve_vrev64q_m_uv4si */
    case 3927:  /* mve_vrev64q_m_sv4si */
    case 3926:  /* mve_vrev64q_m_uv8hi */
    case 3925:  /* mve_vrev64q_m_sv8hi */
    case 3924:  /* mve_vrev64q_m_uv16qi */
    case 3923:  /* mve_vrev64q_m_sv16qi */
    case 3922:  /* mve_vqshlq_m_r_uv4si */
    case 3921:  /* mve_vqshlq_m_r_sv4si */
    case 3920:  /* mve_vqshlq_m_r_uv8hi */
    case 3919:  /* mve_vqshlq_m_r_sv8hi */
    case 3918:  /* mve_vqshlq_m_r_uv16qi */
    case 3917:  /* mve_vqshlq_m_r_sv16qi */
    case 3916:  /* mve_vqrshlq_m_n_uv4si */
    case 3915:  /* mve_vqrshlq_m_n_sv4si */
    case 3914:  /* mve_vqrshlq_m_n_uv8hi */
    case 3913:  /* mve_vqrshlq_m_n_sv8hi */
    case 3912:  /* mve_vqrshlq_m_n_uv16qi */
    case 3911:  /* mve_vqrshlq_m_n_sv16qi */
    case 3892:  /* mve_vqnegq_m_sv4si */
    case 3891:  /* mve_vqnegq_m_sv8hi */
    case 3890:  /* mve_vqnegq_m_sv16qi */
    case 3883:  /* mve_vqabsq_m_sv4si */
    case 3882:  /* mve_vqabsq_m_sv8hi */
    case 3881:  /* mve_vqabsq_m_sv16qi */
    case 3872:  /* mve_vnegq_m_sv4si */
    case 3871:  /* mve_vnegq_m_sv8hi */
    case 3870:  /* mve_vnegq_m_sv16qi */
    case 3869:  /* mve_vmvnq_m_uv4si */
    case 3868:  /* mve_vmvnq_m_sv4si */
    case 3867:  /* mve_vmvnq_m_uv8hi */
    case 3866:  /* mve_vmvnq_m_sv8hi */
    case 3865:  /* mve_vmvnq_m_uv16qi */
    case 3864:  /* mve_vmvnq_m_sv16qi */
    case 3863:  /* mve_vmlsdavxq_p_sv4si */
    case 3862:  /* mve_vmlsdavxq_p_sv8hi */
    case 3861:  /* mve_vmlsdavxq_p_sv16qi */
    case 3860:  /* mve_vmlsdavq_p_sv4si */
    case 3859:  /* mve_vmlsdavq_p_sv8hi */
    case 3858:  /* mve_vmlsdavq_p_sv16qi */
    case 3845:  /* mve_vmladavxq_p_sv4si */
    case 3844:  /* mve_vmladavxq_p_sv8hi */
    case 3843:  /* mve_vmladavxq_p_sv16qi */
    case 3842:  /* mve_vmladavq_p_uv4si */
    case 3841:  /* mve_vmladavq_p_sv4si */
    case 3840:  /* mve_vmladavq_p_uv8hi */
    case 3839:  /* mve_vmladavq_p_sv8hi */
    case 3838:  /* mve_vmladavq_p_uv16qi */
    case 3837:  /* mve_vmladavq_p_sv16qi */
    case 3830:  /* mve_vminvq_p_uv4si */
    case 3829:  /* mve_vminvq_p_sv4si */
    case 3828:  /* mve_vminvq_p_uv8hi */
    case 3827:  /* mve_vminvq_p_sv8hi */
    case 3826:  /* mve_vminvq_p_uv16qi */
    case 3825:  /* mve_vminvq_p_sv16qi */
    case 3824:  /* mve_vminavq_p_sv4si */
    case 3823:  /* mve_vminavq_p_sv8hi */
    case 3822:  /* mve_vminavq_p_sv16qi */
    case 3821:  /* mve_vminaq_m_sv4si */
    case 3820:  /* mve_vminaq_m_sv8hi */
    case 3819:  /* mve_vminaq_m_sv16qi */
    case 3818:  /* mve_vmaxvq_p_uv4si */
    case 3817:  /* mve_vmaxvq_p_sv4si */
    case 3816:  /* mve_vmaxvq_p_uv8hi */
    case 3815:  /* mve_vmaxvq_p_sv8hi */
    case 3814:  /* mve_vmaxvq_p_uv16qi */
    case 3813:  /* mve_vmaxvq_p_sv16qi */
    case 3812:  /* mve_vmaxavq_p_sv4si */
    case 3811:  /* mve_vmaxavq_p_sv8hi */
    case 3810:  /* mve_vmaxavq_p_sv16qi */
    case 3809:  /* mve_vmaxaq_m_sv4si */
    case 3808:  /* mve_vmaxaq_m_sv8hi */
    case 3807:  /* mve_vmaxaq_m_sv16qi */
    case 3806:  /* mve_vdupq_m_n_uv4si */
    case 3805:  /* mve_vdupq_m_n_sv4si */
    case 3804:  /* mve_vdupq_m_n_uv8hi */
    case 3803:  /* mve_vdupq_m_n_sv8hi */
    case 3802:  /* mve_vdupq_m_n_uv16qi */
    case 3801:  /* mve_vdupq_m_n_sv16qi */
    case 3800:  /* mve_vcmpneq_m_uv4si */
    case 3799:  /* mve_vcmpneq_m_sv4si */
    case 3798:  /* mve_vcmpneq_m_uv8hi */
    case 3797:  /* mve_vcmpneq_m_sv8hi */
    case 3796:  /* mve_vcmpneq_m_uv16qi */
    case 3795:  /* mve_vcmpneq_m_sv16qi */
    case 3794:  /* mve_vcmpneq_m_n_uv4si */
    case 3793:  /* mve_vcmpneq_m_n_sv4si */
    case 3792:  /* mve_vcmpneq_m_n_uv8hi */
    case 3791:  /* mve_vcmpneq_m_n_sv8hi */
    case 3790:  /* mve_vcmpneq_m_n_uv16qi */
    case 3789:  /* mve_vcmpneq_m_n_sv16qi */
    case 3788:  /* mve_vcmpltq_m_sv4si */
    case 3787:  /* mve_vcmpltq_m_sv8hi */
    case 3786:  /* mve_vcmpltq_m_sv16qi */
    case 3785:  /* mve_vcmpltq_m_n_sv4si */
    case 3784:  /* mve_vcmpltq_m_n_sv8hi */
    case 3783:  /* mve_vcmpltq_m_n_sv16qi */
    case 3782:  /* mve_vcmpleq_m_sv4si */
    case 3781:  /* mve_vcmpleq_m_sv8hi */
    case 3780:  /* mve_vcmpleq_m_sv16qi */
    case 3779:  /* mve_vcmpleq_m_n_sv4si */
    case 3778:  /* mve_vcmpleq_m_n_sv8hi */
    case 3777:  /* mve_vcmpleq_m_n_sv16qi */
    case 3776:  /* mve_vcmphiq_m_uv4si */
    case 3775:  /* mve_vcmphiq_m_uv8hi */
    case 3774:  /* mve_vcmphiq_m_uv16qi */
    case 3773:  /* mve_vcmphiq_m_n_uv4si */
    case 3772:  /* mve_vcmphiq_m_n_uv8hi */
    case 3771:  /* mve_vcmphiq_m_n_uv16qi */
    case 3770:  /* mve_vcmpgtq_m_sv4si */
    case 3769:  /* mve_vcmpgtq_m_sv8hi */
    case 3768:  /* mve_vcmpgtq_m_sv16qi */
    case 3767:  /* mve_vcmpgtq_m_n_sv4si */
    case 3766:  /* mve_vcmpgtq_m_n_sv8hi */
    case 3765:  /* mve_vcmpgtq_m_n_sv16qi */
    case 3764:  /* mve_vcmpgeq_m_sv4si */
    case 3763:  /* mve_vcmpgeq_m_sv8hi */
    case 3762:  /* mve_vcmpgeq_m_sv16qi */
    case 3761:  /* mve_vcmpgeq_m_n_sv4si */
    case 3760:  /* mve_vcmpgeq_m_n_sv8hi */
    case 3759:  /* mve_vcmpgeq_m_n_sv16qi */
    case 3758:  /* mve_vcmpeqq_m_uv4si */
    case 3757:  /* mve_vcmpeqq_m_sv4si */
    case 3756:  /* mve_vcmpeqq_m_uv8hi */
    case 3755:  /* mve_vcmpeqq_m_sv8hi */
    case 3754:  /* mve_vcmpeqq_m_uv16qi */
    case 3753:  /* mve_vcmpeqq_m_sv16qi */
    case 3752:  /* mve_vcmpeqq_m_n_uv4si */
    case 3751:  /* mve_vcmpeqq_m_n_sv4si */
    case 3750:  /* mve_vcmpeqq_m_n_uv8hi */
    case 3749:  /* mve_vcmpeqq_m_n_sv8hi */
    case 3748:  /* mve_vcmpeqq_m_n_uv16qi */
    case 3747:  /* mve_vcmpeqq_m_n_sv16qi */
    case 3746:  /* mve_vcmpcsq_m_uv4si */
    case 3745:  /* mve_vcmpcsq_m_uv8hi */
    case 3744:  /* mve_vcmpcsq_m_uv16qi */
    case 3743:  /* mve_vcmpcsq_m_n_uv4si */
    case 3742:  /* mve_vcmpcsq_m_n_uv8hi */
    case 3741:  /* mve_vcmpcsq_m_n_uv16qi */
    case 3740:  /* mve_vclzq_m_uv4si */
    case 3739:  /* mve_vclzq_m_sv4si */
    case 3738:  /* mve_vclzq_m_uv8hi */
    case 3737:  /* mve_vclzq_m_sv8hi */
    case 3736:  /* mve_vclzq_m_uv16qi */
    case 3735:  /* mve_vclzq_m_sv16qi */
    case 3734:  /* mve_vclsq_m_sv4si */
    case 3733:  /* mve_vclsq_m_sv8hi */
    case 3732:  /* mve_vclsq_m_sv16qi */
    case 3731:  /* mve_vaddvaq_p_uv4si */
    case 3730:  /* mve_vaddvaq_p_sv4si */
    case 3729:  /* mve_vaddvaq_p_uv8hi */
    case 3728:  /* mve_vaddvaq_p_sv8hi */
    case 3727:  /* mve_vaddvaq_p_uv16qi */
    case 3726:  /* mve_vaddvaq_p_sv16qi */
    case 3725:  /* mve_vabsq_m_sv4si */
    case 3724:  /* mve_vabsq_m_sv8hi */
    case 3723:  /* mve_vabsq_m_sv16qi */
    case 3702:  /* mve_vcvtq_m_to_f_uv4sf */
    case 3701:  /* mve_vcvtq_m_to_f_sv4sf */
    case 3700:  /* mve_vcvtq_m_to_f_uv8hf */
    case 3699:  /* mve_vcvtq_m_to_f_sv8hf */
    case 3698:  /* mve_vcvtaq_m_uv4si */
    case 3697:  /* mve_vcvtaq_m_sv4si */
    case 3696:  /* mve_vcvtaq_m_uv8hi */
    case 3695:  /* mve_vcvtaq_m_sv8hi */
    case 3694:  /* mve_vcmpeqq_m_fv4sf */
    case 3693:  /* mve_vcmpeqq_m_fv8hf */
    case 3692:  /* mve_vbicq_m_n_uv4si */
    case 3691:  /* mve_vbicq_m_n_sv4si */
    case 3690:  /* mve_vbicq_m_n_uv8hi */
    case 3689:  /* mve_vbicq_m_n_sv8hi */
    case 3599:  /* mve_vctp64q_mv2qi */
    case 3598:  /* mve_vctp32q_mv4bi */
    case 3597:  /* mve_vctp16q_mv8bi */
    case 3596:  /* mve_vctp8q_mv16bi */
    case 3278:  /* mve_vaddvq_p_sv4si */
    case 3277:  /* mve_vaddvq_p_uv4si */
    case 3276:  /* mve_vaddvq_p_sv8hi */
    case 3275:  /* mve_vaddvq_p_uv8hi */
    case 3274:  /* mve_vaddvq_p_sv16qi */
    case 3273:  /* mve_vaddvq_p_uv16qi */
    case 3206:  /* mve_vaddlvq_p_uv4si */
    case 3205:  /* mve_vaddlvq_p_sv4si */
    case 3188:  /* mve_vcreateq_sv2di */
    case 3187:  /* mve_vcreateq_uv2di */
    case 3186:  /* mve_vcreateq_sv4si */
    case 3185:  /* mve_vcreateq_uv4si */
    case 3184:  /* mve_vcreateq_sv8hi */
    case 3183:  /* mve_vcreateq_uv8hi */
    case 3182:  /* mve_vcreateq_sv16qi */
    case 3181:  /* mve_vcreateq_uv16qi */
    case 3180:  /* mve_vcreateq_fv4sf */
    case 3179:  /* mve_vcreateq_fv8hf */
    case 3059:  /* mve_vrndq_m_fv4sf */
    case 3058:  /* mve_vrndq_m_fv8hf */
    case 2860:  /* *aarch32_crypto_aesd_fused_protected */
    case 2859:  /* *aarch32_crypto_aesd_fused */
    case 2858:  /* *aarch32_crypto_aese_fused_protected */
    case 2857:  /* *aarch32_crypto_aese_fused */
    case 2813:  /* vec_pack_trunc_v2di */
    case 2812:  /* vec_pack_trunc_v4si */
    case 2811:  /* vec_pack_trunc_v8hi */
    case 2548:  /* neon_vld1_dupv2di */
    case 2053:  /* neon_vdup_nv2di */
    case 1027:  /* *thumb2_ior_scc_strict_it */
    case 1015:  /* *thumb2_mov_notscc_strict_it */
    case 1013:  /* *thumb2_mov_negscc_strict_it */
    case 994:  /* prologue_thumb1_interwork */
    case 865:  /* *combine_vcvt_f64_s32 */
    case 864:  /* *combine_vcvt_f64_u32 */
    case 506:  /* *speculation_barrier_insn */
    case 397:  /* consttable_8 */
    case 382:  /* *sign_extract_onebit */
    case 375:  /* *if_arith_not */
    case 373:  /* *if_not_arith */
    case 371:  /* *if_shift_shift */
    case 357:  /* *if_arith_arith */
    case 334:  /* *and_scc */
    case 304:  /* *check_arch2 */
    case 282:  /* *mov_notscc */
    case 281:  /* *mov_negscc */
    case 279:  /* *mov_scc */
    case 172:  /* *arm_neg_abssi2 */
    case 171:  /* *arm_abssi2 */
    case 161:  /* unaligned_storedi */
    case 157:  /* unaligned_loaddi */
    case 116:  /* *andsi_iorsi3_notsi */
    case 97:  /* *ite_ne_zeroextractsi_shifted */
    case 96:  /* *ite_ne_zeroextractsi */
    case 95:  /* *ne_zeroextractsi_shifted */
    case 1058:  /* *thumb2_cbnz */
    case 1057:  /* *thumb2_cbz */
    case 976:  /* *addsi3_cbranch_scratch */
    case 973:  /* *tstsi3_cbranch */
    case 972:  /* *tlobits_cbranch */
    case 971:  /* *tbit_cbranch */
    case 970:  /* *negated_cbranchsi4 */
    case 969:  /* cbranchsi4_scratch */
    case 968:  /* cbranchsi4_insn */
    case 967:  /* thumb1_cbz */
      return 8;

    case 957:  /* thumb1_extendqisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (((
#line 83 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6)) == (
(IS_ARCH6_YES))))
	    {
	      return 2;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else if (which_alternative == 1)
        {
	  return 2;
        }
      else
        {
	  if (((
#line 83 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6)) == (
(IS_ARCH6_YES))))
	    {
	      return 4;
	    }
	  else
	    {
	      return 6;
	    }
        }

    case 956:  /* thumb1_extendhisi2 */
    case 953:  /* *thumb1_zero_extendhisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (((
#line 83 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6)) == (
(IS_ARCH6_YES))))
	    {
	      return 2;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else
        {
	  return 4;
        }

    case 954:  /* *thumb1_zero_extendqisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else
        {
	  return 2;
        }

    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x19ULL))
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 12 /* 0xc */;
        }
      else if (which_alternative == 2)
        {
	  return 16 /* 0x10 */;
        }
      else if (which_alternative == 12)
        {
	  if ((
#line 145 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/iwmmxt.md"
(TARGET_VFP_SINGLE)) == (1))
	    {
	      return 8;
	    }
	  else
	    {
	      return 4;
	    }
        }
      else
        {
	  return 4;
        }

    case 403:  /* force_register_use */
    case 385:  /* stack_tie */
    case 305:  /* blockage */
    case 276:  /* *deleted_compare */
      return 0;

    case 384:  /* *push_multi */
      extract_constrain_insn_cached (insn);
      return 
#line 11899 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_attr_length_push_multi (operands[2], operands[1]));

    case 2852:  /* aes_op_protect */
    case 369:  /* *if_move_shift */
    case 367:  /* *if_shift_move */
    case 365:  /* *if_not_move */
    case 363:  /* *if_move_not */
    case 381:  /* *cond_move_not */
    case 361:  /* *if_move_arith */
    case 359:  /* *if_arith_move */
    case 335:  /* *ior_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else
        {
	  return 8;
        }

    case 378:  /* *ifcompare_move_neg */
    case 376:  /* *ifcompare_neg_move */
    case 368:  /* *ifcompare_move_shift */
    case 366:  /* *ifcompare_shift_move */
    case 364:  /* *ifcompare_not_move */
    case 362:  /* *ifcompare_move_not */
    case 360:  /* *ifcompare_move_arith */
    case 358:  /* *ifcompare_arith_move */
    case 354:  /* *ifcompare_move_plus */
    case 352:  /* *ifcompare_plus_move */
    case 339:  /* *cond_sub */
    case 309:  /* *stack_protect_set_insn */
    case 121:  /* *arm_smin_insn */
    case 119:  /* *arm_smax_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else
        {
	  return 12 /* 0xc */;
        }

    case 318:  /* trap */
    case 317:  /* nop */
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 311:  /* arm_stack_protect_test_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 12 /* 0xc */;
        }
      else
        {
	  return 16 /* 0x10 */;
        }

    case 278:  /* *arm_cond_branch_reversed */
    case 277:  /* arm_cond_branch */
      extract_constrain_insn_cached (insn);
      if (
#line 8035 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(!TARGET_THUMB2))
        {
	  return 4;
        }
      else
        {
	  return 6;
        }

    case 258:  /* pic_load_addr_unified */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 8;
        }
      else if (which_alternative == 1)
        {
	  return 6;
        }
      else
        {
	  return 4;
        }

    case 126:  /* *minmax_arithsi_non_canon */
    case 125:  /* *minmax_arithsi */
    case 124:  /* *store_minmaxsi */
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return 14 /* 0xe */;
        }
      else
        {
	  return 12 /* 0xc */;
        }

    case 112:  /* *iorsi3_compare0_scratch */
    case 111:  /* *iorsi3_compare0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4;
        }
      else if (which_alternative == 1)
        {
	  return 2;
        }
      else
        {
	  return 4;
        }

    case 94:  /* *ne_zeroextractsi */
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return 12 /* 0xc */;
        }
      else
        {
	  return 8;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 4;

    }
}

int
bypass_p (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;
  enum attr_mul32 cached_mul32 ATTRIBUTE_UNUSED;
  enum attr_widen_mul64 cached_widen_mul64 ATTRIBUTE_UNUSED;
  enum attr_cortex_a8_neon_type cached_cortex_a8_neon_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a9_neon_type cached_cortex_a9_neon_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a15_neon_type cached_cortex_a15_neon_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a53_advsimd_type cached_cortex_a53_advsimd_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a57_neon_type cached_cortex_a57_neon_type ATTRIBUTE_UNUSED;
  enum attr_predicated cached_predicated ATTRIBUTE_UNUSED;
  enum attr_exynos_m1_neon_type cached_exynos_m1_neon_type ATTRIBUTE_UNUSED;
  enum attr_conds cached_conds ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2836:  /* neon_vbfcvtv4sf_highv8bf */
    case 2835:  /* neon_vbfcvtv4sfv8bf */
    case 2834:  /* neon_vbfcvtv4sfv4bf */
    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
    case 2745:  /* neon_vst4di */
    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
    case 2739:  /* neon_vst4v8qi */
    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
    case 2677:  /* neon_vst3di */
    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
    case 2671:  /* neon_vst3v8qi */
    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
    case 2615:  /* neon_vst2di */
    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
    case 2609:  /* neon_vst2v8qi */
    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
    case 2562:  /* neon_vst1v2di */
    case 2561:  /* neon_vst1di */
    case 2560:  /* neon_vst1v4sf */
    case 2559:  /* neon_vst1v2sf */
    case 2558:  /* neon_vst1v8bf */
    case 2557:  /* neon_vst1v4bf */
    case 2556:  /* neon_vst1v8hf */
    case 2555:  /* neon_vst1v4hf */
    case 2554:  /* neon_vst1v4si */
    case 2553:  /* neon_vst1v2si */
    case 2552:  /* neon_vst1v8hi */
    case 2551:  /* neon_vst1v4hi */
    case 2550:  /* neon_vst1v16qi */
    case 2549:  /* neon_vst1v8qi */
    case 2184:  /* neon_vqrdmulh_lanev2si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2104:  /* neon_vcvtv4hfv4sf */
    case 2103:  /* neon_vcvtv4sfv4hf */
    case 2040:  /* neon_vget_lanev4sf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2031:  /* neon_vget_lanev16qi_sext_internal */
    case 2030:  /* neon_vget_lanev2sf_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2023:  /* neon_vget_lanev8qi_sext_internal */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1070:  /* unaligned_storev8qi */
      if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 6922:  /* *p rintdf2 */
    case 6921:  /* *p nearbyintdf2 */
    case 6920:  /* *p btruncdf2 */
    case 6919:  /* *p rintsf2 */
    case 6918:  /* *p nearbyintsf2 */
    case 6917:  /* *p btruncsf2 */
    case 1035:  /* *thumb2_csneg */
    case 1034:  /* *thumb2_csinc */
    case 1033:  /* *thumb2_csinv */
    case 917:  /* fmindf3 */
    case 916:  /* fmaxdf3 */
    case 915:  /* fminsf3 */
    case 914:  /* fmaxsf3 */
    case 913:  /* neon_vminnmhf */
    case 912:  /* neon_vmaxnmhf */
    case 911:  /* smindf3 */
    case 910:  /* sminsf3 */
    case 909:  /* smaxdf3 */
    case 908:  /* smaxsf3 */
    case 895:  /* rounddf2 */
    case 894:  /* rintdf2 */
    case 893:  /* nearbyintdf2 */
    case 892:  /* floordf2 */
    case 891:  /* ceildf2 */
    case 890:  /* btruncdf2 */
    case 889:  /* roundsf2 */
    case 888:  /* rintsf2 */
    case 887:  /* nearbyintsf2 */
    case 886:  /* floorsf2 */
    case 885:  /* ceilsf2 */
    case 884:  /* btruncsf2 */
      if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 848:  /* *movcc_vfp */
      if (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 2833:  /* neon_vbfdot_lanev8bfv4sf */
    case 2832:  /* neon_vbfdot_lanev8bfv2sf */
    case 2831:  /* neon_vbfdot_lanev4bfv4sf */
    case 2830:  /* neon_vbfdot_lanev4bfv2sf */
    case 2829:  /* neon_vbfdotv4sf */
    case 2828:  /* neon_vbfdotv2sf */
    case 1992:  /* neon_sudot_laneqv16qi */
    case 1991:  /* neon_usdot_laneqv16qi */
    case 1990:  /* neon_sudot_laneqv8qi */
    case 1989:  /* neon_usdot_laneqv8qi */
    case 1988:  /* neon_sudot_lanev16qi */
    case 1987:  /* neon_usdot_lanev16qi */
    case 1986:  /* neon_sudot_lanev8qi */
    case 1985:  /* neon_usdot_lanev8qi */
    case 1984:  /* neon_udot_laneqv16qi */
    case 1983:  /* neon_sdot_laneqv16qi */
    case 1982:  /* neon_udot_laneqv8qi */
    case 1981:  /* neon_sdot_laneqv8qi */
    case 1980:  /* neon_udot_lanev16qi */
    case 1979:  /* neon_sdot_lanev16qi */
    case 1978:  /* neon_udot_lanev8qi */
    case 1977:  /* neon_sdot_lanev8qi */
    case 1976:  /* neon_usdotv16qi */
    case 1975:  /* neon_usdotv8qi */
    case 1974:  /* udot_prodv16qi */
    case 1973:  /* sdot_prodv16qi */
    case 1972:  /* udot_prodv8qi */
    case 1971:  /* sdot_prodv8qi */
    case 1970:  /* neon_vcmlaq_lane270v4sf */
    case 1969:  /* neon_vcmlaq_lane180v4sf */
    case 1968:  /* neon_vcmlaq_lane90v4sf */
    case 1967:  /* neon_vcmlaq_lane0v4sf */
    case 1966:  /* neon_vcmlaq_lane270v8hf */
    case 1965:  /* neon_vcmlaq_lane180v8hf */
    case 1964:  /* neon_vcmlaq_lane90v8hf */
    case 1963:  /* neon_vcmlaq_lane0v8hf */
    case 1962:  /* neon_vcmla_laneq270v4hf */
    case 1961:  /* neon_vcmla_laneq180v4hf */
    case 1960:  /* neon_vcmla_laneq90v4hf */
    case 1959:  /* neon_vcmla_laneq0v4hf */
    case 1958:  /* neon_vcmla_laneq270v2sf */
    case 1957:  /* neon_vcmla_laneq180v2sf */
    case 1956:  /* neon_vcmla_laneq90v2sf */
    case 1955:  /* neon_vcmla_laneq0v2sf */
    case 1954:  /* neon_vcmla_lane270v4sf */
    case 1953:  /* neon_vcmla_lane180v4sf */
    case 1952:  /* neon_vcmla_lane90v4sf */
    case 1951:  /* neon_vcmla_lane0v4sf */
    case 1950:  /* neon_vcmla_lane270v2sf */
    case 1949:  /* neon_vcmla_lane180v2sf */
    case 1948:  /* neon_vcmla_lane90v2sf */
    case 1947:  /* neon_vcmla_lane0v2sf */
    case 1946:  /* neon_vcmla_lane270v8hf */
    case 1945:  /* neon_vcmla_lane180v8hf */
    case 1944:  /* neon_vcmla_lane90v8hf */
    case 1943:  /* neon_vcmla_lane0v8hf */
    case 1942:  /* neon_vcmla_lane270v4hf */
    case 1941:  /* neon_vcmla_lane180v4hf */
    case 1940:  /* neon_vcmla_lane90v4hf */
    case 1939:  /* neon_vcmla_lane0v4hf */
    case 1938:  /* neon_vcmla270v4sf */
    case 1937:  /* neon_vcmla180v4sf */
    case 1936:  /* neon_vcmla90v4sf */
    case 1935:  /* neon_vcmla0v4sf */
    case 1934:  /* neon_vcmla270v2sf */
    case 1933:  /* neon_vcmla180v2sf */
    case 1932:  /* neon_vcmla90v2sf */
    case 1931:  /* neon_vcmla0v2sf */
    case 1930:  /* neon_vcmla270v8hf */
    case 1929:  /* neon_vcmla180v8hf */
    case 1928:  /* neon_vcmla90v8hf */
    case 1927:  /* neon_vcmla0v8hf */
    case 1926:  /* neon_vcmla270v4hf */
    case 1925:  /* neon_vcmla180v4hf */
    case 1924:  /* neon_vcmla90v4hf */
    case 1923:  /* neon_vcmla0v4hf */
    case 1922:  /* neon_vcadd270v4sf */
    case 1921:  /* neon_vcadd90v4sf */
    case 1920:  /* neon_vcadd270v2sf */
    case 1919:  /* neon_vcadd90v2sf */
    case 1918:  /* neon_vcadd270v8hf */
    case 1917:  /* neon_vcadd90v8hf */
    case 1916:  /* neon_vcadd270v4hf */
    case 1915:  /* neon_vcadd90v4hf */
    case 995:  /* *epilogue_insns */
    case 506:  /* *speculation_barrier_insn */
    case 385:  /* stack_tie */
    case 305:  /* blockage */
      if (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 285:  /* *cmovhf */
    case 284:  /* *cmovdf */
    case 283:  /* *cmovsf */
      if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 6907:  /* *p lazy_store_multiple_insn */
    case 6904:  /* *p push_fpsysreg_insn */
    case 6614:  /* *p *stm2_db_update */
    case 6613:  /* *p *stm2_db */
    case 6610:  /* *p *stm2_da_update */
    case 6609:  /* *p *stm2_da */
    case 6606:  /* *p *stm2_ib_update */
    case 6605:  /* *p *stm2_ib */
    case 6602:  /* *p *stm2_ia_update */
    case 6601:  /* *p *stm2_ */
    case 6598:  /* *p *stm3_db_update */
    case 6597:  /* *p *stm3_db */
    case 6594:  /* *p *stm3_da_update */
    case 6593:  /* *p *stm3_da */
    case 6590:  /* *p *stm3_ib_update */
    case 6589:  /* *p *stm3_ib */
    case 6586:  /* *p *stm3_ia_update */
    case 6585:  /* *p *stm3_ */
    case 6582:  /* *p *stm4_db_update */
    case 6581:  /* *p *stm4_db */
    case 6578:  /* *p *stm4_da_update */
    case 6577:  /* *p *stm4_da */
    case 6574:  /* *p *stm4_ib_update */
    case 6573:  /* *p *stm4_ib */
    case 6570:  /* *p *stm4_ia_update */
    case 6569:  /* *p *stm4_ */
    case 6566:  /* *p *arm_strd */
    case 6564:  /* *p *thumb2_strd_base_neg */
    case 6563:  /* *p *thumb2_strd_base */
    case 6562:  /* *p *thumb2_strd */
    case 6536:  /* *p *arm_indirect_jump */
    case 6535:  /* *p probe_stack */
    case 6534:  /* *p *arm_simple_return */
    case 6532:  /* *p *arm_jump */
    case 6437:  /* *p udivsi3 */
    case 6436:  /* *p divsi3 */
    case 6433:  /* *p unaligned_storehi */
    case 6432:  /* *p unaligned_storesi */
    case 2871:  /* crypto_sha1p_lb */
    case 2870:  /* crypto_sha1m_lb */
    case 2869:  /* crypto_sha1c_lb */
    case 2868:  /* crypto_vmullp64 */
    case 2867:  /* crypto_sha1h_lb */
    case 2866:  /* crypto_sha256su1 */
    case 2865:  /* crypto_sha256h2 */
    case 2864:  /* crypto_sha256h */
    case 2863:  /* crypto_sha1su0 */
    case 2862:  /* crypto_sha256su0 */
    case 2861:  /* crypto_sha1su1 */
    case 2860:  /* *aarch32_crypto_aesd_fused_protected */
    case 2859:  /* *aarch32_crypto_aesd_fused */
    case 2858:  /* *aarch32_crypto_aese_fused_protected */
    case 2857:  /* *aarch32_crypto_aese_fused */
    case 2856:  /* *crypto_aesimc_protected */
    case 2855:  /* *crypto_aesmc_protected */
    case 2851:  /* *crypto_aese_insn */
    case 2850:  /* *crypto_aesd_insn */
    case 2849:  /* crypto_aesimc */
    case 2848:  /* crypto_aesmc */
    case 1323:  /* neon_vrndxv4hf */
    case 1322:  /* neon_vrndpv4hf */
    case 1321:  /* neon_vrndnv4hf */
    case 1320:  /* neon_vrndmv4hf */
    case 1319:  /* neon_vrndav4hf */
    case 1318:  /* neon_vrndv4hf */
    case 1317:  /* neon_vrndxv8hf */
    case 1316:  /* neon_vrndpv8hf */
    case 1315:  /* neon_vrndnv8hf */
    case 1314:  /* neon_vrndmv8hf */
    case 1313:  /* neon_vrndav8hf */
    case 1312:  /* neon_vrndv8hf */
    case 1213:  /* neon_vrintnv4sf */
    case 1212:  /* neon_vrintav4sf */
    case 1211:  /* neon_vrintxv4sf */
    case 1210:  /* neon_vrintmv4sf */
    case 1209:  /* neon_vrintzv4sf */
    case 1208:  /* neon_vrintpv4sf */
    case 1207:  /* neon_vrintnv2sf */
    case 1206:  /* neon_vrintav2sf */
    case 1205:  /* neon_vrintxv2sf */
    case 1204:  /* neon_vrintmv2sf */
    case 1203:  /* neon_vrintzv2sf */
    case 1202:  /* neon_vrintpv2sf */
    case 1068:  /* *doloop_end_internal */
    case 1043:  /* *thumb2_cmse_entry_return */
    case 1042:  /* *thumb2_return */
    case 1024:  /* *thumb2_indirect_jump */
    case 1023:  /* *nonsecure_call_value_reg_thumb2 */
    case 1022:  /* *nonsecure_call_value_reg_thumb2_fpcxt */
    case 1021:  /* *call_value_reg_thumb2 */
    case 1020:  /* *nonsecure_call_reg_thumb2 */
    case 1019:  /* *nonsecure_call_reg_thumb2_fpcxt */
    case 1018:  /* *call_reg_thumb2 */
    case 1010:  /* *thumb2_storewb_pairsi */
    case 997:  /* *thumb1_tablejump */
    case 993:  /* *thumb1_indirect_jump */
    case 991:  /* *call_value_insn */
    case 990:  /* *call_insn */
    case 989:  /* *call_value_reg_thumb1 */
    case 988:  /* *nonsecure_call_value_reg_thumb1_v5 */
    case 987:  /* *call_value_reg_thumb1_v5 */
    case 986:  /* *call_reg_thumb1 */
    case 985:  /* *nonsecure_call_reg_thumb1_v5 */
    case 984:  /* *call_reg_thumb1_v5 */
    case 983:  /* *thumb_jump */
    case 966:  /* cpymem8b */
    case 965:  /* cpymem12b */
    case 852:  /* lazy_store_multiple_insn */
    case 849:  /* push_fpsysreg_insn */
    case 787:  /* neon_vrndihf */
    case 786:  /* neon_vrndxhf */
    case 785:  /* neon_vrndphf */
    case 784:  /* neon_vrndnhf */
    case 783:  /* neon_vrndmhf */
    case 782:  /* neon_vrndahf */
    case 781:  /* neon_vrndhf */
    case 486:  /* *stm2_db_update */
    case 485:  /* *stm2_db */
    case 482:  /* *stm2_da_update */
    case 481:  /* *stm2_da */
    case 478:  /* *stm2_ib_update */
    case 477:  /* *stm2_ib */
    case 474:  /* *thumb_stm2_ia_update */
    case 473:  /* *stm2_ia_update */
    case 472:  /* *stm2_ */
    case 467:  /* *stm3_db_update */
    case 466:  /* *stm3_db */
    case 463:  /* *stm3_da_update */
    case 462:  /* *stm3_da */
    case 459:  /* *stm3_ib_update */
    case 458:  /* *stm3_ib */
    case 455:  /* *thumb_stm3_ia_update */
    case 454:  /* *stm3_ia_update */
    case 453:  /* *stm3_ */
    case 448:  /* *stm4_db_update */
    case 447:  /* *stm4_db */
    case 444:  /* *stm4_da_update */
    case 443:  /* *stm4_da */
    case 440:  /* *stm4_ib_update */
    case 439:  /* *stm4_ib */
    case 436:  /* *thumb_stm4_ia_update */
    case 435:  /* *stm4_ia_update */
    case 434:  /* *stm4_ */
    case 429:  /* *arm_strd */
    case 421:  /* *thumb2_strd_base_neg */
    case 420:  /* *thumb2_strd_base */
    case 419:  /* *thumb2_strd */
    case 409:  /* tlscall */
    case 408:  /* load_tp_soft */
    case 407:  /* load_tp_soft_fdpic */
    case 384:  /* *push_multi */
    case 315:  /* *arm_indirect_jump */
    case 306:  /* probe_stack */
    case 303:  /* *arm_simple_return */
    case 297:  /* *sibcall_value_insn */
    case 296:  /* *sibcall_insn */
    case 295:  /* *call_value_symbol */
    case 294:  /* *call_symbol */
    case 293:  /* *call_value_reg_arm */
    case 292:  /* *call_value_reg_armv5 */
    case 291:  /* *call_reg_arm */
    case 290:  /* *call_reg_armv5 */
    case 288:  /* *arm_jump */
    case 278:  /* *arm_cond_branch_reversed */
    case 277:  /* arm_cond_branch */
    case 167:  /* udivsi3 */
    case 166:  /* divsi3 */
    case 163:  /* unaligned_storehi */
    case 162:  /* unaligned_storesi */
    case 161:  /* unaligned_storedi */
    case 124:  /* *store_minmaxsi */
    case 123:  /* *arm_uminsi3 */
    case 122:  /* *arm_umaxsi3 */
      if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    case 7040:  /* *p mve_sqshll_di */
    case 7039:  /* *p mve_srshrl_di */
    case 7038:  /* *p mve_srshr_si */
    case 7037:  /* *p mve_sqshl_si */
    case 7036:  /* *p mve_urshr_si */
    case 7035:  /* *p mve_uqshl_si */
    case 7034:  /* *p mve_urshrl_di */
    case 7033:  /* *p mve_uqshll_di */
    case 7032:  /* *p mve_sqrshr_si */
    case 7031:  /* *p mve_uqrshl_si */
    case 7030:  /* *p mve_sqrshrl_sat48_di */
    case 7029:  /* *p mve_sqrshrl_sat64_di */
    case 7028:  /* *p mve_uqrshll_sat48_di */
    case 7027:  /* *p mve_uqrshll_sat64_di */
    case 6970:  /* *p arm_store_release_exclusivesi */
    case 6969:  /* *p arm_store_release_exclusivehi */
    case 6968:  /* *p arm_store_release_exclusiveqi */
    case 6967:  /* *p arm_store_release_exclusivedi */
    case 6966:  /* *p arm_store_exclusivedi */
    case 6965:  /* *p arm_store_exclusivesi */
    case 6964:  /* *p arm_store_exclusivehi */
    case 6963:  /* *p arm_store_exclusiveqi */
    case 6962:  /* *p arm_load_acquire_exclusivedi */
    case 6961:  /* *p arm_load_exclusivedi */
    case 6960:  /* *p arm_load_acquire_exclusivesi */
    case 6959:  /* *p arm_load_exclusivesi */
    case 6958:  /* *p arm_load_acquire_exclusivehi */
    case 6957:  /* *p arm_load_acquire_exclusiveqi */
    case 6956:  /* *p arm_load_exclusivehi */
    case 6955:  /* *p arm_load_exclusiveqi */
    case 6954:  /* *p arm_atomic_loaddi2_ldrd */
    case 6953:  /* *p atomic_storesi */
    case 6952:  /* *p atomic_storehi */
    case 6951:  /* *p atomic_storeqi */
    case 6950:  /* *p atomic_loadsi */
    case 6949:  /* *p atomic_loadhi */
    case 6948:  /* *p atomic_loadqi */
    case 6947:  /* *p thumb2_lsrl */
    case 6946:  /* *p thumb2_lsll */
    case 6945:  /* *p thumb2_asrl */
    case 6944:  /* *p *clear_multiple */
    case 6943:  /* *p *clear_apsr */
    case 6835:  /* *p iwmmxt_textrcv8qi3 */
    case 6834:  /* *p iwmmxt_textrcv4hi3 */
    case 6833:  /* *p iwmmxt_textrcv2si3 */
    case 6832:  /* *p iwmmxt_torvscv8qi3 */
    case 6831:  /* *p iwmmxt_torvscv4hi3 */
    case 6830:  /* *p iwmmxt_torvscv2si3 */
    case 6829:  /* *p iwmmxt_torcv8qi3 */
    case 6828:  /* *p iwmmxt_torcv4hi3 */
    case 6827:  /* *p iwmmxt_torcv2si3 */
    case 6826:  /* *p iwmmxt_tandcv8qi3 */
    case 6825:  /* *p iwmmxt_tandcv4hi3 */
    case 6824:  /* *p iwmmxt_tandcv2si3 */
    case 6823:  /* *p iwmmxt_wmerge */
    case 6822:  /* *p iwmmxt_wmiawttn */
    case 6821:  /* *p iwmmxt_wmiawtbn */
    case 6820:  /* *p iwmmxt_wmiawbtn */
    case 6819:  /* *p iwmmxt_wmiawbbn */
    case 6818:  /* *p iwmmxt_wmiawtt */
    case 6817:  /* *p iwmmxt_wmiawtb */
    case 6816:  /* *p iwmmxt_wmiawbt */
    case 6815:  /* *p iwmmxt_wmiawbb */
    case 6814:  /* *p iwmmxt_wmiattn */
    case 6813:  /* *p iwmmxt_wmiatbn */
    case 6812:  /* *p iwmmxt_wmiabtn */
    case 6811:  /* *p iwmmxt_wmiabbn */
    case 6810:  /* *p iwmmxt_wmiatt */
    case 6809:  /* *p iwmmxt_wmiatb */
    case 6808:  /* *p iwmmxt_wmiabt */
    case 6807:  /* *p iwmmxt_wmiabb */
    case 6806:  /* *p iwmmxt_wqmiattn */
    case 6805:  /* *p iwmmxt_wqmiatbn */
    case 6804:  /* *p iwmmxt_wqmiabtn */
    case 6803:  /* *p iwmmxt_wqmiabbn */
    case 6802:  /* *p iwmmxt_wqmiatt */
    case 6801:  /* *p iwmmxt_wqmiatb */
    case 6800:  /* *p iwmmxt_wqmiabt */
    case 6799:  /* *p iwmmxt_wqmiabb */
    case 6798:  /* *p iwmmxt_waddbhusl */
    case 6797:  /* *p iwmmxt_waddbhusm */
    case 6796:  /* *p iwmmxt_wqmulwmr */
    case 6795:  /* *p iwmmxt_wqmulmr */
    case 6794:  /* *p iwmmxt_wqmulwm */
    case 6793:  /* *p iwmmxt_wqmulm */
    case 6792:  /* *p iwmmxt_wmulwl */
    case 6791:  /* *p iwmmxt_wmulwumr */
    case 6790:  /* *p iwmmxt_wmulwsmr */
    case 6789:  /* *p iwmmxt_wmulumr */
    case 6788:  /* *p iwmmxt_wmulsmr */
    case 6787:  /* *p iwmmxt_wmulwum */
    case 6786:  /* *p iwmmxt_wmulwsm */
    case 6785:  /* *p iwmmxt_wmaddun */
    case 6784:  /* *p iwmmxt_wmaddsn */
    case 6783:  /* *p iwmmxt_wmaddux */
    case 6782:  /* *p iwmmxt_wmaddsx */
    case 6781:  /* *p iwmmxt_avg4r */
    case 6780:  /* *p iwmmxt_avg4 */
    case 6779:  /* *p addcv2si3 */
    case 6778:  /* *p addcv4hi3 */
    case 6777:  /* *p iwmmxt_wsubaddhx */
    case 6776:  /* *p iwmmxt_waddsubhx */
    case 6775:  /* *p iwmmxt_wabsdiffw */
    case 6774:  /* *p iwmmxt_wabsdiffh */
    case 6773:  /* *p iwmmxt_wabsdiffb */
    case 6772:  /* *p iwmmxt_wabsv8qi3 */
    case 6771:  /* *p iwmmxt_wabsv4hi3 */
    case 6770:  /* *p iwmmxt_wabsv2si3 */
    case 6769:  /* *p iwmmxt_wsadhz */
    case 6768:  /* *p iwmmxt_wsadbz */
    case 6767:  /* *p iwmmxt_wsadh */
    case 6766:  /* *p iwmmxt_wsadb */
    case 6765:  /* *p iwmmxt_walignr3 */
    case 6764:  /* *p iwmmxt_walignr2 */
    case 6763:  /* *p iwmmxt_walignr1 */
    case 6762:  /* *p iwmmxt_walignr0 */
    case 6761:  /* *p iwmmxt_walignr */
    case 6760:  /* *p iwmmxt_waligni */
    case 6759:  /* *p iwmmxt_waccw */
    case 6758:  /* *p iwmmxt_wacch */
    case 6757:  /* *p iwmmxt_waccb */
    case 6756:  /* *p iwmmxt_tmovmskw */
    case 6755:  /* *p iwmmxt_tmovmskh */
    case 6754:  /* *p iwmmxt_tmovmskb */
    case 6753:  /* *p iwmmxt_tmiatt */
    case 6752:  /* *p iwmmxt_tmiabt */
    case 6751:  /* *p iwmmxt_tmiatb */
    case 6750:  /* *p iwmmxt_tmiabb */
    case 6749:  /* *p iwmmxt_tmiaph */
    case 6748:  /* *p iwmmxt_tmia */
    case 6747:  /* *p iwmmxt_wmaddu */
    case 6746:  /* *p iwmmxt_wmadds */
    case 6745:  /* *p ashldi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6736:  /* *p rordi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6734:  /* *p rorv4hi3_di */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6724:  /* *p rordi3 */
    case 6723:  /* *p rorv2si3 */
    case 6722:  /* *p rorv4hi3 */
    case 6721:  /* *p iwmmxt_wunpckelsw */
    case 6720:  /* *p iwmmxt_wunpckelsh */
    case 6719:  /* *p iwmmxt_wunpckelsb */
    case 6718:  /* *p iwmmxt_wunpckeluw */
    case 6717:  /* *p iwmmxt_wunpckeluh */
    case 6716:  /* *p iwmmxt_wunpckelub */
    case 6715:  /* *p iwmmxt_wunpckehsw */
    case 6714:  /* *p iwmmxt_wunpckehsh */
    case 6713:  /* *p iwmmxt_wunpckehsb */
    case 6712:  /* *p iwmmxt_wunpckehuw */
    case 6711:  /* *p iwmmxt_wunpckehuh */
    case 6710:  /* *p iwmmxt_wunpckehub */
    case 6709:  /* *p iwmmxt_wunpckilw */
    case 6708:  /* *p iwmmxt_wunpckilh */
    case 6707:  /* *p iwmmxt_wunpckilb */
    case 6706:  /* *p iwmmxt_wunpckihw */
    case 6705:  /* *p iwmmxt_wunpckihh */
    case 6704:  /* *p iwmmxt_wunpckihb */
    case 6703:  /* *p iwmmxt_wpackdus */
    case 6702:  /* *p iwmmxt_wpackwus */
    case 6701:  /* *p iwmmxt_wpackhus */
    case 6700:  /* *p iwmmxt_wpackdss */
    case 6699:  /* *p iwmmxt_wpackwss */
    case 6698:  /* *p iwmmxt_wpackhss */
    case 6697:  /* *p *uminv8qi3_iwmmxt */
    case 6696:  /* *p *uminv4hi3_iwmmxt */
    case 6695:  /* *p *uminv2si3_iwmmxt */
    case 6694:  /* *p *sminv8qi3_iwmmxt */
    case 6693:  /* *p *sminv4hi3_iwmmxt */
    case 6692:  /* *p *sminv2si3_iwmmxt */
    case 6691:  /* *p *umaxv8qi3_iwmmxt */
    case 6690:  /* *p *umaxv4hi3_iwmmxt */
    case 6689:  /* *p *umaxv2si3_iwmmxt */
    case 6688:  /* *p *smaxv8qi3_iwmmxt */
    case 6687:  /* *p *smaxv4hi3_iwmmxt */
    case 6686:  /* *p *smaxv2si3_iwmmxt */
    case 6685:  /* *p gtv2si3 */
    case 6684:  /* *p gtv4hi3 */
    case 6683:  /* *p gtv8qi3 */
    case 6682:  /* *p gtuv2si3 */
    case 6681:  /* *p gtuv4hi3 */
    case 6680:  /* *p gtuv8qi3 */
    case 6679:  /* *p eqv2si3 */
    case 6678:  /* *p eqv4hi3 */
    case 6677:  /* *p eqv8qi3 */
    case 6676:  /* *p iwmmxt_wshufh */
    case 6675:  /* *p iwmmxt_textrmw */
    case 6674:  /* *p iwmmxt_textrmsh */
    case 6673:  /* *p iwmmxt_textrmuh */
    case 6672:  /* *p iwmmxt_textrmsb */
    case 6671:  /* *p iwmmxt_textrmub */
    case 6670:  /* *p iwmmxt_tinsrw */
    case 6669:  /* *p iwmmxt_tinsrh */
    case 6668:  /* *p iwmmxt_tinsrb */
    case 6667:  /* *p iwmmxt_uavgv4hi3 */
    case 6666:  /* *p iwmmxt_uavgv8qi3 */
    case 6665:  /* *p iwmmxt_uavgrndv4hi3 */
    case 6664:  /* *p iwmmxt_uavgrndv8qi3 */
    case 6663:  /* *p iwmmxt_clrv2si */
    case 6662:  /* *p iwmmxt_clrv4hi */
    case 6661:  /* *p iwmmxt_clrv8qi */
    case 6660:  /* *p iwmmxt_clrdi */
    case 6659:  /* *p iwmmxt_wmacuz */
    case 6658:  /* *p iwmmxt_wmacu */
    case 6657:  /* *p iwmmxt_wmacsz */
    case 6656:  /* *p iwmmxt_wmacs */
    case 6655:  /* *p umulv4hi3_highpart */
    case 6654:  /* *p smulv4hi3_highpart */
    case 6653:  /* *p *mulv4hi3_iwmmxt */
    case 6652:  /* *p ussubv2si3 */
    case 6651:  /* *p ussubv4hi3 */
    case 6650:  /* *p ussubv8qi3 */
    case 6649:  /* *p sssubv2si3 */
    case 6648:  /* *p sssubv4hi3 */
    case 6647:  /* *p sssubv8qi3 */
    case 6646:  /* *p *subv8qi3_iwmmxt */
    case 6645:  /* *p *subv4hi3_iwmmxt */
    case 6644:  /* *p *subv2si3_iwmmxt */
    case 6643:  /* *p usaddv2si3 */
    case 6642:  /* *p usaddv4hi3 */
    case 6641:  /* *p usaddv8qi3 */
    case 6640:  /* *p ssaddv2si3 */
    case 6639:  /* *p ssaddv4hi3 */
    case 6638:  /* *p ssaddv8qi3 */
    case 6637:  /* *p *addv8qi3_iwmmxt */
    case 6636:  /* *p *addv4hi3_iwmmxt */
    case 6635:  /* *p *addv2si3_iwmmxt */
    case 6634:  /* *p *xorv8qi3_iwmmxt */
    case 6633:  /* *p *xorv4hi3_iwmmxt */
    case 6632:  /* *p *xorv2si3_iwmmxt */
    case 6631:  /* *p *iorv8qi3_iwmmxt */
    case 6630:  /* *p *iorv4hi3_iwmmxt */
    case 6629:  /* *p *iorv2si3_iwmmxt */
    case 6628:  /* *p *andv8qi3_iwmmxt */
    case 6627:  /* *p *andv4hi3_iwmmxt */
    case 6626:  /* *p *andv2si3_iwmmxt */
    case 6622:  /* *p iwmmxt_nanddi3 */
    case 6621:  /* *p iwmmxt_anddi3 */
    case 6620:  /* *p iwmmxt_xordi3 */
    case 6619:  /* *p iwmmxt_iordi3 */
    case 6618:  /* *p tbcstv2si */
    case 6617:  /* *p tbcstv4hi */
    case 6616:  /* *p tbcstv8qi */
    case 6615:  /* *p *load_multiple */
    case 6420:  /* *p arm_set_apsr */
    case 6419:  /* *p arm_get_apsr */
    case 4963:  /* *movmisalignv4sf_mve_load */
    case 4962:  /* *movmisalignv8hf_mve_load */
    case 4961:  /* *movmisalignv4si_mve_load */
    case 4960:  /* *movmisalignv8hi_mve_load */
    case 4959:  /* *movmisalignv16qi_mve_load */
    case 4958:  /* *movmisalignv4sf_mve_store */
    case 4957:  /* *movmisalignv8hf_mve_store */
    case 4956:  /* *movmisalignv4si_mve_store */
    case 4955:  /* *movmisalignv8hi_mve_store */
    case 4954:  /* *movmisalignv16qi_mve_store */
    case 4953:  /* arm_vcx3qa_p_v16qi */
    case 4952:  /* arm_vcx3q_p_v16qi */
    case 4951:  /* arm_vcx2qa_p_v16qi */
    case 4950:  /* arm_vcx2q_p_v16qi */
    case 4949:  /* arm_vcx1qa_p_v16qi */
    case 4948:  /* arm_vcx1q_p_v16qi */
    case 4947:  /* arm_vcx3qav16qi */
    case 4946:  /* arm_vcx3qv16qi */
    case 4945:  /* arm_vcx2qav16qi */
    case 4944:  /* arm_vcx2qv16qi */
    case 4943:  /* arm_vcx1qav16qi */
    case 4942:  /* arm_vcx1qv16qi */
    case 4941:  /* mve_vshlcq_m_uv4si */
    case 4940:  /* mve_vshlcq_m_sv4si */
    case 4939:  /* mve_vshlcq_m_uv8hi */
    case 4938:  /* mve_vshlcq_m_sv8hi */
    case 4937:  /* mve_vshlcq_m_uv16qi */
    case 4936:  /* mve_vshlcq_m_sv16qi */
    case 4935:  /* mve_sqshll_di */
    case 4934:  /* mve_srshrl_di */
    case 4933:  /* mve_srshr_si */
    case 4932:  /* mve_sqshl_si */
    case 4931:  /* mve_urshr_si */
    case 4930:  /* mve_uqshl_si */
    case 4929:  /* mve_urshrl_di */
    case 4928:  /* mve_uqshll_di */
    case 4927:  /* mve_sqrshr_si */
    case 4926:  /* mve_uqrshl_si */
    case 4925:  /* mve_sqrshrl_sat48_di */
    case 4924:  /* mve_sqrshrl_sat64_di */
    case 4923:  /* mve_uqrshll_sat48_di */
    case 4922:  /* mve_uqrshll_sat64_di */
    case 4921:  /* mve_vec_setv2di_internal */
    case 4920:  /* mve_vec_setv4sf_internal */
    case 4919:  /* mve_vec_setv4si_internal */
    case 4918:  /* mve_vec_setv8hf_internal */
    case 4917:  /* mve_vec_setv8hi_internal */
    case 4916:  /* mve_vec_setv16qi_internal */
    case 4915:  /* *mve_vec_extract_zext_internalv4si */
    case 4914:  /* *mve_vec_extract_zext_internalv8hi */
    case 4913:  /* *mve_vec_extract_zext_internalv16qi */
    case 4912:  /* *mve_vec_extract_sext_internalv4si */
    case 4911:  /* *mve_vec_extract_sext_internalv8hi */
    case 4910:  /* *mve_vec_extract_sext_internalv16qi */
    case 4909:  /* mve_vec_extractv2didi */
    case 4908:  /* mve_vec_extractv4sfsf */
    case 4907:  /* mve_vec_extractv8hfhf */
    case 4906:  /* mve_vec_extractv4sisi */
    case 4905:  /* mve_vec_extractv8hihi */
    case 4904:  /* mve_vec_extractv16qiqi */
    case 4903:  /* mve_vld4qv4sf */
    case 4902:  /* mve_vld4qv8hf */
    case 4901:  /* mve_vld4qv4si */
    case 4900:  /* mve_vld4qv8hi */
    case 4899:  /* mve_vld4qv16qi */
    case 4898:  /* mve_vld2qv4sf */
    case 4897:  /* mve_vld2qv8hf */
    case 4896:  /* mve_vld2qv4si */
    case 4895:  /* mve_vld2qv8hi */
    case 4894:  /* mve_vld2qv16qi */
    case 4893:  /* mve_vst2qv4sf */
    case 4892:  /* mve_vst2qv8hf */
    case 4891:  /* mve_vst2qv4si */
    case 4890:  /* mve_vst2qv8hi */
    case 4889:  /* mve_vst2qv16qi */
    case 4888:  /* mve_vsbcq_sv4si */
    case 4887:  /* mve_vsbcq_uv4si */
    case 4886:  /* mve_vsbcq_m_sv4si */
    case 4885:  /* mve_vsbcq_m_uv4si */
    case 4884:  /* mve_vsbciq_sv4si */
    case 4883:  /* mve_vsbciq_uv4si */
    case 4882:  /* mve_vsbciq_m_sv4si */
    case 4881:  /* mve_vsbciq_m_uv4si */
    case 4880:  /* mve_vadcq_sv4si */
    case 4879:  /* mve_vadcq_uv4si */
    case 4878:  /* mve_vadcq_m_sv4si */
    case 4877:  /* mve_vadcq_m_uv4si */
    case 4876:  /* mve_vadciq_sv4si */
    case 4875:  /* mve_vadciq_uv4si */
    case 4874:  /* mve_vadciq_m_sv4si */
    case 4873:  /* mve_vadciq_m_uv4si */
    case 4872:  /* mve_vldrdq_gather_base_wb_z_uv2di_insn */
    case 4871:  /* mve_vldrdq_gather_base_wb_z_sv2di_insn */
    case 4870:  /* set_fpscr_nzcvqc */
    case 4869:  /* get_fpscr_nzcvqc */
    case 4868:  /* mve_vldrdq_gather_base_wb_uv2di_insn */
    case 4867:  /* mve_vldrdq_gather_base_wb_sv2di_insn */
    case 4866:  /* mve_vldrwq_gather_base_wb_z_fv4sf_insn */
    case 4865:  /* mve_vldrwq_gather_base_wb_fv4sf_insn */
    case 4864:  /* mve_vldrwq_gather_base_wb_z_uv4si_insn */
    case 4863:  /* mve_vldrwq_gather_base_wb_z_sv4si_insn */
    case 4862:  /* mve_vldrwq_gather_base_wb_uv4si_insn */
    case 4861:  /* mve_vldrwq_gather_base_wb_sv4si_insn */
    case 4860:  /* mve_vstrdq_scatter_base_wb_p_uv2di */
    case 4859:  /* mve_vstrdq_scatter_base_wb_p_sv2di */
    case 4858:  /* mve_vstrdq_scatter_base_wb_uv2di */
    case 4857:  /* mve_vstrdq_scatter_base_wb_sv2di */
    case 4856:  /* mve_vstrwq_scatter_base_wb_p_fv4sf */
    case 4855:  /* mve_vstrwq_scatter_base_wb_fv4sf */
    case 4854:  /* mve_vstrwq_scatter_base_wb_p_uv4si */
    case 4853:  /* mve_vstrwq_scatter_base_wb_p_sv4si */
    case 4852:  /* mve_vstrwq_scatter_base_wb_uv4si */
    case 4851:  /* mve_vstrwq_scatter_base_wb_sv4si */
    case 4850:  /* mve_viwdupq_m_wb_uv4si_insn */
    case 4849:  /* mve_viwdupq_m_wb_uv8hi_insn */
    case 4848:  /* mve_viwdupq_m_wb_uv16qi_insn */
    case 4847:  /* mve_viwdupq_wb_uv4si_insn */
    case 4846:  /* mve_viwdupq_wb_uv8hi_insn */
    case 4845:  /* mve_viwdupq_wb_uv16qi_insn */
    case 4844:  /* mve_vdwdupq_m_wb_uv4si_insn */
    case 4843:  /* mve_vdwdupq_m_wb_uv8hi_insn */
    case 4842:  /* mve_vdwdupq_m_wb_uv16qi_insn */
    case 4841:  /* mve_vdwdupq_wb_uv4si_insn */
    case 4840:  /* mve_vdwdupq_wb_uv8hi_insn */
    case 4839:  /* mve_vdwdupq_wb_uv16qi_insn */
    case 4838:  /* mve_vddupq_m_wb_uv4si_insn */
    case 4837:  /* mve_vddupq_m_wb_uv8hi_insn */
    case 4836:  /* mve_vddupq_m_wb_uv16qi_insn */
    case 4835:  /* mve_vddupq_uv4si_insn */
    case 4834:  /* mve_vddupq_uv8hi_insn */
    case 4833:  /* mve_vddupq_uv16qi_insn */
    case 4832:  /* mve_vidupq_m_wb_uv4si_insn */
    case 4831:  /* mve_vidupq_m_wb_uv8hi_insn */
    case 4830:  /* mve_vidupq_m_wb_uv16qi_insn */
    case 4829:  /* mve_vidupq_uv4si_insn */
    case 4828:  /* mve_vidupq_uv8hi_insn */
    case 4827:  /* mve_vidupq_uv16qi_insn */
    case 4826:  /* mve_vaddq_fv4sf */
    case 4825:  /* mve_vaddq_fv8hf */
    case 4824:  /* mve_vaddqv4si */
    case 4823:  /* mve_vaddqv8hi */
    case 4822:  /* mve_vaddqv16qi */
    case 4821:  /* mve_vstrwq_scatter_shifted_offset_uv4si_insn */
    case 4820:  /* mve_vstrwq_scatter_shifted_offset_sv4si_insn */
    case 4819:  /* mve_vstrwq_scatter_shifted_offset_p_uv4si_insn */
    case 4818:  /* mve_vstrwq_scatter_shifted_offset_p_sv4si_insn */
    case 4817:  /* mve_vstrwq_scatter_shifted_offset_p_fv4sf_insn */
    case 4816:  /* mve_vstrwq_scatter_shifted_offset_fv4sf_insn */
    case 4815:  /* mve_vstrwq_scatter_offset_uv4si_insn */
    case 4814:  /* mve_vstrwq_scatter_offset_sv4si_insn */
    case 4813:  /* mve_vstrwq_scatter_offset_p_uv4si_insn */
    case 4812:  /* mve_vstrwq_scatter_offset_p_sv4si_insn */
    case 4811:  /* mve_vstrwq_scatter_offset_p_fv4sf_insn */
    case 4810:  /* mve_vstrwq_scatter_offset_fv4sf_insn */
    case 4809:  /* mve_vstrwq_scatter_base_p_fv4sf */
    case 4808:  /* mve_vstrwq_scatter_base_fv4sf */
    case 4807:  /* mve_vstrhq_scatter_shifted_offset_p_fv8hf_insn */
    case 4806:  /* mve_vstrhq_scatter_shifted_offset_fv8hf_insn */
    case 4805:  /* mve_vstrhq_scatter_offset_p_fv8hf_insn */
    case 4804:  /* mve_vstrhq_scatter_offset_fv8hf_insn */
    case 4803:  /* mve_vstrdq_scatter_shifted_offset_uv2di_insn */
    case 4802:  /* mve_vstrdq_scatter_shifted_offset_sv2di_insn */
    case 4801:  /* mve_vstrdq_scatter_shifted_offset_p_uv2di_insn */
    case 4800:  /* mve_vstrdq_scatter_shifted_offset_p_sv2di_insn */
    case 4799:  /* mve_vstrdq_scatter_offset_uv2di_insn */
    case 4798:  /* mve_vstrdq_scatter_offset_sv2di_insn */
    case 4797:  /* mve_vstrdq_scatter_offset_p_uv2di_insn */
    case 4796:  /* mve_vstrdq_scatter_offset_p_sv2di_insn */
    case 4795:  /* mve_vstrdq_scatter_base_uv2di */
    case 4794:  /* mve_vstrdq_scatter_base_sv2di */
    case 4793:  /* mve_vstrdq_scatter_base_p_uv2di */
    case 4792:  /* mve_vstrdq_scatter_base_p_sv2di */
    case 4791:  /* mve_vstrwq_uv4si */
    case 4790:  /* mve_vstrwq_sv4si */
    case 4789:  /* mve_vstrwq_p_uv4si */
    case 4788:  /* mve_vstrwq_p_sv4si */
    case 4787:  /* mve_vstrwq_p_fv4sf */
    case 4786:  /* mve_vstrwq_fv4sf */
    case 4785:  /* mve_vstrhq_uv4si */
    case 4784:  /* mve_vstrhq_sv4si */
    case 4783:  /* mve_vstrhq_uv8hi */
    case 4782:  /* mve_vstrhq_sv8hi */
    case 4781:  /* mve_vstrhq_scatter_shifted_offset_uv4si_insn */
    case 4780:  /* mve_vstrhq_scatter_shifted_offset_sv4si_insn */
    case 4779:  /* mve_vstrhq_scatter_shifted_offset_uv8hi_insn */
    case 4778:  /* mve_vstrhq_scatter_shifted_offset_sv8hi_insn */
    case 4777:  /* mve_vstrhq_scatter_shifted_offset_p_uv4si_insn */
    case 4776:  /* mve_vstrhq_scatter_shifted_offset_p_sv4si_insn */
    case 4775:  /* mve_vstrhq_scatter_shifted_offset_p_uv8hi_insn */
    case 4774:  /* mve_vstrhq_scatter_shifted_offset_p_sv8hi_insn */
    case 4773:  /* mve_vstrhq_scatter_offset_uv4si_insn */
    case 4772:  /* mve_vstrhq_scatter_offset_sv4si_insn */
    case 4771:  /* mve_vstrhq_scatter_offset_uv8hi_insn */
    case 4770:  /* mve_vstrhq_scatter_offset_sv8hi_insn */
    case 4769:  /* mve_vstrhq_scatter_offset_p_uv4si_insn */
    case 4768:  /* mve_vstrhq_scatter_offset_p_sv4si_insn */
    case 4767:  /* mve_vstrhq_scatter_offset_p_uv8hi_insn */
    case 4766:  /* mve_vstrhq_scatter_offset_p_sv8hi_insn */
    case 4765:  /* mve_vstrhq_p_uv4si */
    case 4764:  /* mve_vstrhq_p_sv4si */
    case 4763:  /* mve_vstrhq_p_uv8hi */
    case 4762:  /* mve_vstrhq_p_sv8hi */
    case 4761:  /* mve_vstrhq_p_fv8hf */
    case 4760:  /* mve_vstrhq_fv8hf */
    case 4759:  /* mve_vldrwq_gather_shifted_offset_z_uv4si */
    case 4758:  /* mve_vldrwq_gather_shifted_offset_z_sv4si */
    case 4757:  /* mve_vldrwq_gather_shifted_offset_z_fv4sf */
    case 4756:  /* mve_vldrwq_gather_shifted_offset_uv4si */
    case 4755:  /* mve_vldrwq_gather_shifted_offset_sv4si */
    case 4754:  /* mve_vldrwq_gather_shifted_offset_fv4sf */
    case 4753:  /* mve_vldrwq_gather_offset_z_uv4si */
    case 4752:  /* mve_vldrwq_gather_offset_z_sv4si */
    case 4751:  /* mve_vldrwq_gather_offset_z_fv4sf */
    case 4750:  /* mve_vldrwq_gather_offset_uv4si */
    case 4749:  /* mve_vldrwq_gather_offset_sv4si */
    case 4748:  /* mve_vldrwq_gather_offset_fv4sf */
    case 4747:  /* mve_vldrwq_gather_base_z_fv4sf */
    case 4746:  /* mve_vldrwq_gather_base_fv4sf */
    case 4745:  /* mve_vldrhq_gather_shifted_offset_z_fv8hf */
    case 4744:  /* mve_vldrhq_gather_shifted_offset_fv8hf */
    case 4743:  /* mve_vldrhq_gather_offset_z_fv8hf */
    case 4742:  /* mve_vldrhq_gather_offset_fv8hf */
    case 4741:  /* mve_vldrdq_gather_shifted_offset_z_uv2di */
    case 4740:  /* mve_vldrdq_gather_shifted_offset_z_sv2di */
    case 4739:  /* mve_vldrdq_gather_shifted_offset_uv2di */
    case 4738:  /* mve_vldrdq_gather_shifted_offset_sv2di */
    case 4737:  /* mve_vldrdq_gather_offset_z_uv2di */
    case 4736:  /* mve_vldrdq_gather_offset_z_sv2di */
    case 4735:  /* mve_vldrdq_gather_offset_uv2di */
    case 4734:  /* mve_vldrdq_gather_offset_sv2di */
    case 4733:  /* mve_vldrdq_gather_base_z_uv2di */
    case 4732:  /* mve_vldrdq_gather_base_z_sv2di */
    case 4731:  /* mve_vldrdq_gather_base_uv2di */
    case 4730:  /* mve_vldrdq_gather_base_sv2di */
    case 4729:  /* mve_vldrwq_z_uv4si */
    case 4728:  /* mve_vldrwq_z_sv4si */
    case 4727:  /* mve_vldrwq_z_fv4sf */
    case 4726:  /* mve_vldrwq_uv4si */
    case 4725:  /* mve_vldrwq_sv4si */
    case 4724:  /* mve_vldrwq_fv4sf */
    case 4723:  /* mve_vldrhq_z_uv4si */
    case 4722:  /* mve_vldrhq_z_sv4si */
    case 4721:  /* mve_vldrhq_z_uv8hi */
    case 4720:  /* mve_vldrhq_z_sv8hi */
    case 4719:  /* mve_vldrhq_z_fv8hf */
    case 4718:  /* mve_vldrhq_uv4si */
    case 4717:  /* mve_vldrhq_sv4si */
    case 4716:  /* mve_vldrhq_uv8hi */
    case 4715:  /* mve_vldrhq_sv8hi */
    case 4714:  /* mve_vldrhq_gather_shifted_offset_z_uv4si */
    case 4713:  /* mve_vldrhq_gather_shifted_offset_z_sv4si */
    case 4712:  /* mve_vldrhq_gather_shifted_offset_z_uv8hi */
    case 4711:  /* mve_vldrhq_gather_shifted_offset_z_sv8hi */
    case 4710:  /* mve_vldrhq_gather_shifted_offset_uv4si */
    case 4709:  /* mve_vldrhq_gather_shifted_offset_sv4si */
    case 4708:  /* mve_vldrhq_gather_shifted_offset_uv8hi */
    case 4707:  /* mve_vldrhq_gather_shifted_offset_sv8hi */
    case 4706:  /* mve_vldrhq_gather_offset_z_uv4si */
    case 4705:  /* mve_vldrhq_gather_offset_z_sv4si */
    case 4704:  /* mve_vldrhq_gather_offset_z_uv8hi */
    case 4703:  /* mve_vldrhq_gather_offset_z_sv8hi */
    case 4702:  /* mve_vldrhq_gather_offset_uv4si */
    case 4701:  /* mve_vldrhq_gather_offset_sv4si */
    case 4700:  /* mve_vldrhq_gather_offset_uv8hi */
    case 4699:  /* mve_vldrhq_gather_offset_sv8hi */
    case 4698:  /* mve_vldrhq_fv8hf */
    case 4697:  /* mve_vldrwq_gather_base_z_uv4si */
    case 4696:  /* mve_vldrwq_gather_base_z_sv4si */
    case 4695:  /* mve_vldrbq_z_uv4si */
    case 4694:  /* mve_vldrbq_z_sv4si */
    case 4693:  /* mve_vldrbq_z_uv8hi */
    case 4692:  /* mve_vldrbq_z_sv8hi */
    case 4691:  /* mve_vldrbq_z_uv16qi */
    case 4690:  /* mve_vldrbq_z_sv16qi */
    case 4689:  /* mve_vldrbq_gather_offset_z_uv4si */
    case 4688:  /* mve_vldrbq_gather_offset_z_sv4si */
    case 4687:  /* mve_vldrbq_gather_offset_z_uv8hi */
    case 4686:  /* mve_vldrbq_gather_offset_z_sv8hi */
    case 4685:  /* mve_vldrbq_gather_offset_z_uv16qi */
    case 4684:  /* mve_vldrbq_gather_offset_z_sv16qi */
    case 4683:  /* mve_vstrbq_p_uv4si */
    case 4682:  /* mve_vstrbq_p_sv4si */
    case 4681:  /* mve_vstrbq_p_uv8hi */
    case 4680:  /* mve_vstrbq_p_sv8hi */
    case 4679:  /* mve_vstrbq_p_uv16qi */
    case 4678:  /* mve_vstrbq_p_sv16qi */
    case 4677:  /* mve_vstrwq_scatter_base_p_uv4si */
    case 4676:  /* mve_vstrwq_scatter_base_p_sv4si */
    case 4675:  /* mve_vstrbq_scatter_offset_p_uv4si_insn */
    case 4674:  /* mve_vstrbq_scatter_offset_p_sv4si_insn */
    case 4673:  /* mve_vstrbq_scatter_offset_p_uv8hi_insn */
    case 4672:  /* mve_vstrbq_scatter_offset_p_sv8hi_insn */
    case 4671:  /* mve_vstrbq_scatter_offset_p_uv16qi_insn */
    case 4670:  /* mve_vstrbq_scatter_offset_p_sv16qi_insn */
    case 4669:  /* mve_vldrwq_gather_base_uv4si */
    case 4668:  /* mve_vldrwq_gather_base_sv4si */
    case 4667:  /* mve_vldrbq_uv4si */
    case 4666:  /* mve_vldrbq_sv4si */
    case 4665:  /* mve_vldrbq_uv8hi */
    case 4664:  /* mve_vldrbq_sv8hi */
    case 4663:  /* mve_vldrbq_uv16qi */
    case 4662:  /* mve_vldrbq_sv16qi */
    case 4661:  /* mve_vldrbq_gather_offset_uv4si */
    case 4660:  /* mve_vldrbq_gather_offset_sv4si */
    case 4659:  /* mve_vldrbq_gather_offset_uv8hi */
    case 4658:  /* mve_vldrbq_gather_offset_sv8hi */
    case 4657:  /* mve_vldrbq_gather_offset_uv16qi */
    case 4656:  /* mve_vldrbq_gather_offset_sv16qi */
    case 4655:  /* mve_vstrwq_scatter_base_uv4si */
    case 4654:  /* mve_vstrwq_scatter_base_sv4si */
    case 4653:  /* mve_vstrbq_scatter_offset_uv4si_insn */
    case 4652:  /* mve_vstrbq_scatter_offset_sv4si_insn */
    case 4651:  /* mve_vstrbq_scatter_offset_uv8hi_insn */
    case 4650:  /* mve_vstrbq_scatter_offset_sv8hi_insn */
    case 4649:  /* mve_vstrbq_scatter_offset_uv16qi_insn */
    case 4648:  /* mve_vstrbq_scatter_offset_sv16qi_insn */
    case 4647:  /* mve_vstrbq_uv4si */
    case 4646:  /* mve_vstrbq_sv4si */
    case 4645:  /* mve_vstrbq_uv8hi */
    case 4644:  /* mve_vstrbq_sv8hi */
    case 4643:  /* mve_vstrbq_uv16qi */
    case 4642:  /* mve_vstrbq_sv16qi */
    case 4641:  /* mve_vsubq_m_n_fv4sf */
    case 4640:  /* mve_vsubq_m_n_fv8hf */
    case 4639:  /* mve_vsubq_m_fv4sf */
    case 4638:  /* mve_vsubq_m_fv8hf */
    case 4637:  /* mve_vorrq_m_fv4sf */
    case 4636:  /* mve_vorrq_m_fv8hf */
    case 4635:  /* mve_vornq_m_fv4sf */
    case 4634:  /* mve_vornq_m_fv8hf */
    case 4633:  /* mve_vmulq_m_n_fv4sf */
    case 4632:  /* mve_vmulq_m_n_fv8hf */
    case 4631:  /* mve_vmulq_m_fv4sf */
    case 4630:  /* mve_vmulq_m_fv8hf */
    case 4629:  /* mve_vminnmq_m_fv4sf */
    case 4628:  /* mve_vminnmq_m_fv8hf */
    case 4627:  /* mve_vmaxnmq_m_fv4sf */
    case 4626:  /* mve_vmaxnmq_m_fv8hf */
    case 4625:  /* mve_vfmsq_m_fv4sf */
    case 4624:  /* mve_vfmsq_m_fv8hf */
    case 4623:  /* mve_vfmasq_m_n_fv4sf */
    case 4622:  /* mve_vfmasq_m_n_fv8hf */
    case 4621:  /* mve_vfmaq_m_n_fv4sf */
    case 4620:  /* mve_vfmaq_m_n_fv8hf */
    case 4619:  /* mve_vfmaq_m_fv4sf */
    case 4618:  /* mve_vfmaq_m_fv8hf */
    case 4617:  /* mve_veorq_m_fv4sf */
    case 4616:  /* mve_veorq_m_fv8hf */
    case 4615:  /* mve_vcmulq_rot90_m_fv4sf */
    case 4614:  /* mve_vcmulq_rot90_m_fv8hf */
    case 4613:  /* mve_vcmulq_rot270_m_fv4sf */
    case 4612:  /* mve_vcmulq_rot270_m_fv8hf */
    case 4611:  /* mve_vcmulq_rot180_m_fv4sf */
    case 4610:  /* mve_vcmulq_rot180_m_fv8hf */
    case 4609:  /* mve_vcmulq_m_fv4sf */
    case 4608:  /* mve_vcmulq_m_fv8hf */
    case 4607:  /* mve_vcmlaq_rot90_m_fv4sf */
    case 4606:  /* mve_vcmlaq_rot90_m_fv8hf */
    case 4605:  /* mve_vcmlaq_rot270_m_fv4sf */
    case 4604:  /* mve_vcmlaq_rot270_m_fv8hf */
    case 4603:  /* mve_vcmlaq_rot180_m_fv4sf */
    case 4602:  /* mve_vcmlaq_rot180_m_fv8hf */
    case 4601:  /* mve_vcmlaq_m_fv4sf */
    case 4600:  /* mve_vcmlaq_m_fv8hf */
    case 4599:  /* mve_vcaddq_rot90_m_fv4sf */
    case 4598:  /* mve_vcaddq_rot90_m_fv8hf */
    case 4597:  /* mve_vcaddq_rot270_m_fv4sf */
    case 4596:  /* mve_vcaddq_rot270_m_fv8hf */
    case 4595:  /* mve_vbrsrq_m_n_fv4sf */
    case 4594:  /* mve_vbrsrq_m_n_fv8hf */
    case 4593:  /* mve_vbicq_m_fv4sf */
    case 4592:  /* mve_vbicq_m_fv8hf */
    case 4591:  /* mve_vandq_m_fv4sf */
    case 4590:  /* mve_vandq_m_fv8hf */
    case 4589:  /* mve_vaddq_m_n_fv4sf */
    case 4588:  /* mve_vaddq_m_n_fv8hf */
    case 4587:  /* mve_vaddq_m_fv4sf */
    case 4586:  /* mve_vaddq_m_fv8hf */
    case 4585:  /* mve_vabdq_m_fv4sf */
    case 4584:  /* mve_vabdq_m_fv8hf */
    case 4583:  /* mve_vrmlsldavhaxq_p_sv4si */
    case 4582:  /* mve_vrmlsldavhaq_p_sv4si */
    case 4581:  /* mve_vrmlaldavhaxq_p_sv4si */
    case 4580:  /* mve_vrmlaldavhaq_p_uv4si */
    case 4579:  /* mve_vqshruntq_m_n_sv4si */
    case 4578:  /* mve_vqshruntq_m_n_sv8hi */
    case 4577:  /* mve_vqshrunbq_m_n_sv4si */
    case 4576:  /* mve_vqshrunbq_m_n_sv8hi */
    case 4575:  /* mve_vqrshruntq_m_n_sv4si */
    case 4574:  /* mve_vqrshruntq_m_n_sv8hi */
    case 4573:  /* mve_vqrshrunbq_m_n_sv4si */
    case 4572:  /* mve_vqrshrunbq_m_n_sv8hi */
    case 4571:  /* mve_vqdmulltq_m_sv4si */
    case 4570:  /* mve_vqdmulltq_m_sv8hi */
    case 4569:  /* mve_vqdmulltq_m_n_sv4si */
    case 4568:  /* mve_vqdmulltq_m_n_sv8hi */
    case 4567:  /* mve_vqdmullbq_m_sv4si */
    case 4566:  /* mve_vqdmullbq_m_sv8hi */
    case 4565:  /* mve_vqdmullbq_m_n_sv4si */
    case 4564:  /* mve_vqdmullbq_m_n_sv8hi */
    case 4563:  /* mve_vmulltq_poly_m_pv8hi */
    case 4562:  /* mve_vmulltq_poly_m_pv16qi */
    case 4561:  /* mve_vmullbq_poly_m_pv8hi */
    case 4560:  /* mve_vmullbq_poly_m_pv16qi */
    case 4559:  /* mve_vmlsldavaxq_p_sv4si */
    case 4558:  /* mve_vmlsldavaxq_p_sv8hi */
    case 4557:  /* mve_vmlsldavaq_p_sv4si */
    case 4556:  /* mve_vmlsldavaq_p_sv8hi */
    case 4555:  /* mve_vshrntq_m_n_uv4si */
    case 4554:  /* mve_vshrntq_m_n_sv4si */
    case 4553:  /* mve_vshrntq_m_n_uv8hi */
    case 4552:  /* mve_vshrntq_m_n_sv8hi */
    case 4551:  /* mve_vshrnbq_m_n_uv4si */
    case 4550:  /* mve_vshrnbq_m_n_sv4si */
    case 4549:  /* mve_vshrnbq_m_n_uv8hi */
    case 4548:  /* mve_vshrnbq_m_n_sv8hi */
    case 4547:  /* mve_vshlltq_m_n_sv8hi */
    case 4546:  /* mve_vshlltq_m_n_uv8hi */
    case 4545:  /* mve_vshlltq_m_n_sv16qi */
    case 4544:  /* mve_vshlltq_m_n_uv16qi */
    case 4543:  /* mve_vshllbq_m_n_sv8hi */
    case 4542:  /* mve_vshllbq_m_n_uv8hi */
    case 4541:  /* mve_vshllbq_m_n_sv16qi */
    case 4540:  /* mve_vshllbq_m_n_uv16qi */
    case 4539:  /* mve_vrshrntq_m_n_sv4si */
    case 4538:  /* mve_vrshrntq_m_n_uv4si */
    case 4537:  /* mve_vrshrntq_m_n_sv8hi */
    case 4536:  /* mve_vrshrntq_m_n_uv8hi */
    case 4535:  /* mve_vrshrnbq_m_n_sv4si */
    case 4534:  /* mve_vrshrnbq_m_n_uv4si */
    case 4533:  /* mve_vrshrnbq_m_n_sv8hi */
    case 4532:  /* mve_vrshrnbq_m_n_uv8hi */
    case 4531:  /* mve_vrmlaldavhaq_p_sv4si */
    case 4530:  /* mve_vqshrntq_m_n_uv4si */
    case 4529:  /* mve_vqshrntq_m_n_sv4si */
    case 4528:  /* mve_vqshrntq_m_n_uv8hi */
    case 4527:  /* mve_vqshrntq_m_n_sv8hi */
    case 4526:  /* mve_vqshrnbq_m_n_sv4si */
    case 4525:  /* mve_vqshrnbq_m_n_uv4si */
    case 4524:  /* mve_vqshrnbq_m_n_sv8hi */
    case 4523:  /* mve_vqshrnbq_m_n_uv8hi */
    case 4522:  /* mve_vqrshrntq_m_n_uv4si */
    case 4521:  /* mve_vqrshrntq_m_n_sv4si */
    case 4520:  /* mve_vqrshrntq_m_n_uv8hi */
    case 4519:  /* mve_vqrshrntq_m_n_sv8hi */
    case 4518:  /* mve_vqrshrnbq_m_n_sv4si */
    case 4517:  /* mve_vqrshrnbq_m_n_uv4si */
    case 4516:  /* mve_vqrshrnbq_m_n_sv8hi */
    case 4515:  /* mve_vqrshrnbq_m_n_uv8hi */
    case 4514:  /* mve_vmlaldavaxq_p_sv4si */
    case 4513:  /* mve_vmlaldavaxq_p_sv8hi */
    case 4512:  /* mve_vmlaldavaq_p_sv4si */
    case 4511:  /* mve_vmlaldavaq_p_uv4si */
    case 4510:  /* mve_vmlaldavaq_p_sv8hi */
    case 4509:  /* mve_vmlaldavaq_p_uv8hi */
    case 4508:  /* mve_vqrdmulhq_m_sv4si */
    case 4507:  /* mve_vqrdmulhq_m_sv8hi */
    case 4506:  /* mve_vqrdmulhq_m_sv16qi */
    case 4505:  /* mve_vqrdmulhq_m_n_sv4si */
    case 4504:  /* mve_vqrdmulhq_m_n_sv8hi */
    case 4503:  /* mve_vqrdmulhq_m_n_sv16qi */
    case 4502:  /* mve_vqrdmlsdhxq_m_sv4si */
    case 4501:  /* mve_vqrdmlsdhxq_m_sv8hi */
    case 4500:  /* mve_vqrdmlsdhxq_m_sv16qi */
    case 4499:  /* mve_vqrdmlsdhq_m_sv4si */
    case 4498:  /* mve_vqrdmlsdhq_m_sv8hi */
    case 4497:  /* mve_vqrdmlsdhq_m_sv16qi */
    case 4496:  /* mve_vqrdmladhxq_m_sv4si */
    case 4495:  /* mve_vqrdmladhxq_m_sv8hi */
    case 4494:  /* mve_vqrdmladhxq_m_sv16qi */
    case 4493:  /* mve_vqrdmladhq_m_sv4si */
    case 4492:  /* mve_vqrdmladhq_m_sv8hi */
    case 4491:  /* mve_vqrdmladhq_m_sv16qi */
    case 4490:  /* mve_vqdmulhq_m_sv4si */
    case 4489:  /* mve_vqdmulhq_m_sv8hi */
    case 4488:  /* mve_vqdmulhq_m_sv16qi */
    case 4487:  /* mve_vqdmulhq_m_n_sv4si */
    case 4486:  /* mve_vqdmulhq_m_n_sv8hi */
    case 4485:  /* mve_vqdmulhq_m_n_sv16qi */
    case 4484:  /* mve_vqdmlsdhxq_m_sv4si */
    case 4483:  /* mve_vqdmlsdhxq_m_sv8hi */
    case 4482:  /* mve_vqdmlsdhxq_m_sv16qi */
    case 4481:  /* mve_vqdmlsdhq_m_sv4si */
    case 4480:  /* mve_vqdmlsdhq_m_sv8hi */
    case 4479:  /* mve_vqdmlsdhq_m_sv16qi */
    case 4478:  /* mve_vqdmladhxq_m_sv4si */
    case 4477:  /* mve_vqdmladhxq_m_sv8hi */
    case 4476:  /* mve_vqdmladhxq_m_sv16qi */
    case 4475:  /* mve_vqdmladhq_m_sv4si */
    case 4474:  /* mve_vqdmladhq_m_sv8hi */
    case 4473:  /* mve_vqdmladhq_m_sv16qi */
    case 4472:  /* mve_vmlsdavaxq_p_sv4si */
    case 4471:  /* mve_vmlsdavaxq_p_sv8hi */
    case 4470:  /* mve_vmlsdavaxq_p_sv16qi */
    case 4469:  /* mve_vmlsdavaq_p_sv4si */
    case 4468:  /* mve_vmlsdavaq_p_sv8hi */
    case 4467:  /* mve_vmlsdavaq_p_sv16qi */
    case 4466:  /* mve_vmladavaxq_p_sv4si */
    case 4465:  /* mve_vmladavaxq_p_sv8hi */
    case 4464:  /* mve_vmladavaxq_p_sv16qi */
    case 4463:  /* mve_vhcaddq_rot90_m_sv4si */
    case 4462:  /* mve_vhcaddq_rot90_m_sv8hi */
    case 4461:  /* mve_vhcaddq_rot90_m_sv16qi */
    case 4460:  /* mve_vhcaddq_rot270_m_sv4si */
    case 4459:  /* mve_vhcaddq_rot270_m_sv8hi */
    case 4458:  /* mve_vhcaddq_rot270_m_sv16qi */
    case 4457:  /* mve_vsubq_m_n_uv4si */
    case 4456:  /* mve_vsubq_m_n_sv4si */
    case 4455:  /* mve_vsubq_m_n_uv8hi */
    case 4454:  /* mve_vsubq_m_n_sv8hi */
    case 4453:  /* mve_vsubq_m_n_uv16qi */
    case 4452:  /* mve_vsubq_m_n_sv16qi */
    case 4451:  /* mve_vsliq_m_n_sv4si */
    case 4450:  /* mve_vsliq_m_n_uv4si */
    case 4449:  /* mve_vsliq_m_n_sv8hi */
    case 4448:  /* mve_vsliq_m_n_uv8hi */
    case 4447:  /* mve_vsliq_m_n_sv16qi */
    case 4446:  /* mve_vsliq_m_n_uv16qi */
    case 4445:  /* mve_vshrq_m_n_uv4si */
    case 4444:  /* mve_vshrq_m_n_sv4si */
    case 4443:  /* mve_vshrq_m_n_uv8hi */
    case 4442:  /* mve_vshrq_m_n_sv8hi */
    case 4441:  /* mve_vshrq_m_n_uv16qi */
    case 4440:  /* mve_vshrq_m_n_sv16qi */
    case 4439:  /* mve_vshlq_m_n_uv4si */
    case 4438:  /* mve_vshlq_m_n_sv4si */
    case 4437:  /* mve_vshlq_m_n_uv8hi */
    case 4436:  /* mve_vshlq_m_n_sv8hi */
    case 4435:  /* mve_vshlq_m_n_uv16qi */
    case 4434:  /* mve_vshlq_m_n_sv16qi */
    case 4433:  /* mve_vrshrq_m_n_uv4si */
    case 4432:  /* mve_vrshrq_m_n_sv4si */
    case 4431:  /* mve_vrshrq_m_n_uv8hi */
    case 4430:  /* mve_vrshrq_m_n_sv8hi */
    case 4429:  /* mve_vrshrq_m_n_uv16qi */
    case 4428:  /* mve_vrshrq_m_n_sv16qi */
    case 4427:  /* mve_vrshlq_m_uv4si */
    case 4426:  /* mve_vrshlq_m_sv4si */
    case 4425:  /* mve_vrshlq_m_uv8hi */
    case 4424:  /* mve_vrshlq_m_sv8hi */
    case 4423:  /* mve_vrshlq_m_uv16qi */
    case 4422:  /* mve_vrshlq_m_sv16qi */
    case 4421:  /* mve_vrmulhq_m_sv4si */
    case 4420:  /* mve_vrmulhq_m_uv4si */
    case 4419:  /* mve_vrmulhq_m_sv8hi */
    case 4418:  /* mve_vrmulhq_m_uv8hi */
    case 4417:  /* mve_vrmulhq_m_sv16qi */
    case 4416:  /* mve_vrmulhq_m_uv16qi */
    case 4415:  /* mve_vrhaddq_m_sv4si */
    case 4414:  /* mve_vrhaddq_m_uv4si */
    case 4413:  /* mve_vrhaddq_m_sv8hi */
    case 4412:  /* mve_vrhaddq_m_uv8hi */
    case 4411:  /* mve_vrhaddq_m_sv16qi */
    case 4410:  /* mve_vrhaddq_m_uv16qi */
    case 4409:  /* mve_vqsubq_m_sv4si */
    case 4408:  /* mve_vqsubq_m_uv4si */
    case 4407:  /* mve_vqsubq_m_sv8hi */
    case 4406:  /* mve_vqsubq_m_uv8hi */
    case 4405:  /* mve_vqsubq_m_sv16qi */
    case 4404:  /* mve_vqsubq_m_uv16qi */
    case 4403:  /* mve_vqsubq_m_n_sv4si */
    case 4402:  /* mve_vqsubq_m_n_uv4si */
    case 4401:  /* mve_vqsubq_m_n_sv8hi */
    case 4400:  /* mve_vqsubq_m_n_uv8hi */
    case 4399:  /* mve_vqsubq_m_n_sv16qi */
    case 4398:  /* mve_vqsubq_m_n_uv16qi */
    case 4397:  /* mve_vqshlq_m_sv4si */
    case 4396:  /* mve_vqshlq_m_uv4si */
    case 4395:  /* mve_vqshlq_m_sv8hi */
    case 4394:  /* mve_vqshlq_m_uv8hi */
    case 4393:  /* mve_vqshlq_m_sv16qi */
    case 4392:  /* mve_vqshlq_m_uv16qi */
    case 4391:  /* mve_vqshlq_m_n_uv4si */
    case 4390:  /* mve_vqshlq_m_n_sv4si */
    case 4389:  /* mve_vqshlq_m_n_uv8hi */
    case 4388:  /* mve_vqshlq_m_n_sv8hi */
    case 4387:  /* mve_vqshlq_m_n_uv16qi */
    case 4386:  /* mve_vqshlq_m_n_sv16qi */
    case 4385:  /* mve_vqrshlq_m_sv4si */
    case 4384:  /* mve_vqrshlq_m_uv4si */
    case 4383:  /* mve_vqrshlq_m_sv8hi */
    case 4382:  /* mve_vqrshlq_m_uv8hi */
    case 4381:  /* mve_vqrshlq_m_sv16qi */
    case 4380:  /* mve_vqrshlq_m_uv16qi */
    case 4379:  /* mve_vqrdmlashq_m_n_sv4si */
    case 4378:  /* mve_vqrdmlashq_m_n_sv8hi */
    case 4377:  /* mve_vqrdmlashq_m_n_sv16qi */
    case 4376:  /* mve_vqrdmlahq_m_n_sv4si */
    case 4375:  /* mve_vqrdmlahq_m_n_sv8hi */
    case 4374:  /* mve_vqrdmlahq_m_n_sv16qi */
    case 4373:  /* mve_vqdmlashq_m_n_sv4si */
    case 4372:  /* mve_vqdmlashq_m_n_sv8hi */
    case 4371:  /* mve_vqdmlashq_m_n_sv16qi */
    case 4370:  /* mve_vqdmlahq_m_n_sv4si */
    case 4369:  /* mve_vqdmlahq_m_n_sv8hi */
    case 4368:  /* mve_vqdmlahq_m_n_sv16qi */
    case 4367:  /* mve_vqaddq_m_sv4si */
    case 4366:  /* mve_vqaddq_m_uv4si */
    case 4365:  /* mve_vqaddq_m_sv8hi */
    case 4364:  /* mve_vqaddq_m_uv8hi */
    case 4363:  /* mve_vqaddq_m_sv16qi */
    case 4362:  /* mve_vqaddq_m_uv16qi */
    case 4361:  /* mve_vqaddq_m_n_sv4si */
    case 4360:  /* mve_vqaddq_m_n_uv4si */
    case 4359:  /* mve_vqaddq_m_n_sv8hi */
    case 4358:  /* mve_vqaddq_m_n_uv8hi */
    case 4357:  /* mve_vqaddq_m_n_sv16qi */
    case 4356:  /* mve_vqaddq_m_n_uv16qi */
    case 4355:  /* mve_vorrq_m_uv4si */
    case 4354:  /* mve_vorrq_m_sv4si */
    case 4353:  /* mve_vorrq_m_uv8hi */
    case 4352:  /* mve_vorrq_m_sv8hi */
    case 4351:  /* mve_vorrq_m_uv16qi */
    case 4350:  /* mve_vorrq_m_sv16qi */
    case 4349:  /* mve_vornq_m_sv4si */
    case 4348:  /* mve_vornq_m_uv4si */
    case 4347:  /* mve_vornq_m_sv8hi */
    case 4346:  /* mve_vornq_m_uv8hi */
    case 4345:  /* mve_vornq_m_sv16qi */
    case 4344:  /* mve_vornq_m_uv16qi */
    case 4343:  /* mve_vmulq_m_uv4si */
    case 4342:  /* mve_vmulq_m_sv4si */
    case 4341:  /* mve_vmulq_m_uv8hi */
    case 4340:  /* mve_vmulq_m_sv8hi */
    case 4339:  /* mve_vmulq_m_uv16qi */
    case 4338:  /* mve_vmulq_m_sv16qi */
    case 4337:  /* mve_vmulq_m_n_sv4si */
    case 4336:  /* mve_vmulq_m_n_uv4si */
    case 4335:  /* mve_vmulq_m_n_sv8hi */
    case 4334:  /* mve_vmulq_m_n_uv8hi */
    case 4333:  /* mve_vmulq_m_n_sv16qi */
    case 4332:  /* mve_vmulq_m_n_uv16qi */
    case 4331:  /* mve_vmulltq_int_m_uv4si */
    case 4330:  /* mve_vmulltq_int_m_sv4si */
    case 4329:  /* mve_vmulltq_int_m_uv8hi */
    case 4328:  /* mve_vmulltq_int_m_sv8hi */
    case 4327:  /* mve_vmulltq_int_m_uv16qi */
    case 4326:  /* mve_vmulltq_int_m_sv16qi */
    case 4325:  /* mve_vmullbq_int_m_sv4si */
    case 4324:  /* mve_vmullbq_int_m_uv4si */
    case 4323:  /* mve_vmullbq_int_m_sv8hi */
    case 4322:  /* mve_vmullbq_int_m_uv8hi */
    case 4321:  /* mve_vmullbq_int_m_sv16qi */
    case 4320:  /* mve_vmullbq_int_m_uv16qi */
    case 4319:  /* mve_vmulhq_m_uv4si */
    case 4318:  /* mve_vmulhq_m_sv4si */
    case 4317:  /* mve_vmulhq_m_uv8hi */
    case 4316:  /* mve_vmulhq_m_sv8hi */
    case 4315:  /* mve_vmulhq_m_uv16qi */
    case 4314:  /* mve_vmulhq_m_sv16qi */
    case 4313:  /* mve_vmlasq_m_n_sv4si */
    case 4312:  /* mve_vmlasq_m_n_uv4si */
    case 4311:  /* mve_vmlasq_m_n_sv8hi */
    case 4310:  /* mve_vmlasq_m_n_uv8hi */
    case 4309:  /* mve_vmlasq_m_n_sv16qi */
    case 4308:  /* mve_vmlasq_m_n_uv16qi */
    case 4307:  /* mve_vmlaq_m_n_uv4si */
    case 4306:  /* mve_vmlaq_m_n_sv4si */
    case 4305:  /* mve_vmlaq_m_n_uv8hi */
    case 4304:  /* mve_vmlaq_m_n_sv8hi */
    case 4303:  /* mve_vmlaq_m_n_uv16qi */
    case 4302:  /* mve_vmlaq_m_n_sv16qi */
    case 4301:  /* mve_vmladavaq_p_sv4si */
    case 4300:  /* mve_vmladavaq_p_uv4si */
    case 4299:  /* mve_vmladavaq_p_sv8hi */
    case 4298:  /* mve_vmladavaq_p_uv8hi */
    case 4297:  /* mve_vmladavaq_p_sv16qi */
    case 4296:  /* mve_vmladavaq_p_uv16qi */
    case 4295:  /* mve_vminq_m_uv4si */
    case 4294:  /* mve_vminq_m_sv4si */
    case 4293:  /* mve_vminq_m_uv8hi */
    case 4292:  /* mve_vminq_m_sv8hi */
    case 4291:  /* mve_vminq_m_uv16qi */
    case 4290:  /* mve_vminq_m_sv16qi */
    case 4289:  /* mve_vmaxq_m_uv4si */
    case 4288:  /* mve_vmaxq_m_sv4si */
    case 4287:  /* mve_vmaxq_m_uv8hi */
    case 4286:  /* mve_vmaxq_m_sv8hi */
    case 4285:  /* mve_vmaxq_m_uv16qi */
    case 4284:  /* mve_vmaxq_m_sv16qi */
    case 4283:  /* mve_vhsubq_m_uv4si */
    case 4282:  /* mve_vhsubq_m_sv4si */
    case 4281:  /* mve_vhsubq_m_uv8hi */
    case 4280:  /* mve_vhsubq_m_sv8hi */
    case 4279:  /* mve_vhsubq_m_uv16qi */
    case 4278:  /* mve_vhsubq_m_sv16qi */
    case 4277:  /* mve_vhsubq_m_n_uv4si */
    case 4276:  /* mve_vhsubq_m_n_sv4si */
    case 4275:  /* mve_vhsubq_m_n_uv8hi */
    case 4274:  /* mve_vhsubq_m_n_sv8hi */
    case 4273:  /* mve_vhsubq_m_n_uv16qi */
    case 4272:  /* mve_vhsubq_m_n_sv16qi */
    case 4271:  /* mve_vhaddq_m_uv4si */
    case 4270:  /* mve_vhaddq_m_sv4si */
    case 4269:  /* mve_vhaddq_m_uv8hi */
    case 4268:  /* mve_vhaddq_m_sv8hi */
    case 4267:  /* mve_vhaddq_m_uv16qi */
    case 4266:  /* mve_vhaddq_m_sv16qi */
    case 4265:  /* mve_vhaddq_m_n_uv4si */
    case 4264:  /* mve_vhaddq_m_n_sv4si */
    case 4263:  /* mve_vhaddq_m_n_uv8hi */
    case 4262:  /* mve_vhaddq_m_n_sv8hi */
    case 4261:  /* mve_vhaddq_m_n_uv16qi */
    case 4260:  /* mve_vhaddq_m_n_sv16qi */
    case 4259:  /* mve_veorq_m_uv4si */
    case 4258:  /* mve_veorq_m_sv4si */
    case 4257:  /* mve_veorq_m_uv8hi */
    case 4256:  /* mve_veorq_m_sv8hi */
    case 4255:  /* mve_veorq_m_uv16qi */
    case 4254:  /* mve_veorq_m_sv16qi */
    case 4253:  /* mve_vcaddq_rot90_m_sv4si */
    case 4252:  /* mve_vcaddq_rot90_m_uv4si */
    case 4251:  /* mve_vcaddq_rot90_m_sv8hi */
    case 4250:  /* mve_vcaddq_rot90_m_uv8hi */
    case 4249:  /* mve_vcaddq_rot90_m_sv16qi */
    case 4248:  /* mve_vcaddq_rot90_m_uv16qi */
    case 4247:  /* mve_vcaddq_rot270_m_sv4si */
    case 4246:  /* mve_vcaddq_rot270_m_uv4si */
    case 4245:  /* mve_vcaddq_rot270_m_sv8hi */
    case 4244:  /* mve_vcaddq_rot270_m_uv8hi */
    case 4243:  /* mve_vcaddq_rot270_m_sv16qi */
    case 4242:  /* mve_vcaddq_rot270_m_uv16qi */
    case 4241:  /* mve_vbrsrq_m_n_sv4si */
    case 4240:  /* mve_vbrsrq_m_n_uv4si */
    case 4239:  /* mve_vbrsrq_m_n_sv8hi */
    case 4238:  /* mve_vbrsrq_m_n_uv8hi */
    case 4237:  /* mve_vbrsrq_m_n_sv16qi */
    case 4236:  /* mve_vbrsrq_m_n_uv16qi */
    case 4235:  /* mve_vbicq_m_sv4si */
    case 4234:  /* mve_vbicq_m_uv4si */
    case 4233:  /* mve_vbicq_m_sv8hi */
    case 4232:  /* mve_vbicq_m_uv8hi */
    case 4231:  /* mve_vbicq_m_sv16qi */
    case 4230:  /* mve_vbicq_m_uv16qi */
    case 4229:  /* mve_vandq_m_sv4si */
    case 4228:  /* mve_vandq_m_uv4si */
    case 4227:  /* mve_vandq_m_sv8hi */
    case 4226:  /* mve_vandq_m_uv8hi */
    case 4225:  /* mve_vandq_m_sv16qi */
    case 4224:  /* mve_vandq_m_uv16qi */
    case 4223:  /* mve_vaddq_m_sv4si */
    case 4222:  /* mve_vaddq_m_uv4si */
    case 4221:  /* mve_vaddq_m_sv8hi */
    case 4220:  /* mve_vaddq_m_uv8hi */
    case 4219:  /* mve_vaddq_m_sv16qi */
    case 4218:  /* mve_vaddq_m_uv16qi */
    case 4217:  /* mve_vaddq_m_n_uv4si */
    case 4216:  /* mve_vaddq_m_n_sv4si */
    case 4215:  /* mve_vaddq_m_n_uv8hi */
    case 4214:  /* mve_vaddq_m_n_sv8hi */
    case 4213:  /* mve_vaddq_m_n_uv16qi */
    case 4212:  /* mve_vaddq_m_n_sv16qi */
    case 4211:  /* mve_vabdq_m_uv4si */
    case 4210:  /* mve_vabdq_m_sv4si */
    case 4209:  /* mve_vabdq_m_uv8hi */
    case 4208:  /* mve_vabdq_m_sv8hi */
    case 4207:  /* mve_vabdq_m_uv16qi */
    case 4206:  /* mve_vabdq_m_sv16qi */
    case 4205:  /* mve_vcvtq_m_n_to_f_sv4sf */
    case 4204:  /* mve_vcvtq_m_n_to_f_uv4sf */
    case 4203:  /* mve_vcvtq_m_n_to_f_sv8hf */
    case 4202:  /* mve_vcvtq_m_n_to_f_uv8hf */
    case 4201:  /* mve_vsubq_m_sv4si */
    case 4200:  /* mve_vsubq_m_uv4si */
    case 4199:  /* mve_vsubq_m_sv8hi */
    case 4198:  /* mve_vsubq_m_uv8hi */
    case 4197:  /* mve_vsubq_m_sv16qi */
    case 4196:  /* mve_vsubq_m_uv16qi */
    case 4195:  /* mve_vsriq_m_n_uv4si */
    case 4194:  /* mve_vsriq_m_n_sv4si */
    case 4193:  /* mve_vsriq_m_n_uv8hi */
    case 4192:  /* mve_vsriq_m_n_sv8hi */
    case 4191:  /* mve_vsriq_m_n_uv16qi */
    case 4190:  /* mve_vsriq_m_n_sv16qi */
    case 4189:  /* mve_vshlq_m_uv4si */
    case 4188:  /* mve_vshlq_m_sv4si */
    case 4187:  /* mve_vshlq_m_uv8hi */
    case 4186:  /* mve_vshlq_m_sv8hi */
    case 4185:  /* mve_vshlq_m_uv16qi */
    case 4184:  /* mve_vshlq_m_sv16qi */
    case 4183:  /* mve_vqshluq_m_n_sv4si */
    case 4182:  /* mve_vqshluq_m_n_sv8hi */
    case 4181:  /* mve_vqshluq_m_n_sv16qi */
    case 4180:  /* mve_vabavq_p_uv4si */
    case 4179:  /* mve_vabavq_p_sv4si */
    case 4178:  /* mve_vabavq_p_uv8hi */
    case 4177:  /* mve_vabavq_p_sv8hi */
    case 4176:  /* mve_vabavq_p_uv16qi */
    case 4175:  /* mve_vabavq_p_sv16qi */
    case 4174:  /* mve_vrmlsldavhaq_sv4si */
    case 4173:  /* mve_vrmlaldavhq_p_uv4si */
    case 4172:  /* mve_vrmlaldavhq_p_sv4si */
    case 4171:  /* mve_vcvtq_m_from_f_sv4si */
    case 4170:  /* mve_vcvtq_m_from_f_uv4si */
    case 4169:  /* mve_vcvtq_m_from_f_sv8hi */
    case 4168:  /* mve_vcvtq_m_from_f_uv8hi */
    case 4167:  /* mve_vrev16q_m_uv16qi */
    case 4166:  /* mve_vrev16q_m_sv16qi */
    case 4165:  /* mve_vcvtq_m_n_from_f_uv4si */
    case 4164:  /* mve_vcvtq_m_n_from_f_sv4si */
    case 4163:  /* mve_vcvtq_m_n_from_f_uv8hi */
    case 4162:  /* mve_vcvtq_m_n_from_f_sv8hi */
    case 4161:  /* mve_vcvtnq_m_uv4si */
    case 4160:  /* mve_vcvtnq_m_sv4si */
    case 4159:  /* mve_vcvtnq_m_uv8hi */
    case 4158:  /* mve_vcvtnq_m_sv8hi */
    case 4157:  /* mve_vcvtpq_m_uv4si */
    case 4156:  /* mve_vcvtpq_m_sv4si */
    case 4155:  /* mve_vcvtpq_m_uv8hi */
    case 4154:  /* mve_vcvtpq_m_sv8hi */
    case 4153:  /* mve_vcvtmq_m_uv4si */
    case 4152:  /* mve_vcvtmq_m_sv4si */
    case 4151:  /* mve_vcvtmq_m_uv8hi */
    case 4150:  /* mve_vcvtmq_m_sv8hi */
    case 4149:  /* mve_vshrntq_n_uv4si */
    case 4148:  /* mve_vshrntq_n_sv4si */
    case 4147:  /* mve_vshrntq_n_uv8hi */
    case 4146:  /* mve_vshrntq_n_sv8hi */
    case 4145:  /* mve_vshrnbq_n_sv4si */
    case 4144:  /* mve_vshrnbq_n_uv4si */
    case 4143:  /* mve_vshrnbq_n_sv8hi */
    case 4142:  /* mve_vshrnbq_n_uv8hi */
    case 4141:  /* mve_vrshrntq_n_sv4si */
    case 4140:  /* mve_vrshrntq_n_uv4si */
    case 4139:  /* mve_vrshrntq_n_sv8hi */
    case 4138:  /* mve_vrshrntq_n_uv8hi */
    case 4137:  /* mve_vrshrnbq_n_uv4si */
    case 4136:  /* mve_vrshrnbq_n_sv4si */
    case 4135:  /* mve_vrshrnbq_n_uv8hi */
    case 4134:  /* mve_vrshrnbq_n_sv8hi */
    case 4133:  /* mve_vrndxq_m_fv4sf */
    case 4132:  /* mve_vrndxq_m_fv8hf */
    case 4131:  /* mve_vrndpq_m_fv4sf */
    case 4130:  /* mve_vrndpq_m_fv8hf */
    case 4129:  /* mve_vrndnq_m_fv4sf */
    case 4128:  /* mve_vrndnq_m_fv8hf */
    case 4127:  /* mve_vrndmq_m_fv4sf */
    case 4126:  /* mve_vrndmq_m_fv8hf */
    case 4125:  /* mve_vrndaq_m_fv4sf */
    case 4124:  /* mve_vrndaq_m_fv8hf */
    case 4123:  /* mve_vrmlsldavhxq_p_sv4si */
    case 4122:  /* mve_vrmlsldavhq_p_sv4si */
    case 4121:  /* mve_vrmlsldavhaxq_sv4si */
    case 4120:  /* mve_vrmlaldavhxq_p_sv4si */
    case 4119:  /* mve_vrmlaldavhaxq_sv4si */
    case 4118:  /* mve_vrev64q_m_fv4sf */
    case 4117:  /* mve_vrev64q_m_fv8hf */
    case 4116:  /* mve_vrev32q_m_uv8hi */
    case 4115:  /* mve_vrev32q_m_sv8hi */
    case 4114:  /* mve_vrev32q_m_uv16qi */
    case 4113:  /* mve_vrev32q_m_sv16qi */
    case 4112:  /* mve_vrev32q_m_fv8hf */
    case 4111:  /* mve_vqshruntq_n_sv4si */
    case 4110:  /* mve_vqshruntq_n_sv8hi */
    case 4109:  /* mve_vqshrunbq_n_sv4si */
    case 4108:  /* mve_vqshrunbq_n_sv8hi */
    case 4107:  /* mve_vqshrntq_n_sv4si */
    case 4106:  /* mve_vqshrntq_n_uv4si */
    case 4105:  /* mve_vqshrntq_n_sv8hi */
    case 4104:  /* mve_vqshrntq_n_uv8hi */
    case 4103:  /* mve_vqshrnbq_n_sv4si */
    case 4102:  /* mve_vqshrnbq_n_uv4si */
    case 4101:  /* mve_vqshrnbq_n_sv8hi */
    case 4100:  /* mve_vqshrnbq_n_uv8hi */
    case 4099:  /* mve_vqrshruntq_n_sv4si */
    case 4098:  /* mve_vqrshruntq_n_sv8hi */
    case 4097:  /* mve_vqrshrntq_n_sv4si */
    case 4096:  /* mve_vqrshrntq_n_uv4si */
    case 4095:  /* mve_vqrshrntq_n_sv8hi */
    case 4094:  /* mve_vqrshrntq_n_uv8hi */
    case 4093:  /* mve_vqmovuntq_m_sv4si */
    case 4092:  /* mve_vqmovuntq_m_sv8hi */
    case 4091:  /* mve_vqmovunbq_m_sv4si */
    case 4090:  /* mve_vqmovunbq_m_sv8hi */
    case 4089:  /* mve_vqmovntq_m_sv4si */
    case 4088:  /* mve_vqmovntq_m_uv4si */
    case 4087:  /* mve_vqmovntq_m_sv8hi */
    case 4086:  /* mve_vqmovntq_m_uv8hi */
    case 4085:  /* mve_vqmovnbq_m_uv4si */
    case 4084:  /* mve_vqmovnbq_m_sv4si */
    case 4083:  /* mve_vqmovnbq_m_uv8hi */
    case 4082:  /* mve_vqmovnbq_m_sv8hi */
    case 4081:  /* mve_vpselq_fv4sf */
    case 4080:  /* mve_vpselq_fv8hf */
    case 4079:  /* mve_vorrq_m_n_uv4si */
    case 4078:  /* mve_vorrq_m_n_sv4si */
    case 4077:  /* mve_vorrq_m_n_uv8hi */
    case 4076:  /* mve_vorrq_m_n_sv8hi */
    case 4075:  /* mve_vnegq_m_fv4sf */
    case 4074:  /* mve_vnegq_m_fv8hf */
    case 4073:  /* mve_vmvnq_m_n_sv4si */
    case 4072:  /* mve_vmvnq_m_n_uv4si */
    case 4071:  /* mve_vmvnq_m_n_sv8hi */
    case 4070:  /* mve_vmvnq_m_n_uv8hi */
    case 4069:  /* mve_vmovntq_m_sv4si */
    case 4068:  /* mve_vmovntq_m_uv4si */
    case 4067:  /* mve_vmovntq_m_sv8hi */
    case 4066:  /* mve_vmovntq_m_uv8hi */
    case 4065:  /* mve_vmovnbq_m_sv4si */
    case 4064:  /* mve_vmovnbq_m_uv4si */
    case 4063:  /* mve_vmovnbq_m_sv8hi */
    case 4062:  /* mve_vmovnbq_m_uv8hi */
    case 4061:  /* mve_vmovltq_m_sv8hi */
    case 4060:  /* mve_vmovltq_m_uv8hi */
    case 4059:  /* mve_vmovltq_m_sv16qi */
    case 4058:  /* mve_vmovltq_m_uv16qi */
    case 4057:  /* mve_vmovlbq_m_sv8hi */
    case 4056:  /* mve_vmovlbq_m_uv8hi */
    case 4055:  /* mve_vmovlbq_m_sv16qi */
    case 4054:  /* mve_vmovlbq_m_uv16qi */
    case 4053:  /* mve_vmlsldavxq_p_sv4si */
    case 4052:  /* mve_vmlsldavxq_p_sv8hi */
    case 4051:  /* mve_vmlsldavq_p_sv4si */
    case 4050:  /* mve_vmlsldavq_p_sv8hi */
    case 4049:  /* mve_vmlsldavaxq_sv4si */
    case 4048:  /* mve_vmlsldavaxq_sv8hi */
    case 4047:  /* mve_vmlsldavaq_sv4si */
    case 4046:  /* mve_vmlsldavaq_sv8hi */
    case 4045:  /* mve_vmlaldavxq_p_sv4si */
    case 4044:  /* mve_vmlaldavxq_p_sv8hi */
    case 4043:  /* mve_vmlaldavq_p_sv4si */
    case 4042:  /* mve_vmlaldavq_p_uv4si */
    case 4041:  /* mve_vmlaldavq_p_sv8hi */
    case 4040:  /* mve_vmlaldavq_p_uv8hi */
    case 4039:  /* mve_vmlaldavaxq_sv4si */
    case 4038:  /* mve_vmlaldavaxq_sv8hi */
    case 4037:  /* mve_vmlaldavaq_uv4si */
    case 4036:  /* mve_vmlaldavaq_sv4si */
    case 4035:  /* mve_vmlaldavaq_uv8hi */
    case 4034:  /* mve_vmlaldavaq_sv8hi */
    case 4033:  /* mve_vminnmvq_p_fv4sf */
    case 4032:  /* mve_vminnmvq_p_fv8hf */
    case 4031:  /* mve_vminnmavq_p_fv4sf */
    case 4030:  /* mve_vminnmavq_p_fv8hf */
    case 4029:  /* mve_vminnmaq_m_fv4sf */
    case 4028:  /* mve_vminnmaq_m_fv8hf */
    case 4027:  /* mve_vmaxnmvq_p_fv4sf */
    case 4026:  /* mve_vmaxnmvq_p_fv8hf */
    case 4025:  /* mve_vmaxnmavq_p_fv4sf */
    case 4024:  /* mve_vmaxnmavq_p_fv8hf */
    case 4023:  /* mve_vmaxnmaq_m_fv4sf */
    case 4022:  /* mve_vmaxnmaq_m_fv8hf */
    case 4021:  /* mve_vfmsq_fv4sf */
    case 4020:  /* mve_vfmsq_fv8hf */
    case 4019:  /* mve_vfmasq_n_fv4sf */
    case 4018:  /* mve_vfmasq_n_fv8hf */
    case 4017:  /* mve_vfmaq_n_fv4sf */
    case 4016:  /* mve_vfmaq_n_fv8hf */
    case 4015:  /* mve_vfmaq_fv4sf */
    case 4014:  /* mve_vfmaq_fv8hf */
    case 4013:  /* mve_vdupq_m_n_fv4sf */
    case 4012:  /* mve_vdupq_m_n_fv8hf */
    case 4011:  /* mve_vcvttq_m_f32_f16v4sf */
    case 4010:  /* mve_vcvttq_m_f16_f32v8hf */
    case 4009:  /* mve_vcvtbq_m_f32_f16v4sf */
    case 4008:  /* mve_vcvtbq_m_f16_f32v8hf */
    case 4007:  /* mve_vcmpneq_m_n_fv4sf */
    case 4006:  /* mve_vcmpneq_m_n_fv8hf */
    case 4005:  /* mve_vcmpneq_m_fv4sf */
    case 4004:  /* mve_vcmpneq_m_fv8hf */
    case 4003:  /* mve_vcmpltq_m_n_fv4sf */
    case 4002:  /* mve_vcmpltq_m_n_fv8hf */
    case 4001:  /* mve_vcmpltq_m_fv4sf */
    case 4000:  /* mve_vcmpltq_m_fv8hf */
    case 3999:  /* mve_vcmpleq_m_n_fv4sf */
    case 3998:  /* mve_vcmpleq_m_n_fv8hf */
    case 3997:  /* mve_vcmpleq_m_fv4sf */
    case 3996:  /* mve_vcmpleq_m_fv8hf */
    case 3995:  /* mve_vcmpgtq_m_n_fv4sf */
    case 3994:  /* mve_vcmpgtq_m_n_fv8hf */
    case 3993:  /* mve_vcmpgtq_m_fv4sf */
    case 3992:  /* mve_vcmpgtq_m_fv8hf */
    case 3991:  /* mve_vcmpgeq_m_n_fv4sf */
    case 3990:  /* mve_vcmpgeq_m_n_fv8hf */
    case 3989:  /* mve_vcmpgeq_m_fv4sf */
    case 3988:  /* mve_vcmpgeq_m_fv8hf */
    case 3987:  /* mve_vcmpeqq_m_n_fv4sf */
    case 3986:  /* mve_vcmpeqq_m_n_fv8hf */
    case 3985:  /* mve_vcmlaq_rot270v4sf */
    case 3984:  /* mve_vcmlaq_rot180v4sf */
    case 3983:  /* mve_vcmlaq_rot90v4sf */
    case 3982:  /* mve_vcmlaqv4sf */
    case 3981:  /* mve_vcmlaq_rot270v8hf */
    case 3980:  /* mve_vcmlaq_rot180v8hf */
    case 3979:  /* mve_vcmlaq_rot90v8hf */
    case 3978:  /* mve_vcmlaqv8hf */
    case 3977:  /* mve_vaddlvaq_p_sv4si */
    case 3976:  /* mve_vaddlvaq_p_uv4si */
    case 3975:  /* mve_vabsq_m_fv4sf */
    case 3974:  /* mve_vabsq_m_fv8hf */
    case 3973:  /* mve_vmladavaxq_sv4si */
    case 3972:  /* mve_vmladavaxq_sv8hi */
    case 3971:  /* mve_vmladavaxq_sv16qi */
    case 3970:  /* mve_vmlsdavaq_sv4si */
    case 3969:  /* mve_vmlsdavaq_sv8hi */
    case 3968:  /* mve_vmlsdavaq_sv16qi */
    case 3967:  /* mve_vmlsdavaxq_sv4si */
    case 3966:  /* mve_vmlsdavaxq_sv8hi */
    case 3965:  /* mve_vmlsdavaxq_sv16qi */
    case 3964:  /* mve_vqdmladhq_sv4si */
    case 3963:  /* mve_vqdmladhq_sv8hi */
    case 3962:  /* mve_vqdmladhq_sv16qi */
    case 3961:  /* mve_vqdmladhxq_sv4si */
    case 3960:  /* mve_vqdmladhxq_sv8hi */
    case 3959:  /* mve_vqdmladhxq_sv16qi */
    case 3958:  /* mve_vqdmlsdhq_sv4si */
    case 3957:  /* mve_vqdmlsdhq_sv8hi */
    case 3956:  /* mve_vqdmlsdhq_sv16qi */
    case 3955:  /* mve_vqdmlsdhxq_sv4si */
    case 3954:  /* mve_vqdmlsdhxq_sv8hi */
    case 3953:  /* mve_vqdmlsdhxq_sv16qi */
    case 3952:  /* mve_vsriq_n_uv4si */
    case 3951:  /* mve_vsriq_n_sv4si */
    case 3950:  /* mve_vsriq_n_uv8hi */
    case 3949:  /* mve_vsriq_n_sv8hi */
    case 3948:  /* mve_vsriq_n_uv16qi */
    case 3947:  /* mve_vsriq_n_sv16qi */
    case 3946:  /* mve_vsliq_n_uv4si */
    case 3945:  /* mve_vsliq_n_sv4si */
    case 3944:  /* mve_vsliq_n_uv8hi */
    case 3943:  /* mve_vsliq_n_sv8hi */
    case 3942:  /* mve_vsliq_n_uv16qi */
    case 3941:  /* mve_vsliq_n_sv16qi */
    case 3940:  /* mve_vshlq_m_r_uv4si */
    case 3939:  /* mve_vshlq_m_r_sv4si */
    case 3938:  /* mve_vshlq_m_r_uv8hi */
    case 3937:  /* mve_vshlq_m_r_sv8hi */
    case 3936:  /* mve_vshlq_m_r_uv16qi */
    case 3935:  /* mve_vshlq_m_r_sv16qi */
    case 3934:  /* mve_vrshlq_m_n_uv4si */
    case 3933:  /* mve_vrshlq_m_n_sv4si */
    case 3932:  /* mve_vrshlq_m_n_uv8hi */
    case 3931:  /* mve_vrshlq_m_n_sv8hi */
    case 3930:  /* mve_vrshlq_m_n_uv16qi */
    case 3929:  /* mve_vrshlq_m_n_sv16qi */
    case 3928:  /* mve_vrev64q_m_uv4si */
    case 3927:  /* mve_vrev64q_m_sv4si */
    case 3926:  /* mve_vrev64q_m_uv8hi */
    case 3925:  /* mve_vrev64q_m_sv8hi */
    case 3924:  /* mve_vrev64q_m_uv16qi */
    case 3923:  /* mve_vrev64q_m_sv16qi */
    case 3922:  /* mve_vqshlq_m_r_uv4si */
    case 3921:  /* mve_vqshlq_m_r_sv4si */
    case 3920:  /* mve_vqshlq_m_r_uv8hi */
    case 3919:  /* mve_vqshlq_m_r_sv8hi */
    case 3918:  /* mve_vqshlq_m_r_uv16qi */
    case 3917:  /* mve_vqshlq_m_r_sv16qi */
    case 3916:  /* mve_vqrshlq_m_n_uv4si */
    case 3915:  /* mve_vqrshlq_m_n_sv4si */
    case 3914:  /* mve_vqrshlq_m_n_uv8hi */
    case 3913:  /* mve_vqrshlq_m_n_sv8hi */
    case 3912:  /* mve_vqrshlq_m_n_uv16qi */
    case 3911:  /* mve_vqrshlq_m_n_sv16qi */
    case 3910:  /* mve_vqrdmlsdhxq_sv4si */
    case 3909:  /* mve_vqrdmlsdhxq_sv8hi */
    case 3908:  /* mve_vqrdmlsdhxq_sv16qi */
    case 3907:  /* mve_vqrdmlsdhq_sv4si */
    case 3906:  /* mve_vqrdmlsdhq_sv8hi */
    case 3905:  /* mve_vqrdmlsdhq_sv16qi */
    case 3904:  /* mve_vqrdmlashq_n_sv4si */
    case 3903:  /* mve_vqrdmlashq_n_sv8hi */
    case 3902:  /* mve_vqrdmlashq_n_sv16qi */
    case 3901:  /* mve_vqrdmlahq_n_sv4si */
    case 3900:  /* mve_vqrdmlahq_n_sv8hi */
    case 3899:  /* mve_vqrdmlahq_n_sv16qi */
    case 3898:  /* mve_vqrdmladhxq_sv4si */
    case 3897:  /* mve_vqrdmladhxq_sv8hi */
    case 3896:  /* mve_vqrdmladhxq_sv16qi */
    case 3895:  /* mve_vqrdmladhq_sv4si */
    case 3894:  /* mve_vqrdmladhq_sv8hi */
    case 3893:  /* mve_vqrdmladhq_sv16qi */
    case 3892:  /* mve_vqnegq_m_sv4si */
    case 3891:  /* mve_vqnegq_m_sv8hi */
    case 3890:  /* mve_vqnegq_m_sv16qi */
    case 3889:  /* mve_vqdmlashq_n_sv4si */
    case 3888:  /* mve_vqdmlashq_n_sv8hi */
    case 3887:  /* mve_vqdmlashq_n_sv16qi */
    case 3886:  /* mve_vqdmlahq_n_sv4si */
    case 3885:  /* mve_vqdmlahq_n_sv8hi */
    case 3884:  /* mve_vqdmlahq_n_sv16qi */
    case 3883:  /* mve_vqabsq_m_sv4si */
    case 3882:  /* mve_vqabsq_m_sv8hi */
    case 3881:  /* mve_vqabsq_m_sv16qi */
    case 3880:  /* mve_vpselq_uv2di */
    case 3879:  /* mve_vpselq_sv2di */
    case 3878:  /* mve_vpselq_uv4si */
    case 3877:  /* mve_vpselq_sv4si */
    case 3876:  /* mve_vpselq_uv8hi */
    case 3875:  /* mve_vpselq_sv8hi */
    case 3874:  /* mve_vpselq_uv16qi */
    case 3873:  /* mve_vpselq_sv16qi */
    case 3872:  /* mve_vnegq_m_sv4si */
    case 3871:  /* mve_vnegq_m_sv8hi */
    case 3870:  /* mve_vnegq_m_sv16qi */
    case 3869:  /* mve_vmvnq_m_uv4si */
    case 3868:  /* mve_vmvnq_m_sv4si */
    case 3867:  /* mve_vmvnq_m_uv8hi */
    case 3866:  /* mve_vmvnq_m_sv8hi */
    case 3865:  /* mve_vmvnq_m_uv16qi */
    case 3864:  /* mve_vmvnq_m_sv16qi */
    case 3863:  /* mve_vmlsdavxq_p_sv4si */
    case 3862:  /* mve_vmlsdavxq_p_sv8hi */
    case 3861:  /* mve_vmlsdavxq_p_sv16qi */
    case 3860:  /* mve_vmlsdavq_p_sv4si */
    case 3859:  /* mve_vmlsdavq_p_sv8hi */
    case 3858:  /* mve_vmlsdavq_p_sv16qi */
    case 3857:  /* mve_vmlasq_n_uv4si */
    case 3856:  /* mve_vmlasq_n_sv4si */
    case 3855:  /* mve_vmlasq_n_uv8hi */
    case 3854:  /* mve_vmlasq_n_sv8hi */
    case 3853:  /* mve_vmlasq_n_uv16qi */
    case 3852:  /* mve_vmlasq_n_sv16qi */
    case 3851:  /* mve_vmlaq_n_uv4si */
    case 3850:  /* mve_vmlaq_n_sv4si */
    case 3849:  /* mve_vmlaq_n_uv8hi */
    case 3848:  /* mve_vmlaq_n_sv8hi */
    case 3847:  /* mve_vmlaq_n_uv16qi */
    case 3846:  /* mve_vmlaq_n_sv16qi */
    case 3845:  /* mve_vmladavxq_p_sv4si */
    case 3844:  /* mve_vmladavxq_p_sv8hi */
    case 3843:  /* mve_vmladavxq_p_sv16qi */
    case 3842:  /* mve_vmladavq_p_uv4si */
    case 3841:  /* mve_vmladavq_p_sv4si */
    case 3840:  /* mve_vmladavq_p_uv8hi */
    case 3839:  /* mve_vmladavq_p_sv8hi */
    case 3838:  /* mve_vmladavq_p_uv16qi */
    case 3837:  /* mve_vmladavq_p_sv16qi */
    case 3836:  /* mve_vmladavaq_uv4si */
    case 3835:  /* mve_vmladavaq_sv4si */
    case 3834:  /* mve_vmladavaq_uv8hi */
    case 3833:  /* mve_vmladavaq_sv8hi */
    case 3832:  /* mve_vmladavaq_uv16qi */
    case 3831:  /* mve_vmladavaq_sv16qi */
    case 3830:  /* mve_vminvq_p_uv4si */
    case 3829:  /* mve_vminvq_p_sv4si */
    case 3828:  /* mve_vminvq_p_uv8hi */
    case 3827:  /* mve_vminvq_p_sv8hi */
    case 3826:  /* mve_vminvq_p_uv16qi */
    case 3825:  /* mve_vminvq_p_sv16qi */
    case 3824:  /* mve_vminavq_p_sv4si */
    case 3823:  /* mve_vminavq_p_sv8hi */
    case 3822:  /* mve_vminavq_p_sv16qi */
    case 3821:  /* mve_vminaq_m_sv4si */
    case 3820:  /* mve_vminaq_m_sv8hi */
    case 3819:  /* mve_vminaq_m_sv16qi */
    case 3818:  /* mve_vmaxvq_p_uv4si */
    case 3817:  /* mve_vmaxvq_p_sv4si */
    case 3816:  /* mve_vmaxvq_p_uv8hi */
    case 3815:  /* mve_vmaxvq_p_sv8hi */
    case 3814:  /* mve_vmaxvq_p_uv16qi */
    case 3813:  /* mve_vmaxvq_p_sv16qi */
    case 3812:  /* mve_vmaxavq_p_sv4si */
    case 3811:  /* mve_vmaxavq_p_sv8hi */
    case 3810:  /* mve_vmaxavq_p_sv16qi */
    case 3809:  /* mve_vmaxaq_m_sv4si */
    case 3808:  /* mve_vmaxaq_m_sv8hi */
    case 3807:  /* mve_vmaxaq_m_sv16qi */
    case 3806:  /* mve_vdupq_m_n_uv4si */
    case 3805:  /* mve_vdupq_m_n_sv4si */
    case 3804:  /* mve_vdupq_m_n_uv8hi */
    case 3803:  /* mve_vdupq_m_n_sv8hi */
    case 3802:  /* mve_vdupq_m_n_uv16qi */
    case 3801:  /* mve_vdupq_m_n_sv16qi */
    case 3800:  /* mve_vcmpneq_m_uv4si */
    case 3799:  /* mve_vcmpneq_m_sv4si */
    case 3798:  /* mve_vcmpneq_m_uv8hi */
    case 3797:  /* mve_vcmpneq_m_sv8hi */
    case 3796:  /* mve_vcmpneq_m_uv16qi */
    case 3795:  /* mve_vcmpneq_m_sv16qi */
    case 3794:  /* mve_vcmpneq_m_n_uv4si */
    case 3793:  /* mve_vcmpneq_m_n_sv4si */
    case 3792:  /* mve_vcmpneq_m_n_uv8hi */
    case 3791:  /* mve_vcmpneq_m_n_sv8hi */
    case 3790:  /* mve_vcmpneq_m_n_uv16qi */
    case 3789:  /* mve_vcmpneq_m_n_sv16qi */
    case 3788:  /* mve_vcmpltq_m_sv4si */
    case 3787:  /* mve_vcmpltq_m_sv8hi */
    case 3786:  /* mve_vcmpltq_m_sv16qi */
    case 3785:  /* mve_vcmpltq_m_n_sv4si */
    case 3784:  /* mve_vcmpltq_m_n_sv8hi */
    case 3783:  /* mve_vcmpltq_m_n_sv16qi */
    case 3782:  /* mve_vcmpleq_m_sv4si */
    case 3781:  /* mve_vcmpleq_m_sv8hi */
    case 3780:  /* mve_vcmpleq_m_sv16qi */
    case 3779:  /* mve_vcmpleq_m_n_sv4si */
    case 3778:  /* mve_vcmpleq_m_n_sv8hi */
    case 3777:  /* mve_vcmpleq_m_n_sv16qi */
    case 3776:  /* mve_vcmphiq_m_uv4si */
    case 3775:  /* mve_vcmphiq_m_uv8hi */
    case 3774:  /* mve_vcmphiq_m_uv16qi */
    case 3773:  /* mve_vcmphiq_m_n_uv4si */
    case 3772:  /* mve_vcmphiq_m_n_uv8hi */
    case 3771:  /* mve_vcmphiq_m_n_uv16qi */
    case 3770:  /* mve_vcmpgtq_m_sv4si */
    case 3769:  /* mve_vcmpgtq_m_sv8hi */
    case 3768:  /* mve_vcmpgtq_m_sv16qi */
    case 3767:  /* mve_vcmpgtq_m_n_sv4si */
    case 3766:  /* mve_vcmpgtq_m_n_sv8hi */
    case 3765:  /* mve_vcmpgtq_m_n_sv16qi */
    case 3764:  /* mve_vcmpgeq_m_sv4si */
    case 3763:  /* mve_vcmpgeq_m_sv8hi */
    case 3762:  /* mve_vcmpgeq_m_sv16qi */
    case 3761:  /* mve_vcmpgeq_m_n_sv4si */
    case 3760:  /* mve_vcmpgeq_m_n_sv8hi */
    case 3759:  /* mve_vcmpgeq_m_n_sv16qi */
    case 3758:  /* mve_vcmpeqq_m_uv4si */
    case 3757:  /* mve_vcmpeqq_m_sv4si */
    case 3756:  /* mve_vcmpeqq_m_uv8hi */
    case 3755:  /* mve_vcmpeqq_m_sv8hi */
    case 3754:  /* mve_vcmpeqq_m_uv16qi */
    case 3753:  /* mve_vcmpeqq_m_sv16qi */
    case 3752:  /* mve_vcmpeqq_m_n_uv4si */
    case 3751:  /* mve_vcmpeqq_m_n_sv4si */
    case 3750:  /* mve_vcmpeqq_m_n_uv8hi */
    case 3749:  /* mve_vcmpeqq_m_n_sv8hi */
    case 3748:  /* mve_vcmpeqq_m_n_uv16qi */
    case 3747:  /* mve_vcmpeqq_m_n_sv16qi */
    case 3746:  /* mve_vcmpcsq_m_uv4si */
    case 3745:  /* mve_vcmpcsq_m_uv8hi */
    case 3744:  /* mve_vcmpcsq_m_uv16qi */
    case 3743:  /* mve_vcmpcsq_m_n_uv4si */
    case 3742:  /* mve_vcmpcsq_m_n_uv8hi */
    case 3741:  /* mve_vcmpcsq_m_n_uv16qi */
    case 3740:  /* mve_vclzq_m_uv4si */
    case 3739:  /* mve_vclzq_m_sv4si */
    case 3738:  /* mve_vclzq_m_uv8hi */
    case 3737:  /* mve_vclzq_m_sv8hi */
    case 3736:  /* mve_vclzq_m_uv16qi */
    case 3735:  /* mve_vclzq_m_sv16qi */
    case 3734:  /* mve_vclsq_m_sv4si */
    case 3733:  /* mve_vclsq_m_sv8hi */
    case 3732:  /* mve_vclsq_m_sv16qi */
    case 3731:  /* mve_vaddvaq_p_uv4si */
    case 3730:  /* mve_vaddvaq_p_sv4si */
    case 3729:  /* mve_vaddvaq_p_uv8hi */
    case 3728:  /* mve_vaddvaq_p_sv8hi */
    case 3727:  /* mve_vaddvaq_p_uv16qi */
    case 3726:  /* mve_vaddvaq_p_sv16qi */
    case 3725:  /* mve_vabsq_m_sv4si */
    case 3724:  /* mve_vabsq_m_sv8hi */
    case 3723:  /* mve_vabsq_m_sv16qi */
    case 3722:  /* mve_vshlcq_uv4si */
    case 3721:  /* mve_vshlcq_sv4si */
    case 3720:  /* mve_vshlcq_uv8hi */
    case 3719:  /* mve_vshlcq_sv8hi */
    case 3718:  /* mve_vshlcq_uv16qi */
    case 3717:  /* mve_vshlcq_sv16qi */
    case 3716:  /* mve_vabavq_uv4si */
    case 3715:  /* mve_vabavq_sv4si */
    case 3714:  /* mve_vabavq_uv8hi */
    case 3713:  /* mve_vabavq_sv8hi */
    case 3712:  /* mve_vabavq_uv16qi */
    case 3711:  /* mve_vabavq_sv16qi */
    case 3710:  /* mve_vrmlaldavhaq_uv4si */
    case 3709:  /* mve_vrmlaldavhaq_sv4si */
    case 3708:  /* mve_vqrshrunbq_n_sv4si */
    case 3707:  /* mve_vqrshrunbq_n_sv8hi */
    case 3706:  /* mve_vqrshrnbq_n_sv4si */
    case 3705:  /* mve_vqrshrnbq_n_uv4si */
    case 3704:  /* mve_vqrshrnbq_n_sv8hi */
    case 3703:  /* mve_vqrshrnbq_n_uv8hi */
    case 3702:  /* mve_vcvtq_m_to_f_uv4sf */
    case 3701:  /* mve_vcvtq_m_to_f_sv4sf */
    case 3700:  /* mve_vcvtq_m_to_f_uv8hf */
    case 3699:  /* mve_vcvtq_m_to_f_sv8hf */
    case 3698:  /* mve_vcvtaq_m_uv4si */
    case 3697:  /* mve_vcvtaq_m_sv4si */
    case 3696:  /* mve_vcvtaq_m_uv8hi */
    case 3695:  /* mve_vcvtaq_m_sv8hi */
    case 3694:  /* mve_vcmpeqq_m_fv4sf */
    case 3693:  /* mve_vcmpeqq_m_fv8hf */
    case 3692:  /* mve_vbicq_m_n_uv4si */
    case 3691:  /* mve_vbicq_m_n_sv4si */
    case 3690:  /* mve_vbicq_m_n_uv8hi */
    case 3689:  /* mve_vbicq_m_n_sv8hi */
    case 3688:  /* mve_vrmlaldavhq_sv4si */
    case 3687:  /* mve_vrmlaldavhq_uv4si */
    case 3686:  /* mve_vmullbq_poly_pv8hi */
    case 3685:  /* mve_vmullbq_poly_pv16qi */
    case 3684:  /* mve_vmulltq_poly_pv8hi */
    case 3683:  /* mve_vmulltq_poly_pv16qi */
    case 3682:  /* mve_vsubq_fv4sf */
    case 3681:  /* mve_vsubq_fv8hf */
    case 3680:  /* mve_vshlltq_n_sv8hi */
    case 3679:  /* mve_vshlltq_n_uv8hi */
    case 3678:  /* mve_vshlltq_n_sv16qi */
    case 3677:  /* mve_vshlltq_n_uv16qi */
    case 3676:  /* mve_vshllbq_n_uv8hi */
    case 3675:  /* mve_vshllbq_n_sv8hi */
    case 3674:  /* mve_vshllbq_n_uv16qi */
    case 3673:  /* mve_vshllbq_n_sv16qi */
    case 3672:  /* mve_vrmlsldavhxq_sv4si */
    case 3671:  /* mve_vrmlsldavhq_sv4si */
    case 3670:  /* mve_vrmlaldavhxq_sv4si */
    case 3669:  /* mve_vqmovuntq_sv4si */
    case 3668:  /* mve_vqmovuntq_sv8hi */
    case 3667:  /* mve_vqmovunbq_sv4si */
    case 3666:  /* mve_vqmovunbq_sv8hi */
    case 3665:  /* mve_vqmovntq_sv4si */
    case 3664:  /* mve_vqmovntq_uv4si */
    case 3663:  /* mve_vqmovntq_sv8hi */
    case 3662:  /* mve_vqmovntq_uv8hi */
    case 3661:  /* mve_vqmovnbq_sv4si */
    case 3660:  /* mve_vqmovnbq_uv4si */
    case 3659:  /* mve_vqmovnbq_sv8hi */
    case 3658:  /* mve_vqmovnbq_uv8hi */
    case 3657:  /* mve_vqdmulltq_sv4si */
    case 3656:  /* mve_vqdmulltq_sv8hi */
    case 3655:  /* mve_vqdmulltq_n_sv4si */
    case 3654:  /* mve_vqdmulltq_n_sv8hi */
    case 3653:  /* mve_vqdmullbq_sv4si */
    case 3652:  /* mve_vqdmullbq_sv8hi */
    case 3651:  /* mve_vqdmullbq_n_sv4si */
    case 3650:  /* mve_vqdmullbq_n_sv8hi */
    case 3649:  /* mve_vorrq_n_sv4si */
    case 3648:  /* mve_vorrq_n_uv4si */
    case 3647:  /* mve_vorrq_n_sv8hi */
    case 3646:  /* mve_vorrq_n_uv8hi */
    case 3645:  /* mve_vorrq_fv4sf */
    case 3644:  /* mve_vorrq_fv8hf */
    case 3643:  /* mve_vornq_fv4sf */
    case 3642:  /* mve_vornq_fv8hf */
    case 3641:  /* mve_vmulq_n_fv4sf */
    case 3640:  /* mve_vmulq_n_fv8hf */
    case 3639:  /* mve_vmulq_fv4sf */
    case 3638:  /* mve_vmulq_fv8hf */
    case 3637:  /* mve_vmovntq_uv4si */
    case 3636:  /* mve_vmovntq_sv4si */
    case 3635:  /* mve_vmovntq_uv8hi */
    case 3634:  /* mve_vmovntq_sv8hi */
    case 3633:  /* mve_vmovnbq_sv4si */
    case 3632:  /* mve_vmovnbq_uv4si */
    case 3631:  /* mve_vmovnbq_sv8hi */
    case 3630:  /* mve_vmovnbq_uv8hi */
    case 3629:  /* mve_vmlsldavxq_sv4si */
    case 3628:  /* mve_vmlsldavxq_sv8hi */
    case 3627:  /* mve_vmlsldavq_sv4si */
    case 3626:  /* mve_vmlsldavq_sv8hi */
    case 3625:  /* mve_vmlaldavxq_sv4si */
    case 3624:  /* mve_vmlaldavxq_sv8hi */
    case 3623:  /* mve_vmlaldavq_sv4si */
    case 3622:  /* mve_vmlaldavq_uv4si */
    case 3621:  /* mve_vmlaldavq_sv8hi */
    case 3620:  /* mve_vmlaldavq_uv8hi */
    case 3619:  /* mve_vminnmvq_fv4sf */
    case 3618:  /* mve_vminnmvq_fv8hf */
    case 3617:  /* mve_vminnmq_fv4sf */
    case 3616:  /* mve_vminnmq_fv8hf */
    case 3615:  /* mve_vminnmavq_fv4sf */
    case 3614:  /* mve_vminnmavq_fv8hf */
    case 3613:  /* mve_vminnmaq_fv4sf */
    case 3612:  /* mve_vminnmaq_fv8hf */
    case 3611:  /* mve_vmaxnmvq_fv4sf */
    case 3610:  /* mve_vmaxnmvq_fv8hf */
    case 3609:  /* mve_vmaxnmq_fv4sf */
    case 3608:  /* mve_vmaxnmq_fv8hf */
    case 3607:  /* mve_vmaxnmavq_fv4sf */
    case 3606:  /* mve_vmaxnmavq_fv8hf */
    case 3605:  /* mve_vmaxnmaq_fv4sf */
    case 3604:  /* mve_vmaxnmaq_fv8hf */
    case 3603:  /* mve_veorq_fv4sf */
    case 3602:  /* mve_veorq_fv8hf */
    case 3601:  /* mve_vcvttq_f16_f32v8hf */
    case 3600:  /* mve_vcvtbq_f16_f32v8hf */
    case 3599:  /* mve_vctp64q_mv2qi */
    case 3598:  /* mve_vctp32q_mv4bi */
    case 3597:  /* mve_vctp16q_mv8bi */
    case 3596:  /* mve_vctp8q_mv16bi */
    case 3595:  /* mve_vcmulq_rot270v4sf */
    case 3594:  /* mve_vcmulq_rot180v4sf */
    case 3593:  /* mve_vcmulq_rot90v4sf */
    case 3592:  /* mve_vcmulqv4sf */
    case 3591:  /* mve_vcmulq_rot270v8hf */
    case 3590:  /* mve_vcmulq_rot180v8hf */
    case 3589:  /* mve_vcmulq_rot90v8hf */
    case 3588:  /* mve_vcmulqv8hf */
    case 3587:  /* mve_vcmpneq_n_fv4sf */
    case 3586:  /* mve_vcmpltq_n_fv4sf */
    case 3585:  /* mve_vcmpleq_n_fv4sf */
    case 3584:  /* mve_vcmpgtq_n_fv4sf */
    case 3583:  /* mve_vcmpgeq_n_fv4sf */
    case 3582:  /* mve_vcmpeqq_n_fv4sf */
    case 3581:  /* mve_vcmpneq_n_fv8hf */
    case 3580:  /* mve_vcmpltq_n_fv8hf */
    case 3579:  /* mve_vcmpleq_n_fv8hf */
    case 3578:  /* mve_vcmpgtq_n_fv8hf */
    case 3577:  /* mve_vcmpgeq_n_fv8hf */
    case 3576:  /* mve_vcmpeqq_n_fv8hf */
    case 3575:  /* mve_vcmpneq_fv4sf */
    case 3574:  /* mve_vcmpltq_fv4sf */
    case 3573:  /* mve_vcmpleq_fv4sf */
    case 3572:  /* mve_vcmpgtq_fv4sf */
    case 3571:  /* mve_vcmpgeq_fv4sf */
    case 3570:  /* mve_vcmpeqq_fv4sf */
    case 3569:  /* mve_vcmpneq_fv8hf */
    case 3568:  /* mve_vcmpltq_fv8hf */
    case 3567:  /* mve_vcmpleq_fv8hf */
    case 3566:  /* mve_vcmpgtq_fv8hf */
    case 3565:  /* mve_vcmpgeq_fv8hf */
    case 3564:  /* mve_vcmpeqq_fv8hf */
    case 3563:  /* mve_vcaddq_rot270v4sf */
    case 3562:  /* mve_vcaddq_rot90v4sf */
    case 3561:  /* mve_vcaddq_rot270v8hf */
    case 3560:  /* mve_vcaddq_rot90v8hf */
    case 3559:  /* mve_vbicq_n_uv4si */
    case 3558:  /* mve_vbicq_n_sv4si */
    case 3557:  /* mve_vbicq_n_uv8hi */
    case 3556:  /* mve_vbicq_n_sv8hi */
    case 3555:  /* mve_vbicq_fv4sf */
    case 3554:  /* mve_vbicq_fv8hf */
    case 3553:  /* mve_vandq_fv4sf */
    case 3552:  /* mve_vandq_fv8hf */
    case 3551:  /* mve_vaddq_n_fv4sf */
    case 3550:  /* mve_vaddq_n_fv8hf */
    case 3549:  /* mve_vaddlvaq_uv4si */
    case 3548:  /* mve_vaddlvaq_sv4si */
    case 3547:  /* mve_vabdq_fv4sf */
    case 3546:  /* mve_vabdq_fv8hf */
    case 3545:  /* mve_vsubqv4si */
    case 3544:  /* mve_vsubqv8hi */
    case 3543:  /* mve_vsubqv16qi */
    case 3542:  /* mve_vsubq_uv4si */
    case 3541:  /* mve_vsubq_sv4si */
    case 3540:  /* mve_vsubq_uv8hi */
    case 3539:  /* mve_vsubq_sv8hi */
    case 3538:  /* mve_vsubq_uv16qi */
    case 3537:  /* mve_vsubq_sv16qi */
    case 3536:  /* mve_vsubq_n_uv4si */
    case 3535:  /* mve_vsubq_n_sv4si */
    case 3534:  /* mve_vsubq_n_uv8hi */
    case 3533:  /* mve_vsubq_n_sv8hi */
    case 3532:  /* mve_vsubq_n_uv16qi */
    case 3531:  /* mve_vsubq_n_sv16qi */
    case 3530:  /* mve_vshlq_r_uv4si */
    case 3529:  /* mve_vshlq_r_sv4si */
    case 3528:  /* mve_vshlq_r_uv8hi */
    case 3527:  /* mve_vshlq_r_sv8hi */
    case 3526:  /* mve_vshlq_r_uv16qi */
    case 3525:  /* mve_vshlq_r_sv16qi */
    case 3524:  /* mve_vshlq_n_sv4si */
    case 3523:  /* mve_vshlq_n_uv4si */
    case 3522:  /* mve_vshlq_n_sv8hi */
    case 3521:  /* mve_vshlq_n_uv8hi */
    case 3520:  /* mve_vshlq_n_sv16qi */
    case 3519:  /* mve_vshlq_n_uv16qi */
    case 3518:  /* mve_vrshrq_n_uv4si */
    case 3517:  /* mve_vrshrq_n_sv4si */
    case 3516:  /* mve_vrshrq_n_uv8hi */
    case 3515:  /* mve_vrshrq_n_sv8hi */
    case 3514:  /* mve_vrshrq_n_uv16qi */
    case 3513:  /* mve_vrshrq_n_sv16qi */
    case 3512:  /* mve_vrshlq_uv4si */
    case 3511:  /* mve_vrshlq_sv4si */
    case 3510:  /* mve_vrshlq_uv8hi */
    case 3509:  /* mve_vrshlq_sv8hi */
    case 3508:  /* mve_vrshlq_uv16qi */
    case 3507:  /* mve_vrshlq_sv16qi */
    case 3506:  /* mve_vrshlq_n_sv4si */
    case 3505:  /* mve_vrshlq_n_uv4si */
    case 3504:  /* mve_vrshlq_n_sv8hi */
    case 3503:  /* mve_vrshlq_n_uv8hi */
    case 3502:  /* mve_vrshlq_n_sv16qi */
    case 3501:  /* mve_vrshlq_n_uv16qi */
    case 3500:  /* mve_vrmulhq_uv4si */
    case 3499:  /* mve_vrmulhq_sv4si */
    case 3498:  /* mve_vrmulhq_uv8hi */
    case 3497:  /* mve_vrmulhq_sv8hi */
    case 3496:  /* mve_vrmulhq_uv16qi */
    case 3495:  /* mve_vrmulhq_sv16qi */
    case 3494:  /* mve_vrhaddq_uv4si */
    case 3493:  /* mve_vrhaddq_sv4si */
    case 3492:  /* mve_vrhaddq_uv8hi */
    case 3491:  /* mve_vrhaddq_sv8hi */
    case 3490:  /* mve_vrhaddq_uv16qi */
    case 3489:  /* mve_vrhaddq_sv16qi */
    case 3488:  /* mve_vqsubq_sv4si */
    case 3487:  /* mve_vqsubq_uv4si */
    case 3486:  /* mve_vqsubq_sv8hi */
    case 3485:  /* mve_vqsubq_uv8hi */
    case 3484:  /* mve_vqsubq_sv16qi */
    case 3483:  /* mve_vqsubq_uv16qi */
    case 3482:  /* mve_vqsubq_n_uv4si */
    case 3481:  /* mve_vqsubq_n_sv4si */
    case 3480:  /* mve_vqsubq_n_uv8hi */
    case 3479:  /* mve_vqsubq_n_sv8hi */
    case 3478:  /* mve_vqsubq_n_uv16qi */
    case 3477:  /* mve_vqsubq_n_sv16qi */
    case 3476:  /* mve_vqshluq_n_sv4si */
    case 3475:  /* mve_vqshluq_n_sv8hi */
    case 3474:  /* mve_vqshluq_n_sv16qi */
    case 3473:  /* mve_vqshlq_uv4si */
    case 3472:  /* mve_vqshlq_sv4si */
    case 3471:  /* mve_vqshlq_uv8hi */
    case 3470:  /* mve_vqshlq_sv8hi */
    case 3469:  /* mve_vqshlq_uv16qi */
    case 3468:  /* mve_vqshlq_sv16qi */
    case 3467:  /* mve_vqshlq_r_sv4si */
    case 3466:  /* mve_vqshlq_r_uv4si */
    case 3465:  /* mve_vqshlq_r_sv8hi */
    case 3464:  /* mve_vqshlq_r_uv8hi */
    case 3463:  /* mve_vqshlq_r_sv16qi */
    case 3462:  /* mve_vqshlq_r_uv16qi */
    case 3461:  /* mve_vqshlq_n_uv4si */
    case 3460:  /* mve_vqshlq_n_sv4si */
    case 3459:  /* mve_vqshlq_n_uv8hi */
    case 3458:  /* mve_vqshlq_n_sv8hi */
    case 3457:  /* mve_vqshlq_n_uv16qi */
    case 3456:  /* mve_vqshlq_n_sv16qi */
    case 3455:  /* mve_vqrshlq_uv4si */
    case 3454:  /* mve_vqrshlq_sv4si */
    case 3453:  /* mve_vqrshlq_uv8hi */
    case 3452:  /* mve_vqrshlq_sv8hi */
    case 3451:  /* mve_vqrshlq_uv16qi */
    case 3450:  /* mve_vqrshlq_sv16qi */
    case 3449:  /* mve_vqrshlq_n_uv4si */
    case 3448:  /* mve_vqrshlq_n_sv4si */
    case 3447:  /* mve_vqrshlq_n_uv8hi */
    case 3446:  /* mve_vqrshlq_n_sv8hi */
    case 3445:  /* mve_vqrshlq_n_uv16qi */
    case 3444:  /* mve_vqrshlq_n_sv16qi */
    case 3443:  /* mve_vqrdmulhq_sv4si */
    case 3442:  /* mve_vqrdmulhq_sv8hi */
    case 3441:  /* mve_vqrdmulhq_sv16qi */
    case 3440:  /* mve_vqrdmulhq_n_sv4si */
    case 3439:  /* mve_vqrdmulhq_n_sv8hi */
    case 3438:  /* mve_vqrdmulhq_n_sv16qi */
    case 3437:  /* mve_vqdmulhq_sv4si */
    case 3436:  /* mve_vqdmulhq_sv8hi */
    case 3435:  /* mve_vqdmulhq_sv16qi */
    case 3434:  /* mve_vqdmulhq_n_sv4si */
    case 3433:  /* mve_vqdmulhq_n_sv8hi */
    case 3432:  /* mve_vqdmulhq_n_sv16qi */
    case 3431:  /* mve_vqaddq_sv4si */
    case 3430:  /* mve_vqaddq_uv4si */
    case 3429:  /* mve_vqaddq_sv8hi */
    case 3428:  /* mve_vqaddq_uv8hi */
    case 3427:  /* mve_vqaddq_sv16qi */
    case 3426:  /* mve_vqaddq_uv16qi */
    case 3425:  /* mve_vqaddq_n_uv4si */
    case 3424:  /* mve_vqaddq_n_sv4si */
    case 3423:  /* mve_vqaddq_n_uv8hi */
    case 3422:  /* mve_vqaddq_n_sv8hi */
    case 3421:  /* mve_vqaddq_n_uv16qi */
    case 3420:  /* mve_vqaddq_n_sv16qi */
    case 3419:  /* mve_vorrq_sv4si */
    case 3418:  /* mve_vorrq_sv8hi */
    case 3417:  /* mve_vorrq_sv16qi */
    case 3416:  /* mve_vornq_sv4si */
    case 3415:  /* mve_vornq_sv8hi */
    case 3414:  /* mve_vornq_sv16qi */
    case 3413:  /* mve_vmulqv4si */
    case 3412:  /* mve_vmulqv8hi */
    case 3411:  /* mve_vmulqv16qi */
    case 3410:  /* mve_vmulq_sv4si */
    case 3409:  /* mve_vmulq_uv4si */
    case 3408:  /* mve_vmulq_sv8hi */
    case 3407:  /* mve_vmulq_uv8hi */
    case 3406:  /* mve_vmulq_sv16qi */
    case 3405:  /* mve_vmulq_uv16qi */
    case 3404:  /* mve_vmulq_n_sv4si */
    case 3403:  /* mve_vmulq_n_uv4si */
    case 3402:  /* mve_vmulq_n_sv8hi */
    case 3401:  /* mve_vmulq_n_uv8hi */
    case 3400:  /* mve_vmulq_n_sv16qi */
    case 3399:  /* mve_vmulq_n_uv16qi */
    case 3398:  /* mve_vmulltq_int_sv4si */
    case 3397:  /* mve_vmulltq_int_uv4si */
    case 3396:  /* mve_vmulltq_int_sv8hi */
    case 3395:  /* mve_vmulltq_int_uv8hi */
    case 3394:  /* mve_vmulltq_int_sv16qi */
    case 3393:  /* mve_vmulltq_int_uv16qi */
    case 3392:  /* mve_vmullbq_int_sv4si */
    case 3391:  /* mve_vmullbq_int_uv4si */
    case 3390:  /* mve_vmullbq_int_sv8hi */
    case 3389:  /* mve_vmullbq_int_uv8hi */
    case 3388:  /* mve_vmullbq_int_sv16qi */
    case 3387:  /* mve_vmullbq_int_uv16qi */
    case 3386:  /* mve_vmulhq_uv4si */
    case 3385:  /* mve_vmulhq_sv4si */
    case 3384:  /* mve_vmulhq_uv8hi */
    case 3383:  /* mve_vmulhq_sv8hi */
    case 3382:  /* mve_vmulhq_uv16qi */
    case 3381:  /* mve_vmulhq_sv16qi */
    case 3380:  /* mve_vmlsdavxq_sv4si */
    case 3379:  /* mve_vmlsdavxq_sv8hi */
    case 3378:  /* mve_vmlsdavxq_sv16qi */
    case 3377:  /* mve_vmlsdavq_sv4si */
    case 3376:  /* mve_vmlsdavq_sv8hi */
    case 3375:  /* mve_vmlsdavq_sv16qi */
    case 3374:  /* mve_vmladavxq_sv4si */
    case 3373:  /* mve_vmladavxq_sv8hi */
    case 3372:  /* mve_vmladavxq_sv16qi */
    case 3371:  /* mve_vmladavq_sv4si */
    case 3370:  /* mve_vmladavq_uv4si */
    case 3369:  /* mve_vmladavq_sv8hi */
    case 3368:  /* mve_vmladavq_uv8hi */
    case 3367:  /* mve_vmladavq_sv16qi */
    case 3366:  /* mve_vmladavq_uv16qi */
    case 3365:  /* mve_vminvq_sv4si */
    case 3364:  /* mve_vminvq_uv4si */
    case 3363:  /* mve_vminvq_sv8hi */
    case 3362:  /* mve_vminvq_uv8hi */
    case 3361:  /* mve_vminvq_sv16qi */
    case 3360:  /* mve_vminvq_uv16qi */
    case 3359:  /* mve_vminq_uv4si */
    case 3358:  /* mve_vminq_uv8hi */
    case 3357:  /* mve_vminq_uv16qi */
    case 3356:  /* mve_vminq_sv4si */
    case 3355:  /* mve_vminq_sv8hi */
    case 3354:  /* mve_vminq_sv16qi */
    case 3353:  /* mve_vminavq_sv4si */
    case 3352:  /* mve_vminavq_sv8hi */
    case 3351:  /* mve_vminavq_sv16qi */
    case 3350:  /* mve_vminaq_sv4si */
    case 3349:  /* mve_vminaq_sv8hi */
    case 3348:  /* mve_vminaq_sv16qi */
    case 3347:  /* mve_vmaxvq_sv4si */
    case 3346:  /* mve_vmaxvq_uv4si */
    case 3345:  /* mve_vmaxvq_sv8hi */
    case 3344:  /* mve_vmaxvq_uv8hi */
    case 3343:  /* mve_vmaxvq_sv16qi */
    case 3342:  /* mve_vmaxvq_uv16qi */
    case 3341:  /* mve_vmaxq_uv4si */
    case 3340:  /* mve_vmaxq_uv8hi */
    case 3339:  /* mve_vmaxq_uv16qi */
    case 3338:  /* mve_vmaxq_sv4si */
    case 3337:  /* mve_vmaxq_sv8hi */
    case 3336:  /* mve_vmaxq_sv16qi */
    case 3335:  /* mve_vmaxavq_sv4si */
    case 3334:  /* mve_vmaxavq_sv8hi */
    case 3333:  /* mve_vmaxavq_sv16qi */
    case 3332:  /* mve_vmaxaq_sv4si */
    case 3331:  /* mve_vmaxaq_sv8hi */
    case 3330:  /* mve_vmaxaq_sv16qi */
    case 3329:  /* mve_vhsubq_uv4si */
    case 3328:  /* mve_vhsubq_sv4si */
    case 3327:  /* mve_vhsubq_uv8hi */
    case 3326:  /* mve_vhsubq_sv8hi */
    case 3325:  /* mve_vhsubq_uv16qi */
    case 3324:  /* mve_vhsubq_sv16qi */
    case 3323:  /* mve_vhsubq_n_sv4si */
    case 3322:  /* mve_vhsubq_n_uv4si */
    case 3321:  /* mve_vhsubq_n_sv8hi */
    case 3320:  /* mve_vhsubq_n_uv8hi */
    case 3319:  /* mve_vhsubq_n_sv16qi */
    case 3318:  /* mve_vhsubq_n_uv16qi */
    case 3317:  /* mve_vhcaddq_rot90_sv4si */
    case 3316:  /* mve_vhcaddq_rot90_sv8hi */
    case 3315:  /* mve_vhcaddq_rot90_sv16qi */
    case 3314:  /* mve_vhcaddq_rot270_sv4si */
    case 3313:  /* mve_vhcaddq_rot270_sv8hi */
    case 3312:  /* mve_vhcaddq_rot270_sv16qi */
    case 3311:  /* mve_vhaddq_uv4si */
    case 3310:  /* mve_vhaddq_sv4si */
    case 3309:  /* mve_vhaddq_uv8hi */
    case 3308:  /* mve_vhaddq_sv8hi */
    case 3307:  /* mve_vhaddq_uv16qi */
    case 3306:  /* mve_vhaddq_sv16qi */
    case 3305:  /* mve_vhaddq_n_sv4si */
    case 3304:  /* mve_vhaddq_n_uv4si */
    case 3303:  /* mve_vhaddq_n_sv8hi */
    case 3302:  /* mve_vhaddq_n_uv8hi */
    case 3301:  /* mve_vhaddq_n_sv16qi */
    case 3300:  /* mve_vhaddq_n_uv16qi */
    case 3299:  /* mve_veorq_uv4si */
    case 3298:  /* mve_veorq_uv8hi */
    case 3297:  /* mve_veorq_uv16qi */
    case 3296:  /* mve_vcaddq_rot270v4si */
    case 3295:  /* mve_vcaddq_rot90v4si */
    case 3294:  /* mve_vcaddq_rot270v8hi */
    case 3293:  /* mve_vcaddq_rot90v8hi */
    case 3292:  /* mve_vcaddq_rot270v16qi */
    case 3291:  /* mve_vcaddq_rot90v16qi */
    case 3290:  /* mve_vbrsrq_n_sv4si */
    case 3289:  /* mve_vbrsrq_n_uv4si */
    case 3288:  /* mve_vbrsrq_n_sv8hi */
    case 3287:  /* mve_vbrsrq_n_uv8hi */
    case 3286:  /* mve_vbrsrq_n_sv16qi */
    case 3285:  /* mve_vbrsrq_n_uv16qi */
    case 3284:  /* mve_vbicq_uv4si */
    case 3283:  /* mve_vbicq_uv8hi */
    case 3282:  /* mve_vbicq_uv16qi */
    case 3281:  /* mve_vandq_uv4si */
    case 3280:  /* mve_vandq_uv8hi */
    case 3279:  /* mve_vandq_uv16qi */
    case 3278:  /* mve_vaddvq_p_sv4si */
    case 3277:  /* mve_vaddvq_p_uv4si */
    case 3276:  /* mve_vaddvq_p_sv8hi */
    case 3275:  /* mve_vaddvq_p_uv8hi */
    case 3274:  /* mve_vaddvq_p_sv16qi */
    case 3273:  /* mve_vaddvq_p_uv16qi */
    case 3272:  /* mve_vaddvaq_uv4si */
    case 3271:  /* mve_vaddvaq_sv4si */
    case 3270:  /* mve_vaddvaq_uv8hi */
    case 3269:  /* mve_vaddvaq_sv8hi */
    case 3268:  /* mve_vaddvaq_uv16qi */
    case 3267:  /* mve_vaddvaq_sv16qi */
    case 3266:  /* mve_vaddq_n_uv4si */
    case 3265:  /* mve_vaddq_n_sv4si */
    case 3264:  /* mve_vaddq_n_uv8hi */
    case 3263:  /* mve_vaddq_n_sv8hi */
    case 3262:  /* mve_vaddq_n_uv16qi */
    case 3261:  /* mve_vaddq_n_sv16qi */
    case 3260:  /* mve_vabdq_uv4si */
    case 3259:  /* mve_vabdq_sv4si */
    case 3258:  /* mve_vabdq_uv8hi */
    case 3257:  /* mve_vabdq_sv8hi */
    case 3256:  /* mve_vabdq_uv16qi */
    case 3255:  /* mve_vabdq_sv16qi */
    case 3254:  /* mve_vcmpneq_n_v4si */
    case 3253:  /* mve_vcmpltq_n_v4si */
    case 3252:  /* mve_vcmpleq_n_v4si */
    case 3251:  /* mve_vcmphiq_n_v4si */
    case 3250:  /* mve_vcmpgtq_n_v4si */
    case 3249:  /* mve_vcmpcsq_n_v4si */
    case 3248:  /* mve_vcmpgeq_n_v4si */
    case 3247:  /* mve_vcmpeqq_n_v4si */
    case 3246:  /* mve_vcmpneq_n_v8hi */
    case 3245:  /* mve_vcmpltq_n_v8hi */
    case 3244:  /* mve_vcmpleq_n_v8hi */
    case 3243:  /* mve_vcmphiq_n_v8hi */
    case 3242:  /* mve_vcmpgtq_n_v8hi */
    case 3241:  /* mve_vcmpcsq_n_v8hi */
    case 3240:  /* mve_vcmpgeq_n_v8hi */
    case 3239:  /* mve_vcmpeqq_n_v8hi */
    case 3238:  /* mve_vcmpneq_n_v16qi */
    case 3237:  /* mve_vcmpltq_n_v16qi */
    case 3236:  /* mve_vcmpleq_n_v16qi */
    case 3235:  /* mve_vcmphiq_n_v16qi */
    case 3234:  /* mve_vcmpgtq_n_v16qi */
    case 3233:  /* mve_vcmpcsq_n_v16qi */
    case 3232:  /* mve_vcmpgeq_n_v16qi */
    case 3231:  /* mve_vcmpeqq_n_v16qi */
    case 3230:  /* mve_vcmpneq_v4si */
    case 3229:  /* mve_vcmpltq_v4si */
    case 3228:  /* mve_vcmpleq_v4si */
    case 3227:  /* mve_vcmphiq_v4si */
    case 3226:  /* mve_vcmpgtq_v4si */
    case 3225:  /* mve_vcmpcsq_v4si */
    case 3224:  /* mve_vcmpgeq_v4si */
    case 3223:  /* mve_vcmpeqq_v4si */
    case 3222:  /* mve_vcmpneq_v8hi */
    case 3221:  /* mve_vcmpltq_v8hi */
    case 3220:  /* mve_vcmpleq_v8hi */
    case 3219:  /* mve_vcmphiq_v8hi */
    case 3218:  /* mve_vcmpgtq_v8hi */
    case 3217:  /* mve_vcmpcsq_v8hi */
    case 3216:  /* mve_vcmpgeq_v8hi */
    case 3215:  /* mve_vcmpeqq_v8hi */
    case 3214:  /* mve_vcmpneq_v16qi */
    case 3213:  /* mve_vcmpltq_v16qi */
    case 3212:  /* mve_vcmpleq_v16qi */
    case 3211:  /* mve_vcmphiq_v16qi */
    case 3210:  /* mve_vcmpgtq_v16qi */
    case 3209:  /* mve_vcmpcsq_v16qi */
    case 3208:  /* mve_vcmpgeq_v16qi */
    case 3207:  /* mve_vcmpeqq_v16qi */
    case 3206:  /* mve_vaddlvq_p_uv4si */
    case 3205:  /* mve_vaddlvq_p_sv4si */
    case 3204:  /* mve_vcvtq_n_from_f_uv4si */
    case 3203:  /* mve_vcvtq_n_from_f_sv4si */
    case 3202:  /* mve_vcvtq_n_from_f_uv8hi */
    case 3201:  /* mve_vcvtq_n_from_f_sv8hi */
    case 3200:  /* mve_vshrq_n_uv4si_imm */
    case 3199:  /* mve_vshrq_n_uv8hi_imm */
    case 3198:  /* mve_vshrq_n_uv16qi_imm */
    case 3197:  /* mve_vshrq_n_sv4si_imm */
    case 3196:  /* mve_vshrq_n_sv8hi_imm */
    case 3195:  /* mve_vshrq_n_sv16qi_imm */
    case 3194:  /* mve_vshrq_n_uv4si */
    case 3193:  /* mve_vshrq_n_sv4si */
    case 3192:  /* mve_vshrq_n_uv8hi */
    case 3191:  /* mve_vshrq_n_sv8hi */
    case 3190:  /* mve_vshrq_n_uv16qi */
    case 3189:  /* mve_vshrq_n_sv16qi */
    case 3188:  /* mve_vcreateq_sv2di */
    case 3187:  /* mve_vcreateq_uv2di */
    case 3186:  /* mve_vcreateq_sv4si */
    case 3185:  /* mve_vcreateq_uv4si */
    case 3184:  /* mve_vcreateq_sv8hi */
    case 3183:  /* mve_vcreateq_uv8hi */
    case 3182:  /* mve_vcreateq_sv16qi */
    case 3181:  /* mve_vcreateq_uv16qi */
    case 3180:  /* mve_vcreateq_fv4sf */
    case 3179:  /* mve_vcreateq_fv8hf */
    case 3178:  /* mve_vcvtq_n_to_f_uv4sf */
    case 3177:  /* mve_vcvtq_n_to_f_sv4sf */
    case 3176:  /* mve_vcvtq_n_to_f_uv8hf */
    case 3175:  /* mve_vcvtq_n_to_f_sv8hf */
    case 3174:  /* mve_vbrsrq_n_fv4sf */
    case 3173:  /* mve_vbrsrq_n_fv8hf */
    case 3172:  /* mve_vsubq_n_fv4sf */
    case 3171:  /* mve_vsubq_n_fv8hf */
    case 3170:  /* mve_vpnotv16bi */
    case 3169:  /* mve_vctp64qv2qi */
    case 3168:  /* mve_vctp32qv4bi */
    case 3167:  /* mve_vctp16qv8bi */
    case 3166:  /* mve_vctp8qv16bi */
    case 3165:  /* mve_vaddlvq_sv4si */
    case 3164:  /* mve_vaddlvq_uv4si */
    case 3163:  /* mve_vrev16q_sv16qi */
    case 3162:  /* mve_vrev16q_uv16qi */
    case 3161:  /* mve_vmvnq_n_sv4si */
    case 3160:  /* mve_vmvnq_n_uv4si */
    case 3159:  /* mve_vmvnq_n_sv8hi */
    case 3158:  /* mve_vmvnq_n_uv8hi */
    case 3157:  /* mve_vcvtaq_sv4si */
    case 3156:  /* mve_vcvtaq_uv4si */
    case 3155:  /* mve_vcvtaq_sv8hi */
    case 3154:  /* mve_vcvtaq_uv8hi */
    case 3153:  /* mve_vcvtmq_uv4si */
    case 3152:  /* mve_vcvtmq_sv4si */
    case 3151:  /* mve_vcvtmq_uv8hi */
    case 3150:  /* mve_vcvtmq_sv8hi */
    case 3149:  /* mve_vcvtnq_uv4si */
    case 3148:  /* mve_vcvtnq_sv4si */
    case 3147:  /* mve_vcvtnq_uv8hi */
    case 3146:  /* mve_vcvtnq_sv8hi */
    case 3145:  /* mve_vcvtpq_uv4si */
    case 3144:  /* mve_vcvtpq_sv4si */
    case 3143:  /* mve_vcvtpq_uv8hi */
    case 3142:  /* mve_vcvtpq_sv8hi */
    case 3141:  /* mve_vmovlbq_uv8hi */
    case 3140:  /* mve_vmovlbq_sv8hi */
    case 3139:  /* mve_vmovlbq_uv16qi */
    case 3138:  /* mve_vmovlbq_sv16qi */
    case 3137:  /* mve_vmovltq_sv8hi */
    case 3136:  /* mve_vmovltq_uv8hi */
    case 3135:  /* mve_vmovltq_sv16qi */
    case 3134:  /* mve_vmovltq_uv16qi */
    case 3133:  /* mve_vrev32q_sv8hi */
    case 3132:  /* mve_vrev32q_uv8hi */
    case 3131:  /* mve_vrev32q_sv16qi */
    case 3130:  /* mve_vrev32q_uv16qi */
    case 3129:  /* mve_vabsq_sv4si */
    case 3128:  /* mve_vabsq_sv8hi */
    case 3127:  /* mve_vabsq_sv16qi */
    case 3126:  /* mve_vaddvq_sv4si */
    case 3125:  /* mve_vaddvq_uv4si */
    case 3124:  /* mve_vaddvq_sv8hi */
    case 3123:  /* mve_vaddvq_uv8hi */
    case 3122:  /* mve_vaddvq_sv16qi */
    case 3121:  /* mve_vaddvq_uv16qi */
    case 3120:  /* mve_vclsq_sv4si */
    case 3119:  /* mve_vclsq_sv8hi */
    case 3118:  /* mve_vclsq_sv16qi */
    case 3117:  /* mve_vclzq_sv4si */
    case 3116:  /* mve_vclzq_sv8hi */
    case 3115:  /* mve_vclzq_sv16qi */
    case 3114:  /* mve_vdupq_n_sv4si */
    case 3113:  /* mve_vdupq_n_uv4si */
    case 3112:  /* mve_vdupq_n_sv8hi */
    case 3111:  /* mve_vdupq_n_uv8hi */
    case 3110:  /* mve_vdupq_n_sv16qi */
    case 3109:  /* mve_vdupq_n_uv16qi */
    case 3108:  /* mve_vmvnq_uv4si */
    case 3107:  /* mve_vmvnq_uv8hi */
    case 3106:  /* mve_vmvnq_uv16qi */
    case 3105:  /* mve_vnegq_sv4si */
    case 3104:  /* mve_vnegq_sv8hi */
    case 3103:  /* mve_vnegq_sv16qi */
    case 3102:  /* mve_vqabsq_sv4si */
    case 3101:  /* mve_vqabsq_sv8hi */
    case 3100:  /* mve_vqabsq_sv16qi */
    case 3099:  /* mve_vqnegq_sv4si */
    case 3098:  /* mve_vqnegq_sv8hi */
    case 3097:  /* mve_vqnegq_sv16qi */
    case 3096:  /* mve_vcvtq_from_f_uv4si */
    case 3095:  /* mve_vcvtq_from_f_sv4si */
    case 3094:  /* mve_vcvtq_from_f_uv8hi */
    case 3093:  /* mve_vcvtq_from_f_sv8hi */
    case 3092:  /* mve_vrev64q_uv4si */
    case 3091:  /* mve_vrev64q_sv4si */
    case 3090:  /* mve_vrev64q_uv8hi */
    case 3089:  /* mve_vrev64q_sv8hi */
    case 3088:  /* mve_vrev64q_uv16qi */
    case 3087:  /* mve_vrev64q_sv16qi */
    case 3086:  /* mve_vcvtq_to_f_uv4sf */
    case 3085:  /* mve_vcvtq_to_f_sv4sf */
    case 3084:  /* mve_vcvtq_to_f_uv8hf */
    case 3083:  /* mve_vcvtq_to_f_sv8hf */
    case 3082:  /* mve_vcvtbq_f32_f16v4sf */
    case 3081:  /* mve_vcvttq_f32_f16v4sf */
    case 3080:  /* mve_vrev32q_fv8hf */
    case 3079:  /* mve_vabsq_fv4sf */
    case 3078:  /* mve_vabsq_fv8hf */
    case 3077:  /* mve_vdupq_n_fv4sf */
    case 3076:  /* mve_vdupq_n_fv8hf */
    case 3075:  /* mve_vnegq_fv4sf */
    case 3074:  /* mve_vnegq_fv8hf */
    case 3073:  /* mve_vrev64q_fv4sf */
    case 3072:  /* mve_vrev64q_fv8hf */
    case 3071:  /* mve_vrndaq_fv4sf */
    case 3070:  /* mve_vrndaq_fv8hf */
    case 3069:  /* mve_vrndmq_fv4sf */
    case 3068:  /* mve_vrndmq_fv8hf */
    case 3067:  /* mve_vrndnq_fv4sf */
    case 3066:  /* mve_vrndnq_fv8hf */
    case 3065:  /* mve_vrndpq_fv4sf */
    case 3064:  /* mve_vrndpq_fv8hf */
    case 3063:  /* mve_vrndq_fv4sf */
    case 3062:  /* mve_vrndq_fv8hf */
    case 3061:  /* mve_vrndxq_fv4sf */
    case 3060:  /* mve_vrndxq_fv8hf */
    case 3059:  /* mve_vrndq_m_fv4sf */
    case 3058:  /* mve_vrndq_m_fv8hf */
    case 3057:  /* mve_vst4qv4sf */
    case 3056:  /* mve_vst4qv8hf */
    case 3055:  /* mve_vst4qv4si */
    case 3054:  /* mve_vst4qv8hi */
    case 3053:  /* mve_vst4qv16qi */
    case 3052:  /* *mve_vdupv2df */
    case 3051:  /* *mve_vdupv4sf */
    case 3050:  /* *mve_vdupv8hf */
    case 3049:  /* *mve_vdupv2di */
    case 3048:  /* *mve_vdupv4si */
    case 3047:  /* *mve_vdupv8hi */
    case 3046:  /* *mve_vdupv16qi */
    case 2979:  /* arm_store_release_exclusivesi */
    case 2978:  /* arm_store_release_exclusivehi */
    case 2977:  /* arm_store_release_exclusiveqi */
    case 2976:  /* arm_store_release_exclusivedi */
    case 2975:  /* arm_store_exclusivedi */
    case 2974:  /* arm_store_exclusivesi */
    case 2973:  /* arm_store_exclusivehi */
    case 2972:  /* arm_store_exclusiveqi */
    case 2971:  /* arm_load_acquire_exclusivedi */
    case 2970:  /* arm_load_exclusivedi */
    case 2969:  /* arm_load_acquire_exclusivesi */
    case 2968:  /* arm_load_exclusivesi */
    case 2967:  /* arm_load_acquire_exclusivehi */
    case 2966:  /* arm_load_acquire_exclusiveqi */
    case 2965:  /* arm_load_exclusivehi */
    case 2964:  /* arm_load_exclusiveqi */
    case 2963:  /* atomic_nand_fetchdi */
    case 2962:  /* atomic_nand_fetchsi */
    case 2961:  /* atomic_nand_fetchhi */
    case 2960:  /* atomic_nand_fetchqi */
    case 2959:  /* atomic_and_fetchdi */
    case 2958:  /* atomic_xor_fetchdi */
    case 2957:  /* atomic_or_fetchdi */
    case 2956:  /* atomic_sub_fetchdi */
    case 2955:  /* atomic_add_fetchdi */
    case 2954:  /* atomic_and_fetchsi */
    case 2953:  /* atomic_xor_fetchsi */
    case 2952:  /* atomic_or_fetchsi */
    case 2951:  /* atomic_sub_fetchsi */
    case 2950:  /* atomic_add_fetchsi */
    case 2949:  /* atomic_and_fetchhi */
    case 2948:  /* atomic_xor_fetchhi */
    case 2947:  /* atomic_or_fetchhi */
    case 2946:  /* atomic_sub_fetchhi */
    case 2945:  /* atomic_add_fetchhi */
    case 2944:  /* atomic_and_fetchqi */
    case 2943:  /* atomic_xor_fetchqi */
    case 2942:  /* atomic_or_fetchqi */
    case 2941:  /* atomic_sub_fetchqi */
    case 2940:  /* atomic_add_fetchqi */
    case 2939:  /* atomic_fetch_nanddi */
    case 2938:  /* atomic_fetch_nandsi */
    case 2937:  /* atomic_fetch_nandhi */
    case 2936:  /* atomic_fetch_nandqi */
    case 2935:  /* atomic_fetch_anddi */
    case 2934:  /* atomic_fetch_xordi */
    case 2933:  /* atomic_fetch_ordi */
    case 2932:  /* atomic_fetch_subdi */
    case 2931:  /* atomic_fetch_adddi */
    case 2930:  /* atomic_fetch_andsi */
    case 2929:  /* atomic_fetch_xorsi */
    case 2928:  /* atomic_fetch_orsi */
    case 2927:  /* atomic_fetch_subsi */
    case 2926:  /* atomic_fetch_addsi */
    case 2925:  /* atomic_fetch_andhi */
    case 2924:  /* atomic_fetch_xorhi */
    case 2923:  /* atomic_fetch_orhi */
    case 2922:  /* atomic_fetch_subhi */
    case 2921:  /* atomic_fetch_addhi */
    case 2920:  /* atomic_fetch_andqi */
    case 2919:  /* atomic_fetch_xorqi */
    case 2918:  /* atomic_fetch_orqi */
    case 2917:  /* atomic_fetch_subqi */
    case 2916:  /* atomic_fetch_addqi */
    case 2915:  /* atomic_nanddi */
    case 2914:  /* atomic_nandsi */
    case 2913:  /* atomic_nandhi */
    case 2912:  /* atomic_nandqi */
    case 2911:  /* atomic_anddi */
    case 2910:  /* atomic_xordi */
    case 2909:  /* atomic_ordi */
    case 2908:  /* atomic_subdi */
    case 2907:  /* atomic_adddi */
    case 2906:  /* atomic_andsi */
    case 2905:  /* atomic_xorsi */
    case 2904:  /* atomic_orsi */
    case 2903:  /* atomic_subsi */
    case 2902:  /* atomic_addsi */
    case 2901:  /* atomic_andhi */
    case 2900:  /* atomic_xorhi */
    case 2899:  /* atomic_orhi */
    case 2898:  /* atomic_subhi */
    case 2897:  /* atomic_addhi */
    case 2896:  /* atomic_andqi */
    case 2895:  /* atomic_xorqi */
    case 2894:  /* atomic_orqi */
    case 2893:  /* atomic_subqi */
    case 2892:  /* atomic_addqi */
    case 2891:  /* atomic_exchangedi */
    case 2890:  /* atomic_exchangesi */
    case 2889:  /* atomic_exchangehi */
    case 2888:  /* atomic_exchangeqi */
    case 2887:  /* atomic_compare_and_swapt1di_1 */
    case 2886:  /* atomic_compare_and_swapt1si_1 */
    case 2885:  /* atomic_compare_and_swap32di_1 */
    case 2884:  /* atomic_compare_and_swap32si_1 */
    case 2883:  /* atomic_compare_and_swapt1hi_1 */
    case 2882:  /* atomic_compare_and_swapt1qi_1 */
    case 2881:  /* atomic_compare_and_swap32hi_1 */
    case 2880:  /* atomic_compare_and_swap32qi_1 */
    case 2879:  /* arm_atomic_loaddi2_ldrd */
    case 2878:  /* atomic_storesi */
    case 2877:  /* atomic_storehi */
    case 2876:  /* atomic_storeqi */
    case 2875:  /* atomic_loadsi */
    case 2874:  /* atomic_loadhi */
    case 2873:  /* atomic_loadqi */
    case 2872:  /* *memory_barrier */
    case 2842:  /* neon_vbfcvtbf_cvtmodesf */
    case 2841:  /* neon_vbfcvtbf_cvtmodev2si */
    case 1069:  /* dls_insn */
    case 1067:  /* thumb2_lsrl */
    case 1066:  /* thumb2_lsll */
    case 1065:  /* thumb2_asrl */
    case 1064:  /* *clear_multiple */
    case 1063:  /* *clear_apsr */
    case 1044:  /* thumb2_eh_return */
    case 979:  /* *cstoresi_ne0_thumb1_insn */
    case 933:  /* arm_vcx3adi */
    case 932:  /* arm_vcx3asi */
    case 931:  /* arm_vcx3di */
    case 930:  /* arm_vcx3si */
    case 929:  /* arm_vcx2adi */
    case 928:  /* arm_vcx2asi */
    case 927:  /* arm_vcx2di */
    case 926:  /* arm_vcx2si */
    case 925:  /* arm_vcx1adi */
    case 924:  /* arm_vcx1asi */
    case 923:  /* arm_vcx1di */
    case 922:  /* arm_vcx1si */
    case 921:  /* no_literal_pool_sf_immediate */
    case 920:  /* no_literal_pool_df_immediate */
    case 857:  /* *cmpdf_trap_split_vfp */
    case 856:  /* *cmpdf_split_vfp */
    case 855:  /* *cmpsf_trap_split_vfp */
    case 854:  /* *cmpsf_split_vfp */
    case 745:  /* iwmmxt_textrcv8qi3 */
    case 744:  /* iwmmxt_textrcv4hi3 */
    case 743:  /* iwmmxt_textrcv2si3 */
    case 742:  /* iwmmxt_torvscv8qi3 */
    case 741:  /* iwmmxt_torvscv4hi3 */
    case 740:  /* iwmmxt_torvscv2si3 */
    case 739:  /* iwmmxt_torcv8qi3 */
    case 738:  /* iwmmxt_torcv4hi3 */
    case 737:  /* iwmmxt_torcv2si3 */
    case 736:  /* iwmmxt_tandcv8qi3 */
    case 735:  /* iwmmxt_tandcv4hi3 */
    case 734:  /* iwmmxt_tandcv2si3 */
    case 733:  /* iwmmxt_wmerge */
    case 732:  /* iwmmxt_wmiawttn */
    case 731:  /* iwmmxt_wmiawtbn */
    case 730:  /* iwmmxt_wmiawbtn */
    case 729:  /* iwmmxt_wmiawbbn */
    case 728:  /* iwmmxt_wmiawtt */
    case 727:  /* iwmmxt_wmiawtb */
    case 726:  /* iwmmxt_wmiawbt */
    case 725:  /* iwmmxt_wmiawbb */
    case 724:  /* iwmmxt_wmiattn */
    case 723:  /* iwmmxt_wmiatbn */
    case 722:  /* iwmmxt_wmiabtn */
    case 721:  /* iwmmxt_wmiabbn */
    case 720:  /* iwmmxt_wmiatt */
    case 719:  /* iwmmxt_wmiatb */
    case 718:  /* iwmmxt_wmiabt */
    case 717:  /* iwmmxt_wmiabb */
    case 716:  /* iwmmxt_wqmiattn */
    case 715:  /* iwmmxt_wqmiatbn */
    case 714:  /* iwmmxt_wqmiabtn */
    case 713:  /* iwmmxt_wqmiabbn */
    case 712:  /* iwmmxt_wqmiatt */
    case 711:  /* iwmmxt_wqmiatb */
    case 710:  /* iwmmxt_wqmiabt */
    case 709:  /* iwmmxt_wqmiabb */
    case 708:  /* iwmmxt_waddbhusl */
    case 707:  /* iwmmxt_waddbhusm */
    case 706:  /* iwmmxt_wqmulwmr */
    case 705:  /* iwmmxt_wqmulmr */
    case 704:  /* iwmmxt_wqmulwm */
    case 703:  /* iwmmxt_wqmulm */
    case 702:  /* iwmmxt_wmulwl */
    case 701:  /* iwmmxt_wmulwumr */
    case 700:  /* iwmmxt_wmulwsmr */
    case 699:  /* iwmmxt_wmulumr */
    case 698:  /* iwmmxt_wmulsmr */
    case 697:  /* iwmmxt_wmulwum */
    case 696:  /* iwmmxt_wmulwsm */
    case 695:  /* iwmmxt_wmaddun */
    case 694:  /* iwmmxt_wmaddsn */
    case 693:  /* iwmmxt_wmaddux */
    case 692:  /* iwmmxt_wmaddsx */
    case 691:  /* iwmmxt_avg4r */
    case 690:  /* iwmmxt_avg4 */
    case 689:  /* addcv2si3 */
    case 688:  /* addcv4hi3 */
    case 687:  /* iwmmxt_wsubaddhx */
    case 686:  /* iwmmxt_waddsubhx */
    case 685:  /* iwmmxt_wabsdiffw */
    case 684:  /* iwmmxt_wabsdiffh */
    case 683:  /* iwmmxt_wabsdiffb */
    case 682:  /* iwmmxt_wabsv8qi3 */
    case 681:  /* iwmmxt_wabsv4hi3 */
    case 680:  /* iwmmxt_wabsv2si3 */
    case 679:  /* iwmmxt_wsadhz */
    case 678:  /* iwmmxt_wsadbz */
    case 677:  /* iwmmxt_wsadh */
    case 676:  /* iwmmxt_wsadb */
    case 675:  /* iwmmxt_walignr3 */
    case 674:  /* iwmmxt_walignr2 */
    case 673:  /* iwmmxt_walignr1 */
    case 672:  /* iwmmxt_walignr0 */
    case 671:  /* iwmmxt_walignr */
    case 670:  /* iwmmxt_waligni */
    case 669:  /* iwmmxt_waccw */
    case 668:  /* iwmmxt_wacch */
    case 667:  /* iwmmxt_waccb */
    case 666:  /* iwmmxt_tmovmskw */
    case 665:  /* iwmmxt_tmovmskh */
    case 664:  /* iwmmxt_tmovmskb */
    case 663:  /* iwmmxt_tmiatt */
    case 662:  /* iwmmxt_tmiabt */
    case 661:  /* iwmmxt_tmiatb */
    case 660:  /* iwmmxt_tmiabb */
    case 659:  /* iwmmxt_tmiaph */
    case 658:  /* iwmmxt_tmia */
    case 657:  /* iwmmxt_wmaddu */
    case 656:  /* iwmmxt_wmadds */
    case 655:  /* ashldi3_di */
    case 654:  /* ashlv2si3_di */
    case 653:  /* ashlv4hi3_di */
    case 652:  /* lshrdi3_di */
    case 651:  /* lshrv2si3_di */
    case 650:  /* lshrv4hi3_di */
    case 649:  /* ashrdi3_di */
    case 648:  /* ashrv2si3_di */
    case 647:  /* ashrv4hi3_di */
    case 646:  /* rordi3_di */
    case 645:  /* rorv2si3_di */
    case 644:  /* rorv4hi3_di */
    case 643:  /* ashldi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 634:  /* rordi3 */
    case 633:  /* rorv2si3 */
    case 632:  /* rorv4hi3 */
    case 631:  /* iwmmxt_wunpckelsw */
    case 630:  /* iwmmxt_wunpckelsh */
    case 629:  /* iwmmxt_wunpckelsb */
    case 628:  /* iwmmxt_wunpckeluw */
    case 627:  /* iwmmxt_wunpckeluh */
    case 626:  /* iwmmxt_wunpckelub */
    case 625:  /* iwmmxt_wunpckehsw */
    case 624:  /* iwmmxt_wunpckehsh */
    case 623:  /* iwmmxt_wunpckehsb */
    case 622:  /* iwmmxt_wunpckehuw */
    case 621:  /* iwmmxt_wunpckehuh */
    case 620:  /* iwmmxt_wunpckehub */
    case 619:  /* iwmmxt_wunpckilw */
    case 618:  /* iwmmxt_wunpckilh */
    case 617:  /* iwmmxt_wunpckilb */
    case 616:  /* iwmmxt_wunpckihw */
    case 615:  /* iwmmxt_wunpckihh */
    case 614:  /* iwmmxt_wunpckihb */
    case 613:  /* iwmmxt_wpackdus */
    case 612:  /* iwmmxt_wpackwus */
    case 611:  /* iwmmxt_wpackhus */
    case 610:  /* iwmmxt_wpackdss */
    case 609:  /* iwmmxt_wpackwss */
    case 608:  /* iwmmxt_wpackhss */
    case 607:  /* *uminv8qi3_iwmmxt */
    case 606:  /* *uminv4hi3_iwmmxt */
    case 605:  /* *uminv2si3_iwmmxt */
    case 604:  /* *sminv8qi3_iwmmxt */
    case 603:  /* *sminv4hi3_iwmmxt */
    case 602:  /* *sminv2si3_iwmmxt */
    case 601:  /* *umaxv8qi3_iwmmxt */
    case 600:  /* *umaxv4hi3_iwmmxt */
    case 599:  /* *umaxv2si3_iwmmxt */
    case 598:  /* *smaxv8qi3_iwmmxt */
    case 597:  /* *smaxv4hi3_iwmmxt */
    case 596:  /* *smaxv2si3_iwmmxt */
    case 595:  /* gtv2si3 */
    case 594:  /* gtv4hi3 */
    case 593:  /* gtv8qi3 */
    case 592:  /* gtuv2si3 */
    case 591:  /* gtuv4hi3 */
    case 590:  /* gtuv8qi3 */
    case 589:  /* eqv2si3 */
    case 588:  /* eqv4hi3 */
    case 587:  /* eqv8qi3 */
    case 586:  /* iwmmxt_wshufh */
    case 585:  /* iwmmxt_textrmw */
    case 584:  /* iwmmxt_textrmsh */
    case 583:  /* iwmmxt_textrmuh */
    case 582:  /* iwmmxt_textrmsb */
    case 581:  /* iwmmxt_textrmub */
    case 580:  /* iwmmxt_tinsrw */
    case 579:  /* iwmmxt_tinsrh */
    case 578:  /* iwmmxt_tinsrb */
    case 577:  /* iwmmxt_uavgv4hi3 */
    case 576:  /* iwmmxt_uavgv8qi3 */
    case 575:  /* iwmmxt_uavgrndv4hi3 */
    case 574:  /* iwmmxt_uavgrndv8qi3 */
    case 573:  /* iwmmxt_clrv2si */
    case 572:  /* iwmmxt_clrv4hi */
    case 571:  /* iwmmxt_clrv8qi */
    case 570:  /* iwmmxt_clrdi */
    case 569:  /* iwmmxt_wmacuz */
    case 568:  /* iwmmxt_wmacu */
    case 567:  /* iwmmxt_wmacsz */
    case 566:  /* iwmmxt_wmacs */
    case 565:  /* umulv4hi3_highpart */
    case 564:  /* smulv4hi3_highpart */
    case 563:  /* *mulv4hi3_iwmmxt */
    case 562:  /* ussubv2si3 */
    case 561:  /* ussubv4hi3 */
    case 560:  /* ussubv8qi3 */
    case 559:  /* sssubv2si3 */
    case 558:  /* sssubv4hi3 */
    case 557:  /* sssubv8qi3 */
    case 556:  /* *subv8qi3_iwmmxt */
    case 555:  /* *subv4hi3_iwmmxt */
    case 554:  /* *subv2si3_iwmmxt */
    case 553:  /* usaddv2si3 */
    case 552:  /* usaddv4hi3 */
    case 551:  /* usaddv8qi3 */
    case 550:  /* ssaddv2si3 */
    case 549:  /* ssaddv4hi3 */
    case 548:  /* ssaddv8qi3 */
    case 547:  /* *addv8qi3_iwmmxt */
    case 546:  /* *addv4hi3_iwmmxt */
    case 545:  /* *addv2si3_iwmmxt */
    case 544:  /* *xorv8qi3_iwmmxt */
    case 543:  /* *xorv4hi3_iwmmxt */
    case 542:  /* *xorv2si3_iwmmxt */
    case 541:  /* *iorv8qi3_iwmmxt */
    case 540:  /* *iorv4hi3_iwmmxt */
    case 539:  /* *iorv2si3_iwmmxt */
    case 538:  /* *andv8qi3_iwmmxt */
    case 537:  /* *andv4hi3_iwmmxt */
    case 536:  /* *andv2si3_iwmmxt */
    case 529:  /* iwmmxt_nanddi3 */
    case 528:  /* iwmmxt_anddi3 */
    case 527:  /* iwmmxt_xordi3 */
    case 526:  /* iwmmxt_iordi3 */
    case 525:  /* tbcstv2si */
    case 524:  /* tbcstv4hi */
    case 523:  /* tbcstv8qi */
    case 510:  /* bti_nop */
    case 509:  /* aut_nop */
    case 508:  /* pacbti_nop */
    case 507:  /* pac_nop */
    case 505:  /* arm_mrrc2 */
    case 504:  /* arm_mrrc */
    case 503:  /* arm_mcrr2 */
    case 502:  /* arm_mcrr */
    case 501:  /* arm_mrc2 */
    case 500:  /* arm_mrc */
    case 499:  /* arm_mcr2 */
    case 498:  /* arm_mcr */
    case 497:  /* *stc */
    case 496:  /* *stc */
    case 495:  /* *stc */
    case 494:  /* *stc */
    case 493:  /* *ldc */
    case 492:  /* *ldc */
    case 491:  /* *ldc */
    case 490:  /* *ldc */
    case 489:  /* arm_cdp2 */
    case 488:  /* arm_cdp */
    case 487:  /* *load_multiple */
    case 404:  /* arm_eh_return */
    case 403:  /* force_register_use */
    case 401:  /* ctzsi2 */
    case 398:  /* consttable_16 */
    case 397:  /* consttable_8 */
    case 396:  /* consttable_4 */
    case 395:  /* consttable_2 */
    case 394:  /* consttable_1 */
    case 393:  /* consttable_end */
    case 392:  /* align_8 */
    case 391:  /* align_4 */
    case 318:  /* trap */
    case 310:  /* *stack_protect_combined_test_insn */
    case 308:  /* *stack_protect_combined_set_insn */
    case 289:  /* restore_pic_register_after_call */
    case 276:  /* *deleted_compare */
    case 150:  /* arm_cx3adi */
    case 149:  /* arm_cx3asi */
    case 148:  /* arm_cx3di */
    case 147:  /* arm_cx3si */
    case 146:  /* arm_cx2adi */
    case 145:  /* arm_cx2asi */
    case 144:  /* arm_cx2di */
    case 143:  /* arm_cx2si */
    case 142:  /* arm_cx1adi */
    case 141:  /* arm_cx1asi */
    case 140:  /* arm_cx1di */
    case 139:  /* arm_cx1si */
    case 132:  /* arm_set_apsr */
    case 131:  /* arm_get_apsr */
    case 54:  /* subvsi3_borrow */
    case 52:  /* usubvsi3_borrow */
      return 0;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FMOV) || (cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FADDD) || (cached_type == TYPE_FADDS)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FMULS) || (cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FMULD) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type = get_attr_type (insn)) == TYPE_F_LOADS))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type = get_attr_type (insn)) == TYPE_F_LOADD))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (((cached_type = get_attr_type (insn)) == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_MUL) || (cached_type == TYPE_MLA)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_MULS) || (cached_type == TYPE_MLAS)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMLAL)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULLS) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_UMLALS)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUADX) || (cached_type == TYPE_SMLAD) || (cached_type == TYPE_SMLADX) || (cached_type == TYPE_SMUSD) || (cached_type == TYPE_SMUSDX) || (cached_type == TYPE_SMLSD) || (cached_type == TYPE_SMLSDX)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type = get_attr_type (insn)) == TYPE_SMLALXY))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_SMMUL) || (cached_type == TYPE_SMMULR)))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type = get_attr_type (insn)) == TYPE_LOAD_4))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type = get_attr_type (insn)) == TYPE_LOAD_BYTE))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type = get_attr_type (insn)) == TYPE_LOAD_8))
        {
	  return 1;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULWY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (((cached_type = get_attr_type (insn)) == TYPE_MUL) || (cached_type == TYPE_MLA)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (((cached_type = get_attr_type (insn)) == TYPE_MULS) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMLAWX)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULLS) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_12)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type = get_attr_type (insn)) == TYPE_LOAD_16))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (((cached_type = get_attr_type (insn)) == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (((cached_type = get_attr_type (insn)) == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMLALXY) || (cached_type == TYPE_MUL) || (cached_type == TYPE_MLA) || (cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_SMLAWX) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_12)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type = get_attr_type (insn)) == TYPE_LOAD_16))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (((cached_type = get_attr_type (insn)) == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type = get_attr_type (insn)) == TYPE_F_LOADS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type = get_attr_type (insn)) == TYPE_F_LOADD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((((cached_type = get_attr_type (insn)) == TYPE_ADR) || (cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_EXTEND)) || (((cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG)) && (! (get_attr_length (insn) == 8)))))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (get_attr_cortex_a7_neon_type (insn) == CORTEX_A7_NEON_TYPE_NEON_MLA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type = get_attr_type (insn)) == TYPE_FMACD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type = get_attr_type (insn)) == TYPE_F_LOADS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type = get_attr_type (insn)) == TYPE_F_LOADD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_EXTEND)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_MUL) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMMUL)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_MLA) || (cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMMLA) || (cached_type == TYPE_SMLAD) || (cached_type == TYPE_SMLSD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_UMAAL) || (cached_type == TYPE_SMLALXY)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULWY) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUSD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMLALD) || (cached_type == TYPE_SMLSLD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_1))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_2))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_3))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_5))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VQNEG_VQABS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VABA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VABA_QQQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_BIT_OPS_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_8_16))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_QQD_32_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_SHIFT_1))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_SHIFT_2))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_SHIFT_3))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VQSHL_VRSHL_VQRSHL_QQQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VSRA_VRSRA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VSUM))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_DDD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_QQD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_DDD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (((cached_type = get_attr_type (insn)) == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_S_Q)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_BP_SIMPLE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_BP_2CYCLE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_BP_3CYCLE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_LDR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD2_4_REGS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4_LANE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MCR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMOV) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD) || (cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR) || (cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC) || (cached_type == TYPE_F_FLAG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_1))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_2))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_3))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_5))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VQNEG_VQABS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VMOV))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VABA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VABA_QQQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_BIT_OPS_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_8_16))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_QQD_32_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_SHIFT_1))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_SHIFT_2))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_SHIFT_3))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VQSHL_VRSHL_VQRSHL_QQQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VSRA_VRSRA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VSUM))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_DDD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_QQD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_DDD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_QQQ))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_BP_SIMPLE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_BP_2CYCLE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_BP_3CYCLE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_LDR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD2_4_REGS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD1_VLD2_LANE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4_LANE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4_ALL_LANES))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MCR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MCR_2_MCRR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_CRC) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ABD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ABD_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ARITH_ACC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ARITH_ACC_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_MULTIPLY))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_MULTIPLY_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_MLA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_MLA_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SAT_MLA_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_ACC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_BASIC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_COMPLEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_COMPLEX_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_NEGABS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_ARITH))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_ARITH_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_CVT_INT))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_CVT_INT_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_CVT16))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_MUL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_MUL_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_MLA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_MLA_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_RECPE_RSQRTE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_BITOPS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_BITOPS_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FROM_GP))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FROM_GP_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_TBL3_TBL4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ZIP_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_TO_GP))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_A))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_B))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_C))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_D))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_E))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_F))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_A))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_B))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_C))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_D))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_E))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_F))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_G))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_H))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FADDS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FADDD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FMULS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FMULD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FCMPD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FCMPS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FFARITHD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FMOV))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type = get_attr_type (insn)) == TYPE_FFARITHS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (((cached_type = get_attr_type (insn)) == TYPE_MUL) || (cached_type == TYPE_MULS) || (cached_type == TYPE_SMMUL) || (cached_type == TYPE_SMMULR)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (((cached_type = get_attr_type (insn)) == TYPE_MLA) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_SMMLA)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMLAD) || (cached_type == TYPE_SMLADX) || (cached_type == TYPE_SMLSD) || (cached_type == TYPE_SMLSDX) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUADX) || (cached_type == TYPE_SMUSD) || (cached_type == TYPE_SMUSDX)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMLAL) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_UMAAL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_UMLALS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMLALD) || (cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMLSLD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULL) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMULLS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_ADR) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MOV_SHIFT)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_CSEL) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_CRC) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_EXT) || (cached_type == TYPE_ALUS_EXT) || (cached_type == TYPE_BFM) || (cached_type == TYPE_BFX) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type = get_attr_type (insn)) == TYPE_ROTATE_IMM))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_ACQ)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type = get_attr_type (insn)) == TYPE_LOAD_8))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_FFARITHS) || (cached_type == TYPE_FADDS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FADDD) || (cached_type == TYPE_FMOV) || (cached_type == TYPE_F_CVT) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD) || (cached_type == TYPE_FCCMPS) || (cached_type == TYPE_FCCMPD) || (cached_type == TYPE_FCSEL) || (cached_type == TYPE_F_RINTS) || (cached_type == TYPE_F_RINTD) || (cached_type == TYPE_F_MINMAXS) || (cached_type == TYPE_F_MINMAXD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMULS) || (cached_type == TYPE_FMULD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACS) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FFMAD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_CVTI2F) || (cached_type == TYPE_NEON_FROM_GP) || (cached_type == TYPE_NEON_FROM_GP_Q)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((((cached_type = get_attr_type (insn)) == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD)) || ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128) || (cached_cortex_a53_advsimd_type == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFX) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_ROTATE_IMM) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_BFM) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_CRC) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_UDIV) || (cached_type == TYPE_SDIV)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type = get_attr_type (insn)) == TYPE_BLOCK))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type = get_attr_type (insn)) == TYPE_BRANCH))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ABD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ABD_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ARITH_ACC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ARITH_ACC_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_MULTIPLY))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_MULTIPLY_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_MLA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_MLA_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SAT_MLA_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_ACC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_BASIC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_COMPLEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_COMPLEX_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_NEGABS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_ARITH))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_ARITH_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_REDUCTIONS_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_CVT_INT))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_CVT_INT_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_CVT16))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_MUL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_MUL_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_MLA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_MLA_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_RECPE_RSQRTE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_RECPS_RSQRTS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_RECPS_RSQRTS_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_BITOPS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_BITOPS_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FROM_GP))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FROM_GP_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_TBL3_TBL4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ZIP_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_TO_GP))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_A))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_B))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_C))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_D))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_E))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_F))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_STORE_A))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_STORE_B))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FADDS) || (cached_type == TYPE_FADDD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMULS) || (cached_type == TYPE_FMULD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACS) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FCMPS) || (cached_type == TYPE_FCMPD) || (cached_type == TYPE_FCCMPS) || (cached_type == TYPE_FCCMPD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMOV) || (cached_type == TYPE_FCSEL)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS) || (cached_type == TYPE_NEON_FP_DIV_S) || (cached_type == TYPE_NEON_FP_SQRT_S)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD) || (cached_type == TYPE_NEON_FP_DIV_D) || (cached_type == TYPE_NEON_FP_SQRT_D)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD) || (cached_type == TYPE_NEON_FP_DIV_S_Q) || (cached_type == TYPE_NEON_FP_DIV_D_Q) || (cached_type == TYPE_NEON_FP_SQRT_S_Q) || (cached_type == TYPE_NEON_FP_SQRT_D_Q)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_CRYPTO_AESE) || (cached_type == TYPE_CRYPTO_AESMC) || (cached_type == TYPE_CRYPTO_SHA1_FAST) || (cached_type == TYPE_CRYPTO_SHA256_FAST)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_type = get_attr_type (insn)) == TYPE_CRYPTO_SHA1_SLOW) || (cached_type == TYPE_CRYPTO_SHA256_SLOW)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type = get_attr_type (insn)) == TYPE_CRYPTO_SHA1_XOR))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type = get_attr_type (insn)) == TYPE_CALL))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_MUL) || (cached_type == TYPE_SMMUL)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULXY) || (cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUSD)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_MLA) || (cached_type == TYPE_SMMLA)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_SMLAXY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMLAD) || (cached_type == TYPE_SMLSD)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_SMLALD) || (cached_type == TYPE_SMLSLD)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_SMULL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_UMAAL)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type = get_attr_type (insn)) == TYPE_FMOV))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FFARITHS) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCMPS)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FADDS) || (cached_type == TYPE_FMULS)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 1;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (((cached_type = get_attr_type (insn)) == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)) || ((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((cached_type = get_attr_type (insn)) == TYPE_FMULS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((cached_type = get_attr_type (insn)) == TYPE_FADDS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_BRANCH))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_CALL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (! ((cached_predicated = get_attr_predicated (insn)) == PREDICATED_YES)) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_BFX) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_CSEL) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_ROTATE_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_predicated = get_attr_predicated (insn)) == PREDICATED_YES) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_BFX) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_ROTATE_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_EXT) || (cached_type == TYPE_ALUS_EXT) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (! ((cached_predicated = get_attr_predicated (insn)) == PREDICATED_YES)) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_predicated = get_attr_predicated (insn)) == PREDICATED_YES) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_UDIV) || (cached_type == TYPE_SDIV)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_ARITH_SIMPLE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_MULTIPLY) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_MLA) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_SAT_MLA_LONG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_ACC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_BASIC) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_REG_BASIC)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_REG_COMPLEX)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_UNARY))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ADD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ABD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_COMPARE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_MINMAX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_ADD))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ROUND))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_CVT))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_MUL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_MLA))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ESTIMATE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ESTIMATEX))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_STEP))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_BITOPS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_BITOPS_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_BITINS))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_TBL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FROM_GP))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_TO_GP))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD) || (cached_type == TYPE_NEON_LDP)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_NEON_LDP_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ALL)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_2))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_3))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ONE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ONE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ALL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD3_3))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ONE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ALL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD4_4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ONE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ALL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_STORES) || (cached_type == TYPE_F_STORED) || (cached_type == TYPE_NEON_STP)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_NEON_STP_Q))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_1))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_2))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_3))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_4))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_ONE))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE2_2) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_STORE2_ONE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE3_3) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_STORE3_ONE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE4_4) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_STORE4_ONE)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FADDS) || (cached_type == TYPE_FADDD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMULS) || (cached_type == TYPE_FMULD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACS) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_CVT) || (cached_type == TYPE_F_RINTS) || (cached_type == TYPE_F_RINTD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_F_CVTF2I))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_F_CVTI2F))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FCCMPS) || (cached_type == TYPE_FCCMPD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_FCSEL))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_FMOV))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVS) || (cached_type == TYPE_NEON_FP_DIV_S) || (cached_type == TYPE_NEON_FP_DIV_S_Q) || (cached_type == TYPE_FSQRTS) || (cached_type == TYPE_NEON_FP_SQRT_S) || (cached_type == TYPE_NEON_FP_SQRT_S_Q)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_FDIVD) || (cached_type == TYPE_NEON_FP_DIV_D) || (cached_type == TYPE_NEON_FP_DIV_D_Q) || (cached_type == TYPE_FSQRTD) || (cached_type == TYPE_NEON_FP_SQRT_D) || (cached_type == TYPE_NEON_FP_SQRT_D_Q)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_F_MINMAXS) || (cached_type == TYPE_F_MINMAXD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_CRYPTO_AESE) || (cached_type == TYPE_CRYPTO_AESMC) || (cached_type == TYPE_CRYPTO_SHA1_XOR) || (cached_type == TYPE_CRYPTO_SHA1_FAST) || (cached_type == TYPE_CRYPTO_SHA256_FAST)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_CRYPTO_SHA1_SLOW) || (cached_type == TYPE_CRYPTO_SHA256_SLOW)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_type = get_attr_type (insn)) == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_MUL_S_LONG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_NEON_MUL_D_LONG))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type = get_attr_type (insn)) == TYPE_CRC))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)) && (! ((cached_conds = get_attr_conds (insn)) == CONDS_SET)) && (get_attr_shift (insn) == 1))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (! ((cached_conds = get_attr_conds (insn)) == CONDS_SET)) && (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type = get_attr_type (insn)) == TYPE_LOAD_8))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (((cached_type = get_attr_type (insn)) == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (((cached_type = get_attr_type (insn)) == TYPE_FMACS) || (cached_type == TYPE_FMACD)))
        {
	  return 1;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (((cached_type = get_attr_type (insn)) == TYPE_ALUS_IMM) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_ALUS_EXT) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_LOGICS_SHIFT_IMM)))
        {
	  return 1;
        }
      else
        {
	  return 0;
        }

    }
}

int
num_delay_slots (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

enum attr_add_setq
get_attr_add_setq (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 6394:  /* *p arm_smlawb_setq_insn */
    case 6396:  /* *p arm_smlawt_setq_insn */
    case 6416:  /* *p arm_qadd_setq_insn */
    case 6418:  /* *p arm_qsub_setq_insn */
    case 6422:  /* *p satsi_smin_setq */
    case 6424:  /* *p satsi_smax_setq */
    case 6504:  /* *p arm_smlad_setq_insn */
    case 6506:  /* *p arm_smladx_setq_insn */
    case 6508:  /* *p arm_smlsd_setq_insn */
    case 6510:  /* *p arm_smlsdx_setq_insn */
    case 6512:  /* *p arm_smuad_setq_insn */
    case 6514:  /* *p arm_smuadx_setq_insn */
    case 6516:  /* *p arm_ssat16_setq_insn */
    case 6518:  /* *p arm_usat16_setq_insn */
      return ADD_SETQ_YES;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return ADD_SETQ_NO;

    }
}

int
get_attr_arm_neg_pool_range (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 0;
        }
      else if (which_alternative == 3)
        {
	  return 1008 /* 0x3f0 */;
        }
      else if (((1ULL << which_alternative) & 0x1ff0ULL))
        {
	  return 0;
        }
      else if (which_alternative == 13)
        {
	  return 1008 /* 0x3f0 */;
        }
      else
        {
	  return 0;
        }

    case 271:  /* *movdf_soft_insn */
    case 255:  /* *arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 0;
        }
      else if (which_alternative == 3)
        {
	  return 1004 /* 0x3ec */;
        }
      else
        {
	  return 0;
        }

    case 270:  /* *arm_movsf_soft_insn */
    case 6529:  /* *p *arm_movsf_soft_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 0;
        }
      else if (which_alternative == 1)
        {
	  return 4084 /* 0xff4 */;
        }
      else
        {
	  return 0;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

int
get_attr_arm_pool_range (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 0;
        }
      else
        {
	  return 1020 /* 0x3fc */;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 0;
        }
      else if (which_alternative == 4)
        {
	  return 1020 /* 0x3fc */;
        }
      else if (((1ULL << which_alternative) & 0xe0ULL))
        {
	  return 0;
        }
      else if (which_alternative == 8)
        {
	  return 1020 /* 0x3fc */;
        }
      else
        {
	  return 0;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 0;
        }
      else if (which_alternative == 4)
        {
	  return 1020 /* 0x3fc */;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return 0;
        }
      else if (which_alternative == 7)
        {
	  return 1020 /* 0x3fc */;
        }
      else
        {
	  return 0;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 0;
        }
      else if (which_alternative == 4)
        {
	  return 1020 /* 0x3fc */;
        }
      else if (which_alternative == 5)
        {
	  return 4096 /* 0x1000 */;
        }
      else if (((1ULL << which_alternative) & 0x3c0ULL))
        {
	  return 0;
        }
      else if (which_alternative == 10)
        {
	  return 1020 /* 0x3fc */;
        }
      else
        {
	  return 0;
        }

    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 0;
        }
      else if (which_alternative == 3)
        {
	  return 1020 /* 0x3fc */;
        }
      else if (((1ULL << which_alternative) & 0x1ff0ULL))
        {
	  return 0;
        }
      else if (which_alternative == 13)
        {
	  return 1020 /* 0x3fc */;
        }
      else
        {
	  return 0;
        }

    case 271:  /* *movdf_soft_insn */
    case 255:  /* *arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 0;
        }
      else if (which_alternative == 3)
        {
	  return 1020 /* 0x3fc */;
        }
      else
        {
	  return 0;
        }

    case 270:  /* *arm_movsf_soft_insn */
    case 6529:  /* *p *arm_movsf_soft_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 0;
        }
      else if (which_alternative == 1)
        {
	  return 4096 /* 0x1000 */;
        }
      else
        {
	  return 0;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

enum attr_arch_enabled
get_attr_arch_enabled (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_arch cached_arch ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2959:  /* atomic_and_fetchdi */
    case 2958:  /* atomic_xor_fetchdi */
    case 2957:  /* atomic_or_fetchdi */
    case 2956:  /* atomic_sub_fetchdi */
    case 2955:  /* atomic_add_fetchdi */
    case 2954:  /* atomic_and_fetchsi */
    case 2953:  /* atomic_xor_fetchsi */
    case 2952:  /* atomic_or_fetchsi */
    case 2951:  /* atomic_sub_fetchsi */
    case 2950:  /* atomic_add_fetchsi */
    case 2949:  /* atomic_and_fetchhi */
    case 2948:  /* atomic_xor_fetchhi */
    case 2947:  /* atomic_or_fetchhi */
    case 2946:  /* atomic_sub_fetchhi */
    case 2945:  /* atomic_add_fetchhi */
    case 2944:  /* atomic_and_fetchqi */
    case 2943:  /* atomic_xor_fetchqi */
    case 2942:  /* atomic_or_fetchqi */
    case 2941:  /* atomic_sub_fetchqi */
    case 2940:  /* atomic_add_fetchqi */
    case 2935:  /* atomic_fetch_anddi */
    case 2934:  /* atomic_fetch_xordi */
    case 2933:  /* atomic_fetch_ordi */
    case 2932:  /* atomic_fetch_subdi */
    case 2931:  /* atomic_fetch_adddi */
    case 2930:  /* atomic_fetch_andsi */
    case 2929:  /* atomic_fetch_xorsi */
    case 2928:  /* atomic_fetch_orsi */
    case 2927:  /* atomic_fetch_subsi */
    case 2926:  /* atomic_fetch_addsi */
    case 2925:  /* atomic_fetch_andhi */
    case 2924:  /* atomic_fetch_xorhi */
    case 2923:  /* atomic_fetch_orhi */
    case 2922:  /* atomic_fetch_subhi */
    case 2921:  /* atomic_fetch_addhi */
    case 2920:  /* atomic_fetch_andqi */
    case 2919:  /* atomic_fetch_xorqi */
    case 2918:  /* atomic_fetch_orqi */
    case 2917:  /* atomic_fetch_subqi */
    case 2916:  /* atomic_fetch_addqi */
    case 2911:  /* atomic_anddi */
    case 2910:  /* atomic_xordi */
    case 2909:  /* atomic_ordi */
    case 2908:  /* atomic_subdi */
    case 2907:  /* atomic_adddi */
    case 2906:  /* atomic_andsi */
    case 2905:  /* atomic_xorsi */
    case 2904:  /* atomic_orsi */
    case 2903:  /* atomic_subsi */
    case 2902:  /* atomic_addsi */
    case 2901:  /* atomic_andhi */
    case 2900:  /* atomic_xorhi */
    case 2899:  /* atomic_orhi */
    case 2898:  /* atomic_subhi */
    case 2897:  /* atomic_addhi */
    case 2896:  /* atomic_andqi */
    case 2895:  /* atomic_xorqi */
    case 2894:  /* atomic_orqi */
    case 2893:  /* atomic_subqi */
    case 2892:  /* atomic_addqi */
    case 2887:  /* atomic_compare_and_swapt1di_1 */
    case 2886:  /* atomic_compare_and_swapt1si_1 */
    case 2885:  /* atomic_compare_and_swap32di_1 */
    case 2884:  /* atomic_compare_and_swap32si_1 */
    case 2883:  /* atomic_compare_and_swapt1hi_1 */
    case 2882:  /* atomic_compare_and_swapt1qi_1 */
    case 2881:  /* atomic_compare_and_swap32hi_1 */
    case 2880:  /* atomic_compare_and_swap32qi_1 */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))) || ((which_alternative != 0) && (
#line 181 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1 && arm_arch8))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6953:  /* *p atomic_storesi */
    case 6952:  /* *p atomic_storehi */
    case 6951:  /* *p atomic_storeqi */
    case 6950:  /* *p atomic_loadsi */
    case 6949:  /* *p atomic_loadhi */
    case 6948:  /* *p atomic_loadqi */
    case 2878:  /* atomic_storesi */
    case 2877:  /* atomic_storehi */
    case 2876:  /* atomic_storeqi */
    case 2875:  /* atomic_loadsi */
    case 2874:  /* atomic_loadhi */
    case 2873:  /* atomic_loadqi */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x3ULL)) || ((which_alternative == 0) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))) || ((which_alternative == 1) && (
#line 181 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1 && arm_arch8))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 960:  /* *thumb1_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (((((1ULL << which_alternative) & 0x3fULL)) && (
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || ((which_alternative == 6) && (
#line 181 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1 && arm_arch8))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((which_alternative != 2) && (
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || ((which_alternative == 2) && (
#line 181 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1 && arm_arch8))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 958:  /* *thumb1_movdi_insn */
      extract_constrain_insn_cached (insn);
      if (((which_alternative != 3) && (
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || ((which_alternative == 3) && (
#line 181 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1 && arm_arch8))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 853:  /* lazy_load_multiple_insn */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 0) || ((which_alternative == 0) && (
(fix_vlldm))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6903:  /* *p *sqrtdf2_vfp */
    case 6902:  /* *p *sqrtsf2_vfp */
    case 6865:  /* *p *divdf3_vfp */
    case 6864:  /* *p *divsf3_vfp */
    case 847:  /* *sqrtdf2_vfp */
    case 846:  /* *sqrtsf2_vfp */
    case 796:  /* *divdf3_vfp */
    case 795:  /* *divsf3_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 1) || (
#line 193 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6 || TARGET_VFP3)))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 3) || ((which_alternative == 3) && (
#line 197 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_NEON))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x31ULL)) || ((which_alternative == 4) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))) || ((((1ULL << which_alternative) & 0x21ULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0x3fffULL)) || ((!((1ULL << which_alternative) & 0x3fffULL)) && (
#line 201 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_HAVE_MVE))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0x1f7ULL)) || ((which_alternative == 3) && (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2))) || ((!((1ULL << which_alternative) & 0x1ffULL)) && (
#line 201 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_HAVE_MVE))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6745:  /* *p ashldi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6736:  /* *p rordi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6734:  /* *p rorv4hi3_di */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6724:  /* *p rordi3 */
    case 6723:  /* *p rorv2si3 */
    case 6722:  /* *p rorv4hi3 */
    case 655:  /* ashldi3_di */
    case 654:  /* ashlv2si3_di */
    case 653:  /* ashlv4hi3_di */
    case 652:  /* lshrdi3_di */
    case 651:  /* lshrv2si3_di */
    case 650:  /* lshrv4hi3_di */
    case 649:  /* ashrdi3_di */
    case 648:  /* ashrv2si3_di */
    case 647:  /* ashrv4hi3_di */
    case 646:  /* rordi3_di */
    case 645:  /* rorv2si3_di */
    case 644:  /* rorv4hi3_di */
    case 643:  /* ashldi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 634:  /* rordi3 */
    case 633:  /* rorv2si3 */
    case 632:  /* rorv4hi3 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 1) || (
#line 189 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_REALLY_IWMMXT2)))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 379:  /* *if_move_neg */
    case 377:  /* *if_neg_move */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))) || ((which_alternative == 1) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 343:  /* *cmp_ior */
    case 342:  /* *cmp_and */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x3fULL)) || ((((1ULL << which_alternative) & 0x3fULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 341:  /* *cmp_ite1 */
    case 340:  /* *cmp_ite0 */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x1fULL)) || ((((1ULL << which_alternative) & 0x1fULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6547:  /* *p *and_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6543:  /* *p *add_shiftsi */
    case 328:  /* *and_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 324:  /* *add_shiftsi */
      extract_constrain_insn_cached (insn);
      if (((which_alternative != 1) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))) || ((which_alternative == 1) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 311:  /* arm_stack_protect_test_insn */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB))) || ((which_alternative == 1) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 310:  /* *stack_protect_combined_test_insn */
    case 309:  /* *stack_protect_set_insn */
    case 308:  /* *stack_protect_combined_set_insn */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || ((which_alternative == 1) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6526:  /* *p *arm_movqi_insn */
    case 267:  /* *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x69ULL)) || ((((1ULL << which_alternative) & 0x69ULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 6524:  /* *p *movhi_insn_arch4 */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
    case 265:  /* *movhi_insn_arch4 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 2) || ((which_alternative == 2) && (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 264:  /* *movsi_compare0 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 1) || ((which_alternative == 4) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))) || ((((1ULL << which_alternative) & 0xdULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 258:  /* pic_load_addr_unified */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))) || ((which_alternative == 2) && (
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || ((which_alternative == 1) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6521:  /* *p *arm_movsi_insn */
    case 257:  /* *arm_movsi_insn */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 3) || ((which_alternative == 3) && (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6542:  /* *p *and_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6538:  /* *p *add_multsi */
    case 323:  /* *and_multsi */
    case 322:  /* *eor_multsi */
    case 321:  /* *orr_multsi */
    case 320:  /* *rsb_multsi */
    case 319:  /* *add_multsi */
    case 170:  /* negsi2_carryin */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))) || ((which_alternative == 1) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6970:  /* *p arm_store_release_exclusivesi */
    case 6969:  /* *p arm_store_release_exclusivehi */
    case 6968:  /* *p arm_store_release_exclusiveqi */
    case 6960:  /* *p arm_load_acquire_exclusivesi */
    case 6959:  /* *p arm_load_exclusivesi */
    case 6958:  /* *p arm_load_acquire_exclusivehi */
    case 6957:  /* *p arm_load_acquire_exclusiveqi */
    case 6956:  /* *p arm_load_exclusivehi */
    case 6955:  /* *p arm_load_exclusiveqi */
    case 6557:  /* *p *arm_movtas_ze */
    case 6520:  /* *p *arm_movt */
    case 6437:  /* *p udivsi3 */
    case 6436:  /* *p divsi3 */
    case 2979:  /* arm_store_release_exclusivesi */
    case 2978:  /* arm_store_release_exclusivehi */
    case 2977:  /* arm_store_release_exclusiveqi */
    case 2969:  /* arm_load_acquire_exclusivesi */
    case 2968:  /* arm_load_exclusivesi */
    case 2967:  /* arm_load_acquire_exclusivehi */
    case 2966:  /* arm_load_acquire_exclusiveqi */
    case 2965:  /* arm_load_exclusivehi */
    case 2964:  /* arm_load_exclusiveqi */
    case 2963:  /* atomic_nand_fetchdi */
    case 2962:  /* atomic_nand_fetchsi */
    case 2961:  /* atomic_nand_fetchhi */
    case 2960:  /* atomic_nand_fetchqi */
    case 2939:  /* atomic_fetch_nanddi */
    case 2938:  /* atomic_fetch_nandsi */
    case 2937:  /* atomic_fetch_nandhi */
    case 2936:  /* atomic_fetch_nandqi */
    case 2915:  /* atomic_nanddi */
    case 2914:  /* atomic_nandsi */
    case 2913:  /* atomic_nandhi */
    case 2912:  /* atomic_nandqi */
    case 2891:  /* atomic_exchangedi */
    case 2890:  /* atomic_exchangesi */
    case 2889:  /* atomic_exchangehi */
    case 2888:  /* atomic_exchangeqi */
    case 410:  /* *arm_movtas_ze */
    case 256:  /* *arm_movt */
    case 167:  /* udivsi3 */
    case 166:  /* divsi3 */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))) || ((which_alternative == 1) && (
#line 181 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1 && arm_arch8))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6558:  /* *p *arm_rev */
    case 6433:  /* *p unaligned_storehi */
    case 6432:  /* *p unaligned_storesi */
    case 6431:  /* *p unaligned_loadhiu */
    case 6429:  /* *p unaligned_loadsi */
    case 415:  /* arm_rev16si2_alt */
    case 414:  /* arm_rev16si2 */
    case 413:  /* *arm_rev16 */
    case 412:  /* *arm_revsh */
    case 411:  /* *arm_rev */
    case 163:  /* unaligned_storehi */
    case 162:  /* unaligned_storesi */
    case 160:  /* unaligned_loadhiu */
    case 158:  /* unaligned_loadsi */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || ((which_alternative == 1) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))) || ((which_alternative == 2) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 112:  /* *iorsi3_compare0_scratch */
    case 111:  /* *iorsi3_compare0 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 1) || ((which_alternative == 1) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6409:  /* *p *iorsi3_insn */
    case 110:  /* *iorsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((((1ULL << which_alternative) & 0x6ULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))) || ((!((1ULL << which_alternative) & 0x6ULL)) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6397:  /* *p *arm_andsi3_insn */
    case 90:  /* *arm_andsi3_insn */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 4) || ((which_alternative == 4) && (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6377:  /* *p umlal */
    case 6376:  /* *p smlal */
    case 6375:  /* *p umull */
    case 6374:  /* *p smull */
    case 70:  /* umlal */
    case 69:  /* smlal */
    case 68:  /* umull */
    case 67:  /* smull */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 169 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6))) || ((which_alternative == 1) && (
#line 173 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && !arm_arch6))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6379:  /* *p *umull_high */
    case 6378:  /* *p *smull_high */
    case 6372:  /* *p *mla */
    case 72:  /* *umull_high */
    case 71:  /* *smull_high */
    case 57:  /* *mla */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 169 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6))) || ((which_alternative != 0) && (
#line 173 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && !arm_arch6))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6371:  /* *p *mul */
    case 56:  /* *mul */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 0) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))) || ((which_alternative == 1) && (
#line 169 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6))) || ((!((1ULL << which_alternative) & 0x3ULL)) && (
#line 173 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && !arm_arch6))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6364:  /* *p *add_not_cin */
    case 31:  /* *add_not_cin */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 1) || (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM)))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6362:  /* *p subsi3_carryin */
    case 29:  /* subsi3_carryin */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 0) || ((which_alternative == 1) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))) || ((which_alternative == 2) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6548:  /* *p *sub_shiftsi */
    case 6531:  /* *p *arm_cmpsi_negshiftsi_si */
    case 6428:  /* *p *not_shiftsi */
    case 6408:  /* *p andsi_not_shiftsi_si_scc */
    case 6407:  /* *p andsi_not_shiftsi_si_scc_no_reuse */
    case 6406:  /* *p andsi_not_shiftsi_si */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6361:  /* *p *addsi3_carryin_shift */
    case 333:  /* *sub_shiftsi_compare0_scratch */
    case 332:  /* *sub_shiftsi_compare0 */
    case 331:  /* *sub_shiftsi */
    case 330:  /* *arith_shiftsi_compare0_scratch */
    case 329:  /* *arith_shiftsi_compare0 */
    case 275:  /* *arm_cmpsi_negshiftsi_si */
    case 274:  /* *cmpsi_shiftsi_swp */
    case 273:  /* *cmpsi_shiftsi */
    case 156:  /* *not_shiftsi_compare0_scratch */
    case 155:  /* *not_shiftsi_compare0 */
    case 154:  /* *not_shiftsi */
    case 107:  /* andsi_not_shiftsi_si_scc */
    case 106:  /* andsi_not_shiftsi_si_scc_no_reuse */
    case 105:  /* andsi_not_shiftsi_si */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 41:  /* *subsi3_carryin_shift */
    case 24:  /* *addsi3_carryin_shift */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 1) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))) || ((which_alternative == 0) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6370:  /* *p *arm_subsi3_insn */
    case 45:  /* *arm_subsi3_insn */
    case 18:  /* *addsi3_compare_op2 */
    case 17:  /* addsi3_compare_op1 */
    case 11:  /* addsi3_compareV_imm */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0xfULL)) || ((((1ULL << which_alternative) & 0xfULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6530:  /* *p *arm_cmpsi_insn */
    case 6427:  /* *p *arm_shiftsi3 */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 272:  /* *arm_cmpsi_insn */
    case 151:  /* *arm_shiftsi3 */
    case 20:  /* *compare_addsi2_op1 */
    case 19:  /* *compare_addsi2_op0 */
    case 8:  /* addsi3_compareV_reg */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x3ULL)) || ((((1ULL << which_alternative) & 0x3ULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6353:  /* *p *arm_addsi3 */
    case 7:  /* *arm_addsi3 */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x738fULL)) || ((((1ULL << which_alternative) & 0x1080ULL)) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))) || ((((1ULL << which_alternative) & 0x630fULL)) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case 6441:  /* *p *arm_one_cmplsi2 */
    case 6438:  /* *p *arm_negsi2 */
    case 6360:  /* *p *addsi3_carryin_alt2 */
    case 6358:  /* *p addsi3_carryin */
    case 6355:  /* *p *compare_negsi_si */
    case 173:  /* *arm_one_cmplsi2 */
    case 169:  /* negsi2_0compare */
    case 168:  /* *arm_negsi2 */
    case 54:  /* subvsi3_borrow */
    case 52:  /* usubvsi3_borrow */
    case 34:  /* cmpsi3_carryin_CC_Bout */
    case 33:  /* cmpsi3_carryin_CC_NVout */
    case 27:  /* subvsi3 */
    case 23:  /* *addsi3_carryin_alt2 */
    case 21:  /* addsi3_carryin */
    case 15:  /* *compare_negsi_si */
    case 12:  /* addsi3_compareV_imm_nosum */
    case 9:  /* *addsi3_compareV_reg_nosum */
    case 4:  /* *addsi3_cin_cout_reg_insn */
    case 1:  /* *addsi3_cin_vout_reg_insn */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 0) || ((which_alternative == 0) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if ((cached_arch = get_attr_arch (insn)) == ARCH_ANY)
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_A) && (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_T) && (
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_T1) && (
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_T2) && (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_32) && (
#line 165 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_V6) && (
#line 169 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_NOV6) && (
#line 173 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && !arm_arch6)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_V6T2) && (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_V8MB) && (
#line 181 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1 && arm_arch8)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_FIX_VLLDM) && (
(fix_vlldm)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_IWMMXT2) && (
#line 189 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_REALLY_IWMMXT2)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_ARMV6_OR_VFPV3) && (
#line 193 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6 || TARGET_VFP3)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_NEON) && (
#line 197 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_NEON)))
        {
	  return ARCH_ENABLED_YES;
        }
      else if ((cached_arch == ARCH_MVE) && (
#line 201 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_HAVE_MVE)))
        {
	  return ARCH_ENABLED_YES;
        }
      else
        {
	  return ARCH_ENABLED_NO;
        }

    default:
      return ARCH_ENABLED_YES;

    }
}

enum attr_arch
get_attr_arch (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 960:  /* *thumb1_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3fULL))
        {
	  return ARCH_T1;
        }
      else
        {
	  return ARCH_V8MB;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return ARCH_T1;
        }
      else if (which_alternative == 2)
        {
	  return ARCH_V8MB;
        }
      else
        {
	  return ARCH_T1;
        }

    case 958:  /* *thumb1_movdi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return ARCH_T1;
        }
      else if (which_alternative == 3)
        {
	  return ARCH_V8MB;
        }
      else
        {
	  return ARCH_T1;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 3)
        {
	  return ARCH_NEON;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T2;
        }
      else if (((1ULL << which_alternative) & 0xeULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 4)
        {
	  return ARCH_A;
        }
      else if (which_alternative == 5)
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3fffULL))
        {
	  return ARCH_ANY;
        }
      else
        {
	  return ARCH_MVE;
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 3)
        {
	  return ARCH_V6T2;
        }
      else if (((1ULL << which_alternative) & 0x1f0ULL))
        {
	  return ARCH_ANY;
        }
      else
        {
	  return ARCH_MVE;
        }

    case 343:  /* *cmp_ior */
    case 342:  /* *cmp_and */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3fULL))
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 341:  /* *cmp_ite1 */
    case 340:  /* *cmp_ite0 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 6526:  /* *p *arm_movqi_insn */
    case 267:  /* *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T2;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 3)
        {
	  return ARCH_T2;
        }
      else if (which_alternative == 4)
        {
	  return ARCH_ANY;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 6524:  /* *p *movhi_insn_arch4 */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
    case 265:  /* *movhi_insn_arch4 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 2)
        {
	  return ARCH_V6T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 264:  /* *movsi_compare0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T2;
        }
      else if (which_alternative == 1)
        {
	  return ARCH_ANY;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_A;
        }

    case 6521:  /* *p *arm_movsi_insn */
    case 257:  /* *arm_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 3)
        {
	  return ARCH_V6T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 6409:  /* *p *iorsi3_insn */
    case 110:  /* *iorsi3_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_32;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_32;
        }

    case 6397:  /* *p *arm_andsi3_insn */
    case 90:  /* *arm_andsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 4)
        {
	  return ARCH_V6T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 6371:  /* *p *mul */
    case 56:  /* *mul */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T2;
        }
      else if (which_alternative == 1)
        {
	  return ARCH_V6;
        }
      else
        {
	  return ARCH_NOV6;
        }

    case 6370:  /* *p *arm_subsi3_insn */
    case 45:  /* *arm_subsi3_insn */
    case 18:  /* *addsi3_compare_op2 */
    case 17:  /* addsi3_compare_op1 */
    case 11:  /* addsi3_compareV_imm */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 6530:  /* *p *arm_cmpsi_insn */
    case 6427:  /* *p *arm_shiftsi3 */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 272:  /* *arm_cmpsi_insn */
    case 151:  /* *arm_shiftsi3 */
    case 20:  /* *compare_addsi2_op1 */
    case 19:  /* *compare_addsi2_op0 */
    case 8:  /* addsi3_compareV_reg */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 6353:  /* *p *arm_addsi3 */
    case 7:  /* *arm_addsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return ARCH_T2;
        }
      else if (((1ULL << which_alternative) & 0x70ULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 7)
        {
	  return ARCH_A;
        }
      else if (((1ULL << which_alternative) & 0x300ULL))
        {
	  return ARCH_T2;
        }
      else if (((1ULL << which_alternative) & 0xc00ULL))
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 12)
        {
	  return ARCH_A;
        }
      else if (((1ULL << which_alternative) & 0x6000ULL))
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 111:  /* *iorsi3_compare0 */
    case 112:  /* *iorsi3_compare0_scratch */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 1)
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 258:  /* pic_load_addr_unified */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_A;
        }
      else if (which_alternative == 1)
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_T1;
        }

    case 308:  /* *stack_protect_combined_set_insn */
    case 309:  /* *stack_protect_set_insn */
    case 310:  /* *stack_protect_combined_test_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T1;
        }
      else
        {
	  return ARCH_32;
        }

    case 311:  /* arm_stack_protect_test_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T;
        }
      else
        {
	  return ARCH_32;
        }

    case 377:  /* *if_neg_move */
    case 379:  /* *if_move_neg */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_32;
        }

    case 853:  /* lazy_load_multiple_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_FIX_VLLDM;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 29:  /* subsi3_carryin */
    case 6362:  /* *p subsi3_carryin */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_ANY;
        }
      else if (which_alternative == 1)
        {
	  return ARCH_A;
        }
      else
        {
	  return ARCH_T2;
        }

    case 31:  /* *add_not_cin */
    case 6364:  /* *p *add_not_cin */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_ANY;
        }
      else
        {
	  return ARCH_A;
        }

    case 6379:  /* *p *umull_high */
    case 6378:  /* *p *smull_high */
    case 6372:  /* *p *mla */
    case 72:  /* *umull_high */
    case 71:  /* *smull_high */
    case 57:  /* *mla */
    case 67:  /* smull */
    case 68:  /* umull */
    case 69:  /* smlal */
    case 70:  /* umlal */
    case 6374:  /* *p smull */
    case 6375:  /* *p umull */
    case 6376:  /* *p smlal */
    case 6377:  /* *p umlal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_V6;
        }
      else
        {
	  return ARCH_NOV6;
        }

    case 6360:  /* *p *addsi3_carryin_alt2 */
    case 6358:  /* *p addsi3_carryin */
    case 23:  /* *addsi3_carryin_alt2 */
    case 21:  /* addsi3_carryin */
    case 12:  /* addsi3_compareV_imm_nosum */
    case 1:  /* *addsi3_cin_vout_reg_insn */
    case 4:  /* *addsi3_cin_cout_reg_insn */
    case 9:  /* *addsi3_compareV_reg_nosum */
    case 15:  /* *compare_negsi_si */
    case 27:  /* subvsi3 */
    case 33:  /* cmpsi3_carryin_CC_NVout */
    case 34:  /* cmpsi3_carryin_CC_Bout */
    case 52:  /* usubvsi3_borrow */
    case 54:  /* subvsi3_borrow */
    case 168:  /* *arm_negsi2 */
    case 169:  /* negsi2_0compare */
    case 173:  /* *arm_one_cmplsi2 */
    case 6355:  /* *p *compare_negsi_si */
    case 6438:  /* *p *arm_negsi2 */
    case 6441:  /* *p *arm_one_cmplsi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 170:  /* negsi2_carryin */
    case 319:  /* *add_multsi */
    case 320:  /* *rsb_multsi */
    case 321:  /* *orr_multsi */
    case 322:  /* *eor_multsi */
    case 323:  /* *and_multsi */
    case 6538:  /* *p *add_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6542:  /* *p *and_multsi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_A;
        }
      else
        {
	  return ARCH_T2;
        }

    case 324:  /* *add_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 328:  /* *and_shiftsi */
    case 6543:  /* *p *add_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6547:  /* *p *and_shiftsi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_A;
        }
      else if (which_alternative == 1)
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_A;
        }

    case 24:  /* *addsi3_carryin_shift */
    case 41:  /* *subsi3_carryin_shift */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 105:  /* andsi_not_shiftsi_si */
    case 106:  /* andsi_not_shiftsi_si_scc_no_reuse */
    case 107:  /* andsi_not_shiftsi_si_scc */
    case 154:  /* *not_shiftsi */
    case 155:  /* *not_shiftsi_compare0 */
    case 156:  /* *not_shiftsi_compare0_scratch */
    case 273:  /* *cmpsi_shiftsi */
    case 274:  /* *cmpsi_shiftsi_swp */
    case 275:  /* *arm_cmpsi_negshiftsi_si */
    case 329:  /* *arith_shiftsi_compare0 */
    case 330:  /* *arith_shiftsi_compare0_scratch */
    case 331:  /* *sub_shiftsi */
    case 332:  /* *sub_shiftsi_compare0 */
    case 333:  /* *sub_shiftsi_compare0_scratch */
    case 6361:  /* *p *addsi3_carryin_shift */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6406:  /* *p andsi_not_shiftsi_si */
    case 6407:  /* *p andsi_not_shiftsi_si_scc_no_reuse */
    case 6408:  /* *p andsi_not_shiftsi_si_scc */
    case 6428:  /* *p *not_shiftsi */
    case 6531:  /* *p *arm_cmpsi_negshiftsi_si */
    case 6548:  /* *p *sub_shiftsi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_32;
        }
      else
        {
	  return ARCH_A;
        }

    case 158:  /* unaligned_loadsi */
    case 160:  /* unaligned_loadhiu */
    case 162:  /* unaligned_storesi */
    case 163:  /* unaligned_storehi */
    case 411:  /* *arm_rev */
    case 412:  /* *arm_revsh */
    case 413:  /* *arm_rev16 */
    case 414:  /* arm_rev16si2 */
    case 415:  /* arm_rev16si2_alt */
    case 6429:  /* *p unaligned_loadsi */
    case 6431:  /* *p unaligned_loadhiu */
    case 6432:  /* *p unaligned_storesi */
    case 6433:  /* *p unaligned_storehi */
    case 6558:  /* *p *arm_rev */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_T1;
        }
      else if (which_alternative == 1)
        {
	  return ARCH_T2;
        }
      else
        {
	  return ARCH_32;
        }

    case 632:  /* rorv4hi3 */
    case 633:  /* rorv2si3 */
    case 634:  /* rordi3 */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 643:  /* ashldi3_iwmmxt */
    case 644:  /* rorv4hi3_di */
    case 645:  /* rorv2si3_di */
    case 646:  /* rordi3_di */
    case 647:  /* ashrv4hi3_di */
    case 648:  /* ashrv2si3_di */
    case 649:  /* ashrdi3_di */
    case 650:  /* lshrv4hi3_di */
    case 651:  /* lshrv2si3_di */
    case 652:  /* lshrdi3_di */
    case 653:  /* ashlv4hi3_di */
    case 654:  /* ashlv2si3_di */
    case 655:  /* ashldi3_di */
    case 6722:  /* *p rorv4hi3 */
    case 6723:  /* *p rorv2si3 */
    case 6724:  /* *p rordi3 */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6734:  /* *p rorv4hi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6736:  /* *p rordi3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6745:  /* *p ashldi3_di */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_ANY;
        }
      else
        {
	  return ARCH_IWMMXT2;
        }

    case 795:  /* *divsf3_vfp */
    case 796:  /* *divdf3_vfp */
    case 846:  /* *sqrtsf2_vfp */
    case 847:  /* *sqrtdf2_vfp */
    case 6864:  /* *p *divsf3_vfp */
    case 6865:  /* *p *divdf3_vfp */
    case 6902:  /* *p *sqrtsf2_vfp */
    case 6903:  /* *p *sqrtdf2_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_ANY;
        }
      else
        {
	  return ARCH_ARMV6_OR_VFPV3;
        }

    case 2873:  /* atomic_loadqi */
    case 2874:  /* atomic_loadhi */
    case 2875:  /* atomic_loadsi */
    case 2876:  /* atomic_storeqi */
    case 2877:  /* atomic_storehi */
    case 2878:  /* atomic_storesi */
    case 6948:  /* *p atomic_loadqi */
    case 6949:  /* *p atomic_loadhi */
    case 6950:  /* *p atomic_loadsi */
    case 6951:  /* *p atomic_storeqi */
    case 6952:  /* *p atomic_storehi */
    case 6953:  /* *p atomic_storesi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_32;
        }
      else if (which_alternative == 1)
        {
	  return ARCH_V8MB;
        }
      else
        {
	  return ARCH_ANY;
        }

    case 2959:  /* atomic_and_fetchdi */
    case 2958:  /* atomic_xor_fetchdi */
    case 2957:  /* atomic_or_fetchdi */
    case 2956:  /* atomic_sub_fetchdi */
    case 2955:  /* atomic_add_fetchdi */
    case 2954:  /* atomic_and_fetchsi */
    case 2953:  /* atomic_xor_fetchsi */
    case 2952:  /* atomic_or_fetchsi */
    case 2951:  /* atomic_sub_fetchsi */
    case 2950:  /* atomic_add_fetchsi */
    case 2949:  /* atomic_and_fetchhi */
    case 2948:  /* atomic_xor_fetchhi */
    case 2947:  /* atomic_or_fetchhi */
    case 2946:  /* atomic_sub_fetchhi */
    case 2945:  /* atomic_add_fetchhi */
    case 2944:  /* atomic_and_fetchqi */
    case 2943:  /* atomic_xor_fetchqi */
    case 2942:  /* atomic_or_fetchqi */
    case 2941:  /* atomic_sub_fetchqi */
    case 2940:  /* atomic_add_fetchqi */
    case 2935:  /* atomic_fetch_anddi */
    case 2934:  /* atomic_fetch_xordi */
    case 2933:  /* atomic_fetch_ordi */
    case 2932:  /* atomic_fetch_subdi */
    case 2931:  /* atomic_fetch_adddi */
    case 2930:  /* atomic_fetch_andsi */
    case 2929:  /* atomic_fetch_xorsi */
    case 2928:  /* atomic_fetch_orsi */
    case 2927:  /* atomic_fetch_subsi */
    case 2926:  /* atomic_fetch_addsi */
    case 2925:  /* atomic_fetch_andhi */
    case 2924:  /* atomic_fetch_xorhi */
    case 2923:  /* atomic_fetch_orhi */
    case 2922:  /* atomic_fetch_subhi */
    case 2921:  /* atomic_fetch_addhi */
    case 2920:  /* atomic_fetch_andqi */
    case 2919:  /* atomic_fetch_xorqi */
    case 2918:  /* atomic_fetch_orqi */
    case 2917:  /* atomic_fetch_subqi */
    case 2916:  /* atomic_fetch_addqi */
    case 2911:  /* atomic_anddi */
    case 2910:  /* atomic_xordi */
    case 2909:  /* atomic_ordi */
    case 2908:  /* atomic_subdi */
    case 2907:  /* atomic_adddi */
    case 2906:  /* atomic_andsi */
    case 2905:  /* atomic_xorsi */
    case 2904:  /* atomic_orsi */
    case 2903:  /* atomic_subsi */
    case 2902:  /* atomic_addsi */
    case 2901:  /* atomic_andhi */
    case 2900:  /* atomic_xorhi */
    case 2899:  /* atomic_orhi */
    case 2898:  /* atomic_subhi */
    case 2897:  /* atomic_addhi */
    case 2896:  /* atomic_andqi */
    case 2895:  /* atomic_xorqi */
    case 2894:  /* atomic_orqi */
    case 2893:  /* atomic_subqi */
    case 2892:  /* atomic_addqi */
    case 2887:  /* atomic_compare_and_swapt1di_1 */
    case 2886:  /* atomic_compare_and_swapt1si_1 */
    case 2885:  /* atomic_compare_and_swap32di_1 */
    case 2884:  /* atomic_compare_and_swap32si_1 */
    case 2883:  /* atomic_compare_and_swapt1hi_1 */
    case 2882:  /* atomic_compare_and_swapt1qi_1 */
    case 2881:  /* atomic_compare_and_swap32hi_1 */
    case 2880:  /* atomic_compare_and_swap32qi_1 */
    case 166:  /* divsi3 */
    case 167:  /* udivsi3 */
    case 256:  /* *arm_movt */
    case 410:  /* *arm_movtas_ze */
    case 2888:  /* atomic_exchangeqi */
    case 2889:  /* atomic_exchangehi */
    case 2890:  /* atomic_exchangesi */
    case 2891:  /* atomic_exchangedi */
    case 2912:  /* atomic_nandqi */
    case 2913:  /* atomic_nandhi */
    case 2914:  /* atomic_nandsi */
    case 2915:  /* atomic_nanddi */
    case 2936:  /* atomic_fetch_nandqi */
    case 2937:  /* atomic_fetch_nandhi */
    case 2938:  /* atomic_fetch_nandsi */
    case 2939:  /* atomic_fetch_nanddi */
    case 2960:  /* atomic_nand_fetchqi */
    case 2961:  /* atomic_nand_fetchhi */
    case 2962:  /* atomic_nand_fetchsi */
    case 2963:  /* atomic_nand_fetchdi */
    case 2964:  /* arm_load_exclusiveqi */
    case 2965:  /* arm_load_exclusivehi */
    case 2966:  /* arm_load_acquire_exclusiveqi */
    case 2967:  /* arm_load_acquire_exclusivehi */
    case 2968:  /* arm_load_exclusivesi */
    case 2969:  /* arm_load_acquire_exclusivesi */
    case 2977:  /* arm_store_release_exclusiveqi */
    case 2978:  /* arm_store_release_exclusivehi */
    case 2979:  /* arm_store_release_exclusivesi */
    case 6436:  /* *p divsi3 */
    case 6437:  /* *p udivsi3 */
    case 6520:  /* *p *arm_movt */
    case 6557:  /* *p *arm_movtas_ze */
    case 6955:  /* *p arm_load_exclusiveqi */
    case 6956:  /* *p arm_load_exclusivehi */
    case 6957:  /* *p arm_load_acquire_exclusiveqi */
    case 6958:  /* *p arm_load_acquire_exclusivehi */
    case 6959:  /* *p arm_load_exclusivesi */
    case 6960:  /* *p arm_load_acquire_exclusivesi */
    case 6968:  /* *p arm_store_release_exclusiveqi */
    case 6969:  /* *p arm_store_release_exclusivehi */
    case 6970:  /* *p arm_store_release_exclusivesi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ARCH_32;
        }
      else
        {
	  return ARCH_V8MB;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return ARCH_ANY;

    }
}

enum attr_autodetect_type
get_attr_autodetect_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 1062:  /* *orsi_not_shiftsi_si */
    case 6942:  /* *p *orsi_not_shiftsi_si */
      return AUTODETECT_TYPE_ALU_SHIFT_OPERATOR4;

    case 32:  /* add_not_shift_cin */
    case 151:  /* *arm_shiftsi3 */
    case 6365:  /* *p add_not_shift_cin */
    case 6427:  /* *p *arm_shiftsi3 */
      return AUTODETECT_TYPE_ALU_SHIFT_OPERATOR3;

    case 24:  /* *addsi3_carryin_shift */
    case 41:  /* *subsi3_carryin_shift */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 43:  /* *rsbsi3_carryin_shift */
    case 44:  /* *rsbsi3_carryin_shift_alt */
    case 324:  /* *add_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 328:  /* *and_shiftsi */
    case 6361:  /* *p *addsi3_carryin_shift */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6368:  /* *p *rsbsi3_carryin_shift */
    case 6369:  /* *p *rsbsi3_carryin_shift_alt */
    case 6543:  /* *p *add_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6547:  /* *p *and_shiftsi */
      return AUTODETECT_TYPE_ALU_SHIFT_OPERATOR2;

    case 3036:  /* arm_ssatsihi_shift */
    case 7025:  /* *p arm_ssatsihi_shift */
      return AUTODETECT_TYPE_ALU_SHIFT_OPERATOR1;

    case 319:  /* *add_multsi */
    case 320:  /* *rsb_multsi */
    case 321:  /* *orr_multsi */
    case 322:  /* *eor_multsi */
    case 323:  /* *and_multsi */
    case 6538:  /* *p *add_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6542:  /* *p *and_multsi */
      return AUTODETECT_TYPE_ALU_SHIFT_MUL_OP3;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return AUTODETECT_TYPE_NONE;

    }
}

enum attr_cortex_a57_neon_type
get_attr_cortex_a57_neon_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_B;
        }

    case 2737:  /* neon_vld4_dupdi */
    case 2669:  /* neon_vld3_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_E;
        }

    case 2736:  /* neon_vld4_dupv2sf */
    case 2735:  /* neon_vld4_dupv2si */
    case 2668:  /* neon_vld3_dupv2sf */
    case 2667:  /* neon_vld3_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_E;
        }

    case 2734:  /* neon_vld4_dupv4bf */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2732:  /* neon_vld4_dupv4hi */
    case 2666:  /* neon_vld3_dupv4bf */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2664:  /* neon_vld3_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_E;
        }

    case 2731:  /* neon_vld4_dupv8qi */
    case 2663:  /* neon_vld3_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_E;
        }

    case 2707:  /* neon_vld4di */
    case 2639:  /* neon_vld3di */
      if ((64) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_D;
        }

    case 2706:  /* neon_vld4v2sf */
    case 2705:  /* neon_vld4v2si */
    case 2638:  /* neon_vld3v2sf */
    case 2637:  /* neon_vld3v2si */
      if ((32) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_D;
        }

    case 2704:  /* neon_vld4v4bf */
    case 2703:  /* neon_vld4v4hf */
    case 2702:  /* neon_vld4v4hi */
    case 2636:  /* neon_vld3v4bf */
    case 2635:  /* neon_vld3v4hf */
    case 2634:  /* neon_vld3v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_D;
        }

    case 2701:  /* neon_vld4v8qi */
    case 2633:  /* neon_vld3v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_D;
        }

    case 2615:  /* neon_vst2di */
      if ((64) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;
        }

    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
      if ((32) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;
        }

    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;
        }

    case 2609:  /* neon_vst2v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;
        }

    case 2607:  /* neon_vld2_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 2606:  /* neon_vld2_dupv2sf */
    case 2605:  /* neon_vld2_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 2604:  /* neon_vld2_dupv4bf */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2602:  /* neon_vld2_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 2601:  /* neon_vld2_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 2583:  /* neon_vld2di */
      if ((64) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 2582:  /* neon_vld2v2sf */
    case 2581:  /* neon_vld2v2si */
      if ((32) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 2580:  /* neon_vld2v4bf */
    case 2579:  /* neon_vld2v4hf */
    case 2578:  /* neon_vld2v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 2577:  /* neon_vld2v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 2052:  /* neon_vdup_nv4sf */
    case 2051:  /* neon_vdup_nv4si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP_Q;
        }

    case 2050:  /* neon_vdup_nv2sf */
    case 2049:  /* neon_vdup_nv2si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }

    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else if (get_attr_is_neon_type (insn) == IS_NEON_TYPE_YES)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_ZERO))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else if (get_attr_is_neon_type (insn) == IS_NEON_TYPE_YES)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 1380:  /* neon_load_count */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }

    case 1353:  /* *smaxv4sf3_neon */
    case 1345:  /* *sminv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH_Q;
        }

    case 1430:  /* neon_vpsmaxv2sf */
    case 1426:  /* neon_vpsminv2sf */
    case 1352:  /* *smaxv2sf3_neon */
    case 1344:  /* *sminv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1351:  /* *smaxv4si3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1339:  /* *sminv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH_Q;
        }

    case 1429:  /* neon_vpsmaxv2si */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1425:  /* neon_vpsminv2si */
    case 1424:  /* neon_vpsminv4hi */
    case 1423:  /* neon_vpsminv8qi */
    case 1350:  /* *smaxv2si3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1338:  /* *sminv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1307:  /* neon_negv4sf2 */
    case 1306:  /* neon_negv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1305:  /* neon_negv4si2 */
    case 1304:  /* neon_negv2si2 */
    case 1303:  /* neon_negv8hi2 */
    case 1302:  /* neon_negv4hi2 */
    case 1301:  /* neon_negv16qi2 */
    case 1300:  /* neon_negv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1299:  /* neon_absv4sf2 */
    case 1298:  /* neon_absv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1297:  /* neon_absv4si2 */
    case 1296:  /* neon_absv2si2 */
    case 1295:  /* neon_absv8hi2 */
    case 1294:  /* neon_absv4hi2 */
    case 1293:  /* neon_absv16qi2 */
    case 1292:  /* neon_absv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 2210:  /* neon_vmls_lanev4sf */
    case 2198:  /* neon_vmla_lanev4sf */
    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MLA_Q;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MLA_Q;
        }

    case 2207:  /* neon_vmls_lanev2sf */
    case 2195:  /* neon_vmla_lanev2sf */
    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MLA;
        }

    case 2209:  /* neon_vmls_lanev4si */
    case 2208:  /* neon_vmls_lanev8hi */
    case 2197:  /* neon_vmla_lanev4si */
    case 2196:  /* neon_vmla_lanev8hi */
    case 1562:  /* neon_vmlsv4si_unspec */
    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1177:  /* mulv4si3addv4si_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MLA_Q;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MLA_Q;
        }

    case 2206:  /* neon_vmls_lanev2si */
    case 2205:  /* neon_vmls_lanev4hi */
    case 2194:  /* neon_vmla_lanev2si */
    case 2193:  /* neon_vmla_lanev4hi */
    case 1561:  /* neon_vmlsv2si_unspec */
    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1176:  /* mulv2si3addv2si_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MLA;
        }

    case 2168:  /* neon_vmul_lanev4sf */
    case 1516:  /* neon_vmulfv4sf */
    case 1171:  /* *mulv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MUL_Q;
        }

    case 2165:  /* neon_vmul_lanev2sf */
    case 1515:  /* neon_vmulfv2sf */
    case 1170:  /* *mulv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MULTIPLY;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MUL;
        }

    case 2167:  /* neon_vmul_lanev4si */
    case 2166:  /* neon_vmul_lanev8hi */
    case 1514:  /* neon_vmulpv16qi */
    case 1169:  /* *mulv4si3_neon */
    case 1167:  /* *mulv8hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MUL_Q;
        }

    case 2164:  /* neon_vmul_lanev2si */
    case 2163:  /* neon_vmul_lanev4hi */
    case 1513:  /* neon_vmulpv8qi */
    case 1168:  /* *mulv2si3_neon */
    case 1166:  /* *mulv4hi3_neon */
    case 1164:  /* *mulv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MULTIPLY;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MUL;
        }

    case 1603:  /* neon_vsubv4sf_unspec */
    case 1454:  /* neon_vaddv4sf_unspec */
    case 1162:  /* *subv4sf3_neon */
    case 1160:  /* *subv8hf3_neon */
    case 1151:  /* *addv4sf3_neon */
    case 1149:  /* *addv8hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH_Q;
        }

    case 1602:  /* neon_vsubv2sf_unspec */
    case 1453:  /* neon_vaddv2sf_unspec */
    case 1421:  /* neon_vpadd_internalv2sf */
    case 1161:  /* *subv2sf3_neon */
    case 1159:  /* *subv4hf3_neon */
    case 1150:  /* *addv2sf3_neon */
    case 1148:  /* *addv4hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1163:  /* *subv2di3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1154:  /* *subv16qi3_neon */
    case 1152:  /* *addv2di3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1143:  /* *addv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH_Q;
        }

    case 1420:  /* neon_vpadd_internalv2si */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1418:  /* neon_vpadd_internalv8qi */
    case 1157:  /* *subv2si3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1153:  /* *subv8qi3_neon */
    case 1146:  /* *addv2si3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1142:  /* *addv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1141:  /* neon_vec_extractv2didi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1136:  /* neon_vec_extractv16qiqi */
    case 1135:  /* vec_extractv2sfsf */
    case 1134:  /* vec_extractv2sisi */
    case 1133:  /* vec_extractv4bfbf */
    case 1132:  /* vec_extractv4hfhf */
    case 1131:  /* vec_extractv4hihi */
    case 1130:  /* vec_extractv8qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;
        }

    case 1129:  /* vec_setv2di_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1124:  /* vec_setv16qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 1123:  /* vec_setv2sf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1118:  /* vec_setv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_B;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }
      else if (!((1ULL << which_alternative) & 0x1fdULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (((1ULL << which_alternative) & 0x90ULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 774:  /* *thumb2_movdfcc_vfp */
    case 773:  /* *movdfcc_vfp */
    case 772:  /* *thumb2_movsfcc_vfp */
    case 771:  /* *movsfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x38ULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (!((1ULL << which_alternative) & 0x3fULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 768:  /* *thumb2_movsf_vfp */
    case 767:  /* *movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 3)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 766:  /* *movbf_vfp */
    case 765:  /* *movhf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 4)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 6)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 4)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 7)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 10)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (!((1ULL << which_alternative) & 0x7ffULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 9)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 10)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 12)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 13)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 6848:  /* *p *arm_movsi_vfp */
    case 758:  /* *arm_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 6)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 9)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (!((1ULL << which_alternative) & 0x3ffULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 6)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 5)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 531:  /* *iwmmxt_movsi_insn */
    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 10)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 11)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 13)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if (!((1ULL << which_alternative) & 0x3fffULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 522:  /* mve_vshlq_uv4si */
    case 521:  /* mve_vshlq_sv4si */
    case 518:  /* mve_vshlq_uv8hi */
    case 517:  /* mve_vshlq_sv8hi */
    case 514:  /* mve_vshlq_uv16qi */
    case 513:  /* mve_vshlq_sv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;
        }

    case 520:  /* mve_vshlq_uv2si */
    case 519:  /* mve_vshlq_sv2si */
    case 516:  /* mve_vshlq_uv4hi */
    case 515:  /* mve_vshlq_sv4hi */
    case 512:  /* mve_vshlq_uv8qi */
    case 511:  /* mve_vshlq_sv8qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_ABD) || (cached_type == TYPE_NEON_ABD_LONG))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ABD;
        }
      else if (cached_type == TYPE_NEON_ABD_Q)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ABD_Q;
        }
      else if ((cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_ACC;
        }
      else if (cached_type == TYPE_NEON_ARITH_ACC_Q)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_ACC_Q;
        }
      else if ((cached_type == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_ADD_Q) || (cached_type == TYPE_NEON_ADD_LONG) || (cached_type == TYPE_NEON_ADD_WIDEN) || (cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_REDUC_ADD_LONG) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_SUB_Q) || (cached_type == TYPE_NEON_SUB_LONG) || (cached_type == TYPE_NEON_SUB_WIDEN) || (cached_type == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_TST_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else if ((cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_QABS) || (cached_type == TYPE_NEON_QABS_Q) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_QNEG) || (cached_type == TYPE_NEON_QNEG_Q) || (cached_type == TYPE_NEON_QSUB) || (cached_type == TYPE_NEON_QSUB_Q) || (cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_MINMAX_Q) || (cached_type == TYPE_NEON_REDUC_MINMAX) || (cached_type == TYPE_NEON_REDUC_MINMAX_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else if ((cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_MUL_S_LONG) || (cached_type == TYPE_NEON_MUL_D_LONG) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG) || (cached_type == TYPE_CRYPTO_PMULL))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MULTIPLY;
        }
      else if ((cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else if ((cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MLA;
        }
      else if ((cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H_Q) || (cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_MLA_Q;
        }
      else if ((cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SAT_MLA_LONG;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SHIFT_ACC_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_ACC;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else if ((cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX;
        }
      else if (cached_type == TYPE_NEON_SHIFT_REG)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC;
        }
      else if (cached_type == TYPE_NEON_SHIFT_REG_Q)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;
        }
      else if (cached_type == TYPE_NEON_SAT_SHIFT_REG)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_COMPLEX;
        }
      else if (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_COMPLEX_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_ABS_S_Q) || (cached_type == TYPE_NEON_FP_NEG_D) || (cached_type == TYPE_NEON_FP_NEG_D_Q) || (cached_type == TYPE_NEON_FP_ABS_D) || (cached_type == TYPE_NEON_FP_ABS_D_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_NEGABS;
        }
      else if ((cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_MINMAX_S) || (cached_type == TYPE_NEON_FP_ROUND_S) || (cached_type == TYPE_NEON_FP_ADDSUB_D) || (cached_type == TYPE_NEON_FP_ABD_D) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D) || (cached_type == TYPE_NEON_FP_COMPARE_D) || (cached_type == TYPE_NEON_FP_MINMAX_D) || (cached_type == TYPE_NEON_FP_ROUND_D) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_D))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH;
        }
      else if ((cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q) || (cached_type == TYPE_NEON_FP_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_ROUND_S_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_D_Q) || (cached_type == TYPE_NEON_FP_ABD_D_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D_Q) || (cached_type == TYPE_NEON_FP_COMPARE_D_Q) || (cached_type == TYPE_NEON_FP_MINMAX_D_Q) || (cached_type == TYPE_NEON_FP_ROUND_D_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_REDUC_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_D_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_REDUCTIONS_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_TO_INT_S) || (cached_type == TYPE_NEON_INT_TO_FP_S) || (cached_type == TYPE_NEON_FP_TO_INT_D) || (cached_type == TYPE_NEON_INT_TO_FP_D))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_CVT_INT;
        }
      else if ((cached_type == TYPE_NEON_FP_TO_INT_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q) || (cached_type == TYPE_NEON_FP_TO_INT_D_Q) || (cached_type == TYPE_NEON_INT_TO_FP_D_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_CVT_INT_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_CVT_NARROW_S_Q) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_H))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_CVT16;
        }
      else if ((cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR) || (cached_type == TYPE_NEON_FP_MUL_D))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MUL;
        }
      else if ((cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MUL_D_Q) || (cached_type == TYPE_NEON_FP_MUL_D_SCALAR_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MUL_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_MLA_S) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR) || (cached_type == TYPE_NEON_FP_MLA_D))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MLA;
        }
      else if ((cached_type == TYPE_NEON_FP_MLA_S_Q) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MLA_D_Q) || (cached_type == TYPE_NEON_FP_MLA_D_SCALAR_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_MLA_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RSQRTE_S) || (cached_type == TYPE_NEON_FP_RECPX_S) || (cached_type == TYPE_NEON_FP_RECPE_D) || (cached_type == TYPE_NEON_FP_RSQRTE_D) || (cached_type == TYPE_NEON_FP_RECPX_D))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_RECPE_RSQRTE;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_S_Q) || (cached_type == TYPE_NEON_FP_RECPX_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_D_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_D_Q) || (cached_type == TYPE_NEON_FP_RECPX_D_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPS_S) || (cached_type == TYPE_NEON_FP_RSQRTS_S) || (cached_type == TYPE_NEON_FP_RECPS_D) || (cached_type == TYPE_NEON_FP_RSQRTS_D))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_RECPS_RSQRTS;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_S_Q) || (cached_type == TYPE_NEON_FP_RECPS_D_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_D_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FP_RECPS_RSQRTS_Q;
        }
      else if ((cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CNT) || (cached_type == TYPE_NEON_REV) || (cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_RBIT) || (cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL2) || (cached_type == TYPE_NEON_ZIP) || (cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_DUP_Q) || (cached_type == TYPE_NEON_EXT) || (cached_type == TYPE_NEON_EXT_Q) || (cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_MOVE_Q) || (cached_type == TYPE_NEON_MOVE_NARROW_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS;
        }
      else if ((cached_type == TYPE_NEON_BSL_Q) || (cached_type == TYPE_NEON_CLS_Q) || (cached_type == TYPE_NEON_CNT_Q) || (cached_type == TYPE_NEON_REV_Q) || (cached_type == TYPE_NEON_PERMUTE_Q) || (cached_type == TYPE_NEON_RBIT_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_BITOPS_Q;
        }
      else if ((cached_type == TYPE_NEON_FROM_GP) || (cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;
        }
      else if (cached_type == TYPE_NEON_FROM_GP_Q)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else if ((cached_type == TYPE_NEON_TBL3) || (cached_type == TYPE_NEON_TBL4))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TBL3_TBL4;
        }
      else if (cached_type == TYPE_NEON_ZIP_Q)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ZIP_Q;
        }
      else if ((cached_type == TYPE_NEON_TO_GP) || (cached_type == TYPE_NEON_TO_GP_Q) || (cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_TO_GP;
        }
      else if ((cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD) || (cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_1REG_Q) || (cached_type == TYPE_NEON_LOAD1_2REG) || (cached_type == TYPE_NEON_LOAD1_2REG_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_3REG) || (cached_type == TYPE_NEON_LOAD1_3REG_Q) || (cached_type == TYPE_NEON_LOAD1_4REG) || (cached_type == TYPE_NEON_LOAD1_4REG_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_B;
        }
      else if ((cached_type == TYPE_NEON_LDP) || (cached_type == TYPE_NEON_LDP_Q) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_2REG) || (cached_type == TYPE_NEON_LOAD2_2REG_Q) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;
        }
      else if ((cached_type == TYPE_NEON_LOAD2_4REG) || (cached_type == TYPE_NEON_LOAD2_4REG_Q) || (cached_type == TYPE_NEON_LOAD3_3REG) || (cached_type == TYPE_NEON_LOAD3_3REG_Q) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD4_4REG) || (cached_type == TYPE_NEON_LOAD4_4REG_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_D;
        }
      else if ((cached_type == TYPE_NEON_LOAD2_ONE_LANE) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_E;
        }
      else if ((cached_type == TYPE_NEON_LOAD4_ONE_LANE) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_LOAD_F;
        }
      else if ((cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED) || (cached_type == TYPE_NEON_STORE1_1REG))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_A;
        }
      else if ((cached_type == TYPE_NEON_STORE1_2REG) || (cached_type == TYPE_NEON_STORE1_1REG_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_B;
        }
      else if ((cached_type == TYPE_NEON_STP) || (cached_type == TYPE_NEON_STP_Q) || (cached_type == TYPE_NEON_STORE1_3REG) || (cached_type == TYPE_NEON_STORE1_3REG_Q) || (cached_type == TYPE_NEON_STORE3_3REG) || (cached_type == TYPE_NEON_STORE3_3REG_Q) || (cached_type == TYPE_NEON_STORE2_4REG) || (cached_type == TYPE_NEON_STORE2_4REG_Q) || (cached_type == TYPE_NEON_STORE4_4REG) || (cached_type == TYPE_NEON_STORE4_4REG_Q) || (cached_type == TYPE_NEON_STORE2_2REG) || (cached_type == TYPE_NEON_STORE2_2REG_Q) || (cached_type == TYPE_NEON_STORE3_ONE_LANE) || (cached_type == TYPE_NEON_STORE3_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE4_ONE_LANE) || (cached_type == TYPE_NEON_STORE4_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE1_4REG) || (cached_type == TYPE_NEON_STORE1_4REG_Q) || (cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE2_ONE_LANE) || (cached_type == TYPE_NEON_STORE2_ONE_LANE_Q))
        {
	  return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;
        }
      else if (get_attr_is_neon_type (insn) == IS_NEON_TYPE_YES)
        {
	  return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A57_NEON_TYPE_UNKNOWN;
        }

    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
    case 2745:  /* neon_vst4di */
    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
    case 2739:  /* neon_vst4v8qi */
    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
    case 2677:  /* neon_vst3di */
    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
    case 2671:  /* neon_vst3v8qi */
    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
      return CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX;

    case 2562:  /* neon_vst1v2di */
    case 2560:  /* neon_vst1v4sf */
    case 2558:  /* neon_vst1v8bf */
    case 2556:  /* neon_vst1v8hf */
    case 2554:  /* neon_vst1v4si */
    case 2552:  /* neon_vst1v8hi */
    case 2550:  /* neon_vst1v16qi */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
      return CORTEX_A57_NEON_TYPE_NEON_STORE_B;

    case 2561:  /* neon_vst1di */
    case 2559:  /* neon_vst1v2sf */
    case 2557:  /* neon_vst1v4bf */
    case 2555:  /* neon_vst1v4hf */
    case 2553:  /* neon_vst1v2si */
    case 2551:  /* neon_vst1v4hi */
    case 2549:  /* neon_vst1v8qi */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1070:  /* unaligned_storev8qi */
    case 883:  /* *push_multi_vfp */
      return CORTEX_A57_NEON_TYPE_NEON_STORE_A;

    case 2730:  /* neon_vld4_lanev8bf */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2726:  /* neon_vld4_lanev8hi */
    case 2725:  /* neon_vld4_lanev2sf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2720:  /* neon_vld4_lanev8qi */
      return CORTEX_A57_NEON_TYPE_NEON_LOAD_F;

    case 2738:  /* neon_vld4_dupv8bf */
    case 2670:  /* neon_vld3_dupv8bf */
    case 2600:  /* neon_vld2_lanev8bf */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2596:  /* neon_vld2_lanev8hi */
    case 2595:  /* neon_vld2_lanev2sf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2590:  /* neon_vld2_lanev8qi */
      return CORTEX_A57_NEON_TYPE_NEON_LOAD_E;

    case 2719:  /* neon_vld4qbv4sf */
    case 2718:  /* neon_vld4qbv4si */
    case 2717:  /* neon_vld4qbv8bf */
    case 2716:  /* neon_vld4qbv8hf */
    case 2715:  /* neon_vld4qbv8hi */
    case 2714:  /* neon_vld4qbv16qi */
    case 2713:  /* neon_vld4qav4sf */
    case 2712:  /* neon_vld4qav4si */
    case 2711:  /* neon_vld4qav8bf */
    case 2710:  /* neon_vld4qav8hf */
    case 2709:  /* neon_vld4qav8hi */
    case 2708:  /* neon_vld4qav16qi */
    case 2662:  /* neon_vld3_lanev8bf */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2658:  /* neon_vld3_lanev8hi */
    case 2657:  /* neon_vld3_lanev2sf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2652:  /* neon_vld3_lanev8qi */
    case 2651:  /* neon_vld3qbv4sf */
    case 2650:  /* neon_vld3qbv4si */
    case 2649:  /* neon_vld3qbv8bf */
    case 2648:  /* neon_vld3qbv8hf */
    case 2647:  /* neon_vld3qbv8hi */
    case 2646:  /* neon_vld3qbv16qi */
    case 2645:  /* neon_vld3qav4sf */
    case 2644:  /* neon_vld3qav4si */
    case 2643:  /* neon_vld3qav8bf */
    case 2642:  /* neon_vld3qav8hf */
    case 2641:  /* neon_vld3qav8hi */
    case 2640:  /* neon_vld3qav16qi */
      return CORTEX_A57_NEON_TYPE_NEON_LOAD_D;

    case 2608:  /* neon_vld2_dupv8bf */
    case 2589:  /* neon_vld2v4sf */
    case 2588:  /* neon_vld2v4si */
    case 2587:  /* neon_vld2v8bf */
    case 2586:  /* neon_vld2v8hf */
    case 2585:  /* neon_vld2v8hi */
    case 2584:  /* neon_vld2v16qi */
    case 2548:  /* neon_vld1_dupv2di */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2543:  /* neon_vld1_dupv16qi */
    case 2542:  /* neon_vld1_dupv2sf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2537:  /* neon_vld1_dupv8qi */
    case 2536:  /* neon_vld1_lanev2di */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2530:  /* neon_vld1_lanev16qi */
    case 2529:  /* neon_vld1_lanedi */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2523:  /* neon_vld1_lanev8qi */
      return CORTEX_A57_NEON_TYPE_NEON_LOAD_C;

    case 2854:  /* aes_op_protect_neon_vld1v16qi */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2522:  /* neon_vld1v2di */
    case 2521:  /* neon_vld1di */
    case 2520:  /* neon_vld1v4sf */
    case 2519:  /* neon_vld1v2sf */
    case 2518:  /* neon_vld1v8bf */
    case 2517:  /* neon_vld1v4bf */
    case 2516:  /* neon_vld1v8hf */
    case 2515:  /* neon_vld1v4hf */
    case 2514:  /* neon_vld1v4si */
    case 2513:  /* neon_vld1v2si */
    case 2512:  /* neon_vld1v8hi */
    case 2511:  /* neon_vld1v4hi */
    case 2510:  /* neon_vld1v16qi */
    case 2509:  /* neon_vld1v8qi */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1111:  /* *movmisalignv16qi_neon_load */
    case 1103:  /* *movmisaligndi_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1097:  /* *movmisalignv8qi_neon_load */
      return CORTEX_A57_NEON_TYPE_NEON_LOAD_A;

    case 2040:  /* neon_vget_lanev4sf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2031:  /* neon_vget_lanev16qi_sext_internal */
    case 2030:  /* neon_vget_lanev2sf_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2023:  /* neon_vget_lanev8qi_sext_internal */
      return CORTEX_A57_NEON_TYPE_NEON_TO_GP;

    case 2507:  /* *neon_vuzpv8hf_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2490:  /* *neon_vzipv16qi_insn */
      return CORTEX_A57_NEON_TYPE_NEON_ZIP_Q;

    case 2478:  /* neon_vtbx4v8qi */
    case 2477:  /* neon_vtbx3v8qi */
    case 2471:  /* neon_vtbl4v8qi */
    case 2470:  /* neon_vtbl3v8qi */
      return CORTEX_A57_NEON_TYPE_NEON_TBL3_TBL4;

    case 2048:  /* neon_vdup_nv8bf */
    case 2046:  /* neon_vdup_nv8hf */
    case 2044:  /* neon_vdup_nv8hi */
    case 2043:  /* neon_vdup_nv16qi */
      return CORTEX_A57_NEON_TYPE_NEON_FROM_GP_Q;

    case 2047:  /* neon_vdup_nv4bf */
    case 2045:  /* neon_vdup_nv4hf */
    case 2042:  /* neon_vdup_nv4hi */
    case 2041:  /* neon_vdup_nv8qi */
      return CORTEX_A57_NEON_TYPE_NEON_FROM_GP;

    case 2487:  /* *neon_vtrnv8hf_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2261:  /* neon_vbslv2di_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2249:  /* neon_vbslv16qi_internal */
    case 2247:  /* neon_vrev16v16qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2244:  /* neon_vrev32v16qi */
    case 2241:  /* neon_vrev64v2di */
    case 2240:  /* neon_vrev64v4sf */
    case 2238:  /* neon_vrev64v8hf */
    case 2236:  /* neon_vrev64v4si */
    case 2234:  /* neon_vrev64v8hi */
    case 2232:  /* neon_vrev64v16qi */
    case 2079:  /* *neon_vswpv2di */
    case 2077:  /* *neon_vswpv4sf */
    case 2075:  /* *neon_vswpv8bf */
    case 2073:  /* *neon_vswpv8hf */
    case 2071:  /* *neon_vswpv4si */
    case 2069:  /* *neon_vswpv8hi */
    case 2067:  /* *neon_vswpv16qi */
    case 2012:  /* popcountv16qi2 */
    case 2010:  /* neon_vclzv4si */
    case 2008:  /* neon_vclzv8hi */
    case 2006:  /* neon_vclzv16qi */
    case 2004:  /* neon_vclsv4si */
    case 2002:  /* neon_vclsv8hi */
    case 2000:  /* neon_vclsv16qi */
    case 1914:  /* neon_bswapv2di */
    case 1913:  /* neon_bswapv4si */
    case 1911:  /* neon_bswapv8hi */
      return CORTEX_A57_NEON_TYPE_NEON_BITOPS_Q;

    case 2816:  /* neon_vec_pack_trunc_v2di */
    case 2815:  /* neon_vec_pack_trunc_v4si */
    case 2814:  /* neon_vec_pack_trunc_v8hi */
    case 2804:  /* neon_unpacku_v2si */
    case 2803:  /* neon_unpacks_v2si */
    case 2802:  /* neon_unpacku_v4hi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2799:  /* neon_unpacks_v8qi */
    case 2508:  /* *neon_vuzpv4hf_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2489:  /* *neon_vzipv8qi_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2476:  /* neon_vtbx2v8qi */
    case 2475:  /* neon_vtbx1v8qi */
    case 2469:  /* neon_vtbl2v8qi */
    case 2468:  /* neon_vtbl1v8qi */
    case 2260:  /* neon_vbsldi_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2248:  /* neon_vbslv8qi_internal */
    case 2246:  /* neon_vrev16v8qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2242:  /* neon_vrev32v8qi */
    case 2239:  /* neon_vrev64v2sf */
    case 2237:  /* neon_vrev64v4hf */
    case 2235:  /* neon_vrev64v2si */
    case 2233:  /* neon_vrev64v4hi */
    case 2231:  /* neon_vrev64v8qi */
    case 2230:  /* neon_vextv2di */
    case 2229:  /* neon_vextdi */
    case 2228:  /* neon_vextv4sf */
    case 2227:  /* neon_vextv2sf */
    case 2226:  /* neon_vextv8bf */
    case 2225:  /* neon_vextv4bf */
    case 2224:  /* neon_vextv8hf */
    case 2223:  /* neon_vextv4hf */
    case 2222:  /* neon_vextv4si */
    case 2221:  /* neon_vextv2si */
    case 2220:  /* neon_vextv8hi */
    case 2219:  /* neon_vextv4hi */
    case 2218:  /* neon_vextv16qi */
    case 2217:  /* neon_vextv8qi */
    case 2078:  /* *neon_vswpdi */
    case 2076:  /* *neon_vswpv2sf */
    case 2074:  /* *neon_vswpv4bf */
    case 2072:  /* *neon_vswpv4hf */
    case 2070:  /* *neon_vswpv2si */
    case 2068:  /* *neon_vswpv4hi */
    case 2066:  /* *neon_vswpv8qi */
    case 2065:  /* neon_vdup_lanev8bf_internal */
    case 2064:  /* neon_vdup_lanev4bf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 2011:  /* popcountv8qi2 */
    case 2009:  /* neon_vclzv2si */
    case 2007:  /* neon_vclzv4hi */
    case 2005:  /* neon_vclzv8qi */
    case 2003:  /* neon_vclsv2si */
    case 2001:  /* neon_vclsv4hi */
    case 1999:  /* neon_vclsv8qi */
    case 1912:  /* neon_bswapv2si */
    case 1910:  /* neon_bswapv4hi */
    case 1291:  /* one_cmplv2di2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1289:  /* one_cmplv2sf2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1282:  /* one_cmplv16qi2_neon */
    case 1281:  /* one_cmplv8qi2_neon */
      return CORTEX_A57_NEON_TYPE_NEON_BITOPS;

    case 1902:  /* neon_vrsqrtsv8hf */
    case 1901:  /* neon_vrsqrtsv4sf */
    case 1898:  /* neon_vrecpsv8hf */
    case 1897:  /* neon_vrecpsv4sf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_RECPS_RSQRTS_Q;

    case 1903:  /* neon_vrsqrtsv4hf */
    case 1900:  /* neon_vrsqrtsv2sf */
    case 1899:  /* neon_vrecpsv4hf */
    case 1896:  /* neon_vrecpsv2sf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_RECPS_RSQRTS;

    case 2022:  /* neon_vrsqrtev4sf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2018:  /* neon_vrecpev4sf */
    case 2017:  /* neon_vrecpev4si */
    case 2013:  /* neon_vrecpev8hf */
    case 1324:  /* neon_vrsqrtev8hf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q;

    case 2020:  /* neon_vrsqrtev2sf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2016:  /* neon_vrecpev2sf */
    case 2015:  /* neon_vrecpev2si */
    case 2014:  /* neon_vrecpev4hf */
    case 1325:  /* neon_vrsqrtev4hf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_RECPE_RSQRTE;

    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1180:  /* mulv8hf3addv8hf_neon */
      return CORTEX_A57_NEON_TYPE_NEON_FP_MLA_Q;

    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1190:  /* fmav2sf4 */
    case 1181:  /* mulv4hf3addv4hf_neon */
      return CORTEX_A57_NEON_TYPE_NEON_FP_MLA;

    case 2169:  /* neon_vmul_lanev8hf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_MUL_Q;

    case 2170:  /* neon_vmul_lanev4hf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_MUL;

    case 2836:  /* neon_vbfcvtv4sf_highv8bf */
    case 2835:  /* neon_vbfcvtv4sfv8bf */
    case 2834:  /* neon_vbfcvtv4sfv4bf */
    case 2104:  /* neon_vcvtv4hfv4sf */
    case 2103:  /* neon_vcvtv4sfv4hf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_CVT16;

    case 2136:  /* neon_vcvtpuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2128:  /* neon_vcvtu_nv8hi */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2123:  /* neon_vcvts_nv4si */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2108:  /* neon_vcvtuv8hi */
    case 2107:  /* neon_vcvtsv8hi */
    case 2102:  /* neon_vcvtuv4si */
    case 2101:  /* neon_vcvtsv4si */
    case 2098:  /* neon_vcvtuv4sf */
    case 2097:  /* neon_vcvtsv4sf */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2088:  /* floatv4siv4sf2 */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1220:  /* neon_vcvtpv4sfv4si */
      return CORTEX_A57_NEON_TYPE_NEON_FP_CVT_INT_Q;

    case 2144:  /* neon_vcvtpuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2126:  /* neon_vcvtu_nv4hi */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2121:  /* neon_vcvts_nv2si */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2106:  /* neon_vcvtuv4hi */
    case 2105:  /* neon_vcvtsv4hi */
    case 2100:  /* neon_vcvtuv2si */
    case 2099:  /* neon_vcvtsv2si */
    case 2096:  /* neon_vcvtuv2sf */
    case 2095:  /* neon_vcvtsv2sf */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2087:  /* floatv2siv2sf2 */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1214:  /* neon_vcvtpv2sfv2si */
      return CORTEX_A57_NEON_TYPE_NEON_FP_CVT_INT;

    case 1895:  /* neon_vpminfv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1405:  /* quad_halves_sminv4sf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_REDUCTIONS_Q;

    case 2824:  /* neon_vabdv4sf_3 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2818:  /* neon_vabdv8hf_2 */
    case 1855:  /* fminv4sf3 */
    case 1854:  /* fmaxv4sf3 */
    case 1851:  /* neon_vminnmv4sf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1845:  /* neon_vminnmv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1839:  /* neon_vminfv8hf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1837:  /* neon_vminfv4sf */
    case 1836:  /* neon_vmaxfv4sf */
    case 1785:  /* neon_vabdfv4sf */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1404:  /* quad_halves_plusv4sf */
    case 1317:  /* neon_vrndxv8hf */
    case 1316:  /* neon_vrndpv8hf */
    case 1315:  /* neon_vrndnv8hf */
    case 1314:  /* neon_vrndmv8hf */
    case 1313:  /* neon_vrndav8hf */
    case 1312:  /* neon_vrndv8hf */
    case 1213:  /* neon_vrintnv4sf */
    case 1212:  /* neon_vrintav4sf */
    case 1211:  /* neon_vrintxv4sf */
    case 1210:  /* neon_vrintmv4sf */
    case 1209:  /* neon_vrintzv4sf */
    case 1208:  /* neon_vrintpv4sf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH_Q;

    case 2823:  /* neon_vabdv2sf_3 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2817:  /* neon_vabdv4hf_2 */
    case 1893:  /* neon_vpminfv2sf */
    case 1892:  /* neon_vpmaxfv2sf */
    case 1853:  /* fminv2sf3 */
    case 1852:  /* fmaxv2sf3 */
    case 1849:  /* neon_vminnmv2sf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1847:  /* neon_vminnmv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1841:  /* neon_vminfv4hf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1835:  /* neon_vminfv2sf */
    case 1834:  /* neon_vmaxfv2sf */
    case 1784:  /* neon_vabdfv2sf */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1690:  /* neon_vceqv2sf_insn_unspec */
    case 1323:  /* neon_vrndxv4hf */
    case 1322:  /* neon_vrndpv4hf */
    case 1321:  /* neon_vrndnv4hf */
    case 1320:  /* neon_vrndmv4hf */
    case 1319:  /* neon_vrndav4hf */
    case 1318:  /* neon_vrndv4hf */
    case 1207:  /* neon_vrintnv2sf */
    case 1206:  /* neon_vrintav2sf */
    case 1205:  /* neon_vrintxv2sf */
    case 1204:  /* neon_vrintmv2sf */
    case 1203:  /* neon_vrintzv2sf */
    case 1202:  /* neon_vrintpv2sf */
    case 787:  /* neon_vrndihf */
    case 786:  /* neon_vrndxhf */
    case 785:  /* neon_vrndphf */
    case 784:  /* neon_vrndnhf */
    case 783:  /* neon_vrndmhf */
    case 782:  /* neon_vrndahf */
    case 781:  /* neon_vrndhf */
      return CORTEX_A57_NEON_TYPE_NEON_FP_ARITH;

    case 2467:  /* neon_vsli_nv2di */
    case 2465:  /* neon_vsli_nv4si */
    case 2463:  /* neon_vsli_nv8hi */
    case 2461:  /* neon_vsli_nv16qi */
    case 2459:  /* neon_vsri_nv2di */
    case 2457:  /* neon_vsri_nv4si */
    case 2455:  /* neon_vsri_nv8hi */
    case 2453:  /* neon_vsri_nv16qi */
    case 1379:  /* ashlv2di3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1372:  /* ashlv2di3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1367:  /* ashlv16qi3_signed */
      return CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;

    case 2466:  /* neon_vsli_ndi */
    case 2464:  /* neon_vsli_nv2si */
    case 2462:  /* neon_vsli_nv4hi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2458:  /* neon_vsri_ndi */
    case 2456:  /* neon_vsri_nv2si */
    case 2454:  /* neon_vsri_nv4hi */
    case 2452:  /* neon_vsri_nv8qi */
    case 1377:  /* ashlv2si3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1370:  /* ashlv2si3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1366:  /* ashlv8qi3_signed */
      return CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC;

    case 2413:  /* neon_vqshlu_nv2di */
    case 2412:  /* neon_vqshlu_ndi */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2381:  /* neon_vqrshrun_nv2di */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2325:  /* neon_vqrshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2322:  /* neon_vqshlsv2di */
    case 2321:  /* neon_vqrshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2318:  /* neon_vqshlsdi */
    case 2317:  /* neon_vqrshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2314:  /* neon_vqshlsv4si */
    case 2313:  /* neon_vqrshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2310:  /* neon_vqshlsv2si */
    case 2309:  /* neon_vqrshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2305:  /* neon_vqrshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2298:  /* neon_vqshlsv16qi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2294:  /* neon_vqshlsv8qi */
    case 2156:  /* neon_vqmovunv2di */
    case 2155:  /* neon_vqmovunv4si */
    case 2154:  /* neon_vqmovunv8hi */
    case 2153:  /* neon_vqmovnuv2di */
    case 2152:  /* neon_vqmovnsv2di */
    case 2151:  /* neon_vqmovnuv4si */
    case 2150:  /* neon_vqmovnsv4si */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2148:  /* neon_vqmovnsv8hi */
      return CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX;

    case 2840:  /* neon_vbfcvt_highv8bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2798:  /* neon_vec_ushiftl_v2si */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2419:  /* neon_vshllu_nv2si */
    case 2418:  /* neon_vshlls_nv2si */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2389:  /* neon_vshl_nv2di */
    case 2388:  /* neon_vshl_ndi */
    case 2387:  /* neon_vshl_nv4si */
    case 2386:  /* neon_vshl_nv2si */
    case 2385:  /* neon_vshl_nv8hi */
    case 2384:  /* neon_vshl_nv4hi */
    case 2383:  /* neon_vshl_nv16qi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2363:  /* neon_vrshrn_nv2di */
    case 2362:  /* neon_vshrn_nv2di */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2360:  /* neon_vshrn_nv4si */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2357:  /* neon_vrshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2354:  /* neon_vshrs_nv2di */
    case 2353:  /* neon_vrshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2350:  /* neon_vshrs_ndi */
    case 2349:  /* neon_vrshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2346:  /* neon_vshrs_nv4si */
    case 2345:  /* neon_vrshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2342:  /* neon_vshrs_nv2si */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2293:  /* neon_vrshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2290:  /* neon_vshlsv2di */
    case 2289:  /* neon_vrshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2287:  /* neon_vshludi */
    case 2286:  /* neon_vshlsdi */
    case 2285:  /* neon_vrshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2282:  /* neon_vshlsv4si */
    case 2281:  /* neon_vrshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2278:  /* neon_vshlsv2si */
    case 2277:  /* neon_vrshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2274:  /* neon_vshlsv8hi */
    case 2273:  /* neon_vrshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2270:  /* neon_vshlsv4hi */
    case 2269:  /* neon_vrshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2266:  /* neon_vshlsv16qi */
    case 2265:  /* neon_vrshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2262:  /* neon_vshlsv8qi */
    case 2162:  /* neon_vmovluv2si */
    case 2161:  /* neon_vmovlsv2si */
    case 2160:  /* neon_vmovluv4hi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2158:  /* neon_vmovluv8qi */
    case 2157:  /* neon_vmovlsv8qi */
    case 2147:  /* neon_vmovnv2di */
    case 2146:  /* neon_vmovnv4si */
    case 2145:  /* neon_vmovnv8hi */
    case 1365:  /* vlshrv4si3_imm */
    case 1364:  /* vlshrv2si3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1355:  /* vashrv16qi3_imm */
    case 1354:  /* vashrv8qi3_imm */
      return CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_BASIC;

    case 2451:  /* neon_vrsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2448:  /* neon_vsras_nv2di */
    case 2447:  /* neon_vrsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2444:  /* neon_vsras_ndi */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2440:  /* neon_vsras_nv4si */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2436:  /* neon_vsras_nv2si */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2424:  /* neon_vsras_nv16qi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2420:  /* neon_vsras_nv8qi */
      return CORTEX_A57_NEON_TYPE_NEON_SHIFT_ACC;

    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1588:  /* neon_vqdmlalv2si */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
      return CORTEX_A57_NEON_TYPE_NEON_SAT_MLA_LONG;

    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
      return CORTEX_A57_NEON_TYPE_NEON_MLA_Q;

    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
      return CORTEX_A57_NEON_TYPE_NEON_MLA;

    case 2184:  /* neon_vqrdmulh_lanev2si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
    case 1517:  /* neon_vmulfv8hf */
      return CORTEX_A57_NEON_TYPE_NEON_MULTIPLY_Q;

    case 2868:  /* crypto_vmullp64 */
    case 2810:  /* neon_vec_umult_v2si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2808:  /* neon_vec_umult_v4hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2806:  /* neon_vec_umult_v8qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
    case 1601:  /* neon_vqdmullv2si */
    case 1600:  /* neon_vqdmullv4hi */
    case 1599:  /* neon_vmullpv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1597:  /* neon_vmullsv2si */
    case 1596:  /* neon_vmullpv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1594:  /* neon_vmullsv4hi */
    case 1593:  /* neon_vmullpv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1591:  /* neon_vmullsv8qi */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
    case 1518:  /* neon_vmulfv4hf */
      return CORTEX_A57_NEON_TYPE_NEON_MULTIPLY;

    case 1998:  /* neon_vqnegv4si */
    case 1997:  /* neon_vqnegv2si */
    case 1996:  /* neon_vqnegv8hi */
    case 1995:  /* neon_vqnegv4hi */
    case 1994:  /* neon_vqnegv16qi */
    case 1993:  /* neon_vqnegv8qi */
    case 1909:  /* neon_vqabsv4si */
    case 1908:  /* neon_vqabsv2si */
    case 1907:  /* neon_vqabsv8hi */
    case 1906:  /* neon_vqabsv4hi */
    case 1905:  /* neon_vqabsv16qi */
    case 1904:  /* neon_vqabsv8qi */
    case 1891:  /* neon_vpminuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1888:  /* neon_vpmaxsv2si */
    case 1887:  /* neon_vpminuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1883:  /* neon_vpminuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1843:  /* neon_vpminfv4hf */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1833:  /* neon_vminuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1830:  /* neon_vmaxsv4si */
    case 1829:  /* neon_vminuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1826:  /* neon_vmaxsv2si */
    case 1825:  /* neon_vminuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1821:  /* neon_vminuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1817:  /* neon_vminuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1814:  /* neon_vmaxsv16qi */
    case 1813:  /* neon_vminuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1810:  /* neon_vmaxsv8qi */
    case 1731:  /* neon_vcgeuv4si */
    case 1730:  /* neon_vcgtuv4si */
    case 1729:  /* neon_vcgeuv2si */
    case 1728:  /* neon_vcgtuv2si */
    case 1727:  /* neon_vcgeuv8hi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1725:  /* neon_vcgeuv4hi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1722:  /* neon_vcgtuv16qi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1720:  /* neon_vcgtuv8qi */
    case 1649:  /* neon_vrsubhnv2di */
    case 1648:  /* neon_vsubhnv2di */
    case 1647:  /* neon_vrsubhnv4si */
    case 1646:  /* neon_vsubhnv4si */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1644:  /* neon_vsubhnv8hi */
    case 1643:  /* neon_vhsubuv4si */
    case 1642:  /* neon_vhsubsv4si */
    case 1641:  /* neon_vhsubuv2si */
    case 1640:  /* neon_vhsubsv2si */
    case 1639:  /* neon_vhsubuv8hi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1637:  /* neon_vhsubuv4hi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1634:  /* neon_vhsubsv16qi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1632:  /* neon_vhsubsv8qi */
    case 1631:  /* neon_vqsubuv2di */
    case 1630:  /* neon_vqsubsv2di */
    case 1629:  /* neon_vqsubudi */
    case 1628:  /* neon_vqsubsdi */
    case 1627:  /* neon_vqsubuv4si */
    case 1626:  /* neon_vqsubsv4si */
    case 1625:  /* neon_vqsubuv2si */
    case 1624:  /* neon_vqsubsv2si */
    case 1623:  /* neon_vqsubuv8hi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1621:  /* neon_vqsubuv4hi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1618:  /* neon_vqsubsv16qi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1616:  /* neon_vqsubsv8qi */
    case 1512:  /* neon_vraddhnv2di */
    case 1511:  /* neon_vaddhnv2di */
    case 1510:  /* neon_vraddhnv4si */
    case 1509:  /* neon_vaddhnv4si */
    case 1508:  /* neon_vraddhnv8hi */
    case 1507:  /* neon_vaddhnv8hi */
    case 1506:  /* neon_vqadduv2di */
    case 1505:  /* neon_vqaddsv2di */
    case 1504:  /* neon_vqaddudi */
    case 1503:  /* neon_vqaddsdi */
    case 1502:  /* neon_vqadduv4si */
    case 1501:  /* neon_vqaddsv4si */
    case 1500:  /* neon_vqadduv2si */
    case 1499:  /* neon_vqaddsv2si */
    case 1498:  /* neon_vqadduv8hi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1496:  /* neon_vqadduv4hi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1494:  /* neon_vqadduv16qi */
    case 1493:  /* neon_vqaddsv16qi */
    case 1492:  /* neon_vqadduv8qi */
    case 1491:  /* neon_vqaddsv8qi */
    case 1490:  /* neon_vhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1486:  /* neon_vhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1483:  /* neon_vrhaddsv2si */
    case 1482:  /* neon_vhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1474:  /* neon_vhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1467:  /* neon_vrhaddsv8qi */
    case 1452:  /* *us_subv2sf_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1445:  /* *ss_subv8qi_neon */
    case 1444:  /* *us_addv2sf_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1437:  /* *ss_addv8qi_neon */
    case 1436:  /* neon_vpumaxv2si */
    case 1435:  /* neon_vpumaxv4hi */
    case 1434:  /* neon_vpumaxv8qi */
    case 1433:  /* neon_vpuminv2si */
    case 1432:  /* neon_vpuminv4hi */
    case 1431:  /* neon_vpuminv8qi */
    case 1416:  /* quad_halves_umaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1408:  /* quad_halves_sminv8hi */
    case 1403:  /* quad_halves_umaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1400:  /* quad_halves_sminv4si */
    case 1337:  /* *umaxv4si3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1327:  /* *uminv16qi3_neon */
    case 1326:  /* *uminv8qi3_neon */
    case 1311:  /* neon_negv4hf2 */
    case 1310:  /* neon_absv4hf2 */
    case 1309:  /* neon_negv8hf2 */
    case 1308:  /* neon_absv8hf2 */
      return CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX;

    case 2871:  /* crypto_sha1p_lb */
    case 2870:  /* crypto_sha1m_lb */
    case 2869:  /* crypto_sha1c_lb */
    case 2867:  /* crypto_sha1h_lb */
    case 2866:  /* crypto_sha256su1 */
    case 2865:  /* crypto_sha256h2 */
    case 2864:  /* crypto_sha256h */
    case 2863:  /* crypto_sha1su0 */
    case 2862:  /* crypto_sha256su0 */
    case 2861:  /* crypto_sha1su1 */
    case 2860:  /* *aarch32_crypto_aesd_fused_protected */
    case 2859:  /* *aarch32_crypto_aesd_fused */
    case 2858:  /* *aarch32_crypto_aese_fused_protected */
    case 2857:  /* *aarch32_crypto_aese_fused */
    case 2856:  /* *crypto_aesimc_protected */
    case 2855:  /* *crypto_aesmc_protected */
    case 2851:  /* *crypto_aese_insn */
    case 2850:  /* *crypto_aesd_insn */
    case 2849:  /* crypto_aesimc */
    case 2848:  /* crypto_aesmc */
    case 2833:  /* neon_vbfdot_lanev8bfv4sf */
    case 2832:  /* neon_vbfdot_lanev8bfv2sf */
    case 2831:  /* neon_vbfdot_lanev4bfv4sf */
    case 2830:  /* neon_vbfdot_lanev4bfv2sf */
    case 2829:  /* neon_vbfdotv4sf */
    case 2828:  /* neon_vbfdotv2sf */
    case 1992:  /* neon_sudot_laneqv16qi */
    case 1991:  /* neon_usdot_laneqv16qi */
    case 1990:  /* neon_sudot_laneqv8qi */
    case 1989:  /* neon_usdot_laneqv8qi */
    case 1988:  /* neon_sudot_lanev16qi */
    case 1987:  /* neon_usdot_lanev16qi */
    case 1986:  /* neon_sudot_lanev8qi */
    case 1985:  /* neon_usdot_lanev8qi */
    case 1984:  /* neon_udot_laneqv16qi */
    case 1983:  /* neon_sdot_laneqv16qi */
    case 1982:  /* neon_udot_laneqv8qi */
    case 1981:  /* neon_sdot_laneqv8qi */
    case 1980:  /* neon_udot_lanev16qi */
    case 1979:  /* neon_sdot_lanev16qi */
    case 1978:  /* neon_udot_lanev8qi */
    case 1977:  /* neon_sdot_lanev8qi */
    case 1976:  /* neon_usdotv16qi */
    case 1975:  /* neon_usdotv8qi */
    case 1974:  /* udot_prodv16qi */
    case 1973:  /* sdot_prodv16qi */
    case 1972:  /* udot_prodv8qi */
    case 1971:  /* sdot_prodv8qi */
    case 1970:  /* neon_vcmlaq_lane270v4sf */
    case 1969:  /* neon_vcmlaq_lane180v4sf */
    case 1968:  /* neon_vcmlaq_lane90v4sf */
    case 1967:  /* neon_vcmlaq_lane0v4sf */
    case 1966:  /* neon_vcmlaq_lane270v8hf */
    case 1965:  /* neon_vcmlaq_lane180v8hf */
    case 1964:  /* neon_vcmlaq_lane90v8hf */
    case 1963:  /* neon_vcmlaq_lane0v8hf */
    case 1962:  /* neon_vcmla_laneq270v4hf */
    case 1961:  /* neon_vcmla_laneq180v4hf */
    case 1960:  /* neon_vcmla_laneq90v4hf */
    case 1959:  /* neon_vcmla_laneq0v4hf */
    case 1958:  /* neon_vcmla_laneq270v2sf */
    case 1957:  /* neon_vcmla_laneq180v2sf */
    case 1956:  /* neon_vcmla_laneq90v2sf */
    case 1955:  /* neon_vcmla_laneq0v2sf */
    case 1954:  /* neon_vcmla_lane270v4sf */
    case 1953:  /* neon_vcmla_lane180v4sf */
    case 1952:  /* neon_vcmla_lane90v4sf */
    case 1951:  /* neon_vcmla_lane0v4sf */
    case 1950:  /* neon_vcmla_lane270v2sf */
    case 1949:  /* neon_vcmla_lane180v2sf */
    case 1948:  /* neon_vcmla_lane90v2sf */
    case 1947:  /* neon_vcmla_lane0v2sf */
    case 1946:  /* neon_vcmla_lane270v8hf */
    case 1945:  /* neon_vcmla_lane180v8hf */
    case 1944:  /* neon_vcmla_lane90v8hf */
    case 1943:  /* neon_vcmla_lane0v8hf */
    case 1942:  /* neon_vcmla_lane270v4hf */
    case 1941:  /* neon_vcmla_lane180v4hf */
    case 1940:  /* neon_vcmla_lane90v4hf */
    case 1939:  /* neon_vcmla_lane0v4hf */
    case 1938:  /* neon_vcmla270v4sf */
    case 1937:  /* neon_vcmla180v4sf */
    case 1936:  /* neon_vcmla90v4sf */
    case 1935:  /* neon_vcmla0v4sf */
    case 1934:  /* neon_vcmla270v2sf */
    case 1933:  /* neon_vcmla180v2sf */
    case 1932:  /* neon_vcmla90v2sf */
    case 1931:  /* neon_vcmla0v2sf */
    case 1930:  /* neon_vcmla270v8hf */
    case 1929:  /* neon_vcmla180v8hf */
    case 1928:  /* neon_vcmla90v8hf */
    case 1927:  /* neon_vcmla0v8hf */
    case 1926:  /* neon_vcmla270v4hf */
    case 1925:  /* neon_vcmla180v4hf */
    case 1924:  /* neon_vcmla90v4hf */
    case 1923:  /* neon_vcmla0v4hf */
    case 1922:  /* neon_vcadd270v4sf */
    case 1921:  /* neon_vcadd90v4sf */
    case 1920:  /* neon_vcadd270v2sf */
    case 1919:  /* neon_vcadd90v2sf */
    case 1918:  /* neon_vcadd270v8hf */
    case 1917:  /* neon_vcadd90v8hf */
    case 1916:  /* neon_vcadd270v4hf */
    case 1915:  /* neon_vcadd90v4hf */
    case 1867:  /* neon_vpaddluv4si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1865:  /* neon_vpaddluv2si */
    case 1864:  /* neon_vpaddlsv2si */
    case 1863:  /* neon_vpaddluv8hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1856:  /* neon_vpaddlsv8qi */
    case 1769:  /* neon_vtst_combinev4si */
    case 1768:  /* neon_vtst_combinev2si */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1765:  /* neon_vtst_combinev16qi */
    case 1764:  /* neon_vtst_combinev8qi */
    case 1615:  /* neon_vsubwuv2si */
    case 1614:  /* neon_vsubwsv2si */
    case 1613:  /* neon_vsubwuv4hi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1610:  /* neon_vsubwsv8qi */
    case 1609:  /* neon_vsubluv2si */
    case 1608:  /* neon_vsublsv2si */
    case 1607:  /* neon_vsubluv4hi */
    case 1606:  /* neon_vsublsv4hi */
    case 1605:  /* neon_vsubluv8qi */
    case 1604:  /* neon_vsublsv8qi */
    case 1466:  /* neon_vaddwuv2si */
    case 1465:  /* neon_vaddwsv2si */
    case 1464:  /* neon_vaddwuv4hi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1461:  /* neon_vaddwsv8qi */
    case 1460:  /* neon_vaddluv2si */
    case 1459:  /* neon_vaddlsv2si */
    case 1458:  /* neon_vaddluv4hi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1456:  /* neon_vaddluv8qi */
    case 1455:  /* neon_vaddlsv8qi */
    case 1422:  /* neon_vpaddv4hf */
    case 1417:  /* arm_reduc_plus_internal_v2di */
    case 1412:  /* quad_halves_plusv16qi */
    case 1407:  /* quad_halves_plusv8hi */
    case 1399:  /* quad_halves_plusv4si */
    case 1398:  /* widen_usumv2si3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
    case 1280:  /* xorv2di3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1278:  /* xorv2sf3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1247:  /* andv2di3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1242:  /* andv4si3_neon */
    case 1241:  /* andv2si3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1227:  /* iorv16qi3_neon */
    case 1226:  /* iorv8qi3_neon */
      return CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC;

    case 1803:  /* neon_vabauv4si */
    case 1802:  /* neon_vabasv4si */
    case 1799:  /* neon_vabauv8hi */
    case 1798:  /* neon_vabasv8hi */
    case 1795:  /* neon_vabauv16qi */
    case 1794:  /* neon_vabasv16qi */
      return CORTEX_A57_NEON_TYPE_NEON_ARITH_ACC_Q;

    case 1879:  /* neon_vpadaluv4si */
    case 1878:  /* neon_vpadalsv4si */
    case 1877:  /* neon_vpadaluv2si */
    case 1876:  /* neon_vpadalsv2si */
    case 1875:  /* neon_vpadaluv8hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1868:  /* neon_vpadalsv8qi */
    case 1809:  /* neon_vabaluv2si */
    case 1808:  /* neon_vabalsv2si */
    case 1807:  /* neon_vabaluv4hi */
    case 1806:  /* neon_vabalsv4hi */
    case 1805:  /* neon_vabaluv8qi */
    case 1804:  /* neon_vabalsv8qi */
    case 1801:  /* neon_vabauv2si */
    case 1800:  /* neon_vabasv2si */
    case 1797:  /* neon_vabauv4hi */
    case 1796:  /* neon_vabasv4hi */
    case 1793:  /* neon_vabauv8qi */
    case 1792:  /* neon_vabasv8qi */
      return CORTEX_A57_NEON_TYPE_NEON_ARITH_ACC;

    case 1782:  /* neon_vabdv8hf */
    case 1781:  /* neon_vabduv4si */
    case 1780:  /* neon_vabdsv4si */
    case 1777:  /* neon_vabduv8hi */
    case 1776:  /* neon_vabdsv8hi */
    case 1773:  /* neon_vabduv16qi */
    case 1772:  /* neon_vabdsv16qi */
      return CORTEX_A57_NEON_TYPE_NEON_ABD_Q;

    case 1791:  /* neon_vabdluv2si */
    case 1790:  /* neon_vabdlsv2si */
    case 1789:  /* neon_vabdluv4hi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1787:  /* neon_vabdluv8qi */
    case 1786:  /* neon_vabdlsv8qi */
    case 1783:  /* neon_vabdv4hf */
    case 1779:  /* neon_vabduv2si */
    case 1778:  /* neon_vabdsv2si */
    case 1775:  /* neon_vabduv4hi */
    case 1774:  /* neon_vabdsv4hi */
    case 1771:  /* neon_vabduv8qi */
    case 1770:  /* neon_vabdsv8qi */
      return CORTEX_A57_NEON_TYPE_NEON_ABD;

    default:
      return CORTEX_A57_NEON_TYPE_UNKNOWN;

    }
}

enum attr_cortex_a53_advsimd_type
get_attr_cortex_a53_advsimd_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU_Q;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 2737:  /* neon_vld4_dupdi */
    case 2669:  /* neon_vld3_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;
        }

    case 2736:  /* neon_vld4_dupv2sf */
    case 2735:  /* neon_vld4_dupv2si */
    case 2668:  /* neon_vld3_dupv2sf */
    case 2667:  /* neon_vld3_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;
        }

    case 2734:  /* neon_vld4_dupv4bf */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2732:  /* neon_vld4_dupv4hi */
    case 2666:  /* neon_vld3_dupv4bf */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2664:  /* neon_vld3_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;
        }

    case 2731:  /* neon_vld4_dupv8qi */
    case 2663:  /* neon_vld3_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;
        }

    case 2607:  /* neon_vld2_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128;
        }

    case 2606:  /* neon_vld2_dupv2sf */
    case 2605:  /* neon_vld2_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128;
        }

    case 2604:  /* neon_vld2_dupv4bf */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2602:  /* neon_vld2_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128;
        }

    case 2601:  /* neon_vld2_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128;
        }

    case 2052:  /* neon_vdup_nv4sf */
    case 2051:  /* neon_vdup_nv4si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU_Q;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 2050:  /* neon_vdup_nv2sf */
    case 2049:  /* neon_vdup_nv2si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU_Q;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_ZERO))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 1141:  /* neon_vec_extractv2didi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1136:  /* neon_vec_extractv16qiqi */
    case 1135:  /* vec_extractv2sfsf */
    case 1134:  /* vec_extractv2sisi */
    case 1133:  /* vec_extractv4bfbf */
    case 1132:  /* vec_extractv4hfhf */
    case 1131:  /* vec_extractv4hihi */
    case 1130:  /* vec_extractv8qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 1380:  /* neon_load_count */
    case 1129:  /* vec_setv2di_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1124:  /* vec_setv16qi_internal */
    case 1123:  /* vec_setv2sf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1118:  /* vec_setv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU_Q;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_LOTS;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU_Q;
        }
      else if (((1ULL << which_alternative) & 0x110ULL))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;
        }
      else if (!((1ULL << which_alternative) & 0x1fdULL))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_LOTS;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_64;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_128;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 7)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_64;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_QSUB) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_QNEG) || (cached_type == TYPE_NEON_QABS) || (cached_type == TYPE_NEON_ABD) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_ACC) || (cached_type == TYPE_NEON_REDUC_MINMAX) || (cached_type == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_REG) || (cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_REG) || (cached_type == TYPE_NEON_INS) || (cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_ZIP) || (cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL2) || (cached_type == TYPE_NEON_TBL3) || (cached_type == TYPE_NEON_TBL4) || (cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CNT) || (cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_EXT) || (cached_type == TYPE_NEON_RBIT) || (cached_type == TYPE_NEON_REV) || (cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_ABD_D) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_ABS_D) || (cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_ADDSUB_D) || (cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_COMPARE_D) || (cached_type == TYPE_NEON_FP_MINMAX_S) || (cached_type == TYPE_NEON_FP_MINMAX_D) || (cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_NEG_D) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_D) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_H) || (cached_type == TYPE_NEON_FP_TO_INT_S) || (cached_type == TYPE_NEON_FP_TO_INT_D) || (cached_type == TYPE_NEON_INT_TO_FP_S) || (cached_type == TYPE_NEON_INT_TO_FP_D) || (cached_type == TYPE_NEON_FP_ROUND_S) || (cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RECPE_D) || (cached_type == TYPE_NEON_FP_RECPS_S) || (cached_type == TYPE_NEON_FP_RECPS_D) || (cached_type == TYPE_NEON_FP_RECPX_S) || (cached_type == TYPE_NEON_FP_RECPX_D) || (cached_type == TYPE_NEON_FP_RSQRTE_S) || (cached_type == TYPE_NEON_FP_RSQRTE_D) || (cached_type == TYPE_NEON_FP_RSQRTS_S) || (cached_type == TYPE_NEON_FP_RSQRTS_D))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU;
        }
      else if ((cached_type == TYPE_NEON_ADD_Q) || (cached_type == TYPE_NEON_ADD_WIDEN) || (cached_type == TYPE_NEON_ADD_LONG) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_SUB_Q) || (cached_type == TYPE_NEON_SUB_WIDEN) || (cached_type == TYPE_NEON_SUB_LONG) || (cached_type == TYPE_NEON_QSUB_Q) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_QNEG_Q) || (cached_type == TYPE_NEON_QABS_Q) || (cached_type == TYPE_NEON_ABD_Q) || (cached_type == TYPE_NEON_ABD_LONG) || (cached_type == TYPE_NEON_MINMAX_Q) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q) || (cached_type == TYPE_NEON_ARITH_ACC_Q) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_REDUC_ADD_LONG) || (cached_type == TYPE_NEON_REDUC_ADD_ACC_Q) || (cached_type == TYPE_NEON_REDUC_MINMAX_Q) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_TST_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG) || (cached_type == TYPE_NEON_SHIFT_REG_Q) || (cached_type == TYPE_NEON_SHIFT_ACC_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q) || (cached_type == TYPE_NEON_INS_Q) || (cached_type == TYPE_NEON_MOVE_Q) || (cached_type == TYPE_NEON_MOVE_NARROW_Q) || (cached_type == TYPE_NEON_PERMUTE_Q) || (cached_type == TYPE_NEON_ZIP_Q) || (cached_type == TYPE_NEON_TBL1_Q) || (cached_type == TYPE_NEON_TBL2_Q) || (cached_type == TYPE_NEON_TBL3_Q) || (cached_type == TYPE_NEON_TBL4_Q) || (cached_type == TYPE_NEON_BSL_Q) || (cached_type == TYPE_NEON_CLS_Q) || (cached_type == TYPE_NEON_CNT_Q) || (cached_type == TYPE_NEON_DUP_Q) || (cached_type == TYPE_NEON_EXT_Q) || (cached_type == TYPE_NEON_RBIT_Q) || (cached_type == TYPE_NEON_REV_Q) || (cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_ABD_D_Q) || (cached_type == TYPE_NEON_FP_ABS_S_Q) || (cached_type == TYPE_NEON_FP_ABS_D_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_D_Q) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_D_Q) || (cached_type == TYPE_NEON_FP_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_MINMAX_D_Q) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_S) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_NEG_D_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_D_Q) || (cached_type == TYPE_NEON_FP_CVT_NARROW_S_Q) || (cached_type == TYPE_NEON_FP_CVT_NARROW_D_Q) || (cached_type == TYPE_NEON_FP_TO_INT_S_Q) || (cached_type == TYPE_NEON_FP_TO_INT_D_Q) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_D_Q) || (cached_type == TYPE_NEON_FP_ROUND_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_D_Q) || (cached_type == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RECPS_D_Q) || (cached_type == TYPE_NEON_FP_RECPX_S_Q) || (cached_type == TYPE_NEON_FP_RECPX_D_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_D_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_D_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU_Q;
        }
      else if ((cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR) || (cached_type == TYPE_NEON_FP_MUL_D) || (cached_type == TYPE_NEON_FP_MLA_S) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR) || (cached_type == TYPE_NEON_FP_MLA_D))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_MUL;
        }
      else if ((cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_MUL_S_LONG) || (cached_type == TYPE_NEON_MUL_D_LONG) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG) || (cached_type == TYPE_CRYPTO_PMULL) || (cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H_Q) || (cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MUL_D_Q) || (cached_type == TYPE_NEON_FP_MUL_D_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MLA_S_Q) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MLA_D_Q) || (cached_type == TYPE_NEON_FP_MLA_D_SCALAR_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_MUL_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_SQRT_S) || (cached_type == TYPE_NEON_FP_DIV_S))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_DIV_S;
        }
      else if ((cached_type == TYPE_NEON_FP_SQRT_S_Q) || (cached_type == TYPE_NEON_FP_DIV_S_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_DIV_S_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_SQRT_D) || (cached_type == TYPE_NEON_FP_DIV_D))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_DIV_D;
        }
      else if ((cached_type == TYPE_NEON_FP_SQRT_D_Q) || (cached_type == TYPE_NEON_FP_DIV_D_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_DIV_D_Q;
        }
      else if ((cached_type == TYPE_NEON_LDR) || (cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;
        }
      else if ((cached_type == TYPE_NEON_STR) || (cached_type == TYPE_NEON_STORE1_1REG) || (cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_64;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_1REG_Q) || (cached_type == TYPE_NEON_LOAD1_2REG) || (cached_type == TYPE_NEON_LOAD2_2REG) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128;
        }
      else if ((cached_type == TYPE_NEON_STORE1_1REG_Q) || (cached_type == TYPE_NEON_STORE1_2REG) || (cached_type == TYPE_NEON_STORE2_2REG) || (cached_type == TYPE_NEON_STORE2_ONE_LANE) || (cached_type == TYPE_NEON_STORE2_ONE_LANE_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_128;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_2REG_Q) || (cached_type == TYPE_NEON_LOAD1_3REG) || (cached_type == TYPE_NEON_LOAD1_3REG_Q) || (cached_type == TYPE_NEON_LOAD1_4REG) || (cached_type == TYPE_NEON_LOAD1_4REG_Q) || (cached_type == TYPE_NEON_LOAD2_2REG_Q) || (cached_type == TYPE_NEON_LOAD2_4REG) || (cached_type == TYPE_NEON_LOAD2_4REG_Q) || (cached_type == TYPE_NEON_LOAD3_3REG) || (cached_type == TYPE_NEON_LOAD3_3REG_Q) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD4_4REG) || (cached_type == TYPE_NEON_LOAD4_4REG_Q) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE_Q) || (cached_type == TYPE_NEON_LDP) || (cached_type == TYPE_NEON_LDP_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;
        }
      else if ((cached_type == TYPE_NEON_STORE1_2REG_Q) || (cached_type == TYPE_NEON_STORE1_3REG) || (cached_type == TYPE_NEON_STORE1_3REG_Q) || (cached_type == TYPE_NEON_STORE1_4REG) || (cached_type == TYPE_NEON_STORE1_4REG_Q) || (cached_type == TYPE_NEON_STORE2_2REG_Q) || (cached_type == TYPE_NEON_STORE2_4REG) || (cached_type == TYPE_NEON_STORE2_4REG_Q) || (cached_type == TYPE_NEON_STORE3_3REG) || (cached_type == TYPE_NEON_STORE3_3REG_Q) || (cached_type == TYPE_NEON_STORE3_ONE_LANE) || (cached_type == TYPE_NEON_STORE3_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE4_4REG) || (cached_type == TYPE_NEON_STORE4_4REG_Q) || (cached_type == TYPE_NEON_STORE4_ONE_LANE) || (cached_type == TYPE_NEON_STORE4_ONE_LANE_Q) || (cached_type == TYPE_NEON_STP) || (cached_type == TYPE_NEON_STP_Q))
        {
	  return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_LOTS;
        }
      else
        {
	  return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;
        }

    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
    case 2745:  /* neon_vst4di */
    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
    case 2739:  /* neon_vst4v8qi */
    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
    case 2677:  /* neon_vst3di */
    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
    case 2671:  /* neon_vst3v8qi */
    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_LOTS;

    case 2738:  /* neon_vld4_dupv8bf */
    case 2730:  /* neon_vld4_lanev8bf */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2726:  /* neon_vld4_lanev8hi */
    case 2725:  /* neon_vld4_lanev2sf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2720:  /* neon_vld4_lanev8qi */
    case 2719:  /* neon_vld4qbv4sf */
    case 2718:  /* neon_vld4qbv4si */
    case 2717:  /* neon_vld4qbv8bf */
    case 2716:  /* neon_vld4qbv8hf */
    case 2715:  /* neon_vld4qbv8hi */
    case 2714:  /* neon_vld4qbv16qi */
    case 2713:  /* neon_vld4qav4sf */
    case 2712:  /* neon_vld4qav4si */
    case 2711:  /* neon_vld4qav8bf */
    case 2710:  /* neon_vld4qav8hf */
    case 2709:  /* neon_vld4qav8hi */
    case 2708:  /* neon_vld4qav16qi */
    case 2707:  /* neon_vld4di */
    case 2706:  /* neon_vld4v2sf */
    case 2705:  /* neon_vld4v2si */
    case 2704:  /* neon_vld4v4bf */
    case 2703:  /* neon_vld4v4hf */
    case 2702:  /* neon_vld4v4hi */
    case 2701:  /* neon_vld4v8qi */
    case 2670:  /* neon_vld3_dupv8bf */
    case 2662:  /* neon_vld3_lanev8bf */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2658:  /* neon_vld3_lanev8hi */
    case 2657:  /* neon_vld3_lanev2sf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2652:  /* neon_vld3_lanev8qi */
    case 2651:  /* neon_vld3qbv4sf */
    case 2650:  /* neon_vld3qbv4si */
    case 2649:  /* neon_vld3qbv8bf */
    case 2648:  /* neon_vld3qbv8hf */
    case 2647:  /* neon_vld3qbv8hi */
    case 2646:  /* neon_vld3qbv16qi */
    case 2645:  /* neon_vld3qav4sf */
    case 2644:  /* neon_vld3qav4si */
    case 2643:  /* neon_vld3qav8bf */
    case 2642:  /* neon_vld3qav8hf */
    case 2641:  /* neon_vld3qav8hi */
    case 2640:  /* neon_vld3qav16qi */
    case 2639:  /* neon_vld3di */
    case 2638:  /* neon_vld3v2sf */
    case 2637:  /* neon_vld3v2si */
    case 2636:  /* neon_vld3v4bf */
    case 2635:  /* neon_vld3v4hf */
    case 2634:  /* neon_vld3v4hi */
    case 2633:  /* neon_vld3v8qi */
    case 2589:  /* neon_vld2v4sf */
    case 2588:  /* neon_vld2v4si */
    case 2587:  /* neon_vld2v8bf */
    case 2586:  /* neon_vld2v8hf */
    case 2585:  /* neon_vld2v8hi */
    case 2584:  /* neon_vld2v16qi */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS;

    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
    case 2615:  /* neon_vst2di */
    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
    case 2609:  /* neon_vst2v8qi */
    case 2562:  /* neon_vst1v2di */
    case 2560:  /* neon_vst1v4sf */
    case 2558:  /* neon_vst1v8bf */
    case 2556:  /* neon_vst1v8hf */
    case 2554:  /* neon_vst1v4si */
    case 2552:  /* neon_vst1v8hi */
    case 2550:  /* neon_vst1v16qi */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_128;

    case 2854:  /* aes_op_protect_neon_vld1v16qi */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2608:  /* neon_vld2_dupv8bf */
    case 2600:  /* neon_vld2_lanev8bf */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2596:  /* neon_vld2_lanev8hi */
    case 2595:  /* neon_vld2_lanev2sf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2590:  /* neon_vld2_lanev8qi */
    case 2583:  /* neon_vld2di */
    case 2582:  /* neon_vld2v2sf */
    case 2581:  /* neon_vld2v2si */
    case 2580:  /* neon_vld2v4bf */
    case 2579:  /* neon_vld2v4hf */
    case 2578:  /* neon_vld2v4hi */
    case 2577:  /* neon_vld2v8qi */
    case 2522:  /* neon_vld1v2di */
    case 2520:  /* neon_vld1v4sf */
    case 2518:  /* neon_vld1v8bf */
    case 2516:  /* neon_vld1v8hf */
    case 2514:  /* neon_vld1v4si */
    case 2512:  /* neon_vld1v8hi */
    case 2510:  /* neon_vld1v16qi */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1111:  /* *movmisalignv16qi_neon_load */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128;

    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
    case 2561:  /* neon_vst1di */
    case 2559:  /* neon_vst1v2sf */
    case 2557:  /* neon_vst1v4bf */
    case 2555:  /* neon_vst1v4hf */
    case 2553:  /* neon_vst1v2si */
    case 2551:  /* neon_vst1v4hi */
    case 2549:  /* neon_vst1v8qi */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1070:  /* unaligned_storev8qi */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_64;

    case 2548:  /* neon_vld1_dupv2di */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2543:  /* neon_vld1_dupv16qi */
    case 2542:  /* neon_vld1_dupv2sf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2537:  /* neon_vld1_dupv8qi */
    case 2536:  /* neon_vld1_lanev2di */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2530:  /* neon_vld1_lanev16qi */
    case 2529:  /* neon_vld1_lanedi */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2523:  /* neon_vld1_lanev8qi */
    case 2521:  /* neon_vld1di */
    case 2519:  /* neon_vld1v2sf */
    case 2517:  /* neon_vld1v4bf */
    case 2515:  /* neon_vld1v4hf */
    case 2513:  /* neon_vld1v2si */
    case 2511:  /* neon_vld1v4hi */
    case 2509:  /* neon_vld1v8qi */
    case 1103:  /* *movmisaligndi_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1097:  /* *movmisalignv8qi_neon_load */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64;

    case 2868:  /* crypto_vmullp64 */
    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2810:  /* neon_vec_umult_v2si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2808:  /* neon_vec_umult_v4hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2806:  /* neon_vec_umult_v8qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2210:  /* neon_vmls_lanev4sf */
    case 2209:  /* neon_vmls_lanev4si */
    case 2208:  /* neon_vmls_lanev8hi */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2198:  /* neon_vmla_lanev4sf */
    case 2197:  /* neon_vmla_lanev4si */
    case 2196:  /* neon_vmla_lanev8hi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
    case 2184:  /* neon_vqrdmulh_lanev2si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
    case 2169:  /* neon_vmul_lanev8hf */
    case 2168:  /* neon_vmul_lanev4sf */
    case 2167:  /* neon_vmul_lanev4si */
    case 2166:  /* neon_vmul_lanev8hi */
    case 1601:  /* neon_vqdmullv2si */
    case 1600:  /* neon_vqdmullv4hi */
    case 1599:  /* neon_vmullpv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1597:  /* neon_vmullsv2si */
    case 1596:  /* neon_vmullpv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1594:  /* neon_vmullsv4hi */
    case 1593:  /* neon_vmullpv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1591:  /* neon_vmullsv8qi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1588:  /* neon_vqdmlalv2si */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1562:  /* neon_vmlsv4si_unspec */
    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1517:  /* neon_vmulfv8hf */
    case 1516:  /* neon_vmulfv4sf */
    case 1514:  /* neon_vmulpv16qi */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1180:  /* mulv8hf3addv8hf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
    case 1177:  /* mulv4si3addv4si_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
    case 1171:  /* *mulv4sf3_neon */
    case 1169:  /* *mulv4si3_neon */
    case 1167:  /* *mulv8hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_MUL_Q;

    case 2207:  /* neon_vmls_lanev2sf */
    case 2206:  /* neon_vmls_lanev2si */
    case 2205:  /* neon_vmls_lanev4hi */
    case 2195:  /* neon_vmla_lanev2sf */
    case 2194:  /* neon_vmla_lanev2si */
    case 2193:  /* neon_vmla_lanev4hi */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
    case 2170:  /* neon_vmul_lanev4hf */
    case 2165:  /* neon_vmul_lanev2sf */
    case 2164:  /* neon_vmul_lanev2si */
    case 2163:  /* neon_vmul_lanev4hi */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1561:  /* neon_vmlsv2si_unspec */
    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1518:  /* neon_vmulfv4hf */
    case 1515:  /* neon_vmulfv2sf */
    case 1513:  /* neon_vmulpv8qi */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1190:  /* fmav2sf4 */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1181:  /* mulv4hf3addv4hf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
    case 1176:  /* mulv2si3addv2si_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
    case 1170:  /* *mulv2sf3_neon */
    case 1168:  /* *mulv2si3_neon */
    case 1166:  /* *mulv4hi3_neon */
    case 1164:  /* *mulv8qi3_neon */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_MUL;

    case 2840:  /* neon_vbfcvt_highv8bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2836:  /* neon_vbfcvtv4sf_highv8bf */
    case 2835:  /* neon_vbfcvtv4sfv8bf */
    case 2834:  /* neon_vbfcvtv4sfv4bf */
    case 2824:  /* neon_vabdv4sf_3 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2818:  /* neon_vabdv8hf_2 */
    case 2816:  /* neon_vec_pack_trunc_v2di */
    case 2815:  /* neon_vec_pack_trunc_v4si */
    case 2814:  /* neon_vec_pack_trunc_v8hi */
    case 2798:  /* neon_vec_ushiftl_v2si */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2507:  /* *neon_vuzpv8hf_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2490:  /* *neon_vzipv16qi_insn */
    case 2487:  /* *neon_vtrnv8hf_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2467:  /* neon_vsli_nv2di */
    case 2465:  /* neon_vsli_nv4si */
    case 2463:  /* neon_vsli_nv8hi */
    case 2461:  /* neon_vsli_nv16qi */
    case 2459:  /* neon_vsri_nv2di */
    case 2457:  /* neon_vsri_nv4si */
    case 2455:  /* neon_vsri_nv8hi */
    case 2453:  /* neon_vsri_nv16qi */
    case 2451:  /* neon_vrsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2448:  /* neon_vsras_nv2di */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2440:  /* neon_vsras_nv4si */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2424:  /* neon_vsras_nv16qi */
    case 2419:  /* neon_vshllu_nv2si */
    case 2418:  /* neon_vshlls_nv2si */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2413:  /* neon_vqshlu_nv2di */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2389:  /* neon_vshl_nv2di */
    case 2387:  /* neon_vshl_nv4si */
    case 2385:  /* neon_vshl_nv8hi */
    case 2383:  /* neon_vshl_nv16qi */
    case 2381:  /* neon_vqrshrun_nv2di */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2363:  /* neon_vrshrn_nv2di */
    case 2362:  /* neon_vshrn_nv2di */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2360:  /* neon_vshrn_nv4si */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2357:  /* neon_vrshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2354:  /* neon_vshrs_nv2di */
    case 2349:  /* neon_vrshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2346:  /* neon_vshrs_nv4si */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2325:  /* neon_vqrshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2322:  /* neon_vqshlsv2di */
    case 2317:  /* neon_vqrshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2314:  /* neon_vqshlsv4si */
    case 2309:  /* neon_vqrshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2298:  /* neon_vqshlsv16qi */
    case 2293:  /* neon_vrshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2290:  /* neon_vshlsv2di */
    case 2285:  /* neon_vrshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2282:  /* neon_vshlsv4si */
    case 2277:  /* neon_vrshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2274:  /* neon_vshlsv8hi */
    case 2269:  /* neon_vrshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2266:  /* neon_vshlsv16qi */
    case 2261:  /* neon_vbslv2di_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2249:  /* neon_vbslv16qi_internal */
    case 2247:  /* neon_vrev16v16qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2244:  /* neon_vrev32v16qi */
    case 2241:  /* neon_vrev64v2di */
    case 2240:  /* neon_vrev64v4sf */
    case 2238:  /* neon_vrev64v8hf */
    case 2236:  /* neon_vrev64v4si */
    case 2234:  /* neon_vrev64v8hi */
    case 2232:  /* neon_vrev64v16qi */
    case 2230:  /* neon_vextv2di */
    case 2228:  /* neon_vextv4sf */
    case 2226:  /* neon_vextv8bf */
    case 2224:  /* neon_vextv8hf */
    case 2222:  /* neon_vextv4si */
    case 2220:  /* neon_vextv8hi */
    case 2218:  /* neon_vextv16qi */
    case 2162:  /* neon_vmovluv2si */
    case 2161:  /* neon_vmovlsv2si */
    case 2160:  /* neon_vmovluv4hi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2158:  /* neon_vmovluv8qi */
    case 2157:  /* neon_vmovlsv8qi */
    case 2156:  /* neon_vqmovunv2di */
    case 2155:  /* neon_vqmovunv4si */
    case 2154:  /* neon_vqmovunv8hi */
    case 2153:  /* neon_vqmovnuv2di */
    case 2152:  /* neon_vqmovnsv2di */
    case 2151:  /* neon_vqmovnuv4si */
    case 2150:  /* neon_vqmovnsv4si */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2148:  /* neon_vqmovnsv8hi */
    case 2147:  /* neon_vmovnv2di */
    case 2146:  /* neon_vmovnv4si */
    case 2145:  /* neon_vmovnv8hi */
    case 2136:  /* neon_vcvtpuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2128:  /* neon_vcvtu_nv8hi */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2123:  /* neon_vcvts_nv4si */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2108:  /* neon_vcvtuv8hi */
    case 2107:  /* neon_vcvtsv8hi */
    case 2104:  /* neon_vcvtv4hfv4sf */
    case 2102:  /* neon_vcvtuv4si */
    case 2101:  /* neon_vcvtsv4si */
    case 2098:  /* neon_vcvtuv4sf */
    case 2097:  /* neon_vcvtsv4sf */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2088:  /* floatv4siv4sf2 */
    case 2079:  /* *neon_vswpv2di */
    case 2077:  /* *neon_vswpv4sf */
    case 2075:  /* *neon_vswpv8bf */
    case 2073:  /* *neon_vswpv8hf */
    case 2071:  /* *neon_vswpv4si */
    case 2069:  /* *neon_vswpv8hi */
    case 2067:  /* *neon_vswpv16qi */
    case 2065:  /* neon_vdup_lanev8bf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2022:  /* neon_vrsqrtev4sf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2018:  /* neon_vrecpev4sf */
    case 2017:  /* neon_vrecpev4si */
    case 2013:  /* neon_vrecpev8hf */
    case 2012:  /* popcountv16qi2 */
    case 2010:  /* neon_vclzv4si */
    case 2008:  /* neon_vclzv8hi */
    case 2006:  /* neon_vclzv16qi */
    case 2004:  /* neon_vclsv4si */
    case 2002:  /* neon_vclsv8hi */
    case 2000:  /* neon_vclsv16qi */
    case 1998:  /* neon_vqnegv4si */
    case 1996:  /* neon_vqnegv8hi */
    case 1994:  /* neon_vqnegv16qi */
    case 1914:  /* neon_bswapv2di */
    case 1913:  /* neon_bswapv4si */
    case 1911:  /* neon_bswapv8hi */
    case 1909:  /* neon_vqabsv4si */
    case 1907:  /* neon_vqabsv8hi */
    case 1905:  /* neon_vqabsv16qi */
    case 1902:  /* neon_vrsqrtsv8hf */
    case 1901:  /* neon_vrsqrtsv4sf */
    case 1898:  /* neon_vrecpsv8hf */
    case 1897:  /* neon_vrecpsv4sf */
    case 1895:  /* neon_vpminfv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1867:  /* neon_vpaddluv4si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1865:  /* neon_vpaddluv2si */
    case 1864:  /* neon_vpaddlsv2si */
    case 1863:  /* neon_vpaddluv8hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1856:  /* neon_vpaddlsv8qi */
    case 1855:  /* fminv4sf3 */
    case 1854:  /* fmaxv4sf3 */
    case 1851:  /* neon_vminnmv4sf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1845:  /* neon_vminnmv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1839:  /* neon_vminfv8hf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1837:  /* neon_vminfv4sf */
    case 1836:  /* neon_vmaxfv4sf */
    case 1833:  /* neon_vminuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1830:  /* neon_vmaxsv4si */
    case 1825:  /* neon_vminuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1817:  /* neon_vminuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1814:  /* neon_vmaxsv16qi */
    case 1803:  /* neon_vabauv4si */
    case 1802:  /* neon_vabasv4si */
    case 1799:  /* neon_vabauv8hi */
    case 1798:  /* neon_vabasv8hi */
    case 1795:  /* neon_vabauv16qi */
    case 1794:  /* neon_vabasv16qi */
    case 1791:  /* neon_vabdluv2si */
    case 1790:  /* neon_vabdlsv2si */
    case 1789:  /* neon_vabdluv4hi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1787:  /* neon_vabdluv8qi */
    case 1786:  /* neon_vabdlsv8qi */
    case 1785:  /* neon_vabdfv4sf */
    case 1782:  /* neon_vabdv8hf */
    case 1781:  /* neon_vabduv4si */
    case 1780:  /* neon_vabdsv4si */
    case 1777:  /* neon_vabduv8hi */
    case 1776:  /* neon_vabdsv8hi */
    case 1773:  /* neon_vabduv16qi */
    case 1772:  /* neon_vabdsv16qi */
    case 1769:  /* neon_vtst_combinev4si */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1765:  /* neon_vtst_combinev16qi */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1731:  /* neon_vcgeuv4si */
    case 1730:  /* neon_vcgtuv4si */
    case 1727:  /* neon_vcgeuv8hi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1722:  /* neon_vcgtuv16qi */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1649:  /* neon_vrsubhnv2di */
    case 1648:  /* neon_vsubhnv2di */
    case 1647:  /* neon_vrsubhnv4si */
    case 1646:  /* neon_vsubhnv4si */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1644:  /* neon_vsubhnv8hi */
    case 1643:  /* neon_vhsubuv4si */
    case 1642:  /* neon_vhsubsv4si */
    case 1639:  /* neon_vhsubuv8hi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1634:  /* neon_vhsubsv16qi */
    case 1631:  /* neon_vqsubuv2di */
    case 1630:  /* neon_vqsubsv2di */
    case 1627:  /* neon_vqsubuv4si */
    case 1626:  /* neon_vqsubsv4si */
    case 1623:  /* neon_vqsubuv8hi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1618:  /* neon_vqsubsv16qi */
    case 1615:  /* neon_vsubwuv2si */
    case 1614:  /* neon_vsubwsv2si */
    case 1613:  /* neon_vsubwuv4hi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1610:  /* neon_vsubwsv8qi */
    case 1609:  /* neon_vsubluv2si */
    case 1608:  /* neon_vsublsv2si */
    case 1607:  /* neon_vsubluv4hi */
    case 1606:  /* neon_vsublsv4hi */
    case 1605:  /* neon_vsubluv8qi */
    case 1604:  /* neon_vsublsv8qi */
    case 1603:  /* neon_vsubv4sf_unspec */
    case 1512:  /* neon_vraddhnv2di */
    case 1511:  /* neon_vaddhnv2di */
    case 1510:  /* neon_vraddhnv4si */
    case 1509:  /* neon_vaddhnv4si */
    case 1508:  /* neon_vraddhnv8hi */
    case 1507:  /* neon_vaddhnv8hi */
    case 1506:  /* neon_vqadduv2di */
    case 1505:  /* neon_vqaddsv2di */
    case 1502:  /* neon_vqadduv4si */
    case 1501:  /* neon_vqaddsv4si */
    case 1498:  /* neon_vqadduv8hi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1494:  /* neon_vqadduv16qi */
    case 1493:  /* neon_vqaddsv16qi */
    case 1490:  /* neon_vhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1486:  /* neon_vhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1483:  /* neon_vrhaddsv2si */
    case 1482:  /* neon_vhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1474:  /* neon_vhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1467:  /* neon_vrhaddsv8qi */
    case 1466:  /* neon_vaddwuv2si */
    case 1465:  /* neon_vaddwsv2si */
    case 1464:  /* neon_vaddwuv4hi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1461:  /* neon_vaddwsv8qi */
    case 1460:  /* neon_vaddluv2si */
    case 1459:  /* neon_vaddlsv2si */
    case 1458:  /* neon_vaddluv4hi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1456:  /* neon_vaddluv8qi */
    case 1455:  /* neon_vaddlsv8qi */
    case 1454:  /* neon_vaddv4sf_unspec */
    case 1417:  /* arm_reduc_plus_internal_v2di */
    case 1416:  /* quad_halves_umaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1412:  /* quad_halves_plusv16qi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1408:  /* quad_halves_sminv8hi */
    case 1407:  /* quad_halves_plusv8hi */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1405:  /* quad_halves_sminv4sf */
    case 1404:  /* quad_halves_plusv4sf */
    case 1403:  /* quad_halves_umaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1400:  /* quad_halves_sminv4si */
    case 1399:  /* quad_halves_plusv4si */
    case 1398:  /* widen_usumv2si3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
    case 1379:  /* ashlv2di3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1372:  /* ashlv2di3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1367:  /* ashlv16qi3_signed */
    case 1365:  /* vlshrv4si3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1355:  /* vashrv16qi3_imm */
    case 1353:  /* *smaxv4sf3_neon */
    case 1351:  /* *smaxv4si3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1345:  /* *sminv4sf3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1339:  /* *sminv16qi3_neon */
    case 1337:  /* *umaxv4si3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1327:  /* *uminv16qi3_neon */
    case 1324:  /* neon_vrsqrtev8hf */
    case 1317:  /* neon_vrndxv8hf */
    case 1316:  /* neon_vrndpv8hf */
    case 1315:  /* neon_vrndnv8hf */
    case 1314:  /* neon_vrndmv8hf */
    case 1313:  /* neon_vrndav8hf */
    case 1312:  /* neon_vrndv8hf */
    case 1309:  /* neon_negv8hf2 */
    case 1308:  /* neon_absv8hf2 */
    case 1307:  /* neon_negv4sf2 */
    case 1305:  /* neon_negv4si2 */
    case 1303:  /* neon_negv8hi2 */
    case 1301:  /* neon_negv16qi2 */
    case 1299:  /* neon_absv4sf2 */
    case 1297:  /* neon_absv4si2 */
    case 1295:  /* neon_absv8hi2 */
    case 1293:  /* neon_absv16qi2 */
    case 1291:  /* one_cmplv2di2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1282:  /* one_cmplv16qi2_neon */
    case 1280:  /* xorv2di3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1247:  /* andv2di3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1242:  /* andv4si3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1227:  /* iorv16qi3_neon */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1220:  /* neon_vcvtpv4sfv4si */
    case 1213:  /* neon_vrintnv4sf */
    case 1212:  /* neon_vrintav4sf */
    case 1211:  /* neon_vrintxv4sf */
    case 1210:  /* neon_vrintmv4sf */
    case 1209:  /* neon_vrintzv4sf */
    case 1208:  /* neon_vrintpv4sf */
    case 1163:  /* *subv2di3_neon */
    case 1162:  /* *subv4sf3_neon */
    case 1160:  /* *subv8hf3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1154:  /* *subv16qi3_neon */
    case 1152:  /* *addv2di3_neon */
    case 1151:  /* *addv4sf3_neon */
    case 1149:  /* *addv8hf3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1143:  /* *addv16qi3_neon */
    case 522:  /* mve_vshlq_uv4si */
    case 521:  /* mve_vshlq_sv4si */
    case 518:  /* mve_vshlq_uv8hi */
    case 517:  /* mve_vshlq_sv8hi */
    case 514:  /* mve_vshlq_uv16qi */
    case 513:  /* mve_vshlq_sv16qi */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU_Q;

    case 2823:  /* neon_vabdv2sf_3 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2817:  /* neon_vabdv4hf_2 */
    case 2804:  /* neon_unpacku_v2si */
    case 2803:  /* neon_unpacks_v2si */
    case 2802:  /* neon_unpacku_v4hi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2799:  /* neon_unpacks_v8qi */
    case 2508:  /* *neon_vuzpv4hf_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2489:  /* *neon_vzipv8qi_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2478:  /* neon_vtbx4v8qi */
    case 2477:  /* neon_vtbx3v8qi */
    case 2476:  /* neon_vtbx2v8qi */
    case 2475:  /* neon_vtbx1v8qi */
    case 2471:  /* neon_vtbl4v8qi */
    case 2470:  /* neon_vtbl3v8qi */
    case 2469:  /* neon_vtbl2v8qi */
    case 2468:  /* neon_vtbl1v8qi */
    case 2466:  /* neon_vsli_ndi */
    case 2464:  /* neon_vsli_nv2si */
    case 2462:  /* neon_vsli_nv4hi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2458:  /* neon_vsri_ndi */
    case 2456:  /* neon_vsri_nv2si */
    case 2454:  /* neon_vsri_nv4hi */
    case 2452:  /* neon_vsri_nv8qi */
    case 2447:  /* neon_vrsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2444:  /* neon_vsras_ndi */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2436:  /* neon_vsras_nv2si */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2420:  /* neon_vsras_nv8qi */
    case 2412:  /* neon_vqshlu_ndi */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2388:  /* neon_vshl_ndi */
    case 2386:  /* neon_vshl_nv2si */
    case 2384:  /* neon_vshl_nv4hi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2353:  /* neon_vrshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2350:  /* neon_vshrs_ndi */
    case 2345:  /* neon_vrshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2342:  /* neon_vshrs_nv2si */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2321:  /* neon_vqrshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2318:  /* neon_vqshlsdi */
    case 2313:  /* neon_vqrshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2310:  /* neon_vqshlsv2si */
    case 2305:  /* neon_vqrshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2294:  /* neon_vqshlsv8qi */
    case 2289:  /* neon_vrshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2287:  /* neon_vshludi */
    case 2286:  /* neon_vshlsdi */
    case 2281:  /* neon_vrshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2278:  /* neon_vshlsv2si */
    case 2273:  /* neon_vrshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2270:  /* neon_vshlsv4hi */
    case 2265:  /* neon_vrshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2262:  /* neon_vshlsv8qi */
    case 2260:  /* neon_vbsldi_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2248:  /* neon_vbslv8qi_internal */
    case 2246:  /* neon_vrev16v8qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2242:  /* neon_vrev32v8qi */
    case 2239:  /* neon_vrev64v2sf */
    case 2237:  /* neon_vrev64v4hf */
    case 2235:  /* neon_vrev64v2si */
    case 2233:  /* neon_vrev64v4hi */
    case 2231:  /* neon_vrev64v8qi */
    case 2229:  /* neon_vextdi */
    case 2227:  /* neon_vextv2sf */
    case 2225:  /* neon_vextv4bf */
    case 2223:  /* neon_vextv4hf */
    case 2221:  /* neon_vextv2si */
    case 2219:  /* neon_vextv4hi */
    case 2217:  /* neon_vextv8qi */
    case 2144:  /* neon_vcvtpuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2126:  /* neon_vcvtu_nv4hi */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2121:  /* neon_vcvts_nv2si */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2106:  /* neon_vcvtuv4hi */
    case 2105:  /* neon_vcvtsv4hi */
    case 2103:  /* neon_vcvtv4sfv4hf */
    case 2100:  /* neon_vcvtuv2si */
    case 2099:  /* neon_vcvtsv2si */
    case 2096:  /* neon_vcvtuv2sf */
    case 2095:  /* neon_vcvtsv2sf */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2087:  /* floatv2siv2sf2 */
    case 2078:  /* *neon_vswpdi */
    case 2076:  /* *neon_vswpv2sf */
    case 2074:  /* *neon_vswpv4bf */
    case 2072:  /* *neon_vswpv4hf */
    case 2070:  /* *neon_vswpv2si */
    case 2068:  /* *neon_vswpv4hi */
    case 2066:  /* *neon_vswpv8qi */
    case 2064:  /* neon_vdup_lanev4bf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 2020:  /* neon_vrsqrtev2sf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2016:  /* neon_vrecpev2sf */
    case 2015:  /* neon_vrecpev2si */
    case 2014:  /* neon_vrecpev4hf */
    case 2011:  /* popcountv8qi2 */
    case 2009:  /* neon_vclzv2si */
    case 2007:  /* neon_vclzv4hi */
    case 2005:  /* neon_vclzv8qi */
    case 2003:  /* neon_vclsv2si */
    case 2001:  /* neon_vclsv4hi */
    case 1999:  /* neon_vclsv8qi */
    case 1997:  /* neon_vqnegv2si */
    case 1995:  /* neon_vqnegv4hi */
    case 1993:  /* neon_vqnegv8qi */
    case 1912:  /* neon_bswapv2si */
    case 1910:  /* neon_bswapv4hi */
    case 1908:  /* neon_vqabsv2si */
    case 1906:  /* neon_vqabsv4hi */
    case 1904:  /* neon_vqabsv8qi */
    case 1903:  /* neon_vrsqrtsv4hf */
    case 1900:  /* neon_vrsqrtsv2sf */
    case 1899:  /* neon_vrecpsv4hf */
    case 1896:  /* neon_vrecpsv2sf */
    case 1893:  /* neon_vpminfv2sf */
    case 1892:  /* neon_vpmaxfv2sf */
    case 1891:  /* neon_vpminuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1888:  /* neon_vpmaxsv2si */
    case 1887:  /* neon_vpminuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1883:  /* neon_vpminuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1879:  /* neon_vpadaluv4si */
    case 1878:  /* neon_vpadalsv4si */
    case 1877:  /* neon_vpadaluv2si */
    case 1876:  /* neon_vpadalsv2si */
    case 1875:  /* neon_vpadaluv8hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1868:  /* neon_vpadalsv8qi */
    case 1853:  /* fminv2sf3 */
    case 1852:  /* fmaxv2sf3 */
    case 1849:  /* neon_vminnmv2sf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1847:  /* neon_vminnmv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1843:  /* neon_vpminfv4hf */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1841:  /* neon_vminfv4hf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1835:  /* neon_vminfv2sf */
    case 1834:  /* neon_vmaxfv2sf */
    case 1829:  /* neon_vminuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1826:  /* neon_vmaxsv2si */
    case 1821:  /* neon_vminuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1813:  /* neon_vminuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1810:  /* neon_vmaxsv8qi */
    case 1809:  /* neon_vabaluv2si */
    case 1808:  /* neon_vabalsv2si */
    case 1807:  /* neon_vabaluv4hi */
    case 1806:  /* neon_vabalsv4hi */
    case 1805:  /* neon_vabaluv8qi */
    case 1804:  /* neon_vabalsv8qi */
    case 1801:  /* neon_vabauv2si */
    case 1800:  /* neon_vabasv2si */
    case 1797:  /* neon_vabauv4hi */
    case 1796:  /* neon_vabasv4hi */
    case 1793:  /* neon_vabauv8qi */
    case 1792:  /* neon_vabasv8qi */
    case 1784:  /* neon_vabdfv2sf */
    case 1783:  /* neon_vabdv4hf */
    case 1779:  /* neon_vabduv2si */
    case 1778:  /* neon_vabdsv2si */
    case 1775:  /* neon_vabduv4hi */
    case 1774:  /* neon_vabdsv4hi */
    case 1771:  /* neon_vabduv8qi */
    case 1770:  /* neon_vabdsv8qi */
    case 1768:  /* neon_vtst_combinev2si */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1764:  /* neon_vtst_combinev8qi */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1729:  /* neon_vcgeuv2si */
    case 1728:  /* neon_vcgtuv2si */
    case 1725:  /* neon_vcgeuv4hi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1720:  /* neon_vcgtuv8qi */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1690:  /* neon_vceqv2sf_insn_unspec */
    case 1641:  /* neon_vhsubuv2si */
    case 1640:  /* neon_vhsubsv2si */
    case 1637:  /* neon_vhsubuv4hi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1632:  /* neon_vhsubsv8qi */
    case 1629:  /* neon_vqsubudi */
    case 1628:  /* neon_vqsubsdi */
    case 1625:  /* neon_vqsubuv2si */
    case 1624:  /* neon_vqsubsv2si */
    case 1621:  /* neon_vqsubuv4hi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1616:  /* neon_vqsubsv8qi */
    case 1602:  /* neon_vsubv2sf_unspec */
    case 1504:  /* neon_vqaddudi */
    case 1503:  /* neon_vqaddsdi */
    case 1500:  /* neon_vqadduv2si */
    case 1499:  /* neon_vqaddsv2si */
    case 1496:  /* neon_vqadduv4hi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1492:  /* neon_vqadduv8qi */
    case 1491:  /* neon_vqaddsv8qi */
    case 1453:  /* neon_vaddv2sf_unspec */
    case 1452:  /* *us_subv2sf_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1445:  /* *ss_subv8qi_neon */
    case 1444:  /* *us_addv2sf_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1437:  /* *ss_addv8qi_neon */
    case 1436:  /* neon_vpumaxv2si */
    case 1435:  /* neon_vpumaxv4hi */
    case 1434:  /* neon_vpumaxv8qi */
    case 1433:  /* neon_vpuminv2si */
    case 1432:  /* neon_vpuminv4hi */
    case 1431:  /* neon_vpuminv8qi */
    case 1430:  /* neon_vpsmaxv2sf */
    case 1429:  /* neon_vpsmaxv2si */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1426:  /* neon_vpsminv2sf */
    case 1425:  /* neon_vpsminv2si */
    case 1424:  /* neon_vpsminv4hi */
    case 1423:  /* neon_vpsminv8qi */
    case 1422:  /* neon_vpaddv4hf */
    case 1421:  /* neon_vpadd_internalv2sf */
    case 1420:  /* neon_vpadd_internalv2si */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1418:  /* neon_vpadd_internalv8qi */
    case 1377:  /* ashlv2si3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1370:  /* ashlv2si3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1366:  /* ashlv8qi3_signed */
    case 1364:  /* vlshrv2si3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1354:  /* vashrv8qi3_imm */
    case 1352:  /* *smaxv2sf3_neon */
    case 1350:  /* *smaxv2si3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1344:  /* *sminv2sf3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1338:  /* *sminv8qi3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1326:  /* *uminv8qi3_neon */
    case 1325:  /* neon_vrsqrtev4hf */
    case 1323:  /* neon_vrndxv4hf */
    case 1322:  /* neon_vrndpv4hf */
    case 1321:  /* neon_vrndnv4hf */
    case 1320:  /* neon_vrndmv4hf */
    case 1319:  /* neon_vrndav4hf */
    case 1318:  /* neon_vrndv4hf */
    case 1311:  /* neon_negv4hf2 */
    case 1310:  /* neon_absv4hf2 */
    case 1306:  /* neon_negv2sf2 */
    case 1304:  /* neon_negv2si2 */
    case 1302:  /* neon_negv4hi2 */
    case 1300:  /* neon_negv8qi2 */
    case 1298:  /* neon_absv2sf2 */
    case 1296:  /* neon_absv2si2 */
    case 1294:  /* neon_absv4hi2 */
    case 1292:  /* neon_absv8qi2 */
    case 1289:  /* one_cmplv2sf2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1281:  /* one_cmplv8qi2_neon */
    case 1278:  /* xorv2sf3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1241:  /* andv2si3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1226:  /* iorv8qi3_neon */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1214:  /* neon_vcvtpv2sfv2si */
    case 1207:  /* neon_vrintnv2sf */
    case 1206:  /* neon_vrintav2sf */
    case 1205:  /* neon_vrintxv2sf */
    case 1204:  /* neon_vrintmv2sf */
    case 1203:  /* neon_vrintzv2sf */
    case 1202:  /* neon_vrintpv2sf */
    case 1161:  /* *subv2sf3_neon */
    case 1159:  /* *subv4hf3_neon */
    case 1157:  /* *subv2si3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1153:  /* *subv8qi3_neon */
    case 1150:  /* *addv2sf3_neon */
    case 1148:  /* *addv4hf3_neon */
    case 1146:  /* *addv2si3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1142:  /* *addv8qi3_neon */
    case 787:  /* neon_vrndihf */
    case 786:  /* neon_vrndxhf */
    case 785:  /* neon_vrndphf */
    case 784:  /* neon_vrndnhf */
    case 783:  /* neon_vrndmhf */
    case 782:  /* neon_vrndahf */
    case 781:  /* neon_vrndhf */
    case 520:  /* mve_vshlq_uv2si */
    case 519:  /* mve_vshlq_sv2si */
    case 516:  /* mve_vshlq_uv4hi */
    case 515:  /* mve_vshlq_sv4hi */
    case 512:  /* mve_vshlq_uv8qi */
    case 511:  /* mve_vshlq_sv8qi */
      return CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU;

    default:
      return CORTEX_A53_ADVSIMD_TYPE_UNKNOWN;

    }
}

enum attr_cortex_a17_neon_type
get_attr_cortex_a17_neon_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }

    case 2707:  /* neon_vld4di */
      if ((64) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_H;
        }

    case 2706:  /* neon_vld4v2sf */
    case 2705:  /* neon_vld4v2si */
      if ((32) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_H;
        }

    case 2704:  /* neon_vld4v4bf */
    case 2703:  /* neon_vld4v4hf */
    case 2702:  /* neon_vld4v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_H;
        }

    case 2701:  /* neon_vld4v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_H;
        }

    case 2737:  /* neon_vld4_dupdi */
    case 2669:  /* neon_vld3_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_E;
        }

    case 2736:  /* neon_vld4_dupv2sf */
    case 2735:  /* neon_vld4_dupv2si */
    case 2668:  /* neon_vld3_dupv2sf */
    case 2667:  /* neon_vld3_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_E;
        }

    case 2734:  /* neon_vld4_dupv4bf */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2732:  /* neon_vld4_dupv4hi */
    case 2666:  /* neon_vld3_dupv4bf */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2664:  /* neon_vld3_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_E;
        }

    case 2731:  /* neon_vld4_dupv8qi */
    case 2663:  /* neon_vld3_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_E;
        }

    case 2639:  /* neon_vld3di */
      if ((64) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_G;
        }

    case 2638:  /* neon_vld3v2sf */
    case 2637:  /* neon_vld3v2si */
      if ((32) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_G;
        }

    case 2636:  /* neon_vld3v4bf */
    case 2635:  /* neon_vld3v4hf */
    case 2634:  /* neon_vld3v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_G;
        }

    case 2633:  /* neon_vld3v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_G;
        }

    case 2745:  /* neon_vst4di */
    case 2615:  /* neon_vst2di */
      if ((64) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_B;
        }

    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
      if ((32) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_B;
        }

    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_B;
        }

    case 2739:  /* neon_vst4v8qi */
    case 2609:  /* neon_vst2v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_B;
        }

    case 2607:  /* neon_vld2_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }

    case 2606:  /* neon_vld2_dupv2sf */
    case 2605:  /* neon_vld2_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }

    case 2604:  /* neon_vld2_dupv4bf */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2602:  /* neon_vld2_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }

    case 2601:  /* neon_vld2_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }

    case 2583:  /* neon_vld2di */
      if ((64) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }

    case 2582:  /* neon_vld2v2sf */
    case 2581:  /* neon_vld2v2si */
      if ((32) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }

    case 2580:  /* neon_vld2v4bf */
    case 2579:  /* neon_vld2v4hf */
    case 2578:  /* neon_vld2v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }

    case 2577:  /* neon_vld2v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }

    case 2052:  /* neon_vdup_nv4sf */
    case 2051:  /* neon_vdup_nv4si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP_Q;
        }

    case 2050:  /* neon_vdup_nv2sf */
    case 2049:  /* neon_vdup_nv2si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP;
        }

    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_UNKNOWN;
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_ZERO))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_UNKNOWN;
        }

    case 1380:  /* neon_load_count */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }

    case 1430:  /* neon_vpsmaxv2sf */
    case 1426:  /* neon_vpsminv2sf */
    case 1353:  /* *smaxv4sf3_neon */
    case 1352:  /* *smaxv2sf3_neon */
    case 1345:  /* *sminv4sf3_neon */
    case 1344:  /* *sminv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1429:  /* neon_vpsmaxv2si */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1425:  /* neon_vpsminv2si */
    case 1424:  /* neon_vpsminv4hi */
    case 1423:  /* neon_vpsminv8qi */
    case 1351:  /* *smaxv4si3_neon */
    case 1350:  /* *smaxv2si3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1339:  /* *sminv16qi3_neon */
    case 1338:  /* *sminv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1307:  /* neon_negv4sf2 */
    case 1306:  /* neon_negv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1305:  /* neon_negv4si2 */
    case 1304:  /* neon_negv2si2 */
    case 1303:  /* neon_negv8hi2 */
    case 1302:  /* neon_negv4hi2 */
    case 1301:  /* neon_negv16qi2 */
    case 1300:  /* neon_negv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1299:  /* neon_absv4sf2 */
    case 1298:  /* neon_absv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1297:  /* neon_absv4si2 */
    case 1296:  /* neon_absv2si2 */
    case 1295:  /* neon_absv8hi2 */
    case 1294:  /* neon_absv4hi2 */
    case 1293:  /* neon_absv16qi2 */
    case 1292:  /* neon_absv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 2210:  /* neon_vmls_lanev4sf */
    case 2198:  /* neon_vmla_lanev4sf */
    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MLA_Q;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MLA_Q;
        }

    case 2207:  /* neon_vmls_lanev2sf */
    case 2195:  /* neon_vmla_lanev2sf */
    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MLA;
        }

    case 2209:  /* neon_vmls_lanev4si */
    case 2208:  /* neon_vmls_lanev8hi */
    case 2197:  /* neon_vmla_lanev4si */
    case 2196:  /* neon_vmla_lanev8hi */
    case 1562:  /* neon_vmlsv4si_unspec */
    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1177:  /* mulv4si3addv4si_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MLA_Q;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MLA_Q;
        }

    case 2206:  /* neon_vmls_lanev2si */
    case 2205:  /* neon_vmls_lanev4hi */
    case 2194:  /* neon_vmla_lanev2si */
    case 2193:  /* neon_vmla_lanev4hi */
    case 1561:  /* neon_vmlsv2si_unspec */
    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1176:  /* mulv2si3addv2si_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MLA;
        }

    case 2168:  /* neon_vmul_lanev4sf */
    case 1516:  /* neon_vmulfv4sf */
    case 1171:  /* *mulv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MUL_Q;
        }

    case 2165:  /* neon_vmul_lanev2sf */
    case 1515:  /* neon_vmulfv2sf */
    case 1170:  /* *mulv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MULTIPLY;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MUL;
        }

    case 2167:  /* neon_vmul_lanev4si */
    case 2166:  /* neon_vmul_lanev8hi */
    case 1514:  /* neon_vmulpv16qi */
    case 1169:  /* *mulv4si3_neon */
    case 1167:  /* *mulv8hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MUL_Q;
        }

    case 2164:  /* neon_vmul_lanev2si */
    case 2163:  /* neon_vmul_lanev4hi */
    case 1513:  /* neon_vmulpv8qi */
    case 1168:  /* *mulv2si3_neon */
    case 1166:  /* *mulv4hi3_neon */
    case 1164:  /* *mulv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MULTIPLY;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MUL;
        }

    case 1603:  /* neon_vsubv4sf_unspec */
    case 1454:  /* neon_vaddv4sf_unspec */
    case 1162:  /* *subv4sf3_neon */
    case 1160:  /* *subv8hf3_neon */
    case 1151:  /* *addv4sf3_neon */
    case 1149:  /* *addv8hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH_Q;
        }

    case 1602:  /* neon_vsubv2sf_unspec */
    case 1453:  /* neon_vaddv2sf_unspec */
    case 1421:  /* neon_vpadd_internalv2sf */
    case 1161:  /* *subv2sf3_neon */
    case 1159:  /* *subv4hf3_neon */
    case 1150:  /* *addv2sf3_neon */
    case 1148:  /* *addv4hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1163:  /* *subv2di3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1154:  /* *subv16qi3_neon */
    case 1152:  /* *addv2di3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1143:  /* *addv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH_Q;
        }

    case 1420:  /* neon_vpadd_internalv2si */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1418:  /* neon_vpadd_internalv8qi */
    case 1157:  /* *subv2si3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1153:  /* *subv8qi3_neon */
    case 1146:  /* *addv2si3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1142:  /* *addv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1141:  /* neon_vec_extractv2didi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1136:  /* neon_vec_extractv16qiqi */
    case 1135:  /* vec_extractv2sfsf */
    case 1134:  /* vec_extractv2sisi */
    case 1133:  /* vec_extractv4bfbf */
    case 1132:  /* vec_extractv4hfhf */
    case 1131:  /* vec_extractv4hihi */
    case 1130:  /* vec_extractv8qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }

    case 1129:  /* vec_setv2di_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1124:  /* vec_setv16qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }

    case 1123:  /* vec_setv2sf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1118:  /* vec_setv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_TO_GP;
        }
      else if (((1ULL << which_alternative) & 0x110ULL))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }
      else if (!((1ULL << which_alternative) & 0x1fdULL))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_UNKNOWN;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_B;
        }
      else if (((1ULL << which_alternative) & 0x102ULL))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_UNKNOWN;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_UNKNOWN;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_UNKNOWN;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 7)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_UNKNOWN;
        }

    case 522:  /* mve_vshlq_uv4si */
    case 521:  /* mve_vshlq_sv4si */
    case 518:  /* mve_vshlq_uv8hi */
    case 517:  /* mve_vshlq_sv8hi */
    case 514:  /* mve_vshlq_uv16qi */
    case 513:  /* mve_vshlq_sv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;
        }

    case 520:  /* mve_vshlq_uv2si */
    case 519:  /* mve_vshlq_sv2si */
    case 516:  /* mve_vshlq_uv4hi */
    case 515:  /* mve_vshlq_sv4hi */
    case 512:  /* mve_vshlq_uv8qi */
    case 511:  /* mve_vshlq_sv8qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_BASIC;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_ABD) || (cached_type == TYPE_NEON_ABD_LONG))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ABD;
        }
      else if (cached_type == TYPE_NEON_ABD_Q)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ABD_Q;
        }
      else if ((cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_ACC;
        }
      else if (cached_type == TYPE_NEON_ARITH_ACC_Q)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_ACC_Q;
        }
      else if ((cached_type == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_ADD_Q) || (cached_type == TYPE_NEON_ADD_LONG) || (cached_type == TYPE_NEON_ADD_WIDEN) || (cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_REDUC_ADD_LONG) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_SUB_Q) || (cached_type == TYPE_NEON_SUB_LONG) || (cached_type == TYPE_NEON_SUB_WIDEN) || (cached_type == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_TST_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else if ((cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_QABS) || (cached_type == TYPE_NEON_QABS_Q) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_QNEG) || (cached_type == TYPE_NEON_QNEG_Q) || (cached_type == TYPE_NEON_QSUB) || (cached_type == TYPE_NEON_QSUB_Q) || (cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_MINMAX_Q) || (cached_type == TYPE_NEON_REDUC_MINMAX) || (cached_type == TYPE_NEON_REDUC_MINMAX_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else if ((cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_MUL_S_LONG) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MULTIPLY;
        }
      else if ((cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else if ((cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MLA;
        }
      else if ((cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H_Q) || (cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_MLA_Q;
        }
      else if ((cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SAT_MLA_LONG;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SHIFT_ACC_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_ACC;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else if ((cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX;
        }
      else if (cached_type == TYPE_NEON_SHIFT_REG)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_BASIC;
        }
      else if (cached_type == TYPE_NEON_SHIFT_REG_Q)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;
        }
      else if (cached_type == TYPE_NEON_SAT_SHIFT_REG)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_COMPLEX;
        }
      else if (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_COMPLEX_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_ABS_S_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_NEGABS;
        }
      else if ((cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_MINMAX_S) || (cached_type == TYPE_NEON_FP_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S) || (cached_type == TYPE_NEON_FP_ROUND_S) || (cached_type == TYPE_NEON_FP_ROUND_S_Q) || (cached_type == TYPE_NEON_FP_ROUND_D) || (cached_type == TYPE_NEON_FP_ROUND_D_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH;
        }
      else if ((cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_TO_INT_S) || (cached_type == TYPE_NEON_INT_TO_FP_S))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_CVT_INT;
        }
      else if ((cached_type == TYPE_NEON_FP_TO_INT_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_CVT_INT_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_CVT_NARROW_S_Q) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_H))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_CVT16;
        }
      else if ((cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MUL;
        }
      else if ((cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MUL_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_MLA_S) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MLA;
        }
      else if ((cached_type == TYPE_NEON_FP_MLA_S_Q) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_MLA_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RSQRTE_S))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_RECPE_RSQRTE;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_S_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q;
        }
      else if ((cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CNT) || (cached_type == TYPE_NEON_REV) || (cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL2) || (cached_type == TYPE_NEON_ZIP) || (cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_DUP_Q) || (cached_type == TYPE_NEON_EXT) || (cached_type == TYPE_NEON_EXT_Q) || (cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_MOVE_Q) || (cached_type == TYPE_NEON_MOVE_NARROW_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS;
        }
      else if ((cached_type == TYPE_NEON_BSL_Q) || (cached_type == TYPE_NEON_CLS_Q) || (cached_type == TYPE_NEON_CNT_Q) || (cached_type == TYPE_NEON_REV_Q) || (cached_type == TYPE_NEON_PERMUTE_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_BITOPS_Q;
        }
      else if (cached_type == TYPE_NEON_FROM_GP)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP;
        }
      else if (cached_type == TYPE_NEON_FROM_GP_Q)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else if ((cached_type == TYPE_NEON_TBL3) || (cached_type == TYPE_NEON_TBL4))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_TBL3_TBL4;
        }
      else if (cached_type == TYPE_NEON_ZIP_Q)
        {
	  return CORTEX_A17_NEON_TYPE_NEON_ZIP_Q;
        }
      else if ((cached_type == TYPE_NEON_TO_GP) || (cached_type == TYPE_NEON_TO_GP_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_TO_GP;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_1REG_Q) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_2REG) || (cached_type == TYPE_NEON_LOAD1_2REG_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_B;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_3REG) || (cached_type == TYPE_NEON_LOAD1_3REG_Q) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_4REG) || (cached_type == TYPE_NEON_LOAD1_4REG_Q) || (cached_type == TYPE_NEON_LOAD2_2REG) || (cached_type == TYPE_NEON_LOAD2_2REG_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_ONE_LANE) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_E;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_F;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_3REG) || (cached_type == TYPE_NEON_LOAD3_3REG_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_G;
        }
      else if ((cached_type == TYPE_NEON_LOAD2_4REG) || (cached_type == TYPE_NEON_LOAD2_4REG_Q) || (cached_type == TYPE_NEON_LOAD4_4REG) || (cached_type == TYPE_NEON_LOAD4_4REG_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_LOAD_H;
        }
      else if ((cached_type == TYPE_NEON_STORE1_1REG) || (cached_type == TYPE_NEON_STORE1_1REG_Q) || (cached_type == TYPE_NEON_STORE1_2REG) || (cached_type == TYPE_NEON_STORE1_2REG_Q) || (cached_type == TYPE_NEON_STORE1_3REG) || (cached_type == TYPE_NEON_STORE1_3REG_Q) || (cached_type == TYPE_NEON_STORE1_4REG) || (cached_type == TYPE_NEON_STORE1_4REG_Q) || (cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE2_2REG) || (cached_type == TYPE_NEON_STORE2_2REG_Q) || (cached_type == TYPE_NEON_STORE3_ONE_LANE) || (cached_type == TYPE_NEON_STORE3_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE4_ONE_LANE) || (cached_type == TYPE_NEON_STORE4_ONE_LANE_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_A;
        }
      else if ((cached_type == TYPE_NEON_STORE2_4REG) || (cached_type == TYPE_NEON_STORE2_4REG_Q) || (cached_type == TYPE_NEON_STORE2_ONE_LANE) || (cached_type == TYPE_NEON_STORE2_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE3_3REG) || (cached_type == TYPE_NEON_STORE3_3REG_Q) || (cached_type == TYPE_NEON_STORE4_4REG) || (cached_type == TYPE_NEON_STORE4_4REG_Q))
        {
	  return CORTEX_A17_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A17_NEON_TYPE_UNKNOWN;
        }

    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
      return CORTEX_A17_NEON_TYPE_NEON_STORE_B;

    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
    case 2677:  /* neon_vst3di */
    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
    case 2671:  /* neon_vst3v8qi */
    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
    case 2562:  /* neon_vst1v2di */
    case 2561:  /* neon_vst1di */
    case 2560:  /* neon_vst1v4sf */
    case 2559:  /* neon_vst1v2sf */
    case 2558:  /* neon_vst1v8bf */
    case 2557:  /* neon_vst1v4bf */
    case 2556:  /* neon_vst1v8hf */
    case 2555:  /* neon_vst1v4hf */
    case 2554:  /* neon_vst1v4si */
    case 2553:  /* neon_vst1v2si */
    case 2552:  /* neon_vst1v8hi */
    case 2551:  /* neon_vst1v4hi */
    case 2550:  /* neon_vst1v16qi */
    case 2549:  /* neon_vst1v8qi */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1070:  /* unaligned_storev8qi */
      return CORTEX_A17_NEON_TYPE_NEON_STORE_A;

    case 2719:  /* neon_vld4qbv4sf */
    case 2718:  /* neon_vld4qbv4si */
    case 2717:  /* neon_vld4qbv8bf */
    case 2716:  /* neon_vld4qbv8hf */
    case 2715:  /* neon_vld4qbv8hi */
    case 2714:  /* neon_vld4qbv16qi */
    case 2713:  /* neon_vld4qav4sf */
    case 2712:  /* neon_vld4qav4si */
    case 2711:  /* neon_vld4qav8bf */
    case 2710:  /* neon_vld4qav8hf */
    case 2709:  /* neon_vld4qav8hi */
    case 2708:  /* neon_vld4qav16qi */
      return CORTEX_A17_NEON_TYPE_NEON_LOAD_H;

    case 2651:  /* neon_vld3qbv4sf */
    case 2650:  /* neon_vld3qbv4si */
    case 2649:  /* neon_vld3qbv8bf */
    case 2648:  /* neon_vld3qbv8hf */
    case 2647:  /* neon_vld3qbv8hi */
    case 2646:  /* neon_vld3qbv16qi */
    case 2645:  /* neon_vld3qav4sf */
    case 2644:  /* neon_vld3qav4si */
    case 2643:  /* neon_vld3qav8bf */
    case 2642:  /* neon_vld3qav8hf */
    case 2641:  /* neon_vld3qav8hi */
    case 2640:  /* neon_vld3qav16qi */
      return CORTEX_A17_NEON_TYPE_NEON_LOAD_G;

    case 2738:  /* neon_vld4_dupv8bf */
    case 2730:  /* neon_vld4_lanev8bf */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2726:  /* neon_vld4_lanev8hi */
    case 2670:  /* neon_vld3_dupv8bf */
    case 2662:  /* neon_vld3_lanev8bf */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2658:  /* neon_vld3_lanev8hi */
      return CORTEX_A17_NEON_TYPE_NEON_LOAD_F;

    case 2725:  /* neon_vld4_lanev2sf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2720:  /* neon_vld4_lanev8qi */
    case 2657:  /* neon_vld3_lanev2sf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2652:  /* neon_vld3_lanev8qi */
      return CORTEX_A17_NEON_TYPE_NEON_LOAD_E;

    case 2589:  /* neon_vld2v4sf */
    case 2588:  /* neon_vld2v4si */
    case 2587:  /* neon_vld2v8bf */
    case 2586:  /* neon_vld2v8hf */
    case 2585:  /* neon_vld2v8hi */
    case 2584:  /* neon_vld2v16qi */
      return CORTEX_A17_NEON_TYPE_NEON_LOAD_D;

    case 2608:  /* neon_vld2_dupv8bf */
    case 2600:  /* neon_vld2_lanev8bf */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2596:  /* neon_vld2_lanev8hi */
    case 2595:  /* neon_vld2_lanev2sf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2590:  /* neon_vld2_lanev8qi */
    case 2548:  /* neon_vld1_dupv2di */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2543:  /* neon_vld1_dupv16qi */
    case 2542:  /* neon_vld1_dupv2sf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2537:  /* neon_vld1_dupv8qi */
      return CORTEX_A17_NEON_TYPE_NEON_LOAD_C;

    case 2854:  /* aes_op_protect_neon_vld1v16qi */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2536:  /* neon_vld1_lanev2di */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2530:  /* neon_vld1_lanev16qi */
    case 2529:  /* neon_vld1_lanedi */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2523:  /* neon_vld1_lanev8qi */
    case 2522:  /* neon_vld1v2di */
    case 2521:  /* neon_vld1di */
    case 2520:  /* neon_vld1v4sf */
    case 2519:  /* neon_vld1v2sf */
    case 2518:  /* neon_vld1v8bf */
    case 2517:  /* neon_vld1v4bf */
    case 2516:  /* neon_vld1v8hf */
    case 2515:  /* neon_vld1v4hf */
    case 2514:  /* neon_vld1v4si */
    case 2513:  /* neon_vld1v2si */
    case 2512:  /* neon_vld1v8hi */
    case 2511:  /* neon_vld1v4hi */
    case 2510:  /* neon_vld1v16qi */
    case 2509:  /* neon_vld1v8qi */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1111:  /* *movmisalignv16qi_neon_load */
    case 1103:  /* *movmisaligndi_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1097:  /* *movmisalignv8qi_neon_load */
      return CORTEX_A17_NEON_TYPE_NEON_LOAD_A;

    case 2040:  /* neon_vget_lanev4sf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2031:  /* neon_vget_lanev16qi_sext_internal */
    case 2030:  /* neon_vget_lanev2sf_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2023:  /* neon_vget_lanev8qi_sext_internal */
      return CORTEX_A17_NEON_TYPE_NEON_TO_GP;

    case 2507:  /* *neon_vuzpv8hf_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2490:  /* *neon_vzipv16qi_insn */
      return CORTEX_A17_NEON_TYPE_NEON_ZIP_Q;

    case 2478:  /* neon_vtbx4v8qi */
    case 2477:  /* neon_vtbx3v8qi */
    case 2471:  /* neon_vtbl4v8qi */
    case 2470:  /* neon_vtbl3v8qi */
      return CORTEX_A17_NEON_TYPE_NEON_TBL3_TBL4;

    case 2048:  /* neon_vdup_nv8bf */
    case 2046:  /* neon_vdup_nv8hf */
    case 2044:  /* neon_vdup_nv8hi */
    case 2043:  /* neon_vdup_nv16qi */
      return CORTEX_A17_NEON_TYPE_NEON_FROM_GP_Q;

    case 2047:  /* neon_vdup_nv4bf */
    case 2045:  /* neon_vdup_nv4hf */
    case 2042:  /* neon_vdup_nv4hi */
    case 2041:  /* neon_vdup_nv8qi */
      return CORTEX_A17_NEON_TYPE_NEON_FROM_GP;

    case 2487:  /* *neon_vtrnv8hf_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2261:  /* neon_vbslv2di_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2249:  /* neon_vbslv16qi_internal */
    case 2247:  /* neon_vrev16v16qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2244:  /* neon_vrev32v16qi */
    case 2241:  /* neon_vrev64v2di */
    case 2240:  /* neon_vrev64v4sf */
    case 2238:  /* neon_vrev64v8hf */
    case 2236:  /* neon_vrev64v4si */
    case 2234:  /* neon_vrev64v8hi */
    case 2232:  /* neon_vrev64v16qi */
    case 2079:  /* *neon_vswpv2di */
    case 2077:  /* *neon_vswpv4sf */
    case 2075:  /* *neon_vswpv8bf */
    case 2073:  /* *neon_vswpv8hf */
    case 2071:  /* *neon_vswpv4si */
    case 2069:  /* *neon_vswpv8hi */
    case 2067:  /* *neon_vswpv16qi */
    case 2012:  /* popcountv16qi2 */
    case 2010:  /* neon_vclzv4si */
    case 2008:  /* neon_vclzv8hi */
    case 2006:  /* neon_vclzv16qi */
    case 2004:  /* neon_vclsv4si */
    case 2002:  /* neon_vclsv8hi */
    case 2000:  /* neon_vclsv16qi */
    case 1914:  /* neon_bswapv2di */
    case 1913:  /* neon_bswapv4si */
    case 1911:  /* neon_bswapv8hi */
      return CORTEX_A17_NEON_TYPE_NEON_BITOPS_Q;

    case 2816:  /* neon_vec_pack_trunc_v2di */
    case 2815:  /* neon_vec_pack_trunc_v4si */
    case 2814:  /* neon_vec_pack_trunc_v8hi */
    case 2804:  /* neon_unpacku_v2si */
    case 2803:  /* neon_unpacks_v2si */
    case 2802:  /* neon_unpacku_v4hi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2799:  /* neon_unpacks_v8qi */
    case 2508:  /* *neon_vuzpv4hf_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2489:  /* *neon_vzipv8qi_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2476:  /* neon_vtbx2v8qi */
    case 2475:  /* neon_vtbx1v8qi */
    case 2469:  /* neon_vtbl2v8qi */
    case 2468:  /* neon_vtbl1v8qi */
    case 2260:  /* neon_vbsldi_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2248:  /* neon_vbslv8qi_internal */
    case 2246:  /* neon_vrev16v8qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2242:  /* neon_vrev32v8qi */
    case 2239:  /* neon_vrev64v2sf */
    case 2237:  /* neon_vrev64v4hf */
    case 2235:  /* neon_vrev64v2si */
    case 2233:  /* neon_vrev64v4hi */
    case 2231:  /* neon_vrev64v8qi */
    case 2230:  /* neon_vextv2di */
    case 2229:  /* neon_vextdi */
    case 2228:  /* neon_vextv4sf */
    case 2227:  /* neon_vextv2sf */
    case 2226:  /* neon_vextv8bf */
    case 2225:  /* neon_vextv4bf */
    case 2224:  /* neon_vextv8hf */
    case 2223:  /* neon_vextv4hf */
    case 2222:  /* neon_vextv4si */
    case 2221:  /* neon_vextv2si */
    case 2220:  /* neon_vextv8hi */
    case 2219:  /* neon_vextv4hi */
    case 2218:  /* neon_vextv16qi */
    case 2217:  /* neon_vextv8qi */
    case 2078:  /* *neon_vswpdi */
    case 2076:  /* *neon_vswpv2sf */
    case 2074:  /* *neon_vswpv4bf */
    case 2072:  /* *neon_vswpv4hf */
    case 2070:  /* *neon_vswpv2si */
    case 2068:  /* *neon_vswpv4hi */
    case 2066:  /* *neon_vswpv8qi */
    case 2065:  /* neon_vdup_lanev8bf_internal */
    case 2064:  /* neon_vdup_lanev4bf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 2011:  /* popcountv8qi2 */
    case 2009:  /* neon_vclzv2si */
    case 2007:  /* neon_vclzv4hi */
    case 2005:  /* neon_vclzv8qi */
    case 2003:  /* neon_vclsv2si */
    case 2001:  /* neon_vclsv4hi */
    case 1999:  /* neon_vclsv8qi */
    case 1912:  /* neon_bswapv2si */
    case 1910:  /* neon_bswapv4hi */
    case 1291:  /* one_cmplv2di2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1289:  /* one_cmplv2sf2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1282:  /* one_cmplv16qi2_neon */
    case 1281:  /* one_cmplv8qi2_neon */
      return CORTEX_A17_NEON_TYPE_NEON_BITOPS;

    case 2022:  /* neon_vrsqrtev4sf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2018:  /* neon_vrecpev4sf */
    case 2017:  /* neon_vrecpev4si */
    case 2013:  /* neon_vrecpev8hf */
    case 1324:  /* neon_vrsqrtev8hf */
      return CORTEX_A17_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q;

    case 2020:  /* neon_vrsqrtev2sf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2016:  /* neon_vrecpev2sf */
    case 2015:  /* neon_vrecpev2si */
    case 2014:  /* neon_vrecpev4hf */
    case 1325:  /* neon_vrsqrtev4hf */
      return CORTEX_A17_NEON_TYPE_NEON_FP_RECPE_RSQRTE;

    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1180:  /* mulv8hf3addv8hf_neon */
      return CORTEX_A17_NEON_TYPE_NEON_FP_MLA_Q;

    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1190:  /* fmav2sf4 */
    case 1181:  /* mulv4hf3addv4hf_neon */
      return CORTEX_A17_NEON_TYPE_NEON_FP_MLA;

    case 2169:  /* neon_vmul_lanev8hf */
      return CORTEX_A17_NEON_TYPE_NEON_FP_MUL_Q;

    case 2170:  /* neon_vmul_lanev4hf */
      return CORTEX_A17_NEON_TYPE_NEON_FP_MUL;

    case 2836:  /* neon_vbfcvtv4sf_highv8bf */
    case 2835:  /* neon_vbfcvtv4sfv8bf */
    case 2834:  /* neon_vbfcvtv4sfv4bf */
    case 2104:  /* neon_vcvtv4hfv4sf */
    case 2103:  /* neon_vcvtv4sfv4hf */
      return CORTEX_A17_NEON_TYPE_NEON_FP_CVT16;

    case 2136:  /* neon_vcvtpuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2128:  /* neon_vcvtu_nv8hi */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2123:  /* neon_vcvts_nv4si */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2108:  /* neon_vcvtuv8hi */
    case 2107:  /* neon_vcvtsv8hi */
    case 2102:  /* neon_vcvtuv4si */
    case 2101:  /* neon_vcvtsv4si */
    case 2098:  /* neon_vcvtuv4sf */
    case 2097:  /* neon_vcvtsv4sf */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2088:  /* floatv4siv4sf2 */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1220:  /* neon_vcvtpv4sfv4si */
      return CORTEX_A17_NEON_TYPE_NEON_FP_CVT_INT_Q;

    case 2144:  /* neon_vcvtpuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2126:  /* neon_vcvtu_nv4hi */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2121:  /* neon_vcvts_nv2si */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2106:  /* neon_vcvtuv4hi */
    case 2105:  /* neon_vcvtsv4hi */
    case 2100:  /* neon_vcvtuv2si */
    case 2099:  /* neon_vcvtsv2si */
    case 2096:  /* neon_vcvtuv2sf */
    case 2095:  /* neon_vcvtsv2sf */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2087:  /* floatv2siv2sf2 */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1214:  /* neon_vcvtpv2sfv2si */
      return CORTEX_A17_NEON_TYPE_NEON_FP_CVT_INT;

    case 2824:  /* neon_vabdv4sf_3 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2818:  /* neon_vabdv8hf_2 */
    case 1785:  /* neon_vabdfv4sf */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1404:  /* quad_halves_plusv4sf */
      return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH_Q;

    case 2823:  /* neon_vabdv2sf_3 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2817:  /* neon_vabdv4hf_2 */
    case 1895:  /* neon_vpminfv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1893:  /* neon_vpminfv2sf */
    case 1892:  /* neon_vpmaxfv2sf */
    case 1855:  /* fminv4sf3 */
    case 1854:  /* fmaxv4sf3 */
    case 1853:  /* fminv2sf3 */
    case 1852:  /* fmaxv2sf3 */
    case 1851:  /* neon_vminnmv4sf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1849:  /* neon_vminnmv2sf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1847:  /* neon_vminnmv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1845:  /* neon_vminnmv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1841:  /* neon_vminfv4hf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1839:  /* neon_vminfv8hf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1837:  /* neon_vminfv4sf */
    case 1836:  /* neon_vmaxfv4sf */
    case 1835:  /* neon_vminfv2sf */
    case 1834:  /* neon_vmaxfv2sf */
    case 1784:  /* neon_vabdfv2sf */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1690:  /* neon_vceqv2sf_insn_unspec */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1405:  /* quad_halves_sminv4sf */
    case 1323:  /* neon_vrndxv4hf */
    case 1322:  /* neon_vrndpv4hf */
    case 1321:  /* neon_vrndnv4hf */
    case 1320:  /* neon_vrndmv4hf */
    case 1319:  /* neon_vrndav4hf */
    case 1318:  /* neon_vrndv4hf */
    case 1317:  /* neon_vrndxv8hf */
    case 1316:  /* neon_vrndpv8hf */
    case 1315:  /* neon_vrndnv8hf */
    case 1314:  /* neon_vrndmv8hf */
    case 1313:  /* neon_vrndav8hf */
    case 1312:  /* neon_vrndv8hf */
    case 1213:  /* neon_vrintnv4sf */
    case 1212:  /* neon_vrintav4sf */
    case 1211:  /* neon_vrintxv4sf */
    case 1210:  /* neon_vrintmv4sf */
    case 1209:  /* neon_vrintzv4sf */
    case 1208:  /* neon_vrintpv4sf */
    case 1207:  /* neon_vrintnv2sf */
    case 1206:  /* neon_vrintav2sf */
    case 1205:  /* neon_vrintxv2sf */
    case 1204:  /* neon_vrintmv2sf */
    case 1203:  /* neon_vrintzv2sf */
    case 1202:  /* neon_vrintpv2sf */
    case 787:  /* neon_vrndihf */
    case 786:  /* neon_vrndxhf */
    case 785:  /* neon_vrndphf */
    case 784:  /* neon_vrndnhf */
    case 783:  /* neon_vrndmhf */
    case 782:  /* neon_vrndahf */
    case 781:  /* neon_vrndhf */
      return CORTEX_A17_NEON_TYPE_NEON_FP_ARITH;

    case 2467:  /* neon_vsli_nv2di */
    case 2465:  /* neon_vsli_nv4si */
    case 2463:  /* neon_vsli_nv8hi */
    case 2461:  /* neon_vsli_nv16qi */
    case 2459:  /* neon_vsri_nv2di */
    case 2457:  /* neon_vsri_nv4si */
    case 2455:  /* neon_vsri_nv8hi */
    case 2453:  /* neon_vsri_nv16qi */
    case 1379:  /* ashlv2di3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1372:  /* ashlv2di3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1367:  /* ashlv16qi3_signed */
      return CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;

    case 2466:  /* neon_vsli_ndi */
    case 2464:  /* neon_vsli_nv2si */
    case 2462:  /* neon_vsli_nv4hi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2458:  /* neon_vsri_ndi */
    case 2456:  /* neon_vsri_nv2si */
    case 2454:  /* neon_vsri_nv4hi */
    case 2452:  /* neon_vsri_nv8qi */
    case 1377:  /* ashlv2si3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1370:  /* ashlv2si3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1366:  /* ashlv8qi3_signed */
      return CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_BASIC;

    case 2413:  /* neon_vqshlu_nv2di */
    case 2412:  /* neon_vqshlu_ndi */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2381:  /* neon_vqrshrun_nv2di */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2325:  /* neon_vqrshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2322:  /* neon_vqshlsv2di */
    case 2321:  /* neon_vqrshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2318:  /* neon_vqshlsdi */
    case 2317:  /* neon_vqrshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2314:  /* neon_vqshlsv4si */
    case 2313:  /* neon_vqrshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2310:  /* neon_vqshlsv2si */
    case 2309:  /* neon_vqrshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2305:  /* neon_vqrshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2298:  /* neon_vqshlsv16qi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2294:  /* neon_vqshlsv8qi */
    case 2156:  /* neon_vqmovunv2di */
    case 2155:  /* neon_vqmovunv4si */
    case 2154:  /* neon_vqmovunv8hi */
    case 2153:  /* neon_vqmovnuv2di */
    case 2152:  /* neon_vqmovnsv2di */
    case 2151:  /* neon_vqmovnuv4si */
    case 2150:  /* neon_vqmovnsv4si */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2148:  /* neon_vqmovnsv8hi */
      return CORTEX_A17_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX;

    case 2840:  /* neon_vbfcvt_highv8bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2798:  /* neon_vec_ushiftl_v2si */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2419:  /* neon_vshllu_nv2si */
    case 2418:  /* neon_vshlls_nv2si */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2389:  /* neon_vshl_nv2di */
    case 2388:  /* neon_vshl_ndi */
    case 2387:  /* neon_vshl_nv4si */
    case 2386:  /* neon_vshl_nv2si */
    case 2385:  /* neon_vshl_nv8hi */
    case 2384:  /* neon_vshl_nv4hi */
    case 2383:  /* neon_vshl_nv16qi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2363:  /* neon_vrshrn_nv2di */
    case 2362:  /* neon_vshrn_nv2di */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2360:  /* neon_vshrn_nv4si */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2357:  /* neon_vrshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2354:  /* neon_vshrs_nv2di */
    case 2353:  /* neon_vrshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2350:  /* neon_vshrs_ndi */
    case 2349:  /* neon_vrshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2346:  /* neon_vshrs_nv4si */
    case 2345:  /* neon_vrshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2342:  /* neon_vshrs_nv2si */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2293:  /* neon_vrshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2290:  /* neon_vshlsv2di */
    case 2289:  /* neon_vrshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2287:  /* neon_vshludi */
    case 2286:  /* neon_vshlsdi */
    case 2285:  /* neon_vrshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2282:  /* neon_vshlsv4si */
    case 2281:  /* neon_vrshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2278:  /* neon_vshlsv2si */
    case 2277:  /* neon_vrshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2274:  /* neon_vshlsv8hi */
    case 2273:  /* neon_vrshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2270:  /* neon_vshlsv4hi */
    case 2269:  /* neon_vrshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2266:  /* neon_vshlsv16qi */
    case 2265:  /* neon_vrshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2262:  /* neon_vshlsv8qi */
    case 2162:  /* neon_vmovluv2si */
    case 2161:  /* neon_vmovlsv2si */
    case 2160:  /* neon_vmovluv4hi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2158:  /* neon_vmovluv8qi */
    case 2157:  /* neon_vmovlsv8qi */
    case 2147:  /* neon_vmovnv2di */
    case 2146:  /* neon_vmovnv4si */
    case 2145:  /* neon_vmovnv8hi */
    case 1365:  /* vlshrv4si3_imm */
    case 1364:  /* vlshrv2si3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1355:  /* vashrv16qi3_imm */
    case 1354:  /* vashrv8qi3_imm */
      return CORTEX_A17_NEON_TYPE_NEON_SHIFT_IMM_BASIC;

    case 2451:  /* neon_vrsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2448:  /* neon_vsras_nv2di */
    case 2447:  /* neon_vrsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2444:  /* neon_vsras_ndi */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2440:  /* neon_vsras_nv4si */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2436:  /* neon_vsras_nv2si */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2424:  /* neon_vsras_nv16qi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2420:  /* neon_vsras_nv8qi */
      return CORTEX_A17_NEON_TYPE_NEON_SHIFT_ACC;

    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1588:  /* neon_vqdmlalv2si */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
      return CORTEX_A17_NEON_TYPE_NEON_SAT_MLA_LONG;

    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
      return CORTEX_A17_NEON_TYPE_NEON_MLA_Q;

    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
      return CORTEX_A17_NEON_TYPE_NEON_MLA;

    case 2184:  /* neon_vqrdmulh_lanev2si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
    case 1517:  /* neon_vmulfv8hf */
      return CORTEX_A17_NEON_TYPE_NEON_MULTIPLY_Q;

    case 2810:  /* neon_vec_umult_v2si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2808:  /* neon_vec_umult_v4hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2806:  /* neon_vec_umult_v8qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
    case 1601:  /* neon_vqdmullv2si */
    case 1600:  /* neon_vqdmullv4hi */
    case 1599:  /* neon_vmullpv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1597:  /* neon_vmullsv2si */
    case 1596:  /* neon_vmullpv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1594:  /* neon_vmullsv4hi */
    case 1593:  /* neon_vmullpv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1591:  /* neon_vmullsv8qi */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
    case 1518:  /* neon_vmulfv4hf */
      return CORTEX_A17_NEON_TYPE_NEON_MULTIPLY;

    case 1998:  /* neon_vqnegv4si */
    case 1997:  /* neon_vqnegv2si */
    case 1996:  /* neon_vqnegv8hi */
    case 1995:  /* neon_vqnegv4hi */
    case 1994:  /* neon_vqnegv16qi */
    case 1993:  /* neon_vqnegv8qi */
    case 1909:  /* neon_vqabsv4si */
    case 1908:  /* neon_vqabsv2si */
    case 1907:  /* neon_vqabsv8hi */
    case 1906:  /* neon_vqabsv4hi */
    case 1905:  /* neon_vqabsv16qi */
    case 1904:  /* neon_vqabsv8qi */
    case 1891:  /* neon_vpminuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1888:  /* neon_vpmaxsv2si */
    case 1887:  /* neon_vpminuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1883:  /* neon_vpminuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1843:  /* neon_vpminfv4hf */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1833:  /* neon_vminuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1830:  /* neon_vmaxsv4si */
    case 1829:  /* neon_vminuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1826:  /* neon_vmaxsv2si */
    case 1825:  /* neon_vminuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1821:  /* neon_vminuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1817:  /* neon_vminuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1814:  /* neon_vmaxsv16qi */
    case 1813:  /* neon_vminuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1810:  /* neon_vmaxsv8qi */
    case 1731:  /* neon_vcgeuv4si */
    case 1730:  /* neon_vcgtuv4si */
    case 1729:  /* neon_vcgeuv2si */
    case 1728:  /* neon_vcgtuv2si */
    case 1727:  /* neon_vcgeuv8hi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1725:  /* neon_vcgeuv4hi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1722:  /* neon_vcgtuv16qi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1720:  /* neon_vcgtuv8qi */
    case 1649:  /* neon_vrsubhnv2di */
    case 1648:  /* neon_vsubhnv2di */
    case 1647:  /* neon_vrsubhnv4si */
    case 1646:  /* neon_vsubhnv4si */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1644:  /* neon_vsubhnv8hi */
    case 1643:  /* neon_vhsubuv4si */
    case 1642:  /* neon_vhsubsv4si */
    case 1641:  /* neon_vhsubuv2si */
    case 1640:  /* neon_vhsubsv2si */
    case 1639:  /* neon_vhsubuv8hi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1637:  /* neon_vhsubuv4hi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1634:  /* neon_vhsubsv16qi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1632:  /* neon_vhsubsv8qi */
    case 1631:  /* neon_vqsubuv2di */
    case 1630:  /* neon_vqsubsv2di */
    case 1629:  /* neon_vqsubudi */
    case 1628:  /* neon_vqsubsdi */
    case 1627:  /* neon_vqsubuv4si */
    case 1626:  /* neon_vqsubsv4si */
    case 1625:  /* neon_vqsubuv2si */
    case 1624:  /* neon_vqsubsv2si */
    case 1623:  /* neon_vqsubuv8hi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1621:  /* neon_vqsubuv4hi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1618:  /* neon_vqsubsv16qi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1616:  /* neon_vqsubsv8qi */
    case 1512:  /* neon_vraddhnv2di */
    case 1511:  /* neon_vaddhnv2di */
    case 1510:  /* neon_vraddhnv4si */
    case 1509:  /* neon_vaddhnv4si */
    case 1508:  /* neon_vraddhnv8hi */
    case 1507:  /* neon_vaddhnv8hi */
    case 1506:  /* neon_vqadduv2di */
    case 1505:  /* neon_vqaddsv2di */
    case 1504:  /* neon_vqaddudi */
    case 1503:  /* neon_vqaddsdi */
    case 1502:  /* neon_vqadduv4si */
    case 1501:  /* neon_vqaddsv4si */
    case 1500:  /* neon_vqadduv2si */
    case 1499:  /* neon_vqaddsv2si */
    case 1498:  /* neon_vqadduv8hi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1496:  /* neon_vqadduv4hi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1494:  /* neon_vqadduv16qi */
    case 1493:  /* neon_vqaddsv16qi */
    case 1492:  /* neon_vqadduv8qi */
    case 1491:  /* neon_vqaddsv8qi */
    case 1490:  /* neon_vhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1486:  /* neon_vhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1483:  /* neon_vrhaddsv2si */
    case 1482:  /* neon_vhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1474:  /* neon_vhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1467:  /* neon_vrhaddsv8qi */
    case 1452:  /* *us_subv2sf_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1445:  /* *ss_subv8qi_neon */
    case 1444:  /* *us_addv2sf_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1437:  /* *ss_addv8qi_neon */
    case 1436:  /* neon_vpumaxv2si */
    case 1435:  /* neon_vpumaxv4hi */
    case 1434:  /* neon_vpumaxv8qi */
    case 1433:  /* neon_vpuminv2si */
    case 1432:  /* neon_vpuminv4hi */
    case 1431:  /* neon_vpuminv8qi */
    case 1416:  /* quad_halves_umaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1408:  /* quad_halves_sminv8hi */
    case 1403:  /* quad_halves_umaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1400:  /* quad_halves_sminv4si */
    case 1337:  /* *umaxv4si3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1327:  /* *uminv16qi3_neon */
    case 1326:  /* *uminv8qi3_neon */
    case 1311:  /* neon_negv4hf2 */
    case 1310:  /* neon_absv4hf2 */
    case 1309:  /* neon_negv8hf2 */
    case 1308:  /* neon_absv8hf2 */
      return CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX;

    case 1867:  /* neon_vpaddluv4si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1865:  /* neon_vpaddluv2si */
    case 1864:  /* neon_vpaddlsv2si */
    case 1863:  /* neon_vpaddluv8hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1856:  /* neon_vpaddlsv8qi */
    case 1769:  /* neon_vtst_combinev4si */
    case 1768:  /* neon_vtst_combinev2si */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1765:  /* neon_vtst_combinev16qi */
    case 1764:  /* neon_vtst_combinev8qi */
    case 1615:  /* neon_vsubwuv2si */
    case 1614:  /* neon_vsubwsv2si */
    case 1613:  /* neon_vsubwuv4hi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1610:  /* neon_vsubwsv8qi */
    case 1609:  /* neon_vsubluv2si */
    case 1608:  /* neon_vsublsv2si */
    case 1607:  /* neon_vsubluv4hi */
    case 1606:  /* neon_vsublsv4hi */
    case 1605:  /* neon_vsubluv8qi */
    case 1604:  /* neon_vsublsv8qi */
    case 1466:  /* neon_vaddwuv2si */
    case 1465:  /* neon_vaddwsv2si */
    case 1464:  /* neon_vaddwuv4hi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1461:  /* neon_vaddwsv8qi */
    case 1460:  /* neon_vaddluv2si */
    case 1459:  /* neon_vaddlsv2si */
    case 1458:  /* neon_vaddluv4hi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1456:  /* neon_vaddluv8qi */
    case 1455:  /* neon_vaddlsv8qi */
    case 1422:  /* neon_vpaddv4hf */
    case 1417:  /* arm_reduc_plus_internal_v2di */
    case 1412:  /* quad_halves_plusv16qi */
    case 1407:  /* quad_halves_plusv8hi */
    case 1399:  /* quad_halves_plusv4si */
    case 1398:  /* widen_usumv2si3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
    case 1280:  /* xorv2di3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1278:  /* xorv2sf3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1247:  /* andv2di3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1242:  /* andv4si3_neon */
    case 1241:  /* andv2si3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1227:  /* iorv16qi3_neon */
    case 1226:  /* iorv8qi3_neon */
      return CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC;

    case 1803:  /* neon_vabauv4si */
    case 1802:  /* neon_vabasv4si */
    case 1799:  /* neon_vabauv8hi */
    case 1798:  /* neon_vabasv8hi */
    case 1795:  /* neon_vabauv16qi */
    case 1794:  /* neon_vabasv16qi */
      return CORTEX_A17_NEON_TYPE_NEON_ARITH_ACC_Q;

    case 1879:  /* neon_vpadaluv4si */
    case 1878:  /* neon_vpadalsv4si */
    case 1877:  /* neon_vpadaluv2si */
    case 1876:  /* neon_vpadalsv2si */
    case 1875:  /* neon_vpadaluv8hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1868:  /* neon_vpadalsv8qi */
    case 1809:  /* neon_vabaluv2si */
    case 1808:  /* neon_vabalsv2si */
    case 1807:  /* neon_vabaluv4hi */
    case 1806:  /* neon_vabalsv4hi */
    case 1805:  /* neon_vabaluv8qi */
    case 1804:  /* neon_vabalsv8qi */
    case 1801:  /* neon_vabauv2si */
    case 1800:  /* neon_vabasv2si */
    case 1797:  /* neon_vabauv4hi */
    case 1796:  /* neon_vabasv4hi */
    case 1793:  /* neon_vabauv8qi */
    case 1792:  /* neon_vabasv8qi */
      return CORTEX_A17_NEON_TYPE_NEON_ARITH_ACC;

    case 1782:  /* neon_vabdv8hf */
    case 1781:  /* neon_vabduv4si */
    case 1780:  /* neon_vabdsv4si */
    case 1777:  /* neon_vabduv8hi */
    case 1776:  /* neon_vabdsv8hi */
    case 1773:  /* neon_vabduv16qi */
    case 1772:  /* neon_vabdsv16qi */
      return CORTEX_A17_NEON_TYPE_NEON_ABD_Q;

    case 1791:  /* neon_vabdluv2si */
    case 1790:  /* neon_vabdlsv2si */
    case 1789:  /* neon_vabdluv4hi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1787:  /* neon_vabdluv8qi */
    case 1786:  /* neon_vabdlsv8qi */
    case 1783:  /* neon_vabdv4hf */
    case 1779:  /* neon_vabduv2si */
    case 1778:  /* neon_vabdsv2si */
    case 1775:  /* neon_vabduv4hi */
    case 1774:  /* neon_vabdsv4hi */
    case 1771:  /* neon_vabduv8qi */
    case 1770:  /* neon_vabdsv8qi */
      return CORTEX_A17_NEON_TYPE_NEON_ABD;

    default:
      return CORTEX_A17_NEON_TYPE_UNKNOWN;

    }
}

enum attr_cortex_a15_neon_type
get_attr_cortex_a15_neon_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_B;
        }

    case 2745:  /* neon_vst4di */
      if ((64) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_D;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_G;
        }

    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
      if ((32) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_D;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_G;
        }

    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_D;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_G;
        }

    case 2739:  /* neon_vst4v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_D;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_G;
        }

    case 2677:  /* neon_vst3di */
      if ((64) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_C;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_F;
        }

    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
      if ((32) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_C;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_F;
        }

    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_C;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_F;
        }

    case 2671:  /* neon_vst3v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_C;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_F;
        }

    case 2737:  /* neon_vld4_dupdi */
    case 2669:  /* neon_vld3_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_E;
        }

    case 2736:  /* neon_vld4_dupv2sf */
    case 2735:  /* neon_vld4_dupv2si */
    case 2668:  /* neon_vld3_dupv2sf */
    case 2667:  /* neon_vld3_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_E;
        }

    case 2734:  /* neon_vld4_dupv4bf */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2732:  /* neon_vld4_dupv4hi */
    case 2666:  /* neon_vld3_dupv4bf */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2664:  /* neon_vld3_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_E;
        }

    case 2731:  /* neon_vld4_dupv8qi */
    case 2663:  /* neon_vld3_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_E;
        }

    case 2707:  /* neon_vld4di */
    case 2639:  /* neon_vld3di */
      if ((64) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_D;
        }

    case 2706:  /* neon_vld4v2sf */
    case 2705:  /* neon_vld4v2si */
    case 2638:  /* neon_vld3v2sf */
    case 2637:  /* neon_vld3v2si */
      if ((32) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_D;
        }

    case 2704:  /* neon_vld4v4bf */
    case 2703:  /* neon_vld4v4hf */
    case 2702:  /* neon_vld4v4hi */
    case 2636:  /* neon_vld3v4bf */
    case 2635:  /* neon_vld3v4hf */
    case 2634:  /* neon_vld3v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_D;
        }

    case 2701:  /* neon_vld4v8qi */
    case 2633:  /* neon_vld3v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_D;
        }

    case 2615:  /* neon_vst2di */
      if ((64) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_E;
        }

    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
      if ((32) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_E;
        }

    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_E;
        }

    case 2609:  /* neon_vst2v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_E;
        }

    case 2607:  /* neon_vld2_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 2606:  /* neon_vld2_dupv2sf */
    case 2605:  /* neon_vld2_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 2604:  /* neon_vld2_dupv4bf */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2602:  /* neon_vld2_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 2601:  /* neon_vld2_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 2583:  /* neon_vld2di */
      if ((64) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 2582:  /* neon_vld2v2sf */
    case 2581:  /* neon_vld2v2si */
      if ((32) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 2580:  /* neon_vld2v4bf */
    case 2579:  /* neon_vld2v4hf */
    case 2578:  /* neon_vld2v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 2577:  /* neon_vld2v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 2052:  /* neon_vdup_nv4sf */
    case 2051:  /* neon_vdup_nv4si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP_Q;
        }

    case 2050:  /* neon_vdup_nv2sf */
    case 2049:  /* neon_vdup_nv2si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP;
        }

    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_ZERO))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 1380:  /* neon_load_count */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }

    case 1430:  /* neon_vpsmaxv2sf */
    case 1426:  /* neon_vpsminv2sf */
    case 1353:  /* *smaxv4sf3_neon */
    case 1352:  /* *smaxv2sf3_neon */
    case 1345:  /* *sminv4sf3_neon */
    case 1344:  /* *sminv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1429:  /* neon_vpsmaxv2si */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1425:  /* neon_vpsminv2si */
    case 1424:  /* neon_vpsminv4hi */
    case 1423:  /* neon_vpsminv8qi */
    case 1351:  /* *smaxv4si3_neon */
    case 1350:  /* *smaxv2si3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1339:  /* *sminv16qi3_neon */
    case 1338:  /* *sminv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1307:  /* neon_negv4sf2 */
    case 1306:  /* neon_negv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1305:  /* neon_negv4si2 */
    case 1304:  /* neon_negv2si2 */
    case 1303:  /* neon_negv8hi2 */
    case 1302:  /* neon_negv4hi2 */
    case 1301:  /* neon_negv16qi2 */
    case 1300:  /* neon_negv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1299:  /* neon_absv4sf2 */
    case 1298:  /* neon_absv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 1297:  /* neon_absv4si2 */
    case 1296:  /* neon_absv2si2 */
    case 1295:  /* neon_absv8hi2 */
    case 1294:  /* neon_absv4hi2 */
    case 1293:  /* neon_absv16qi2 */
    case 1292:  /* neon_absv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_NEGABS;
        }

    case 2210:  /* neon_vmls_lanev4sf */
    case 2198:  /* neon_vmla_lanev4sf */
    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MLA_Q;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MLA_Q;
        }

    case 2207:  /* neon_vmls_lanev2sf */
    case 2195:  /* neon_vmla_lanev2sf */
    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MLA;
        }

    case 2209:  /* neon_vmls_lanev4si */
    case 2208:  /* neon_vmls_lanev8hi */
    case 2197:  /* neon_vmla_lanev4si */
    case 2196:  /* neon_vmla_lanev8hi */
    case 1562:  /* neon_vmlsv4si_unspec */
    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1177:  /* mulv4si3addv4si_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MLA_Q;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MLA_Q;
        }

    case 2206:  /* neon_vmls_lanev2si */
    case 2205:  /* neon_vmls_lanev4hi */
    case 2194:  /* neon_vmla_lanev2si */
    case 2193:  /* neon_vmla_lanev4hi */
    case 1561:  /* neon_vmlsv2si_unspec */
    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1176:  /* mulv2si3addv2si_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MLA;
        }

    case 2168:  /* neon_vmul_lanev4sf */
    case 1516:  /* neon_vmulfv4sf */
    case 1171:  /* *mulv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MUL_Q;
        }

    case 2165:  /* neon_vmul_lanev2sf */
    case 1515:  /* neon_vmulfv2sf */
    case 1170:  /* *mulv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MULTIPLY;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MUL;
        }

    case 2167:  /* neon_vmul_lanev4si */
    case 2166:  /* neon_vmul_lanev8hi */
    case 1514:  /* neon_vmulpv16qi */
    case 1169:  /* *mulv4si3_neon */
    case 1167:  /* *mulv8hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MUL_Q;
        }

    case 2164:  /* neon_vmul_lanev2si */
    case 2163:  /* neon_vmul_lanev4hi */
    case 1513:  /* neon_vmulpv8qi */
    case 1168:  /* *mulv2si3_neon */
    case 1166:  /* *mulv4hi3_neon */
    case 1164:  /* *mulv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MULTIPLY;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MUL;
        }

    case 1603:  /* neon_vsubv4sf_unspec */
    case 1454:  /* neon_vaddv4sf_unspec */
    case 1162:  /* *subv4sf3_neon */
    case 1160:  /* *subv8hf3_neon */
    case 1151:  /* *addv4sf3_neon */
    case 1149:  /* *addv8hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH_Q;
        }

    case 1602:  /* neon_vsubv2sf_unspec */
    case 1453:  /* neon_vaddv2sf_unspec */
    case 1421:  /* neon_vpadd_internalv2sf */
    case 1161:  /* *subv2sf3_neon */
    case 1159:  /* *subv4hf3_neon */
    case 1150:  /* *addv2sf3_neon */
    case 1148:  /* *addv4hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1163:  /* *subv2di3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1154:  /* *subv16qi3_neon */
    case 1152:  /* *addv2di3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1143:  /* *addv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH_Q;
        }

    case 1420:  /* neon_vpadd_internalv2si */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1418:  /* neon_vpadd_internalv8qi */
    case 1157:  /* *subv2si3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1153:  /* *subv8qi3_neon */
    case 1146:  /* *addv2si3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1142:  /* *addv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH;
        }

    case 1141:  /* neon_vec_extractv2didi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1136:  /* neon_vec_extractv16qiqi */
    case 1135:  /* vec_extractv2sfsf */
    case 1134:  /* vec_extractv2sisi */
    case 1133:  /* vec_extractv4bfbf */
    case 1132:  /* vec_extractv4hfhf */
    case 1131:  /* vec_extractv4hihi */
    case 1130:  /* vec_extractv8qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_E;
        }

    case 1129:  /* vec_setv2di_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1124:  /* vec_setv16qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 1123:  /* vec_setv2sf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1118:  /* vec_setv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_F;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_B;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }
      else if (!((1ULL << which_alternative) & 0x1ffULL))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_D;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_F;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_TO_GP;
        }
      else if (((1ULL << which_alternative) & 0x90ULL))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_B;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 768:  /* *thumb2_movsf_vfp */
    case 767:  /* *movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 7)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 10)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (!((1ULL << which_alternative) & 0x7ffULL))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 12)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (which_alternative == 13)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 6848:  /* *p *arm_movsi_vfp */
    case 758:  /* *arm_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 9)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (!((1ULL << which_alternative) & 0x3ffULL))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 531:  /* *iwmmxt_movsi_insn */
    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 13)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if (!((1ULL << which_alternative) & 0x3fffULL))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 522:  /* mve_vshlq_uv4si */
    case 521:  /* mve_vshlq_sv4si */
    case 518:  /* mve_vshlq_uv8hi */
    case 517:  /* mve_vshlq_sv8hi */
    case 514:  /* mve_vshlq_uv16qi */
    case 513:  /* mve_vshlq_sv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;
        }

    case 520:  /* mve_vshlq_uv2si */
    case 519:  /* mve_vshlq_sv2si */
    case 516:  /* mve_vshlq_uv4hi */
    case 515:  /* mve_vshlq_sv4hi */
    case 512:  /* mve_vshlq_uv8qi */
    case 511:  /* mve_vshlq_sv8qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_ABD) || (cached_type == TYPE_NEON_ABD_LONG))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ABD;
        }
      else if (cached_type == TYPE_NEON_ABD_Q)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ABD_Q;
        }
      else if ((cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_ACC;
        }
      else if (cached_type == TYPE_NEON_ARITH_ACC_Q)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_ACC_Q;
        }
      else if ((cached_type == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_ADD_Q) || (cached_type == TYPE_NEON_ADD_LONG) || (cached_type == TYPE_NEON_ADD_WIDEN) || (cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_REDUC_ADD_LONG) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_SUB_Q) || (cached_type == TYPE_NEON_SUB_LONG) || (cached_type == TYPE_NEON_SUB_WIDEN) || (cached_type == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_TST_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else if ((cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_QABS) || (cached_type == TYPE_NEON_QABS_Q) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_QNEG) || (cached_type == TYPE_NEON_QNEG_Q) || (cached_type == TYPE_NEON_QSUB) || (cached_type == TYPE_NEON_QSUB_Q) || (cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_MINMAX_Q) || (cached_type == TYPE_NEON_REDUC_MINMAX) || (cached_type == TYPE_NEON_REDUC_MINMAX_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else if ((cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_MUL_S_LONG) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MULTIPLY;
        }
      else if ((cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MULTIPLY_Q;
        }
      else if ((cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MLA;
        }
      else if ((cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H_Q) || (cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_MLA_Q;
        }
      else if ((cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SAT_MLA_LONG;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SHIFT_ACC_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_ACC;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else if ((cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX;
        }
      else if (cached_type == TYPE_NEON_SHIFT_REG)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC;
        }
      else if (cached_type == TYPE_NEON_SHIFT_REG_Q)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;
        }
      else if (cached_type == TYPE_NEON_SAT_SHIFT_REG)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_COMPLEX;
        }
      else if (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_COMPLEX_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_ABS_S_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_NEGABS;
        }
      else if ((cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_MINMAX_S) || (cached_type == TYPE_NEON_FP_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH;
        }
      else if ((cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_TO_INT_S) || (cached_type == TYPE_NEON_INT_TO_FP_S))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_CVT_INT;
        }
      else if ((cached_type == TYPE_NEON_FP_TO_INT_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_CVT_INT_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_CVT_NARROW_S_Q) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_H))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_CVT16;
        }
      else if ((cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MUL;
        }
      else if ((cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MUL_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_MLA_S) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MLA;
        }
      else if ((cached_type == TYPE_NEON_FP_MLA_S_Q) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_MLA_Q;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RSQRTE_S))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_RECPE_RSQRTE;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_S_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q;
        }
      else if ((cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CNT) || (cached_type == TYPE_NEON_REV) || (cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL2) || (cached_type == TYPE_NEON_ZIP) || (cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_DUP_Q) || (cached_type == TYPE_NEON_EXT) || (cached_type == TYPE_NEON_EXT_Q) || (cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_MOVE_Q) || (cached_type == TYPE_NEON_MOVE_NARROW_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS;
        }
      else if ((cached_type == TYPE_NEON_BSL_Q) || (cached_type == TYPE_NEON_CLS_Q) || (cached_type == TYPE_NEON_CNT_Q) || (cached_type == TYPE_NEON_REV_Q) || (cached_type == TYPE_NEON_PERMUTE_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_BITOPS_Q;
        }
      else if (cached_type == TYPE_NEON_FROM_GP)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP;
        }
      else if (cached_type == TYPE_NEON_FROM_GP_Q)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_FROM_GP_Q;
        }
      else if ((cached_type == TYPE_NEON_TBL3) || (cached_type == TYPE_NEON_TBL4))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_TBL3_TBL4;
        }
      else if (cached_type == TYPE_NEON_ZIP_Q)
        {
	  return CORTEX_A15_NEON_TYPE_NEON_ZIP_Q;
        }
      else if ((cached_type == TYPE_NEON_TO_GP) || (cached_type == TYPE_NEON_TO_GP_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_TO_GP;
        }
      else if ((cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD) || (cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_1REG_Q) || (cached_type == TYPE_NEON_LOAD1_2REG) || (cached_type == TYPE_NEON_LOAD1_2REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_3REG) || (cached_type == TYPE_NEON_LOAD1_3REG_Q) || (cached_type == TYPE_NEON_LOAD1_4REG) || (cached_type == TYPE_NEON_LOAD1_4REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_B;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_ONE_LANE) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_2REG) || (cached_type == TYPE_NEON_LOAD2_2REG_Q) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;
        }
      else if ((cached_type == TYPE_NEON_LOAD2_4REG) || (cached_type == TYPE_NEON_LOAD2_4REG_Q) || (cached_type == TYPE_NEON_LOAD3_3REG) || (cached_type == TYPE_NEON_LOAD3_3REG_Q) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD4_4REG) || (cached_type == TYPE_NEON_LOAD4_4REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_D;
        }
      else if ((cached_type == TYPE_NEON_LOAD2_ONE_LANE) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_E;
        }
      else if ((cached_type == TYPE_NEON_LOAD4_ONE_LANE) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_LOAD_F;
        }
      else if ((cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED) || (cached_type == TYPE_NEON_STORE1_1REG) || (cached_type == TYPE_NEON_STORE1_1REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_A;
        }
      else if ((cached_type == TYPE_NEON_STORE1_2REG) || (cached_type == TYPE_NEON_STORE1_2REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_B;
        }
      else if ((cached_type == TYPE_NEON_STORE1_3REG) || (cached_type == TYPE_NEON_STORE1_3REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_C;
        }
      else if ((cached_type == TYPE_NEON_STORE1_4REG) || (cached_type == TYPE_NEON_STORE1_4REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_D;
        }
      else if ((cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE2_ONE_LANE) || (cached_type == TYPE_NEON_STORE2_ONE_LANE_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_E;
        }
      else if ((cached_type == TYPE_NEON_STORE2_2REG) || (cached_type == TYPE_NEON_STORE2_2REG_Q) || (cached_type == TYPE_NEON_STORE3_ONE_LANE) || (cached_type == TYPE_NEON_STORE3_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE4_ONE_LANE) || (cached_type == TYPE_NEON_STORE4_ONE_LANE_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_F;
        }
      else if ((cached_type == TYPE_NEON_STORE2_4REG) || (cached_type == TYPE_NEON_STORE2_4REG_Q) || (cached_type == TYPE_NEON_STORE4_4REG) || (cached_type == TYPE_NEON_STORE4_4REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_G;
        }
      else if ((cached_type == TYPE_NEON_STORE3_3REG) || (cached_type == TYPE_NEON_STORE3_3REG_Q))
        {
	  return CORTEX_A15_NEON_TYPE_NEON_STORE_H;
        }
      else
        {
	  return CORTEX_A15_NEON_TYPE_UNKNOWN;
        }

    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
      return CORTEX_A15_NEON_TYPE_NEON_STORE_H;

    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
      return CORTEX_A15_NEON_TYPE_NEON_STORE_G;

    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
      return CORTEX_A15_NEON_TYPE_NEON_STORE_F;

    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
      return CORTEX_A15_NEON_TYPE_NEON_STORE_E;

    case 2562:  /* neon_vst1v2di */
    case 2561:  /* neon_vst1di */
    case 2560:  /* neon_vst1v4sf */
    case 2559:  /* neon_vst1v2sf */
    case 2558:  /* neon_vst1v8bf */
    case 2557:  /* neon_vst1v4bf */
    case 2556:  /* neon_vst1v8hf */
    case 2555:  /* neon_vst1v4hf */
    case 2554:  /* neon_vst1v4si */
    case 2553:  /* neon_vst1v2si */
    case 2552:  /* neon_vst1v8hi */
    case 2551:  /* neon_vst1v4hi */
    case 2550:  /* neon_vst1v16qi */
    case 2549:  /* neon_vst1v8qi */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1070:  /* unaligned_storev8qi */
    case 883:  /* *push_multi_vfp */
      return CORTEX_A15_NEON_TYPE_NEON_STORE_A;

    case 2730:  /* neon_vld4_lanev8bf */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2726:  /* neon_vld4_lanev8hi */
    case 2725:  /* neon_vld4_lanev2sf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2720:  /* neon_vld4_lanev8qi */
      return CORTEX_A15_NEON_TYPE_NEON_LOAD_F;

    case 2738:  /* neon_vld4_dupv8bf */
    case 2670:  /* neon_vld3_dupv8bf */
    case 2600:  /* neon_vld2_lanev8bf */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2596:  /* neon_vld2_lanev8hi */
    case 2595:  /* neon_vld2_lanev2sf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2590:  /* neon_vld2_lanev8qi */
      return CORTEX_A15_NEON_TYPE_NEON_LOAD_E;

    case 2719:  /* neon_vld4qbv4sf */
    case 2718:  /* neon_vld4qbv4si */
    case 2717:  /* neon_vld4qbv8bf */
    case 2716:  /* neon_vld4qbv8hf */
    case 2715:  /* neon_vld4qbv8hi */
    case 2714:  /* neon_vld4qbv16qi */
    case 2713:  /* neon_vld4qav4sf */
    case 2712:  /* neon_vld4qav4si */
    case 2711:  /* neon_vld4qav8bf */
    case 2710:  /* neon_vld4qav8hf */
    case 2709:  /* neon_vld4qav8hi */
    case 2708:  /* neon_vld4qav16qi */
    case 2662:  /* neon_vld3_lanev8bf */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2658:  /* neon_vld3_lanev8hi */
    case 2657:  /* neon_vld3_lanev2sf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2652:  /* neon_vld3_lanev8qi */
    case 2651:  /* neon_vld3qbv4sf */
    case 2650:  /* neon_vld3qbv4si */
    case 2649:  /* neon_vld3qbv8bf */
    case 2648:  /* neon_vld3qbv8hf */
    case 2647:  /* neon_vld3qbv8hi */
    case 2646:  /* neon_vld3qbv16qi */
    case 2645:  /* neon_vld3qav4sf */
    case 2644:  /* neon_vld3qav4si */
    case 2643:  /* neon_vld3qav8bf */
    case 2642:  /* neon_vld3qav8hf */
    case 2641:  /* neon_vld3qav8hi */
    case 2640:  /* neon_vld3qav16qi */
      return CORTEX_A15_NEON_TYPE_NEON_LOAD_D;

    case 2608:  /* neon_vld2_dupv8bf */
    case 2589:  /* neon_vld2v4sf */
    case 2588:  /* neon_vld2v4si */
    case 2587:  /* neon_vld2v8bf */
    case 2586:  /* neon_vld2v8hf */
    case 2585:  /* neon_vld2v8hi */
    case 2584:  /* neon_vld2v16qi */
    case 2548:  /* neon_vld1_dupv2di */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2543:  /* neon_vld1_dupv16qi */
    case 2542:  /* neon_vld1_dupv2sf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2537:  /* neon_vld1_dupv8qi */
    case 2536:  /* neon_vld1_lanev2di */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2530:  /* neon_vld1_lanev16qi */
    case 2529:  /* neon_vld1_lanedi */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2523:  /* neon_vld1_lanev8qi */
      return CORTEX_A15_NEON_TYPE_NEON_LOAD_C;

    case 2854:  /* aes_op_protect_neon_vld1v16qi */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2522:  /* neon_vld1v2di */
    case 2521:  /* neon_vld1di */
    case 2520:  /* neon_vld1v4sf */
    case 2519:  /* neon_vld1v2sf */
    case 2518:  /* neon_vld1v8bf */
    case 2517:  /* neon_vld1v4bf */
    case 2516:  /* neon_vld1v8hf */
    case 2515:  /* neon_vld1v4hf */
    case 2514:  /* neon_vld1v4si */
    case 2513:  /* neon_vld1v2si */
    case 2512:  /* neon_vld1v8hi */
    case 2511:  /* neon_vld1v4hi */
    case 2510:  /* neon_vld1v16qi */
    case 2509:  /* neon_vld1v8qi */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1111:  /* *movmisalignv16qi_neon_load */
    case 1103:  /* *movmisaligndi_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1097:  /* *movmisalignv8qi_neon_load */
      return CORTEX_A15_NEON_TYPE_NEON_LOAD_A;

    case 2040:  /* neon_vget_lanev4sf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2031:  /* neon_vget_lanev16qi_sext_internal */
    case 2030:  /* neon_vget_lanev2sf_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2023:  /* neon_vget_lanev8qi_sext_internal */
      return CORTEX_A15_NEON_TYPE_NEON_TO_GP;

    case 2507:  /* *neon_vuzpv8hf_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2490:  /* *neon_vzipv16qi_insn */
      return CORTEX_A15_NEON_TYPE_NEON_ZIP_Q;

    case 2478:  /* neon_vtbx4v8qi */
    case 2477:  /* neon_vtbx3v8qi */
    case 2471:  /* neon_vtbl4v8qi */
    case 2470:  /* neon_vtbl3v8qi */
      return CORTEX_A15_NEON_TYPE_NEON_TBL3_TBL4;

    case 2048:  /* neon_vdup_nv8bf */
    case 2046:  /* neon_vdup_nv8hf */
    case 2044:  /* neon_vdup_nv8hi */
    case 2043:  /* neon_vdup_nv16qi */
      return CORTEX_A15_NEON_TYPE_NEON_FROM_GP_Q;

    case 2047:  /* neon_vdup_nv4bf */
    case 2045:  /* neon_vdup_nv4hf */
    case 2042:  /* neon_vdup_nv4hi */
    case 2041:  /* neon_vdup_nv8qi */
      return CORTEX_A15_NEON_TYPE_NEON_FROM_GP;

    case 2487:  /* *neon_vtrnv8hf_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2261:  /* neon_vbslv2di_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2249:  /* neon_vbslv16qi_internal */
    case 2247:  /* neon_vrev16v16qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2244:  /* neon_vrev32v16qi */
    case 2241:  /* neon_vrev64v2di */
    case 2240:  /* neon_vrev64v4sf */
    case 2238:  /* neon_vrev64v8hf */
    case 2236:  /* neon_vrev64v4si */
    case 2234:  /* neon_vrev64v8hi */
    case 2232:  /* neon_vrev64v16qi */
    case 2079:  /* *neon_vswpv2di */
    case 2077:  /* *neon_vswpv4sf */
    case 2075:  /* *neon_vswpv8bf */
    case 2073:  /* *neon_vswpv8hf */
    case 2071:  /* *neon_vswpv4si */
    case 2069:  /* *neon_vswpv8hi */
    case 2067:  /* *neon_vswpv16qi */
    case 2012:  /* popcountv16qi2 */
    case 2010:  /* neon_vclzv4si */
    case 2008:  /* neon_vclzv8hi */
    case 2006:  /* neon_vclzv16qi */
    case 2004:  /* neon_vclsv4si */
    case 2002:  /* neon_vclsv8hi */
    case 2000:  /* neon_vclsv16qi */
    case 1914:  /* neon_bswapv2di */
    case 1913:  /* neon_bswapv4si */
    case 1911:  /* neon_bswapv8hi */
      return CORTEX_A15_NEON_TYPE_NEON_BITOPS_Q;

    case 2816:  /* neon_vec_pack_trunc_v2di */
    case 2815:  /* neon_vec_pack_trunc_v4si */
    case 2814:  /* neon_vec_pack_trunc_v8hi */
    case 2804:  /* neon_unpacku_v2si */
    case 2803:  /* neon_unpacks_v2si */
    case 2802:  /* neon_unpacku_v4hi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2799:  /* neon_unpacks_v8qi */
    case 2508:  /* *neon_vuzpv4hf_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2489:  /* *neon_vzipv8qi_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2476:  /* neon_vtbx2v8qi */
    case 2475:  /* neon_vtbx1v8qi */
    case 2469:  /* neon_vtbl2v8qi */
    case 2468:  /* neon_vtbl1v8qi */
    case 2260:  /* neon_vbsldi_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2248:  /* neon_vbslv8qi_internal */
    case 2246:  /* neon_vrev16v8qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2242:  /* neon_vrev32v8qi */
    case 2239:  /* neon_vrev64v2sf */
    case 2237:  /* neon_vrev64v4hf */
    case 2235:  /* neon_vrev64v2si */
    case 2233:  /* neon_vrev64v4hi */
    case 2231:  /* neon_vrev64v8qi */
    case 2230:  /* neon_vextv2di */
    case 2229:  /* neon_vextdi */
    case 2228:  /* neon_vextv4sf */
    case 2227:  /* neon_vextv2sf */
    case 2226:  /* neon_vextv8bf */
    case 2225:  /* neon_vextv4bf */
    case 2224:  /* neon_vextv8hf */
    case 2223:  /* neon_vextv4hf */
    case 2222:  /* neon_vextv4si */
    case 2221:  /* neon_vextv2si */
    case 2220:  /* neon_vextv8hi */
    case 2219:  /* neon_vextv4hi */
    case 2218:  /* neon_vextv16qi */
    case 2217:  /* neon_vextv8qi */
    case 2078:  /* *neon_vswpdi */
    case 2076:  /* *neon_vswpv2sf */
    case 2074:  /* *neon_vswpv4bf */
    case 2072:  /* *neon_vswpv4hf */
    case 2070:  /* *neon_vswpv2si */
    case 2068:  /* *neon_vswpv4hi */
    case 2066:  /* *neon_vswpv8qi */
    case 2065:  /* neon_vdup_lanev8bf_internal */
    case 2064:  /* neon_vdup_lanev4bf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 2011:  /* popcountv8qi2 */
    case 2009:  /* neon_vclzv2si */
    case 2007:  /* neon_vclzv4hi */
    case 2005:  /* neon_vclzv8qi */
    case 2003:  /* neon_vclsv2si */
    case 2001:  /* neon_vclsv4hi */
    case 1999:  /* neon_vclsv8qi */
    case 1912:  /* neon_bswapv2si */
    case 1910:  /* neon_bswapv4hi */
    case 1291:  /* one_cmplv2di2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1289:  /* one_cmplv2sf2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1282:  /* one_cmplv16qi2_neon */
    case 1281:  /* one_cmplv8qi2_neon */
      return CORTEX_A15_NEON_TYPE_NEON_BITOPS;

    case 2022:  /* neon_vrsqrtev4sf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2018:  /* neon_vrecpev4sf */
    case 2017:  /* neon_vrecpev4si */
    case 2013:  /* neon_vrecpev8hf */
    case 1324:  /* neon_vrsqrtev8hf */
      return CORTEX_A15_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q;

    case 2020:  /* neon_vrsqrtev2sf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2016:  /* neon_vrecpev2sf */
    case 2015:  /* neon_vrecpev2si */
    case 2014:  /* neon_vrecpev4hf */
    case 1325:  /* neon_vrsqrtev4hf */
      return CORTEX_A15_NEON_TYPE_NEON_FP_RECPE_RSQRTE;

    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1180:  /* mulv8hf3addv8hf_neon */
      return CORTEX_A15_NEON_TYPE_NEON_FP_MLA_Q;

    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1190:  /* fmav2sf4 */
    case 1181:  /* mulv4hf3addv4hf_neon */
      return CORTEX_A15_NEON_TYPE_NEON_FP_MLA;

    case 2169:  /* neon_vmul_lanev8hf */
      return CORTEX_A15_NEON_TYPE_NEON_FP_MUL_Q;

    case 2170:  /* neon_vmul_lanev4hf */
      return CORTEX_A15_NEON_TYPE_NEON_FP_MUL;

    case 2836:  /* neon_vbfcvtv4sf_highv8bf */
    case 2835:  /* neon_vbfcvtv4sfv8bf */
    case 2834:  /* neon_vbfcvtv4sfv4bf */
    case 2104:  /* neon_vcvtv4hfv4sf */
    case 2103:  /* neon_vcvtv4sfv4hf */
      return CORTEX_A15_NEON_TYPE_NEON_FP_CVT16;

    case 2136:  /* neon_vcvtpuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2128:  /* neon_vcvtu_nv8hi */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2123:  /* neon_vcvts_nv4si */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2108:  /* neon_vcvtuv8hi */
    case 2107:  /* neon_vcvtsv8hi */
    case 2102:  /* neon_vcvtuv4si */
    case 2101:  /* neon_vcvtsv4si */
    case 2098:  /* neon_vcvtuv4sf */
    case 2097:  /* neon_vcvtsv4sf */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2088:  /* floatv4siv4sf2 */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1220:  /* neon_vcvtpv4sfv4si */
      return CORTEX_A15_NEON_TYPE_NEON_FP_CVT_INT_Q;

    case 2144:  /* neon_vcvtpuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2126:  /* neon_vcvtu_nv4hi */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2121:  /* neon_vcvts_nv2si */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2106:  /* neon_vcvtuv4hi */
    case 2105:  /* neon_vcvtsv4hi */
    case 2100:  /* neon_vcvtuv2si */
    case 2099:  /* neon_vcvtsv2si */
    case 2096:  /* neon_vcvtuv2sf */
    case 2095:  /* neon_vcvtsv2sf */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2087:  /* floatv2siv2sf2 */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1214:  /* neon_vcvtpv2sfv2si */
      return CORTEX_A15_NEON_TYPE_NEON_FP_CVT_INT;

    case 2824:  /* neon_vabdv4sf_3 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2818:  /* neon_vabdv8hf_2 */
    case 1785:  /* neon_vabdfv4sf */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1404:  /* quad_halves_plusv4sf */
      return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH_Q;

    case 2823:  /* neon_vabdv2sf_3 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2817:  /* neon_vabdv4hf_2 */
    case 1895:  /* neon_vpminfv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1893:  /* neon_vpminfv2sf */
    case 1892:  /* neon_vpmaxfv2sf */
    case 1855:  /* fminv4sf3 */
    case 1854:  /* fmaxv4sf3 */
    case 1853:  /* fminv2sf3 */
    case 1852:  /* fmaxv2sf3 */
    case 1851:  /* neon_vminnmv4sf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1849:  /* neon_vminnmv2sf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1847:  /* neon_vminnmv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1845:  /* neon_vminnmv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1841:  /* neon_vminfv4hf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1839:  /* neon_vminfv8hf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1837:  /* neon_vminfv4sf */
    case 1836:  /* neon_vmaxfv4sf */
    case 1835:  /* neon_vminfv2sf */
    case 1834:  /* neon_vmaxfv2sf */
    case 1784:  /* neon_vabdfv2sf */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1690:  /* neon_vceqv2sf_insn_unspec */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1405:  /* quad_halves_sminv4sf */
      return CORTEX_A15_NEON_TYPE_NEON_FP_ARITH;

    case 2467:  /* neon_vsli_nv2di */
    case 2465:  /* neon_vsli_nv4si */
    case 2463:  /* neon_vsli_nv8hi */
    case 2461:  /* neon_vsli_nv16qi */
    case 2459:  /* neon_vsri_nv2di */
    case 2457:  /* neon_vsri_nv4si */
    case 2455:  /* neon_vsri_nv8hi */
    case 2453:  /* neon_vsri_nv16qi */
    case 1379:  /* ashlv2di3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1372:  /* ashlv2di3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1367:  /* ashlv16qi3_signed */
      return CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q;

    case 2466:  /* neon_vsli_ndi */
    case 2464:  /* neon_vsli_nv2si */
    case 2462:  /* neon_vsli_nv4hi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2458:  /* neon_vsri_ndi */
    case 2456:  /* neon_vsri_nv2si */
    case 2454:  /* neon_vsri_nv4hi */
    case 2452:  /* neon_vsri_nv8qi */
    case 1377:  /* ashlv2si3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1370:  /* ashlv2si3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1366:  /* ashlv8qi3_signed */
      return CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC;

    case 2413:  /* neon_vqshlu_nv2di */
    case 2412:  /* neon_vqshlu_ndi */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2381:  /* neon_vqrshrun_nv2di */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2325:  /* neon_vqrshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2322:  /* neon_vqshlsv2di */
    case 2321:  /* neon_vqrshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2318:  /* neon_vqshlsdi */
    case 2317:  /* neon_vqrshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2314:  /* neon_vqshlsv4si */
    case 2313:  /* neon_vqrshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2310:  /* neon_vqshlsv2si */
    case 2309:  /* neon_vqrshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2305:  /* neon_vqrshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2298:  /* neon_vqshlsv16qi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2294:  /* neon_vqshlsv8qi */
    case 2156:  /* neon_vqmovunv2di */
    case 2155:  /* neon_vqmovunv4si */
    case 2154:  /* neon_vqmovunv8hi */
    case 2153:  /* neon_vqmovnuv2di */
    case 2152:  /* neon_vqmovnsv2di */
    case 2151:  /* neon_vqmovnuv4si */
    case 2150:  /* neon_vqmovnsv4si */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2148:  /* neon_vqmovnsv8hi */
      return CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX;

    case 2840:  /* neon_vbfcvt_highv8bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2798:  /* neon_vec_ushiftl_v2si */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2419:  /* neon_vshllu_nv2si */
    case 2418:  /* neon_vshlls_nv2si */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2389:  /* neon_vshl_nv2di */
    case 2388:  /* neon_vshl_ndi */
    case 2387:  /* neon_vshl_nv4si */
    case 2386:  /* neon_vshl_nv2si */
    case 2385:  /* neon_vshl_nv8hi */
    case 2384:  /* neon_vshl_nv4hi */
    case 2383:  /* neon_vshl_nv16qi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2363:  /* neon_vrshrn_nv2di */
    case 2362:  /* neon_vshrn_nv2di */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2360:  /* neon_vshrn_nv4si */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2357:  /* neon_vrshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2354:  /* neon_vshrs_nv2di */
    case 2353:  /* neon_vrshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2350:  /* neon_vshrs_ndi */
    case 2349:  /* neon_vrshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2346:  /* neon_vshrs_nv4si */
    case 2345:  /* neon_vrshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2342:  /* neon_vshrs_nv2si */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2293:  /* neon_vrshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2290:  /* neon_vshlsv2di */
    case 2289:  /* neon_vrshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2287:  /* neon_vshludi */
    case 2286:  /* neon_vshlsdi */
    case 2285:  /* neon_vrshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2282:  /* neon_vshlsv4si */
    case 2281:  /* neon_vrshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2278:  /* neon_vshlsv2si */
    case 2277:  /* neon_vrshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2274:  /* neon_vshlsv8hi */
    case 2273:  /* neon_vrshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2270:  /* neon_vshlsv4hi */
    case 2269:  /* neon_vrshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2266:  /* neon_vshlsv16qi */
    case 2265:  /* neon_vrshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2262:  /* neon_vshlsv8qi */
    case 2162:  /* neon_vmovluv2si */
    case 2161:  /* neon_vmovlsv2si */
    case 2160:  /* neon_vmovluv4hi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2158:  /* neon_vmovluv8qi */
    case 2157:  /* neon_vmovlsv8qi */
    case 2147:  /* neon_vmovnv2di */
    case 2146:  /* neon_vmovnv4si */
    case 2145:  /* neon_vmovnv8hi */
    case 1365:  /* vlshrv4si3_imm */
    case 1364:  /* vlshrv2si3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1355:  /* vashrv16qi3_imm */
    case 1354:  /* vashrv8qi3_imm */
      return CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_BASIC;

    case 2451:  /* neon_vrsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2448:  /* neon_vsras_nv2di */
    case 2447:  /* neon_vrsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2444:  /* neon_vsras_ndi */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2440:  /* neon_vsras_nv4si */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2436:  /* neon_vsras_nv2si */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2424:  /* neon_vsras_nv16qi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2420:  /* neon_vsras_nv8qi */
      return CORTEX_A15_NEON_TYPE_NEON_SHIFT_ACC;

    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1588:  /* neon_vqdmlalv2si */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
      return CORTEX_A15_NEON_TYPE_NEON_SAT_MLA_LONG;

    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
      return CORTEX_A15_NEON_TYPE_NEON_MLA_Q;

    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
      return CORTEX_A15_NEON_TYPE_NEON_MLA;

    case 2184:  /* neon_vqrdmulh_lanev2si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
    case 1517:  /* neon_vmulfv8hf */
      return CORTEX_A15_NEON_TYPE_NEON_MULTIPLY_Q;

    case 2810:  /* neon_vec_umult_v2si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2808:  /* neon_vec_umult_v4hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2806:  /* neon_vec_umult_v8qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
    case 1601:  /* neon_vqdmullv2si */
    case 1600:  /* neon_vqdmullv4hi */
    case 1599:  /* neon_vmullpv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1597:  /* neon_vmullsv2si */
    case 1596:  /* neon_vmullpv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1594:  /* neon_vmullsv4hi */
    case 1593:  /* neon_vmullpv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1591:  /* neon_vmullsv8qi */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
    case 1518:  /* neon_vmulfv4hf */
      return CORTEX_A15_NEON_TYPE_NEON_MULTIPLY;

    case 1998:  /* neon_vqnegv4si */
    case 1997:  /* neon_vqnegv2si */
    case 1996:  /* neon_vqnegv8hi */
    case 1995:  /* neon_vqnegv4hi */
    case 1994:  /* neon_vqnegv16qi */
    case 1993:  /* neon_vqnegv8qi */
    case 1909:  /* neon_vqabsv4si */
    case 1908:  /* neon_vqabsv2si */
    case 1907:  /* neon_vqabsv8hi */
    case 1906:  /* neon_vqabsv4hi */
    case 1905:  /* neon_vqabsv16qi */
    case 1904:  /* neon_vqabsv8qi */
    case 1891:  /* neon_vpminuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1888:  /* neon_vpmaxsv2si */
    case 1887:  /* neon_vpminuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1883:  /* neon_vpminuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1843:  /* neon_vpminfv4hf */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1833:  /* neon_vminuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1830:  /* neon_vmaxsv4si */
    case 1829:  /* neon_vminuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1826:  /* neon_vmaxsv2si */
    case 1825:  /* neon_vminuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1821:  /* neon_vminuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1817:  /* neon_vminuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1814:  /* neon_vmaxsv16qi */
    case 1813:  /* neon_vminuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1810:  /* neon_vmaxsv8qi */
    case 1731:  /* neon_vcgeuv4si */
    case 1730:  /* neon_vcgtuv4si */
    case 1729:  /* neon_vcgeuv2si */
    case 1728:  /* neon_vcgtuv2si */
    case 1727:  /* neon_vcgeuv8hi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1725:  /* neon_vcgeuv4hi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1722:  /* neon_vcgtuv16qi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1720:  /* neon_vcgtuv8qi */
    case 1649:  /* neon_vrsubhnv2di */
    case 1648:  /* neon_vsubhnv2di */
    case 1647:  /* neon_vrsubhnv4si */
    case 1646:  /* neon_vsubhnv4si */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1644:  /* neon_vsubhnv8hi */
    case 1643:  /* neon_vhsubuv4si */
    case 1642:  /* neon_vhsubsv4si */
    case 1641:  /* neon_vhsubuv2si */
    case 1640:  /* neon_vhsubsv2si */
    case 1639:  /* neon_vhsubuv8hi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1637:  /* neon_vhsubuv4hi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1634:  /* neon_vhsubsv16qi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1632:  /* neon_vhsubsv8qi */
    case 1631:  /* neon_vqsubuv2di */
    case 1630:  /* neon_vqsubsv2di */
    case 1629:  /* neon_vqsubudi */
    case 1628:  /* neon_vqsubsdi */
    case 1627:  /* neon_vqsubuv4si */
    case 1626:  /* neon_vqsubsv4si */
    case 1625:  /* neon_vqsubuv2si */
    case 1624:  /* neon_vqsubsv2si */
    case 1623:  /* neon_vqsubuv8hi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1621:  /* neon_vqsubuv4hi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1618:  /* neon_vqsubsv16qi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1616:  /* neon_vqsubsv8qi */
    case 1512:  /* neon_vraddhnv2di */
    case 1511:  /* neon_vaddhnv2di */
    case 1510:  /* neon_vraddhnv4si */
    case 1509:  /* neon_vaddhnv4si */
    case 1508:  /* neon_vraddhnv8hi */
    case 1507:  /* neon_vaddhnv8hi */
    case 1506:  /* neon_vqadduv2di */
    case 1505:  /* neon_vqaddsv2di */
    case 1504:  /* neon_vqaddudi */
    case 1503:  /* neon_vqaddsdi */
    case 1502:  /* neon_vqadduv4si */
    case 1501:  /* neon_vqaddsv4si */
    case 1500:  /* neon_vqadduv2si */
    case 1499:  /* neon_vqaddsv2si */
    case 1498:  /* neon_vqadduv8hi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1496:  /* neon_vqadduv4hi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1494:  /* neon_vqadduv16qi */
    case 1493:  /* neon_vqaddsv16qi */
    case 1492:  /* neon_vqadduv8qi */
    case 1491:  /* neon_vqaddsv8qi */
    case 1490:  /* neon_vhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1486:  /* neon_vhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1483:  /* neon_vrhaddsv2si */
    case 1482:  /* neon_vhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1474:  /* neon_vhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1467:  /* neon_vrhaddsv8qi */
    case 1452:  /* *us_subv2sf_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1445:  /* *ss_subv8qi_neon */
    case 1444:  /* *us_addv2sf_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1437:  /* *ss_addv8qi_neon */
    case 1436:  /* neon_vpumaxv2si */
    case 1435:  /* neon_vpumaxv4hi */
    case 1434:  /* neon_vpumaxv8qi */
    case 1433:  /* neon_vpuminv2si */
    case 1432:  /* neon_vpuminv4hi */
    case 1431:  /* neon_vpuminv8qi */
    case 1416:  /* quad_halves_umaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1408:  /* quad_halves_sminv8hi */
    case 1403:  /* quad_halves_umaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1400:  /* quad_halves_sminv4si */
    case 1337:  /* *umaxv4si3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1327:  /* *uminv16qi3_neon */
    case 1326:  /* *uminv8qi3_neon */
    case 1311:  /* neon_negv4hf2 */
    case 1310:  /* neon_absv4hf2 */
    case 1309:  /* neon_negv8hf2 */
    case 1308:  /* neon_absv8hf2 */
      return CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX;

    case 1867:  /* neon_vpaddluv4si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1865:  /* neon_vpaddluv2si */
    case 1864:  /* neon_vpaddlsv2si */
    case 1863:  /* neon_vpaddluv8hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1856:  /* neon_vpaddlsv8qi */
    case 1769:  /* neon_vtst_combinev4si */
    case 1768:  /* neon_vtst_combinev2si */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1765:  /* neon_vtst_combinev16qi */
    case 1764:  /* neon_vtst_combinev8qi */
    case 1615:  /* neon_vsubwuv2si */
    case 1614:  /* neon_vsubwsv2si */
    case 1613:  /* neon_vsubwuv4hi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1610:  /* neon_vsubwsv8qi */
    case 1609:  /* neon_vsubluv2si */
    case 1608:  /* neon_vsublsv2si */
    case 1607:  /* neon_vsubluv4hi */
    case 1606:  /* neon_vsublsv4hi */
    case 1605:  /* neon_vsubluv8qi */
    case 1604:  /* neon_vsublsv8qi */
    case 1466:  /* neon_vaddwuv2si */
    case 1465:  /* neon_vaddwsv2si */
    case 1464:  /* neon_vaddwuv4hi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1461:  /* neon_vaddwsv8qi */
    case 1460:  /* neon_vaddluv2si */
    case 1459:  /* neon_vaddlsv2si */
    case 1458:  /* neon_vaddluv4hi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1456:  /* neon_vaddluv8qi */
    case 1455:  /* neon_vaddlsv8qi */
    case 1422:  /* neon_vpaddv4hf */
    case 1417:  /* arm_reduc_plus_internal_v2di */
    case 1412:  /* quad_halves_plusv16qi */
    case 1407:  /* quad_halves_plusv8hi */
    case 1399:  /* quad_halves_plusv4si */
    case 1398:  /* widen_usumv2si3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
    case 1280:  /* xorv2di3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1278:  /* xorv2sf3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1247:  /* andv2di3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1242:  /* andv4si3_neon */
    case 1241:  /* andv2si3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1227:  /* iorv16qi3_neon */
    case 1226:  /* iorv8qi3_neon */
      return CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC;

    case 1803:  /* neon_vabauv4si */
    case 1802:  /* neon_vabasv4si */
    case 1799:  /* neon_vabauv8hi */
    case 1798:  /* neon_vabasv8hi */
    case 1795:  /* neon_vabauv16qi */
    case 1794:  /* neon_vabasv16qi */
      return CORTEX_A15_NEON_TYPE_NEON_ARITH_ACC_Q;

    case 1879:  /* neon_vpadaluv4si */
    case 1878:  /* neon_vpadalsv4si */
    case 1877:  /* neon_vpadaluv2si */
    case 1876:  /* neon_vpadalsv2si */
    case 1875:  /* neon_vpadaluv8hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1868:  /* neon_vpadalsv8qi */
    case 1809:  /* neon_vabaluv2si */
    case 1808:  /* neon_vabalsv2si */
    case 1807:  /* neon_vabaluv4hi */
    case 1806:  /* neon_vabalsv4hi */
    case 1805:  /* neon_vabaluv8qi */
    case 1804:  /* neon_vabalsv8qi */
    case 1801:  /* neon_vabauv2si */
    case 1800:  /* neon_vabasv2si */
    case 1797:  /* neon_vabauv4hi */
    case 1796:  /* neon_vabasv4hi */
    case 1793:  /* neon_vabauv8qi */
    case 1792:  /* neon_vabasv8qi */
      return CORTEX_A15_NEON_TYPE_NEON_ARITH_ACC;

    case 1782:  /* neon_vabdv8hf */
    case 1781:  /* neon_vabduv4si */
    case 1780:  /* neon_vabdsv4si */
    case 1777:  /* neon_vabduv8hi */
    case 1776:  /* neon_vabdsv8hi */
    case 1773:  /* neon_vabduv16qi */
    case 1772:  /* neon_vabdsv16qi */
      return CORTEX_A15_NEON_TYPE_NEON_ABD_Q;

    case 1791:  /* neon_vabdluv2si */
    case 1790:  /* neon_vabdlsv2si */
    case 1789:  /* neon_vabdluv4hi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1787:  /* neon_vabdluv8qi */
    case 1786:  /* neon_vabdlsv8qi */
    case 1783:  /* neon_vabdv4hf */
    case 1779:  /* neon_vabduv2si */
    case 1778:  /* neon_vabdsv2si */
    case 1775:  /* neon_vabduv4hi */
    case 1774:  /* neon_vabdsv4hi */
    case 1771:  /* neon_vabduv8qi */
    case 1770:  /* neon_vabdsv8qi */
      return CORTEX_A15_NEON_TYPE_NEON_ABD;

    default:
      return CORTEX_A15_NEON_TYPE_UNKNOWN;

    }
}

enum attr_cortex_a9_neon_type
get_attr_cortex_a9_neon_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VMOV;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR_2_MCRR;
        }

    case 2745:  /* neon_vst4di */
      if ((64) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }

    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
      if ((32) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }

    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }

    case 2739:  /* neon_vst4v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }

    case 2677:  /* neon_vst3di */
      if ((64) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST3_VST4_LANE;
        }

    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
      if ((32) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST3_VST4_LANE;
        }

    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST3_VST4_LANE;
        }

    case 2671:  /* neon_vst3v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST3_VST4_LANE;
        }

    case 2737:  /* neon_vld4_dupdi */
    case 2669:  /* neon_vld3_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_4_REGS;
        }

    case 2736:  /* neon_vld4_dupv2sf */
    case 2735:  /* neon_vld4_dupv2si */
    case 2668:  /* neon_vld3_dupv2sf */
    case 2667:  /* neon_vld3_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_4_REGS;
        }

    case 2734:  /* neon_vld4_dupv4bf */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2732:  /* neon_vld4_dupv4hi */
    case 2666:  /* neon_vld3_dupv4bf */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2664:  /* neon_vld3_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_4_REGS;
        }

    case 2731:  /* neon_vld4_dupv8qi */
    case 2663:  /* neon_vld3_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_4_REGS;
        }

    case 2707:  /* neon_vld4di */
    case 2639:  /* neon_vld3di */
      if ((64) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4;
        }

    case 2706:  /* neon_vld4v2sf */
    case 2705:  /* neon_vld4v2si */
    case 2638:  /* neon_vld3v2sf */
    case 2637:  /* neon_vld3v2si */
      if ((32) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4;
        }

    case 2704:  /* neon_vld4v4bf */
    case 2703:  /* neon_vld4v4hf */
    case 2702:  /* neon_vld4v4hi */
    case 2636:  /* neon_vld3v4bf */
    case 2635:  /* neon_vld3v4hf */
    case 2634:  /* neon_vld3v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4;
        }

    case 2701:  /* neon_vld4v8qi */
    case 2633:  /* neon_vld3v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4;
        }

    case 2615:  /* neon_vst2di */
      if ((64) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE;
        }

    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
      if ((32) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE;
        }

    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE;
        }

    case 2609:  /* neon_vst2v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE;
        }

    case 2607:  /* neon_vld2_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }

    case 2606:  /* neon_vld2_dupv2sf */
    case 2605:  /* neon_vld2_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }

    case 2604:  /* neon_vld2_dupv4bf */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2602:  /* neon_vld2_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }

    case 2601:  /* neon_vld2_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }

    case 2210:  /* neon_vmls_lanev4sf */
    case 2198:  /* neon_vmla_lanev4sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;
        }

    case 2209:  /* neon_vmls_lanev4si */
    case 2197:  /* neon_vmla_lanev4si */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;
        }

    case 2208:  /* neon_vmls_lanev8hi */
    case 2196:  /* neon_vmla_lanev8hi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;
        }

    case 2207:  /* neon_vmls_lanev2sf */
    case 2195:  /* neon_vmla_lanev2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR;
        }

    case 2206:  /* neon_vmls_lanev2si */
    case 2194:  /* neon_vmla_lanev2si */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR;
        }

    case 2205:  /* neon_vmls_lanev4hi */
    case 2193:  /* neon_vmla_lanev4hi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR;
        }

    case 2168:  /* neon_vmul_lanev4sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_QQD;
        }

    case 2167:  /* neon_vmul_lanev4si */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_QQD;
        }

    case 2166:  /* neon_vmul_lanev8hi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_QQD;
        }

    case 2165:  /* neon_vmul_lanev2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_DDD;
        }

    case 2164:  /* neon_vmul_lanev2si */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_DDD;
        }

    case 2163:  /* neon_vmul_lanev4hi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_DDD;
        }

    case 2052:  /* neon_vdup_nv4sf */
    case 2051:  /* neon_vdup_nv4si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_BP_SIMPLE;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR_2_MCRR;
        }

    case 2050:  /* neon_vdup_nv2sf */
    case 2049:  /* neon_vdup_nv2si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_BP_SIMPLE;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR;
        }

    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
      if ((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_ZERO_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_4;
        }
      else if (cached_type == TYPE_NEON_COMPARE_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_UNKNOWN;
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if ((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_ZERO)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_4;
        }
      else if (cached_type == TYPE_NEON_COMPARE)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_UNKNOWN;
        }

    case 1430:  /* neon_vpsmaxv2sf */
    case 1426:  /* neon_vpsminv2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VSUM;
        }

    case 1429:  /* neon_vpsmaxv2si */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1425:  /* neon_vpsminv2si */
    case 1424:  /* neon_vpsminv4hi */
    case 1423:  /* neon_vpsminv8qi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VSUM;
        }

    case 1421:  /* neon_vpadd_internalv2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VSUM;
        }

    case 1420:  /* neon_vpadd_internalv2si */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1418:  /* neon_vpadd_internalv8qi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VSUM;
        }

    case 1380:  /* neon_load_count */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR;
        }

    case 1353:  /* *smaxv4sf3_neon */
    case 1345:  /* *sminv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1352:  /* *smaxv2sf3_neon */
    case 1344:  /* *sminv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1351:  /* *smaxv4si3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1339:  /* *sminv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1350:  /* *smaxv2si3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1338:  /* *sminv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1307:  /* neon_negv4sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1306:  /* neon_negv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1305:  /* neon_negv4si2 */
    case 1303:  /* neon_negv8hi2 */
    case 1301:  /* neon_negv16qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1304:  /* neon_negv2si2 */
    case 1302:  /* neon_negv4hi2 */
    case 1300:  /* neon_negv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1299:  /* neon_absv4sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_4;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1298:  /* neon_absv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_4;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1297:  /* neon_absv4si2 */
    case 1295:  /* neon_absv8hi2 */
    case 1293:  /* neon_absv16qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_4;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1296:  /* neon_absv2si2 */
    case 1294:  /* neon_absv4hi2 */
    case 1292:  /* neon_absv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_4;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ;
        }

    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD;
        }

    case 1562:  /* neon_vmlsv4si_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1177:  /* mulv4si3addv4si_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ;
        }

    case 1561:  /* neon_vmlsv2si_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1176:  /* mulv2si3addv2si_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD;
        }

    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_8_16;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ;
        }

    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD;
        }

    case 1516:  /* neon_vmulfv4sf */
    case 1171:  /* *mulv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1515:  /* neon_vmulfv2sf */
    case 1170:  /* *mulv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1169:  /* *mulv4si3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1168:  /* *mulv2si3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1514:  /* neon_vmulpv16qi */
    case 1167:  /* *mulv8hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1513:  /* neon_vmulpv8qi */
    case 1166:  /* *mulv4hi3_neon */
    case 1164:  /* *mulv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1603:  /* neon_vsubv4sf_unspec */
    case 1162:  /* *subv4sf3_neon */
    case 1160:  /* *subv8hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_2;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1602:  /* neon_vsubv2sf_unspec */
    case 1161:  /* *subv2sf3_neon */
    case 1159:  /* *subv4hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_2;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1163:  /* *subv2di3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1154:  /* *subv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_2;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1157:  /* *subv2si3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1153:  /* *subv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_2;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1454:  /* neon_vaddv4sf_unspec */
    case 1151:  /* *addv4sf3_neon */
    case 1149:  /* *addv8hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_1;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1453:  /* neon_vaddv2sf_unspec */
    case 1150:  /* *addv2sf3_neon */
    case 1148:  /* *addv4hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_1;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1152:  /* *addv2di3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1143:  /* *addv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_1;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1146:  /* *addv2si3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1142:  /* *addv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_1;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1141:  /* neon_vec_extractv2didi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1136:  /* neon_vec_extractv16qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MRRC;
        }

    case 1135:  /* vec_extractv2sfsf */
    case 1134:  /* vec_extractv2sisi */
    case 1133:  /* vec_extractv4bfbf */
    case 1132:  /* vec_extractv4hfhf */
    case 1131:  /* vec_extractv4hihi */
    case 1130:  /* vec_extractv8qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MRC;
        }

    case 1129:  /* vec_setv2di_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1124:  /* vec_setv16qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR_2_MCRR;
        }

    case 1123:  /* vec_setv2sf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1118:  /* vec_setv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VMOV;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VMOV;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else if (!((1ULL << which_alternative) & 0x1ffULL))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR_2_MCRR;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_UNKNOWN;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VMOV;
        }
      else if (((1ULL << which_alternative) & 0x90ULL))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if (((1ULL << which_alternative) & 0x102ULL))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_UNKNOWN;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VMOV;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_UNKNOWN;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_UNKNOWN;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 7)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_UNKNOWN;
        }

    case 522:  /* mve_vshlq_uv4si */
    case 521:  /* mve_vshlq_sv4si */
    case 518:  /* mve_vshlq_uv8hi */
    case 517:  /* mve_vshlq_sv8hi */
    case 514:  /* mve_vshlq_uv16qi */
    case 513:  /* mve_vshlq_sv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_SHIFT_1;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_NEON_SHIFT_3;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CNT) || (cached_type == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_ADD_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_1;
        }
      else if ((cached_type == TYPE_NEON_ADD_WIDEN) || (cached_type == TYPE_NEON_SUB_WIDEN) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_SUB_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_2;
        }
      else if ((cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_REDUC_ADD_LONG) || (cached_type == TYPE_NEON_ADD_LONG) || (cached_type == TYPE_NEON_SUB_LONG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_3;
        }
      else if ((cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_TST_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_4;
        }
      else if ((cached_type == TYPE_NEON_ABD_LONG) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_QSUB) || (cached_type == TYPE_NEON_QSUB_Q) || (cached_type == TYPE_NEON_ABD) || (cached_type == TYPE_NEON_ABD_Q) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_MINMAX_Q) || (cached_type == TYPE_NEON_REDUC_MINMAX) || (cached_type == TYPE_NEON_REDUC_MINMAX_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_INT_5;
        }
      else if ((cached_type == TYPE_NEON_QNEG) || (cached_type == TYPE_NEON_QNEG_Q) || (cached_type == TYPE_NEON_QABS) || (cached_type == TYPE_NEON_QABS_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VQNEG_VQABS;
        }
      else if ((cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_MOVE_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VMOV;
        }
      else if ((cached_type == TYPE_NEON_BSL_Q) || (cached_type == TYPE_NEON_CLS_Q) || (cached_type == TYPE_NEON_CNT_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_BIT_OPS_Q;
        }
      else if ((cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VABA;
        }
      else if (cached_type == TYPE_NEON_ARITH_ACC_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VABA_QQQ;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SHIFT_REG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_SHIFT_1;
        }
      else if ((cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_REG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_SHIFT_2;
        }
      else if (cached_type == TYPE_NEON_SHIFT_REG_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_SHIFT_3;
        }
      else if (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VQSHL_VRSHL_VQRSHL_QQQ;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SHIFT_ACC_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VSRA_VRSRA;
        }
      else if ((cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG;
        }
      else if ((cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32;
        }
      else if ((cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG;
        }
      else if ((cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_8_16;
        }
      else if ((cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else if ((cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_MINMAX_S) || (cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RSQRTE_S) || (cached_type == TYPE_NEON_FP_TO_INT_S) || (cached_type == TYPE_NEON_INT_TO_FP_S))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }
      else if ((cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_ABS_S_Q) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q) || (cached_type == TYPE_NEON_FP_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_S_Q) || (cached_type == TYPE_NEON_FP_TO_INT_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }
      else if ((cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VSUM;
        }
      else if (cached_type == TYPE_NEON_FP_MUL_S_SCALAR)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_DDD;
        }
      else if (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_QQD;
        }
      else if (cached_type == TYPE_NEON_FP_MLA_S)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD;
        }
      else if (cached_type == TYPE_NEON_FP_MLA_S_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ;
        }
      else if (cached_type == TYPE_NEON_FP_MLA_S_SCALAR)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR;
        }
      else if (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPS_S) || (cached_type == TYPE_NEON_FP_RSQRTS_S))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_DDD;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_S_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_QQQ;
        }
      else if ((cached_type == TYPE_NEON_MOVE_NARROW_Q) || (cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_DUP_Q) || (cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_ZIP) || (cached_type == TYPE_NEON_EXT) || (cached_type == TYPE_NEON_REV) || (cached_type == TYPE_NEON_REV_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_BP_SIMPLE;
        }
      else if ((cached_type == TYPE_NEON_PERMUTE_Q) || (cached_type == TYPE_NEON_EXT_Q) || (cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL2))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_BP_2CYCLE;
        }
      else if ((cached_type == TYPE_NEON_ZIP_Q) || (cached_type == TYPE_NEON_TBL3) || (cached_type == TYPE_NEON_TBL4))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_BP_3CYCLE;
        }
      else if (cached_type == TYPE_NEON_LDR)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_LDR;
        }
      else if (cached_type == TYPE_NEON_STR)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_STR;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_1REG_Q) || (cached_type == TYPE_NEON_LOAD1_2REG) || (cached_type == TYPE_NEON_LOAD1_2REG_Q) || (cached_type == TYPE_NEON_LOAD2_2REG) || (cached_type == TYPE_NEON_LOAD2_2REG_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_3REG) || (cached_type == TYPE_NEON_LOAD1_3REG_Q) || (cached_type == TYPE_NEON_LOAD1_4REG) || (cached_type == TYPE_NEON_LOAD1_4REG_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_ALL_LANES) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_ALL_LANES) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_4REG) || (cached_type == TYPE_NEON_LOAD2_4REG_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD2_4_REGS;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_3REG) || (cached_type == TYPE_NEON_LOAD3_3REG_Q) || (cached_type == TYPE_NEON_LOAD4_4REG) || (cached_type == TYPE_NEON_LOAD4_4REG_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_ONE_LANE) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_ONE_LANE) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4_LANE;
        }
      else if ((cached_type == TYPE_NEON_STORE1_1REG) || (cached_type == TYPE_NEON_STORE1_1REG_Q) || (cached_type == TYPE_NEON_STORE1_2REG) || (cached_type == TYPE_NEON_STORE1_2REG_Q) || (cached_type == TYPE_NEON_STORE2_2REG) || (cached_type == TYPE_NEON_STORE2_2REG_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else if ((cached_type == TYPE_NEON_STORE1_3REG) || (cached_type == TYPE_NEON_STORE1_3REG_Q) || (cached_type == TYPE_NEON_STORE1_4REG) || (cached_type == TYPE_NEON_STORE1_4REG_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else if ((cached_type == TYPE_NEON_STORE2_4REG) || (cached_type == TYPE_NEON_STORE2_4REG_Q) || (cached_type == TYPE_NEON_STORE3_3REG) || (cached_type == TYPE_NEON_STORE3_3REG_Q) || (cached_type == TYPE_NEON_STORE4_4REG) || (cached_type == TYPE_NEON_STORE4_4REG_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }
      else if ((cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE2_ONE_LANE) || (cached_type == TYPE_NEON_STORE2_ONE_LANE_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE;
        }
      else if ((cached_type == TYPE_NEON_STORE3_ONE_LANE) || (cached_type == TYPE_NEON_STORE3_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE4_ONE_LANE) || (cached_type == TYPE_NEON_STORE4_ONE_LANE_Q))
        {
	  return CORTEX_A9_NEON_TYPE_NEON_VST3_VST4_LANE;
        }
      else if (cached_type == TYPE_NEON_FROM_GP)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR;
        }
      else if (cached_type == TYPE_NEON_FROM_GP_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MCR_2_MCRR;
        }
      else if (cached_type == TYPE_NEON_TO_GP)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MRC;
        }
      else if (cached_type == TYPE_NEON_TO_GP_Q)
        {
	  return CORTEX_A9_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A9_NEON_TYPE_UNKNOWN;
        }

    case 2040:  /* neon_vget_lanev4sf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2031:  /* neon_vget_lanev16qi_sext_internal */
      return CORTEX_A9_NEON_TYPE_NEON_MRRC;

    case 2030:  /* neon_vget_lanev2sf_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2023:  /* neon_vget_lanev8qi_sext_internal */
      return CORTEX_A9_NEON_TYPE_NEON_MRC;

    case 2048:  /* neon_vdup_nv8bf */
    case 2046:  /* neon_vdup_nv8hf */
    case 2044:  /* neon_vdup_nv8hi */
    case 2043:  /* neon_vdup_nv16qi */
      return CORTEX_A9_NEON_TYPE_NEON_MCR_2_MCRR;

    case 2047:  /* neon_vdup_nv4bf */
    case 2045:  /* neon_vdup_nv4hf */
    case 2042:  /* neon_vdup_nv4hi */
    case 2041:  /* neon_vdup_nv8qi */
      return CORTEX_A9_NEON_TYPE_NEON_MCR;

    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VST3_VST4_LANE;

    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE;

    case 2730:  /* neon_vld4_lanev8bf */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2726:  /* neon_vld4_lanev8hi */
    case 2725:  /* neon_vld4_lanev2sf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2720:  /* neon_vld4_lanev8qi */
    case 2662:  /* neon_vld3_lanev8bf */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2658:  /* neon_vld3_lanev8hi */
    case 2657:  /* neon_vld3_lanev2sf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2652:  /* neon_vld3_lanev8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4_LANE;

    case 2600:  /* neon_vld2_lanev8bf */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2596:  /* neon_vld2_lanev8hi */
    case 2595:  /* neon_vld2_lanev2sf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2590:  /* neon_vld2_lanev8qi */
    case 2536:  /* neon_vld1_lanev2di */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2530:  /* neon_vld1_lanev16qi */
    case 2529:  /* neon_vld1_lanedi */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2523:  /* neon_vld1_lanev8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VLD1_VLD2_LANE;

    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
      return CORTEX_A9_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;

    case 2562:  /* neon_vst1v2di */
    case 2561:  /* neon_vst1di */
    case 2560:  /* neon_vst1v4sf */
    case 2559:  /* neon_vst1v2sf */
    case 2558:  /* neon_vst1v8bf */
    case 2557:  /* neon_vst1v4bf */
    case 2556:  /* neon_vst1v8hf */
    case 2555:  /* neon_vst1v4hf */
    case 2554:  /* neon_vst1v4si */
    case 2553:  /* neon_vst1v2si */
    case 2552:  /* neon_vst1v8hi */
    case 2551:  /* neon_vst1v4hi */
    case 2550:  /* neon_vst1v16qi */
    case 2549:  /* neon_vst1v8qi */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1070:  /* unaligned_storev8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;

    case 2719:  /* neon_vld4qbv4sf */
    case 2718:  /* neon_vld4qbv4si */
    case 2717:  /* neon_vld4qbv8bf */
    case 2716:  /* neon_vld4qbv8hf */
    case 2715:  /* neon_vld4qbv8hi */
    case 2714:  /* neon_vld4qbv16qi */
    case 2713:  /* neon_vld4qav4sf */
    case 2712:  /* neon_vld4qav4si */
    case 2711:  /* neon_vld4qav8bf */
    case 2710:  /* neon_vld4qav8hf */
    case 2709:  /* neon_vld4qav8hi */
    case 2708:  /* neon_vld4qav16qi */
    case 2651:  /* neon_vld3qbv4sf */
    case 2650:  /* neon_vld3qbv4si */
    case 2649:  /* neon_vld3qbv8bf */
    case 2648:  /* neon_vld3qbv8hf */
    case 2647:  /* neon_vld3qbv8hi */
    case 2646:  /* neon_vld3qbv16qi */
    case 2645:  /* neon_vld3qav4sf */
    case 2644:  /* neon_vld3qav4si */
    case 2643:  /* neon_vld3qav8bf */
    case 2642:  /* neon_vld3qav8hf */
    case 2641:  /* neon_vld3qav8hi */
    case 2640:  /* neon_vld3qav16qi */
      return CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4;

    case 2738:  /* neon_vld4_dupv8bf */
    case 2670:  /* neon_vld3_dupv8bf */
      return CORTEX_A9_NEON_TYPE_NEON_VLD2_4_REGS;

    case 2608:  /* neon_vld2_dupv8bf */
    case 2548:  /* neon_vld1_dupv2di */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2543:  /* neon_vld1_dupv16qi */
    case 2542:  /* neon_vld1_dupv2sf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2537:  /* neon_vld1_dupv8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;

    case 2854:  /* aes_op_protect_neon_vld1v16qi */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2589:  /* neon_vld2v4sf */
    case 2588:  /* neon_vld2v4si */
    case 2587:  /* neon_vld2v8bf */
    case 2586:  /* neon_vld2v8hf */
    case 2585:  /* neon_vld2v8hi */
    case 2584:  /* neon_vld2v16qi */
    case 2583:  /* neon_vld2di */
    case 2582:  /* neon_vld2v2sf */
    case 2581:  /* neon_vld2v2si */
    case 2580:  /* neon_vld2v4bf */
    case 2579:  /* neon_vld2v4hf */
    case 2578:  /* neon_vld2v4hi */
    case 2577:  /* neon_vld2v8qi */
    case 2522:  /* neon_vld1v2di */
    case 2521:  /* neon_vld1di */
    case 2520:  /* neon_vld1v4sf */
    case 2519:  /* neon_vld1v2sf */
    case 2518:  /* neon_vld1v8bf */
    case 2517:  /* neon_vld1v4bf */
    case 2516:  /* neon_vld1v8hf */
    case 2515:  /* neon_vld1v4hf */
    case 2514:  /* neon_vld1v4si */
    case 2513:  /* neon_vld1v2si */
    case 2512:  /* neon_vld1v8hi */
    case 2511:  /* neon_vld1v4hi */
    case 2510:  /* neon_vld1v16qi */
    case 2509:  /* neon_vld1v8qi */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1111:  /* *movmisalignv16qi_neon_load */
    case 1103:  /* *movmisaligndi_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1097:  /* *movmisalignv8qi_neon_load */
      return CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS;

    case 2507:  /* *neon_vuzpv8hf_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2490:  /* *neon_vzipv16qi_insn */
    case 2478:  /* neon_vtbx4v8qi */
    case 2477:  /* neon_vtbx3v8qi */
    case 2471:  /* neon_vtbl4v8qi */
    case 2470:  /* neon_vtbl3v8qi */
      return CORTEX_A9_NEON_TYPE_NEON_BP_3CYCLE;

    case 2487:  /* *neon_vtrnv8hf_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2476:  /* neon_vtbx2v8qi */
    case 2475:  /* neon_vtbx1v8qi */
    case 2469:  /* neon_vtbl2v8qi */
    case 2468:  /* neon_vtbl1v8qi */
    case 2230:  /* neon_vextv2di */
    case 2228:  /* neon_vextv4sf */
    case 2226:  /* neon_vextv8bf */
    case 2224:  /* neon_vextv8hf */
    case 2222:  /* neon_vextv4si */
    case 2220:  /* neon_vextv8hi */
    case 2218:  /* neon_vextv16qi */
    case 2079:  /* *neon_vswpv2di */
    case 2077:  /* *neon_vswpv4sf */
    case 2075:  /* *neon_vswpv8bf */
    case 2073:  /* *neon_vswpv8hf */
    case 2071:  /* *neon_vswpv4si */
    case 2069:  /* *neon_vswpv8hi */
    case 2067:  /* *neon_vswpv16qi */
      return CORTEX_A9_NEON_TYPE_NEON_BP_2CYCLE;

    case 2816:  /* neon_vec_pack_trunc_v2di */
    case 2815:  /* neon_vec_pack_trunc_v4si */
    case 2814:  /* neon_vec_pack_trunc_v8hi */
    case 2508:  /* *neon_vuzpv4hf_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2489:  /* *neon_vzipv8qi_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2247:  /* neon_vrev16v16qi */
    case 2246:  /* neon_vrev16v8qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2244:  /* neon_vrev32v16qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2242:  /* neon_vrev32v8qi */
    case 2241:  /* neon_vrev64v2di */
    case 2240:  /* neon_vrev64v4sf */
    case 2239:  /* neon_vrev64v2sf */
    case 2238:  /* neon_vrev64v8hf */
    case 2237:  /* neon_vrev64v4hf */
    case 2236:  /* neon_vrev64v4si */
    case 2235:  /* neon_vrev64v2si */
    case 2234:  /* neon_vrev64v8hi */
    case 2233:  /* neon_vrev64v4hi */
    case 2232:  /* neon_vrev64v16qi */
    case 2231:  /* neon_vrev64v8qi */
    case 2229:  /* neon_vextdi */
    case 2227:  /* neon_vextv2sf */
    case 2225:  /* neon_vextv4bf */
    case 2223:  /* neon_vextv4hf */
    case 2221:  /* neon_vextv2si */
    case 2219:  /* neon_vextv4hi */
    case 2217:  /* neon_vextv8qi */
    case 2078:  /* *neon_vswpdi */
    case 2076:  /* *neon_vswpv2sf */
    case 2074:  /* *neon_vswpv4bf */
    case 2072:  /* *neon_vswpv4hf */
    case 2070:  /* *neon_vswpv2si */
    case 2068:  /* *neon_vswpv4hi */
    case 2066:  /* *neon_vswpv8qi */
    case 2065:  /* neon_vdup_lanev8bf_internal */
    case 2064:  /* neon_vdup_lanev4bf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 1914:  /* neon_bswapv2di */
    case 1913:  /* neon_bswapv4si */
    case 1912:  /* neon_bswapv2si */
    case 1911:  /* neon_bswapv8hi */
    case 1910:  /* neon_bswapv4hi */
      return CORTEX_A9_NEON_TYPE_NEON_BP_SIMPLE;

    case 1902:  /* neon_vrsqrtsv8hf */
    case 1901:  /* neon_vrsqrtsv4sf */
    case 1898:  /* neon_vrecpsv8hf */
    case 1897:  /* neon_vrecpsv4sf */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_QQQ;

    case 1903:  /* neon_vrsqrtsv4hf */
    case 1900:  /* neon_vrsqrtsv2sf */
    case 1899:  /* neon_vrecpsv4hf */
    case 1896:  /* neon_vrecpsv2sf */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_DDD;

    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;

    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1180:  /* mulv8hf3addv8hf_neon */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ;

    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1190:  /* fmav2sf4 */
    case 1181:  /* mulv4hf3addv4hf_neon */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD;

    case 2169:  /* neon_vmul_lanev8hf */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_QQD;

    case 2170:  /* neon_vmul_lanev4hf */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_DDD;

    case 1895:  /* neon_vpminfv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1893:  /* neon_vpminfv2sf */
    case 1892:  /* neon_vpmaxfv2sf */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1405:  /* quad_halves_sminv4sf */
    case 1404:  /* quad_halves_plusv4sf */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VSUM;

    case 2824:  /* neon_vabdv4sf_3 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2818:  /* neon_vabdv8hf_2 */
    case 2136:  /* neon_vcvtpuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2128:  /* neon_vcvtu_nv8hi */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2123:  /* neon_vcvts_nv4si */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2108:  /* neon_vcvtuv8hi */
    case 2107:  /* neon_vcvtsv8hi */
    case 2102:  /* neon_vcvtuv4si */
    case 2101:  /* neon_vcvtsv4si */
    case 2098:  /* neon_vcvtuv4sf */
    case 2097:  /* neon_vcvtsv4sf */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2088:  /* floatv4siv4sf2 */
    case 2022:  /* neon_vrsqrtev4sf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2018:  /* neon_vrecpev4sf */
    case 2017:  /* neon_vrecpev4si */
    case 2013:  /* neon_vrecpev8hf */
    case 1855:  /* fminv4sf3 */
    case 1854:  /* fmaxv4sf3 */
    case 1851:  /* neon_vminnmv4sf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1845:  /* neon_vminnmv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1839:  /* neon_vminfv8hf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1837:  /* neon_vminfv4sf */
    case 1836:  /* neon_vmaxfv4sf */
    case 1785:  /* neon_vabdfv4sf */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1324:  /* neon_vrsqrtev8hf */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1220:  /* neon_vcvtpv4sfv4si */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;

    case 2823:  /* neon_vabdv2sf_3 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2817:  /* neon_vabdv4hf_2 */
    case 2144:  /* neon_vcvtpuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2126:  /* neon_vcvtu_nv4hi */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2121:  /* neon_vcvts_nv2si */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2106:  /* neon_vcvtuv4hi */
    case 2105:  /* neon_vcvtsv4hi */
    case 2100:  /* neon_vcvtuv2si */
    case 2099:  /* neon_vcvtsv2si */
    case 2096:  /* neon_vcvtuv2sf */
    case 2095:  /* neon_vcvtsv2sf */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2087:  /* floatv2siv2sf2 */
    case 2020:  /* neon_vrsqrtev2sf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2016:  /* neon_vrecpev2sf */
    case 2015:  /* neon_vrecpev2si */
    case 2014:  /* neon_vrecpev4hf */
    case 1853:  /* fminv2sf3 */
    case 1852:  /* fmaxv2sf3 */
    case 1849:  /* neon_vminnmv2sf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1847:  /* neon_vminnmv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1841:  /* neon_vminfv4hf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1835:  /* neon_vminfv2sf */
    case 1834:  /* neon_vmaxfv2sf */
    case 1784:  /* neon_vabdfv2sf */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1690:  /* neon_vceqv2sf_insn_unspec */
    case 1325:  /* neon_vrsqrtev4hf */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1214:  /* neon_vcvtpv2sfv2si */
      return CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;

    case 2451:  /* neon_vrsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2448:  /* neon_vsras_nv2di */
    case 2447:  /* neon_vrsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2444:  /* neon_vsras_ndi */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2440:  /* neon_vsras_nv4si */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2436:  /* neon_vsras_nv2si */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2424:  /* neon_vsras_nv16qi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2420:  /* neon_vsras_nv8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VSRA_VRSRA;

    case 2467:  /* neon_vsli_nv2di */
    case 2465:  /* neon_vsli_nv4si */
    case 2463:  /* neon_vsli_nv8hi */
    case 2461:  /* neon_vsli_nv16qi */
    case 2459:  /* neon_vsri_nv2di */
    case 2457:  /* neon_vsri_nv4si */
    case 2455:  /* neon_vsri_nv8hi */
    case 2453:  /* neon_vsri_nv16qi */
    case 1379:  /* ashlv2di3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1372:  /* ashlv2di3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1367:  /* ashlv16qi3_signed */
      return CORTEX_A9_NEON_TYPE_NEON_SHIFT_3;

    case 2413:  /* neon_vqshlu_nv2di */
    case 2412:  /* neon_vqshlu_ndi */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2381:  /* neon_vqrshrun_nv2di */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2325:  /* neon_vqrshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2322:  /* neon_vqshlsv2di */
    case 2321:  /* neon_vqrshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2318:  /* neon_vqshlsdi */
    case 2317:  /* neon_vqrshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2314:  /* neon_vqshlsv4si */
    case 2313:  /* neon_vqrshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2310:  /* neon_vqshlsv2si */
    case 2309:  /* neon_vqrshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2305:  /* neon_vqrshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2298:  /* neon_vqshlsv16qi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2294:  /* neon_vqshlsv8qi */
    case 2156:  /* neon_vqmovunv2di */
    case 2155:  /* neon_vqmovunv4si */
    case 2154:  /* neon_vqmovunv8hi */
    case 2153:  /* neon_vqmovnuv2di */
    case 2152:  /* neon_vqmovnsv2di */
    case 2151:  /* neon_vqmovnuv4si */
    case 2150:  /* neon_vqmovnsv4si */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2148:  /* neon_vqmovnsv8hi */
      return CORTEX_A9_NEON_TYPE_NEON_SHIFT_2;

    case 2840:  /* neon_vbfcvt_highv8bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2798:  /* neon_vec_ushiftl_v2si */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2466:  /* neon_vsli_ndi */
    case 2464:  /* neon_vsli_nv2si */
    case 2462:  /* neon_vsli_nv4hi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2458:  /* neon_vsri_ndi */
    case 2456:  /* neon_vsri_nv2si */
    case 2454:  /* neon_vsri_nv4hi */
    case 2452:  /* neon_vsri_nv8qi */
    case 2419:  /* neon_vshllu_nv2si */
    case 2418:  /* neon_vshlls_nv2si */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2389:  /* neon_vshl_nv2di */
    case 2388:  /* neon_vshl_ndi */
    case 2387:  /* neon_vshl_nv4si */
    case 2386:  /* neon_vshl_nv2si */
    case 2385:  /* neon_vshl_nv8hi */
    case 2384:  /* neon_vshl_nv4hi */
    case 2383:  /* neon_vshl_nv16qi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2363:  /* neon_vrshrn_nv2di */
    case 2362:  /* neon_vshrn_nv2di */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2360:  /* neon_vshrn_nv4si */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2357:  /* neon_vrshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2354:  /* neon_vshrs_nv2di */
    case 2353:  /* neon_vrshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2350:  /* neon_vshrs_ndi */
    case 2349:  /* neon_vrshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2346:  /* neon_vshrs_nv4si */
    case 2345:  /* neon_vrshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2342:  /* neon_vshrs_nv2si */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2293:  /* neon_vrshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2290:  /* neon_vshlsv2di */
    case 2289:  /* neon_vrshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2287:  /* neon_vshludi */
    case 2286:  /* neon_vshlsdi */
    case 2285:  /* neon_vrshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2282:  /* neon_vshlsv4si */
    case 2281:  /* neon_vrshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2278:  /* neon_vshlsv2si */
    case 2277:  /* neon_vrshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2274:  /* neon_vshlsv8hi */
    case 2273:  /* neon_vrshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2270:  /* neon_vshlsv4hi */
    case 2269:  /* neon_vrshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2266:  /* neon_vshlsv16qi */
    case 2265:  /* neon_vrshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2262:  /* neon_vshlsv8qi */
    case 2162:  /* neon_vmovluv2si */
    case 2161:  /* neon_vmovlsv2si */
    case 2160:  /* neon_vmovluv4hi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2158:  /* neon_vmovluv8qi */
    case 2157:  /* neon_vmovlsv8qi */
    case 2147:  /* neon_vmovnv2di */
    case 2146:  /* neon_vmovnv4si */
    case 2145:  /* neon_vmovnv8hi */
    case 1377:  /* ashlv2si3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1370:  /* ashlv2si3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1366:  /* ashlv8qi3_signed */
    case 1365:  /* vlshrv4si3_imm */
    case 1364:  /* vlshrv2si3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1355:  /* vashrv16qi3_imm */
    case 1354:  /* vashrv8qi3_imm */
    case 520:  /* mve_vshlq_uv2si */
    case 519:  /* mve_vshlq_sv2si */
    case 516:  /* mve_vshlq_uv4hi */
    case 515:  /* mve_vshlq_sv4hi */
    case 512:  /* mve_vshlq_uv8qi */
    case 511:  /* mve_vshlq_sv8qi */
      return CORTEX_A9_NEON_TYPE_NEON_SHIFT_1;

    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
      return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR;

    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1517:  /* neon_vmulfv8hf */
      return CORTEX_A9_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;

    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
      return CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR;

    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
      return CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;

    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1588:  /* neon_vqdmlalv2si */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
      return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;

    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
      return CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG;

    case 2810:  /* neon_vec_umult_v2si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 1601:  /* neon_vqdmullv2si */
    case 1599:  /* neon_vmullpv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1597:  /* neon_vmullsv2si */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1518:  /* neon_vmulfv4hf */
      return CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;

    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
      return CORTEX_A9_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32;

    case 2808:  /* neon_vec_umult_v4hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2806:  /* neon_vec_umult_v8qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 1600:  /* neon_vqdmullv4hi */
    case 1596:  /* neon_vmullpv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1594:  /* neon_vmullsv4hi */
    case 1593:  /* neon_vmullpv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1591:  /* neon_vmullsv8qi */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
      return CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG;

    case 2804:  /* neon_unpacku_v2si */
    case 2803:  /* neon_unpacks_v2si */
    case 2802:  /* neon_unpacku_v4hi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2799:  /* neon_unpacks_v8qi */
    case 1291:  /* one_cmplv2di2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1289:  /* one_cmplv2sf2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1282:  /* one_cmplv16qi2_neon */
    case 1281:  /* one_cmplv8qi2_neon */
      return CORTEX_A9_NEON_TYPE_NEON_VMOV;

    case 1803:  /* neon_vabauv4si */
    case 1802:  /* neon_vabasv4si */
    case 1799:  /* neon_vabauv8hi */
    case 1798:  /* neon_vabasv8hi */
    case 1795:  /* neon_vabauv16qi */
    case 1794:  /* neon_vabasv16qi */
      return CORTEX_A9_NEON_TYPE_NEON_VABA_QQQ;

    case 1879:  /* neon_vpadaluv4si */
    case 1878:  /* neon_vpadalsv4si */
    case 1877:  /* neon_vpadaluv2si */
    case 1876:  /* neon_vpadalsv2si */
    case 1875:  /* neon_vpadaluv8hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1868:  /* neon_vpadalsv8qi */
    case 1809:  /* neon_vabaluv2si */
    case 1808:  /* neon_vabalsv2si */
    case 1807:  /* neon_vabaluv4hi */
    case 1806:  /* neon_vabalsv4hi */
    case 1805:  /* neon_vabaluv8qi */
    case 1804:  /* neon_vabalsv8qi */
    case 1801:  /* neon_vabauv2si */
    case 1800:  /* neon_vabasv2si */
    case 1797:  /* neon_vabauv4hi */
    case 1796:  /* neon_vabasv4hi */
    case 1793:  /* neon_vabauv8qi */
    case 1792:  /* neon_vabasv8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VABA;

    case 2261:  /* neon_vbslv2di_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2249:  /* neon_vbslv16qi_internal */
    case 2012:  /* popcountv16qi2 */
    case 2010:  /* neon_vclzv4si */
    case 2008:  /* neon_vclzv8hi */
    case 2006:  /* neon_vclzv16qi */
    case 2004:  /* neon_vclsv4si */
    case 2002:  /* neon_vclsv8hi */
    case 2000:  /* neon_vclsv16qi */
      return CORTEX_A9_NEON_TYPE_NEON_BIT_OPS_Q;

    case 1998:  /* neon_vqnegv4si */
    case 1997:  /* neon_vqnegv2si */
    case 1996:  /* neon_vqnegv8hi */
    case 1995:  /* neon_vqnegv4hi */
    case 1994:  /* neon_vqnegv16qi */
    case 1993:  /* neon_vqnegv8qi */
    case 1909:  /* neon_vqabsv4si */
    case 1908:  /* neon_vqabsv2si */
    case 1907:  /* neon_vqabsv8hi */
    case 1906:  /* neon_vqabsv4hi */
    case 1905:  /* neon_vqabsv16qi */
    case 1904:  /* neon_vqabsv8qi */
      return CORTEX_A9_NEON_TYPE_NEON_VQNEG_VQABS;

    case 1891:  /* neon_vpminuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1888:  /* neon_vpmaxsv2si */
    case 1887:  /* neon_vpminuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1883:  /* neon_vpminuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1843:  /* neon_vpminfv4hf */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1833:  /* neon_vminuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1830:  /* neon_vmaxsv4si */
    case 1829:  /* neon_vminuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1826:  /* neon_vmaxsv2si */
    case 1825:  /* neon_vminuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1821:  /* neon_vminuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1817:  /* neon_vminuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1814:  /* neon_vmaxsv16qi */
    case 1813:  /* neon_vminuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1810:  /* neon_vmaxsv8qi */
    case 1791:  /* neon_vabdluv2si */
    case 1790:  /* neon_vabdlsv2si */
    case 1789:  /* neon_vabdluv4hi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1787:  /* neon_vabdluv8qi */
    case 1786:  /* neon_vabdlsv8qi */
    case 1783:  /* neon_vabdv4hf */
    case 1782:  /* neon_vabdv8hf */
    case 1781:  /* neon_vabduv4si */
    case 1780:  /* neon_vabdsv4si */
    case 1779:  /* neon_vabduv2si */
    case 1778:  /* neon_vabdsv2si */
    case 1777:  /* neon_vabduv8hi */
    case 1776:  /* neon_vabdsv8hi */
    case 1775:  /* neon_vabduv4hi */
    case 1774:  /* neon_vabdsv4hi */
    case 1773:  /* neon_vabduv16qi */
    case 1772:  /* neon_vabdsv16qi */
    case 1771:  /* neon_vabduv8qi */
    case 1770:  /* neon_vabdsv8qi */
    case 1731:  /* neon_vcgeuv4si */
    case 1730:  /* neon_vcgtuv4si */
    case 1729:  /* neon_vcgeuv2si */
    case 1728:  /* neon_vcgtuv2si */
    case 1727:  /* neon_vcgeuv8hi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1725:  /* neon_vcgeuv4hi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1722:  /* neon_vcgtuv16qi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1720:  /* neon_vcgtuv8qi */
    case 1643:  /* neon_vhsubuv4si */
    case 1642:  /* neon_vhsubsv4si */
    case 1641:  /* neon_vhsubuv2si */
    case 1640:  /* neon_vhsubsv2si */
    case 1639:  /* neon_vhsubuv8hi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1637:  /* neon_vhsubuv4hi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1634:  /* neon_vhsubsv16qi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1632:  /* neon_vhsubsv8qi */
    case 1631:  /* neon_vqsubuv2di */
    case 1630:  /* neon_vqsubsv2di */
    case 1629:  /* neon_vqsubudi */
    case 1628:  /* neon_vqsubsdi */
    case 1627:  /* neon_vqsubuv4si */
    case 1626:  /* neon_vqsubsv4si */
    case 1625:  /* neon_vqsubuv2si */
    case 1624:  /* neon_vqsubsv2si */
    case 1623:  /* neon_vqsubuv8hi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1621:  /* neon_vqsubuv4hi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1618:  /* neon_vqsubsv16qi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1616:  /* neon_vqsubsv8qi */
    case 1452:  /* *us_subv2sf_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1445:  /* *ss_subv8qi_neon */
    case 1436:  /* neon_vpumaxv2si */
    case 1435:  /* neon_vpumaxv4hi */
    case 1434:  /* neon_vpumaxv8qi */
    case 1433:  /* neon_vpuminv2si */
    case 1432:  /* neon_vpuminv4hi */
    case 1431:  /* neon_vpuminv8qi */
    case 1416:  /* quad_halves_umaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1408:  /* quad_halves_sminv8hi */
    case 1403:  /* quad_halves_umaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1400:  /* quad_halves_sminv4si */
    case 1337:  /* *umaxv4si3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1327:  /* *uminv16qi3_neon */
    case 1326:  /* *uminv8qi3_neon */
      return CORTEX_A9_NEON_TYPE_NEON_INT_5;

    case 1769:  /* neon_vtst_combinev4si */
    case 1768:  /* neon_vtst_combinev2si */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1765:  /* neon_vtst_combinev16qi */
    case 1764:  /* neon_vtst_combinev8qi */
    case 1649:  /* neon_vrsubhnv2di */
    case 1648:  /* neon_vsubhnv2di */
    case 1647:  /* neon_vrsubhnv4si */
    case 1646:  /* neon_vsubhnv4si */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1644:  /* neon_vsubhnv8hi */
    case 1512:  /* neon_vraddhnv2di */
    case 1511:  /* neon_vaddhnv2di */
    case 1510:  /* neon_vraddhnv4si */
    case 1509:  /* neon_vaddhnv4si */
    case 1508:  /* neon_vraddhnv8hi */
    case 1507:  /* neon_vaddhnv8hi */
    case 1506:  /* neon_vqadduv2di */
    case 1505:  /* neon_vqaddsv2di */
    case 1504:  /* neon_vqaddudi */
    case 1503:  /* neon_vqaddsdi */
    case 1502:  /* neon_vqadduv4si */
    case 1501:  /* neon_vqaddsv4si */
    case 1500:  /* neon_vqadduv2si */
    case 1499:  /* neon_vqaddsv2si */
    case 1498:  /* neon_vqadduv8hi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1496:  /* neon_vqadduv4hi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1494:  /* neon_vqadduv16qi */
    case 1493:  /* neon_vqaddsv16qi */
    case 1492:  /* neon_vqadduv8qi */
    case 1491:  /* neon_vqaddsv8qi */
    case 1490:  /* neon_vhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1486:  /* neon_vhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1483:  /* neon_vrhaddsv2si */
    case 1482:  /* neon_vhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1474:  /* neon_vhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1467:  /* neon_vrhaddsv8qi */
    case 1444:  /* *us_addv2sf_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1437:  /* *ss_addv8qi_neon */
    case 1311:  /* neon_negv4hf2 */
    case 1310:  /* neon_absv4hf2 */
    case 1309:  /* neon_negv8hf2 */
    case 1308:  /* neon_absv8hf2 */
      return CORTEX_A9_NEON_TYPE_NEON_INT_4;

    case 1867:  /* neon_vpaddluv4si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1865:  /* neon_vpaddluv2si */
    case 1864:  /* neon_vpaddlsv2si */
    case 1863:  /* neon_vpaddluv8hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1856:  /* neon_vpaddlsv8qi */
    case 1609:  /* neon_vsubluv2si */
    case 1608:  /* neon_vsublsv2si */
    case 1607:  /* neon_vsubluv4hi */
    case 1606:  /* neon_vsublsv4hi */
    case 1605:  /* neon_vsubluv8qi */
    case 1604:  /* neon_vsublsv8qi */
    case 1460:  /* neon_vaddluv2si */
    case 1459:  /* neon_vaddlsv2si */
    case 1458:  /* neon_vaddluv4hi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1456:  /* neon_vaddluv8qi */
    case 1455:  /* neon_vaddlsv8qi */
    case 1422:  /* neon_vpaddv4hf */
    case 1412:  /* quad_halves_plusv16qi */
    case 1407:  /* quad_halves_plusv8hi */
    case 1399:  /* quad_halves_plusv4si */
      return CORTEX_A9_NEON_TYPE_NEON_INT_3;

    case 1615:  /* neon_vsubwuv2si */
    case 1614:  /* neon_vsubwsv2si */
    case 1613:  /* neon_vsubwuv4hi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1610:  /* neon_vsubwsv8qi */
    case 1466:  /* neon_vaddwuv2si */
    case 1465:  /* neon_vaddwsv2si */
    case 1464:  /* neon_vaddwuv4hi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1461:  /* neon_vaddwsv8qi */
    case 1398:  /* widen_usumv2si3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
      return CORTEX_A9_NEON_TYPE_NEON_INT_2;

    case 2260:  /* neon_vbsldi_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2248:  /* neon_vbslv8qi_internal */
    case 2011:  /* popcountv8qi2 */
    case 2009:  /* neon_vclzv2si */
    case 2007:  /* neon_vclzv4hi */
    case 2005:  /* neon_vclzv8qi */
    case 2003:  /* neon_vclsv2si */
    case 2001:  /* neon_vclsv4hi */
    case 1999:  /* neon_vclsv8qi */
    case 1417:  /* arm_reduc_plus_internal_v2di */
    case 1280:  /* xorv2di3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1278:  /* xorv2sf3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1247:  /* andv2di3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1242:  /* andv4si3_neon */
    case 1241:  /* andv2si3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1227:  /* iorv16qi3_neon */
    case 1226:  /* iorv8qi3_neon */
      return CORTEX_A9_NEON_TYPE_NEON_INT_1;

    default:
      return CORTEX_A9_NEON_TYPE_UNKNOWN;

    }
}

enum attr_cortex_a8_neon_type
get_attr_cortex_a8_neon_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VMOV;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }

    case 2745:  /* neon_vst4di */
      if ((64) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }

    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
      if ((32) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }

    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }

    case 2739:  /* neon_vst4v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }

    case 2677:  /* neon_vst3di */
      if ((64) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST3_VST4_LANE;
        }

    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
      if ((32) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST3_VST4_LANE;
        }

    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST3_VST4_LANE;
        }

    case 2671:  /* neon_vst3v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST3_VST4_LANE;
        }

    case 2737:  /* neon_vld4_dupdi */
    case 2669:  /* neon_vld3_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_4_REGS;
        }

    case 2736:  /* neon_vld4_dupv2sf */
    case 2735:  /* neon_vld4_dupv2si */
    case 2668:  /* neon_vld3_dupv2sf */
    case 2667:  /* neon_vld3_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_4_REGS;
        }

    case 2734:  /* neon_vld4_dupv4bf */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2732:  /* neon_vld4_dupv4hi */
    case 2666:  /* neon_vld3_dupv4bf */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2664:  /* neon_vld3_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_4_REGS;
        }

    case 2731:  /* neon_vld4_dupv8qi */
    case 2663:  /* neon_vld3_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_4_REGS;
        }

    case 2707:  /* neon_vld4di */
    case 2639:  /* neon_vld3di */
      if ((64) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4;
        }

    case 2706:  /* neon_vld4v2sf */
    case 2705:  /* neon_vld4v2si */
    case 2638:  /* neon_vld3v2sf */
    case 2637:  /* neon_vld3v2si */
      if ((32) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4;
        }

    case 2704:  /* neon_vld4v4bf */
    case 2703:  /* neon_vld4v4hf */
    case 2702:  /* neon_vld4v4hi */
    case 2636:  /* neon_vld3v4bf */
    case 2635:  /* neon_vld3v4hf */
    case 2634:  /* neon_vld3v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4;
        }

    case 2701:  /* neon_vld4v8qi */
    case 2633:  /* neon_vld3v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4;
        }

    case 2615:  /* neon_vst2di */
      if ((64) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE;
        }

    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
      if ((32) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE;
        }

    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
      if ((16) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE;
        }

    case 2609:  /* neon_vst2v8qi */
      if ((8) == (64))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE;
        }

    case 2607:  /* neon_vld2_dupdi */
      if (! ((1) > (1)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }

    case 2606:  /* neon_vld2_dupv2sf */
    case 2605:  /* neon_vld2_dupv2si */
      if (! ((2) > (1)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }

    case 2604:  /* neon_vld2_dupv4bf */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2602:  /* neon_vld2_dupv4hi */
      if (! ((4) > (1)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }

    case 2601:  /* neon_vld2_dupv8qi */
      if (! ((8) > (1)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }

    case 2210:  /* neon_vmls_lanev4sf */
    case 2198:  /* neon_vmla_lanev4sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;
        }

    case 2209:  /* neon_vmls_lanev4si */
    case 2197:  /* neon_vmla_lanev4si */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;
        }

    case 2208:  /* neon_vmls_lanev8hi */
    case 2196:  /* neon_vmla_lanev8hi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;
        }

    case 2207:  /* neon_vmls_lanev2sf */
    case 2195:  /* neon_vmla_lanev2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR;
        }

    case 2206:  /* neon_vmls_lanev2si */
    case 2194:  /* neon_vmla_lanev2si */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR;
        }

    case 2205:  /* neon_vmls_lanev4hi */
    case 2193:  /* neon_vmla_lanev4hi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR;
        }

    case 2168:  /* neon_vmul_lanev4sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_QQD;
        }

    case 2167:  /* neon_vmul_lanev4si */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_QQD;
        }

    case 2166:  /* neon_vmul_lanev8hi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_QQD;
        }

    case 2165:  /* neon_vmul_lanev2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_DDD;
        }

    case 2164:  /* neon_vmul_lanev2si */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_DDD;
        }

    case 2163:  /* neon_vmul_lanev4hi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_DDD;
        }

    case 2052:  /* neon_vdup_nv4sf */
    case 2051:  /* neon_vdup_nv4si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_BP_SIMPLE;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }

    case 2050:  /* neon_vdup_nv2sf */
    case 2049:  /* neon_vdup_nv2si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_BP_SIMPLE;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }

    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
      if ((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_ZERO_Q)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_4;
        }
      else if (cached_type == TYPE_NEON_COMPARE_Q)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if ((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_ZERO)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_4;
        }
      else if (cached_type == TYPE_NEON_COMPARE)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 1430:  /* neon_vpsmaxv2sf */
    case 1426:  /* neon_vpsminv2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VSUM;
        }

    case 1429:  /* neon_vpsmaxv2si */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1425:  /* neon_vpsminv2si */
    case 1424:  /* neon_vpsminv4hi */
    case 1423:  /* neon_vpsminv8qi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VSUM;
        }

    case 1421:  /* neon_vpadd_internalv2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VSUM;
        }

    case 1420:  /* neon_vpadd_internalv2si */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1418:  /* neon_vpadd_internalv8qi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VSUM;
        }

    case 1380:  /* neon_load_count */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }

    case 1353:  /* *smaxv4sf3_neon */
    case 1345:  /* *sminv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1352:  /* *smaxv2sf3_neon */
    case 1344:  /* *sminv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1351:  /* *smaxv4si3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1339:  /* *sminv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1350:  /* *smaxv2si3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1338:  /* *sminv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1307:  /* neon_negv4sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1306:  /* neon_negv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1305:  /* neon_negv4si2 */
    case 1303:  /* neon_negv8hi2 */
    case 1301:  /* neon_negv16qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1304:  /* neon_negv2si2 */
    case 1302:  /* neon_negv4hi2 */
    case 1300:  /* neon_negv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_3;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1299:  /* neon_absv4sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_4;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1298:  /* neon_absv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_4;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1297:  /* neon_absv4si2 */
    case 1295:  /* neon_absv8hi2 */
    case 1293:  /* neon_absv16qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_4;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1296:  /* neon_absv2si2 */
    case 1294:  /* neon_absv4hi2 */
    case 1292:  /* neon_absv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_4;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ;
        }

    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD;
        }

    case 1562:  /* neon_vmlsv4si_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1177:  /* mulv4si3addv4si_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ;
        }

    case 1561:  /* neon_vmlsv2si_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1176:  /* mulv2si3addv2si_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD;
        }

    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_8_16;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ;
        }

    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD;
        }

    case 1516:  /* neon_vmulfv4sf */
    case 1171:  /* *mulv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1515:  /* neon_vmulfv2sf */
    case 1170:  /* *mulv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1169:  /* *mulv4si3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1168:  /* *mulv2si3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1514:  /* neon_vmulpv16qi */
    case 1167:  /* *mulv8hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1513:  /* neon_vmulpv8qi */
    case 1166:  /* *mulv4hi3_neon */
    case 1164:  /* *mulv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1603:  /* neon_vsubv4sf_unspec */
    case 1162:  /* *subv4sf3_neon */
    case 1160:  /* *subv8hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_2;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1602:  /* neon_vsubv2sf_unspec */
    case 1161:  /* *subv2sf3_neon */
    case 1159:  /* *subv4hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_2;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1163:  /* *subv2di3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1154:  /* *subv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_2;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1157:  /* *subv2si3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1153:  /* *subv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_2;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1454:  /* neon_vaddv4sf_unspec */
    case 1151:  /* *addv4sf3_neon */
    case 1149:  /* *addv8hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_1;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1453:  /* neon_vaddv2sf_unspec */
    case 1150:  /* *addv2sf3_neon */
    case 1148:  /* *addv4hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_1;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1152:  /* *addv2di3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1143:  /* *addv16qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_1;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }

    case 1146:  /* *addv2si3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1142:  /* *addv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_1;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }

    case 1141:  /* neon_vec_extractv2didi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1136:  /* neon_vec_extractv16qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRRC;
        }

    case 1135:  /* vec_extractv2sfsf */
    case 1134:  /* vec_extractv2sisi */
    case 1133:  /* vec_extractv4bfbf */
    case 1132:  /* vec_extractv4hfhf */
    case 1131:  /* vec_extractv4hihi */
    case 1130:  /* vec_extractv8qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }

    case 1129:  /* vec_setv2di_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1124:  /* vec_setv16qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }

    case 1123:  /* vec_setv2sf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1118:  /* vec_setv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VMOV;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VMOV;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else if (!((1ULL << which_alternative) & 0x1ffULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VMOV;
        }
      else if (((1ULL << which_alternative) & 0x90ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if (((1ULL << which_alternative) & 0x102ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 774:  /* *thumb2_movdfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }
      else if (!((1ULL << which_alternative) & 0x3fULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 773:  /* *movdfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x38ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (!((1ULL << which_alternative) & 0x3fULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 772:  /* *thumb2_movsfcc_vfp */
    case 771:  /* *movsfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x38ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (!((1ULL << which_alternative) & 0x3fULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VMOV;
        }
      else if (((1ULL << which_alternative) & 0x30ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 768:  /* *thumb2_movsf_vfp */
    case 767:  /* *movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 766:  /* *movbf_vfp */
    case 765:  /* *movhf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 4)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if (which_alternative == 1)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 7)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else if (which_alternative == 4)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 5)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3ffULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }
      else if (which_alternative == 8)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3000ULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if (which_alternative == 9)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 10)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 6848:  /* *p *arm_movsi_vfp */
    case 758:  /* *arm_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x1ffULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 6)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 7)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 5)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 6)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 531:  /* *iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x1fffULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if (which_alternative == 10)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if (which_alternative == 11)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x1fffULL))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if (which_alternative == 10)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }
      else if (which_alternative == 11)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 522:  /* mve_vshlq_uv4si */
    case 521:  /* mve_vshlq_sv4si */
    case 518:  /* mve_vshlq_uv8hi */
    case 517:  /* mve_vshlq_sv8hi */
    case 514:  /* mve_vshlq_uv16qi */
    case 513:  /* mve_vshlq_sv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_SHIFT_1;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_NEON_SHIFT_3;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CNT) || (cached_type == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_ADD_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_1;
        }
      else if ((cached_type == TYPE_NEON_ADD_WIDEN) || (cached_type == TYPE_NEON_SUB_WIDEN) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_SUB_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_2;
        }
      else if ((cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_REDUC_ADD_LONG) || (cached_type == TYPE_NEON_ADD_LONG) || (cached_type == TYPE_NEON_SUB_LONG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_3;
        }
      else if ((cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_TST_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_4;
        }
      else if ((cached_type == TYPE_NEON_ABD_LONG) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_QSUB) || (cached_type == TYPE_NEON_QSUB_Q) || (cached_type == TYPE_NEON_ABD) || (cached_type == TYPE_NEON_ABD_Q) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_MINMAX_Q) || (cached_type == TYPE_NEON_REDUC_MINMAX) || (cached_type == TYPE_NEON_REDUC_MINMAX_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_INT_5;
        }
      else if ((cached_type == TYPE_NEON_QNEG) || (cached_type == TYPE_NEON_QNEG_Q) || (cached_type == TYPE_NEON_QABS) || (cached_type == TYPE_NEON_QABS_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VQNEG_VQABS;
        }
      else if ((cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_MOVE_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VMOV;
        }
      else if ((cached_type == TYPE_NEON_BSL_Q) || (cached_type == TYPE_NEON_CLS_Q) || (cached_type == TYPE_NEON_CNT_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_BIT_OPS_Q;
        }
      else if ((cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VABA;
        }
      else if (cached_type == TYPE_NEON_ARITH_ACC_Q)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VABA_QQQ;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SHIFT_REG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_SHIFT_1;
        }
      else if ((cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_REG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_SHIFT_2;
        }
      else if (cached_type == TYPE_NEON_SHIFT_REG_Q)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_SHIFT_3;
        }
      else if (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VQSHL_VRSHL_VQRSHL_QQQ;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SHIFT_ACC_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VSRA_VRSRA;
        }
      else if ((cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG;
        }
      else if ((cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32;
        }
      else if ((cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG;
        }
      else if ((cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_8_16;
        }
      else if ((cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;
        }
      else if ((cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_MINMAX_S) || (cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RSQRTE_S) || (cached_type == TYPE_NEON_FP_TO_INT_S) || (cached_type == TYPE_NEON_INT_TO_FP_S))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;
        }
      else if ((cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_ABS_S_Q) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q) || (cached_type == TYPE_NEON_FP_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_S_Q) || (cached_type == TYPE_NEON_FP_TO_INT_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;
        }
      else if ((cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VSUM;
        }
      else if (cached_type == TYPE_NEON_FP_MUL_S_SCALAR)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_DDD;
        }
      else if (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_QQD;
        }
      else if (cached_type == TYPE_NEON_FP_MLA_S)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD;
        }
      else if (cached_type == TYPE_NEON_FP_MLA_S_Q)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ;
        }
      else if (cached_type == TYPE_NEON_FP_MLA_S_SCALAR)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR;
        }
      else if (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPS_S) || (cached_type == TYPE_NEON_FP_RSQRTS_S))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_DDD;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_S_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_QQQ;
        }
      else if ((cached_type == TYPE_NEON_MOVE_NARROW_Q) || (cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_DUP_Q) || (cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_ZIP) || (cached_type == TYPE_NEON_EXT) || (cached_type == TYPE_NEON_REV) || (cached_type == TYPE_NEON_REV_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_BP_SIMPLE;
        }
      else if ((cached_type == TYPE_NEON_PERMUTE_Q) || (cached_type == TYPE_NEON_EXT_Q) || (cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL2))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_BP_2CYCLE;
        }
      else if ((cached_type == TYPE_NEON_ZIP_Q) || (cached_type == TYPE_NEON_TBL3) || (cached_type == TYPE_NEON_TBL4))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_BP_3CYCLE;
        }
      else if (cached_type == TYPE_NEON_LDR)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_LDR;
        }
      else if (cached_type == TYPE_NEON_STR)
        {
	  return CORTEX_A8_NEON_TYPE_NEON_STR;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_1REG_Q) || (cached_type == TYPE_NEON_LOAD1_2REG) || (cached_type == TYPE_NEON_LOAD1_2REG_Q) || (cached_type == TYPE_NEON_LOAD2_2REG) || (cached_type == TYPE_NEON_LOAD2_2REG_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_3REG) || (cached_type == TYPE_NEON_LOAD1_3REG_Q) || (cached_type == TYPE_NEON_LOAD1_4REG) || (cached_type == TYPE_NEON_LOAD1_4REG_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_ALL_LANES) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_ALL_LANES) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_4REG) || (cached_type == TYPE_NEON_LOAD2_4REG_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD2_4_REGS;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_3REG) || (cached_type == TYPE_NEON_LOAD3_3REG_Q) || (cached_type == TYPE_NEON_LOAD4_4REG) || (cached_type == TYPE_NEON_LOAD4_4REG_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4;
        }
      else if ((cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD) || (cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_ONE_LANE) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4_LANE;
        }
      else if ((cached_type == TYPE_NEON_STORE1_1REG) || (cached_type == TYPE_NEON_STORE1_1REG_Q) || (cached_type == TYPE_NEON_STORE1_2REG) || (cached_type == TYPE_NEON_STORE1_2REG_Q) || (cached_type == TYPE_NEON_STORE2_2REG) || (cached_type == TYPE_NEON_STORE2_2REG_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;
        }
      else if ((cached_type == TYPE_NEON_STORE1_3REG) || (cached_type == TYPE_NEON_STORE1_3REG_Q) || (cached_type == TYPE_NEON_STORE1_4REG) || (cached_type == TYPE_NEON_STORE1_4REG_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS;
        }
      else if ((cached_type == TYPE_NEON_STORE2_4REG) || (cached_type == TYPE_NEON_STORE2_4REG_Q) || (cached_type == TYPE_NEON_STORE3_3REG) || (cached_type == TYPE_NEON_STORE3_3REG_Q) || (cached_type == TYPE_NEON_STORE4_4REG) || (cached_type == TYPE_NEON_STORE4_4REG_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;
        }
      else if ((cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE2_ONE_LANE) || (cached_type == TYPE_NEON_STORE2_ONE_LANE_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE;
        }
      else if ((cached_type == TYPE_NEON_STORE3_ONE_LANE) || (cached_type == TYPE_NEON_STORE3_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE4_ONE_LANE) || (cached_type == TYPE_NEON_STORE4_ONE_LANE_Q))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_VST3_VST4_LANE;
        }
      else if ((cached_type == TYPE_NEON_FROM_GP) || (cached_type == TYPE_F_MCR))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR;
        }
      else if ((cached_type == TYPE_NEON_FROM_GP_Q) || (cached_type == TYPE_F_MCRR))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;
        }
      else if ((cached_type == TYPE_NEON_TO_GP) || (cached_type == TYPE_F_MRC))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRC;
        }
      else if ((cached_type == TYPE_NEON_TO_GP_Q) || (cached_type == TYPE_F_MRRC))
        {
	  return CORTEX_A8_NEON_TYPE_NEON_MRRC;
        }
      else
        {
	  return CORTEX_A8_NEON_TYPE_UNKNOWN;
        }

    case 2040:  /* neon_vget_lanev4sf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2031:  /* neon_vget_lanev16qi_sext_internal */
      return CORTEX_A8_NEON_TYPE_NEON_MRRC;

    case 2030:  /* neon_vget_lanev2sf_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2023:  /* neon_vget_lanev8qi_sext_internal */
      return CORTEX_A8_NEON_TYPE_NEON_MRC;

    case 2048:  /* neon_vdup_nv8bf */
    case 2046:  /* neon_vdup_nv8hf */
    case 2044:  /* neon_vdup_nv8hi */
    case 2043:  /* neon_vdup_nv16qi */
      return CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR;

    case 2047:  /* neon_vdup_nv4bf */
    case 2045:  /* neon_vdup_nv4hf */
    case 2042:  /* neon_vdup_nv4hi */
    case 2041:  /* neon_vdup_nv8qi */
      return CORTEX_A8_NEON_TYPE_NEON_MCR;

    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
      return CORTEX_A8_NEON_TYPE_NEON_VST3_VST4_LANE;

    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
      return CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE;

    case 2730:  /* neon_vld4_lanev8bf */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2726:  /* neon_vld4_lanev8hi */
    case 2725:  /* neon_vld4_lanev2sf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2720:  /* neon_vld4_lanev8qi */
    case 2662:  /* neon_vld3_lanev8bf */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2658:  /* neon_vld3_lanev8hi */
    case 2657:  /* neon_vld3_lanev2sf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2652:  /* neon_vld3_lanev8qi */
      return CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4_LANE;

    case 2600:  /* neon_vld2_lanev8bf */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2596:  /* neon_vld2_lanev8hi */
    case 2595:  /* neon_vld2_lanev2sf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2590:  /* neon_vld2_lanev8qi */
    case 2536:  /* neon_vld1_lanev2di */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2530:  /* neon_vld1_lanev16qi */
    case 2529:  /* neon_vld1_lanedi */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2523:  /* neon_vld1_lanev8qi */
    case 883:  /* *push_multi_vfp */
      return CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE;

    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
      return CORTEX_A8_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4;

    case 2562:  /* neon_vst1v2di */
    case 2561:  /* neon_vst1di */
    case 2560:  /* neon_vst1v4sf */
    case 2559:  /* neon_vst1v2sf */
    case 2558:  /* neon_vst1v8bf */
    case 2557:  /* neon_vst1v4bf */
    case 2556:  /* neon_vst1v8hf */
    case 2555:  /* neon_vst1v4hf */
    case 2554:  /* neon_vst1v4si */
    case 2553:  /* neon_vst1v2si */
    case 2552:  /* neon_vst1v8hi */
    case 2551:  /* neon_vst1v4hi */
    case 2550:  /* neon_vst1v16qi */
    case 2549:  /* neon_vst1v8qi */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1070:  /* unaligned_storev8qi */
      return CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS;

    case 2719:  /* neon_vld4qbv4sf */
    case 2718:  /* neon_vld4qbv4si */
    case 2717:  /* neon_vld4qbv8bf */
    case 2716:  /* neon_vld4qbv8hf */
    case 2715:  /* neon_vld4qbv8hi */
    case 2714:  /* neon_vld4qbv16qi */
    case 2713:  /* neon_vld4qav4sf */
    case 2712:  /* neon_vld4qav4si */
    case 2711:  /* neon_vld4qav8bf */
    case 2710:  /* neon_vld4qav8hf */
    case 2709:  /* neon_vld4qav8hi */
    case 2708:  /* neon_vld4qav16qi */
    case 2651:  /* neon_vld3qbv4sf */
    case 2650:  /* neon_vld3qbv4si */
    case 2649:  /* neon_vld3qbv8bf */
    case 2648:  /* neon_vld3qbv8hf */
    case 2647:  /* neon_vld3qbv8hi */
    case 2646:  /* neon_vld3qbv16qi */
    case 2645:  /* neon_vld3qav4sf */
    case 2644:  /* neon_vld3qav4si */
    case 2643:  /* neon_vld3qav8bf */
    case 2642:  /* neon_vld3qav8hf */
    case 2641:  /* neon_vld3qav8hi */
    case 2640:  /* neon_vld3qav16qi */
      return CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4;

    case 2738:  /* neon_vld4_dupv8bf */
    case 2670:  /* neon_vld3_dupv8bf */
      return CORTEX_A8_NEON_TYPE_NEON_VLD2_4_REGS;

    case 2608:  /* neon_vld2_dupv8bf */
    case 2548:  /* neon_vld1_dupv2di */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2543:  /* neon_vld1_dupv16qi */
    case 2542:  /* neon_vld1_dupv2sf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2537:  /* neon_vld1_dupv8qi */
      return CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES;

    case 2854:  /* aes_op_protect_neon_vld1v16qi */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2589:  /* neon_vld2v4sf */
    case 2588:  /* neon_vld2v4si */
    case 2587:  /* neon_vld2v8bf */
    case 2586:  /* neon_vld2v8hf */
    case 2585:  /* neon_vld2v8hi */
    case 2584:  /* neon_vld2v16qi */
    case 2583:  /* neon_vld2di */
    case 2582:  /* neon_vld2v2sf */
    case 2581:  /* neon_vld2v2si */
    case 2580:  /* neon_vld2v4bf */
    case 2579:  /* neon_vld2v4hf */
    case 2578:  /* neon_vld2v4hi */
    case 2577:  /* neon_vld2v8qi */
    case 2522:  /* neon_vld1v2di */
    case 2521:  /* neon_vld1di */
    case 2520:  /* neon_vld1v4sf */
    case 2519:  /* neon_vld1v2sf */
    case 2518:  /* neon_vld1v8bf */
    case 2517:  /* neon_vld1v4bf */
    case 2516:  /* neon_vld1v8hf */
    case 2515:  /* neon_vld1v4hf */
    case 2514:  /* neon_vld1v4si */
    case 2513:  /* neon_vld1v2si */
    case 2512:  /* neon_vld1v8hi */
    case 2511:  /* neon_vld1v4hi */
    case 2510:  /* neon_vld1v16qi */
    case 2509:  /* neon_vld1v8qi */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1111:  /* *movmisalignv16qi_neon_load */
    case 1103:  /* *movmisaligndi_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1097:  /* *movmisalignv8qi_neon_load */
      return CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS;

    case 2507:  /* *neon_vuzpv8hf_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2490:  /* *neon_vzipv16qi_insn */
    case 2478:  /* neon_vtbx4v8qi */
    case 2477:  /* neon_vtbx3v8qi */
    case 2471:  /* neon_vtbl4v8qi */
    case 2470:  /* neon_vtbl3v8qi */
      return CORTEX_A8_NEON_TYPE_NEON_BP_3CYCLE;

    case 2487:  /* *neon_vtrnv8hf_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2476:  /* neon_vtbx2v8qi */
    case 2475:  /* neon_vtbx1v8qi */
    case 2469:  /* neon_vtbl2v8qi */
    case 2468:  /* neon_vtbl1v8qi */
    case 2230:  /* neon_vextv2di */
    case 2228:  /* neon_vextv4sf */
    case 2226:  /* neon_vextv8bf */
    case 2224:  /* neon_vextv8hf */
    case 2222:  /* neon_vextv4si */
    case 2220:  /* neon_vextv8hi */
    case 2218:  /* neon_vextv16qi */
    case 2079:  /* *neon_vswpv2di */
    case 2077:  /* *neon_vswpv4sf */
    case 2075:  /* *neon_vswpv8bf */
    case 2073:  /* *neon_vswpv8hf */
    case 2071:  /* *neon_vswpv4si */
    case 2069:  /* *neon_vswpv8hi */
    case 2067:  /* *neon_vswpv16qi */
      return CORTEX_A8_NEON_TYPE_NEON_BP_2CYCLE;

    case 2816:  /* neon_vec_pack_trunc_v2di */
    case 2815:  /* neon_vec_pack_trunc_v4si */
    case 2814:  /* neon_vec_pack_trunc_v8hi */
    case 2508:  /* *neon_vuzpv4hf_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2489:  /* *neon_vzipv8qi_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2247:  /* neon_vrev16v16qi */
    case 2246:  /* neon_vrev16v8qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2244:  /* neon_vrev32v16qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2242:  /* neon_vrev32v8qi */
    case 2241:  /* neon_vrev64v2di */
    case 2240:  /* neon_vrev64v4sf */
    case 2239:  /* neon_vrev64v2sf */
    case 2238:  /* neon_vrev64v8hf */
    case 2237:  /* neon_vrev64v4hf */
    case 2236:  /* neon_vrev64v4si */
    case 2235:  /* neon_vrev64v2si */
    case 2234:  /* neon_vrev64v8hi */
    case 2233:  /* neon_vrev64v4hi */
    case 2232:  /* neon_vrev64v16qi */
    case 2231:  /* neon_vrev64v8qi */
    case 2229:  /* neon_vextdi */
    case 2227:  /* neon_vextv2sf */
    case 2225:  /* neon_vextv4bf */
    case 2223:  /* neon_vextv4hf */
    case 2221:  /* neon_vextv2si */
    case 2219:  /* neon_vextv4hi */
    case 2217:  /* neon_vextv8qi */
    case 2078:  /* *neon_vswpdi */
    case 2076:  /* *neon_vswpv2sf */
    case 2074:  /* *neon_vswpv4bf */
    case 2072:  /* *neon_vswpv4hf */
    case 2070:  /* *neon_vswpv2si */
    case 2068:  /* *neon_vswpv4hi */
    case 2066:  /* *neon_vswpv8qi */
    case 2065:  /* neon_vdup_lanev8bf_internal */
    case 2064:  /* neon_vdup_lanev4bf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 1914:  /* neon_bswapv2di */
    case 1913:  /* neon_bswapv4si */
    case 1912:  /* neon_bswapv2si */
    case 1911:  /* neon_bswapv8hi */
    case 1910:  /* neon_bswapv4hi */
      return CORTEX_A8_NEON_TYPE_NEON_BP_SIMPLE;

    case 1902:  /* neon_vrsqrtsv8hf */
    case 1901:  /* neon_vrsqrtsv4sf */
    case 1898:  /* neon_vrecpsv8hf */
    case 1897:  /* neon_vrecpsv4sf */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_QQQ;

    case 1903:  /* neon_vrsqrtsv4hf */
    case 1900:  /* neon_vrsqrtsv2sf */
    case 1899:  /* neon_vrecpsv4hf */
    case 1896:  /* neon_vrecpsv2sf */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_DDD;

    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR;

    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1180:  /* mulv8hf3addv8hf_neon */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ;

    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1190:  /* fmav2sf4 */
    case 1181:  /* mulv4hf3addv4hf_neon */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD;

    case 2169:  /* neon_vmul_lanev8hf */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_QQD;

    case 2170:  /* neon_vmul_lanev4hf */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_DDD;

    case 1895:  /* neon_vpminfv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1893:  /* neon_vpminfv2sf */
    case 1892:  /* neon_vpmaxfv2sf */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1405:  /* quad_halves_sminv4sf */
    case 1404:  /* quad_halves_plusv4sf */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VSUM;

    case 2824:  /* neon_vabdv4sf_3 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2818:  /* neon_vabdv8hf_2 */
    case 2136:  /* neon_vcvtpuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2128:  /* neon_vcvtu_nv8hi */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2123:  /* neon_vcvts_nv4si */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2108:  /* neon_vcvtuv8hi */
    case 2107:  /* neon_vcvtsv8hi */
    case 2102:  /* neon_vcvtuv4si */
    case 2101:  /* neon_vcvtsv4si */
    case 2098:  /* neon_vcvtuv4sf */
    case 2097:  /* neon_vcvtsv4sf */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2088:  /* floatv4siv4sf2 */
    case 2022:  /* neon_vrsqrtev4sf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2018:  /* neon_vrecpev4sf */
    case 2017:  /* neon_vrecpev4si */
    case 2013:  /* neon_vrecpev8hf */
    case 1855:  /* fminv4sf3 */
    case 1854:  /* fmaxv4sf3 */
    case 1851:  /* neon_vminnmv4sf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1845:  /* neon_vminnmv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1839:  /* neon_vminfv8hf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1837:  /* neon_vminfv4sf */
    case 1836:  /* neon_vmaxfv4sf */
    case 1785:  /* neon_vabdfv4sf */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1324:  /* neon_vrsqrtev8hf */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1220:  /* neon_vcvtpv4sfv4si */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ;

    case 2823:  /* neon_vabdv2sf_3 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2817:  /* neon_vabdv4hf_2 */
    case 2144:  /* neon_vcvtpuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2126:  /* neon_vcvtu_nv4hi */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2121:  /* neon_vcvts_nv2si */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2106:  /* neon_vcvtuv4hi */
    case 2105:  /* neon_vcvtsv4hi */
    case 2100:  /* neon_vcvtuv2si */
    case 2099:  /* neon_vcvtsv2si */
    case 2096:  /* neon_vcvtuv2sf */
    case 2095:  /* neon_vcvtsv2sf */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2087:  /* floatv2siv2sf2 */
    case 2020:  /* neon_vrsqrtev2sf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2016:  /* neon_vrecpev2sf */
    case 2015:  /* neon_vrecpev2si */
    case 2014:  /* neon_vrecpev4hf */
    case 1853:  /* fminv2sf3 */
    case 1852:  /* fmaxv2sf3 */
    case 1849:  /* neon_vminnmv2sf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1847:  /* neon_vminnmv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1841:  /* neon_vminfv4hf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1835:  /* neon_vminfv2sf */
    case 1834:  /* neon_vmaxfv2sf */
    case 1784:  /* neon_vabdfv2sf */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1690:  /* neon_vceqv2sf_insn_unspec */
    case 1325:  /* neon_vrsqrtev4hf */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1214:  /* neon_vcvtpv2sfv2si */
      return CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD;

    case 2451:  /* neon_vrsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2448:  /* neon_vsras_nv2di */
    case 2447:  /* neon_vrsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2444:  /* neon_vsras_ndi */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2440:  /* neon_vsras_nv4si */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2436:  /* neon_vsras_nv2si */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2424:  /* neon_vsras_nv16qi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2420:  /* neon_vsras_nv8qi */
      return CORTEX_A8_NEON_TYPE_NEON_VSRA_VRSRA;

    case 2467:  /* neon_vsli_nv2di */
    case 2465:  /* neon_vsli_nv4si */
    case 2463:  /* neon_vsli_nv8hi */
    case 2461:  /* neon_vsli_nv16qi */
    case 2459:  /* neon_vsri_nv2di */
    case 2457:  /* neon_vsri_nv4si */
    case 2455:  /* neon_vsri_nv8hi */
    case 2453:  /* neon_vsri_nv16qi */
    case 1379:  /* ashlv2di3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1372:  /* ashlv2di3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1367:  /* ashlv16qi3_signed */
      return CORTEX_A8_NEON_TYPE_NEON_SHIFT_3;

    case 2413:  /* neon_vqshlu_nv2di */
    case 2412:  /* neon_vqshlu_ndi */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2381:  /* neon_vqrshrun_nv2di */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2325:  /* neon_vqrshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2322:  /* neon_vqshlsv2di */
    case 2321:  /* neon_vqrshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2318:  /* neon_vqshlsdi */
    case 2317:  /* neon_vqrshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2314:  /* neon_vqshlsv4si */
    case 2313:  /* neon_vqrshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2310:  /* neon_vqshlsv2si */
    case 2309:  /* neon_vqrshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2305:  /* neon_vqrshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2298:  /* neon_vqshlsv16qi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2294:  /* neon_vqshlsv8qi */
    case 2156:  /* neon_vqmovunv2di */
    case 2155:  /* neon_vqmovunv4si */
    case 2154:  /* neon_vqmovunv8hi */
    case 2153:  /* neon_vqmovnuv2di */
    case 2152:  /* neon_vqmovnsv2di */
    case 2151:  /* neon_vqmovnuv4si */
    case 2150:  /* neon_vqmovnsv4si */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2148:  /* neon_vqmovnsv8hi */
      return CORTEX_A8_NEON_TYPE_NEON_SHIFT_2;

    case 2840:  /* neon_vbfcvt_highv8bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2798:  /* neon_vec_ushiftl_v2si */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2466:  /* neon_vsli_ndi */
    case 2464:  /* neon_vsli_nv2si */
    case 2462:  /* neon_vsli_nv4hi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2458:  /* neon_vsri_ndi */
    case 2456:  /* neon_vsri_nv2si */
    case 2454:  /* neon_vsri_nv4hi */
    case 2452:  /* neon_vsri_nv8qi */
    case 2419:  /* neon_vshllu_nv2si */
    case 2418:  /* neon_vshlls_nv2si */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2389:  /* neon_vshl_nv2di */
    case 2388:  /* neon_vshl_ndi */
    case 2387:  /* neon_vshl_nv4si */
    case 2386:  /* neon_vshl_nv2si */
    case 2385:  /* neon_vshl_nv8hi */
    case 2384:  /* neon_vshl_nv4hi */
    case 2383:  /* neon_vshl_nv16qi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2363:  /* neon_vrshrn_nv2di */
    case 2362:  /* neon_vshrn_nv2di */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2360:  /* neon_vshrn_nv4si */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2357:  /* neon_vrshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2354:  /* neon_vshrs_nv2di */
    case 2353:  /* neon_vrshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2350:  /* neon_vshrs_ndi */
    case 2349:  /* neon_vrshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2346:  /* neon_vshrs_nv4si */
    case 2345:  /* neon_vrshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2342:  /* neon_vshrs_nv2si */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2293:  /* neon_vrshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2290:  /* neon_vshlsv2di */
    case 2289:  /* neon_vrshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2287:  /* neon_vshludi */
    case 2286:  /* neon_vshlsdi */
    case 2285:  /* neon_vrshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2282:  /* neon_vshlsv4si */
    case 2281:  /* neon_vrshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2278:  /* neon_vshlsv2si */
    case 2277:  /* neon_vrshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2274:  /* neon_vshlsv8hi */
    case 2273:  /* neon_vrshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2270:  /* neon_vshlsv4hi */
    case 2269:  /* neon_vrshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2266:  /* neon_vshlsv16qi */
    case 2265:  /* neon_vrshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2262:  /* neon_vshlsv8qi */
    case 2162:  /* neon_vmovluv2si */
    case 2161:  /* neon_vmovlsv2si */
    case 2160:  /* neon_vmovluv4hi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2158:  /* neon_vmovluv8qi */
    case 2157:  /* neon_vmovlsv8qi */
    case 2147:  /* neon_vmovnv2di */
    case 2146:  /* neon_vmovnv4si */
    case 2145:  /* neon_vmovnv8hi */
    case 1377:  /* ashlv2si3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1370:  /* ashlv2si3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1366:  /* ashlv8qi3_signed */
    case 1365:  /* vlshrv4si3_imm */
    case 1364:  /* vlshrv2si3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1355:  /* vashrv16qi3_imm */
    case 1354:  /* vashrv8qi3_imm */
    case 520:  /* mve_vshlq_uv2si */
    case 519:  /* mve_vshlq_sv2si */
    case 516:  /* mve_vshlq_uv4hi */
    case 515:  /* mve_vshlq_sv4hi */
    case 512:  /* mve_vshlq_uv8qi */
    case 511:  /* mve_vshlq_sv8qi */
      return CORTEX_A8_NEON_TYPE_NEON_SHIFT_1;

    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
      return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR;

    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1517:  /* neon_vmulfv8hf */
      return CORTEX_A8_NEON_TYPE_NEON_MUL_QQD_32_SCALAR;

    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
      return CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR;

    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
      return CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR;

    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1588:  /* neon_vqdmlalv2si */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
      return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG;

    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
      return CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG;

    case 2810:  /* neon_vec_umult_v2si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 1601:  /* neon_vqdmullv2si */
    case 1599:  /* neon_vmullpv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1597:  /* neon_vmullsv2si */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1518:  /* neon_vmulfv4hf */
      return CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR;

    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
      return CORTEX_A8_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32;

    case 2808:  /* neon_vec_umult_v4hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2806:  /* neon_vec_umult_v8qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 1600:  /* neon_vqdmullv4hi */
    case 1596:  /* neon_vmullpv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1594:  /* neon_vmullsv4hi */
    case 1593:  /* neon_vmullpv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1591:  /* neon_vmullsv8qi */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
      return CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG;

    case 2804:  /* neon_unpacku_v2si */
    case 2803:  /* neon_unpacks_v2si */
    case 2802:  /* neon_unpacku_v4hi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2799:  /* neon_unpacks_v8qi */
    case 1291:  /* one_cmplv2di2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1289:  /* one_cmplv2sf2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1282:  /* one_cmplv16qi2_neon */
    case 1281:  /* one_cmplv8qi2_neon */
      return CORTEX_A8_NEON_TYPE_NEON_VMOV;

    case 1803:  /* neon_vabauv4si */
    case 1802:  /* neon_vabasv4si */
    case 1799:  /* neon_vabauv8hi */
    case 1798:  /* neon_vabasv8hi */
    case 1795:  /* neon_vabauv16qi */
    case 1794:  /* neon_vabasv16qi */
      return CORTEX_A8_NEON_TYPE_NEON_VABA_QQQ;

    case 1879:  /* neon_vpadaluv4si */
    case 1878:  /* neon_vpadalsv4si */
    case 1877:  /* neon_vpadaluv2si */
    case 1876:  /* neon_vpadalsv2si */
    case 1875:  /* neon_vpadaluv8hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1868:  /* neon_vpadalsv8qi */
    case 1809:  /* neon_vabaluv2si */
    case 1808:  /* neon_vabalsv2si */
    case 1807:  /* neon_vabaluv4hi */
    case 1806:  /* neon_vabalsv4hi */
    case 1805:  /* neon_vabaluv8qi */
    case 1804:  /* neon_vabalsv8qi */
    case 1801:  /* neon_vabauv2si */
    case 1800:  /* neon_vabasv2si */
    case 1797:  /* neon_vabauv4hi */
    case 1796:  /* neon_vabasv4hi */
    case 1793:  /* neon_vabauv8qi */
    case 1792:  /* neon_vabasv8qi */
      return CORTEX_A8_NEON_TYPE_NEON_VABA;

    case 2261:  /* neon_vbslv2di_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2249:  /* neon_vbslv16qi_internal */
    case 2012:  /* popcountv16qi2 */
    case 2010:  /* neon_vclzv4si */
    case 2008:  /* neon_vclzv8hi */
    case 2006:  /* neon_vclzv16qi */
    case 2004:  /* neon_vclsv4si */
    case 2002:  /* neon_vclsv8hi */
    case 2000:  /* neon_vclsv16qi */
      return CORTEX_A8_NEON_TYPE_NEON_BIT_OPS_Q;

    case 1998:  /* neon_vqnegv4si */
    case 1997:  /* neon_vqnegv2si */
    case 1996:  /* neon_vqnegv8hi */
    case 1995:  /* neon_vqnegv4hi */
    case 1994:  /* neon_vqnegv16qi */
    case 1993:  /* neon_vqnegv8qi */
    case 1909:  /* neon_vqabsv4si */
    case 1908:  /* neon_vqabsv2si */
    case 1907:  /* neon_vqabsv8hi */
    case 1906:  /* neon_vqabsv4hi */
    case 1905:  /* neon_vqabsv16qi */
    case 1904:  /* neon_vqabsv8qi */
      return CORTEX_A8_NEON_TYPE_NEON_VQNEG_VQABS;

    case 1891:  /* neon_vpminuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1888:  /* neon_vpmaxsv2si */
    case 1887:  /* neon_vpminuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1883:  /* neon_vpminuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1843:  /* neon_vpminfv4hf */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1833:  /* neon_vminuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1830:  /* neon_vmaxsv4si */
    case 1829:  /* neon_vminuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1826:  /* neon_vmaxsv2si */
    case 1825:  /* neon_vminuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1821:  /* neon_vminuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1817:  /* neon_vminuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1814:  /* neon_vmaxsv16qi */
    case 1813:  /* neon_vminuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1810:  /* neon_vmaxsv8qi */
    case 1791:  /* neon_vabdluv2si */
    case 1790:  /* neon_vabdlsv2si */
    case 1789:  /* neon_vabdluv4hi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1787:  /* neon_vabdluv8qi */
    case 1786:  /* neon_vabdlsv8qi */
    case 1783:  /* neon_vabdv4hf */
    case 1782:  /* neon_vabdv8hf */
    case 1781:  /* neon_vabduv4si */
    case 1780:  /* neon_vabdsv4si */
    case 1779:  /* neon_vabduv2si */
    case 1778:  /* neon_vabdsv2si */
    case 1777:  /* neon_vabduv8hi */
    case 1776:  /* neon_vabdsv8hi */
    case 1775:  /* neon_vabduv4hi */
    case 1774:  /* neon_vabdsv4hi */
    case 1773:  /* neon_vabduv16qi */
    case 1772:  /* neon_vabdsv16qi */
    case 1771:  /* neon_vabduv8qi */
    case 1770:  /* neon_vabdsv8qi */
    case 1731:  /* neon_vcgeuv4si */
    case 1730:  /* neon_vcgtuv4si */
    case 1729:  /* neon_vcgeuv2si */
    case 1728:  /* neon_vcgtuv2si */
    case 1727:  /* neon_vcgeuv8hi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1725:  /* neon_vcgeuv4hi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1722:  /* neon_vcgtuv16qi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1720:  /* neon_vcgtuv8qi */
    case 1643:  /* neon_vhsubuv4si */
    case 1642:  /* neon_vhsubsv4si */
    case 1641:  /* neon_vhsubuv2si */
    case 1640:  /* neon_vhsubsv2si */
    case 1639:  /* neon_vhsubuv8hi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1637:  /* neon_vhsubuv4hi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1634:  /* neon_vhsubsv16qi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1632:  /* neon_vhsubsv8qi */
    case 1631:  /* neon_vqsubuv2di */
    case 1630:  /* neon_vqsubsv2di */
    case 1629:  /* neon_vqsubudi */
    case 1628:  /* neon_vqsubsdi */
    case 1627:  /* neon_vqsubuv4si */
    case 1626:  /* neon_vqsubsv4si */
    case 1625:  /* neon_vqsubuv2si */
    case 1624:  /* neon_vqsubsv2si */
    case 1623:  /* neon_vqsubuv8hi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1621:  /* neon_vqsubuv4hi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1618:  /* neon_vqsubsv16qi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1616:  /* neon_vqsubsv8qi */
    case 1452:  /* *us_subv2sf_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1445:  /* *ss_subv8qi_neon */
    case 1436:  /* neon_vpumaxv2si */
    case 1435:  /* neon_vpumaxv4hi */
    case 1434:  /* neon_vpumaxv8qi */
    case 1433:  /* neon_vpuminv2si */
    case 1432:  /* neon_vpuminv4hi */
    case 1431:  /* neon_vpuminv8qi */
    case 1416:  /* quad_halves_umaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1408:  /* quad_halves_sminv8hi */
    case 1403:  /* quad_halves_umaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1400:  /* quad_halves_sminv4si */
    case 1337:  /* *umaxv4si3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1327:  /* *uminv16qi3_neon */
    case 1326:  /* *uminv8qi3_neon */
      return CORTEX_A8_NEON_TYPE_NEON_INT_5;

    case 1769:  /* neon_vtst_combinev4si */
    case 1768:  /* neon_vtst_combinev2si */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1765:  /* neon_vtst_combinev16qi */
    case 1764:  /* neon_vtst_combinev8qi */
    case 1649:  /* neon_vrsubhnv2di */
    case 1648:  /* neon_vsubhnv2di */
    case 1647:  /* neon_vrsubhnv4si */
    case 1646:  /* neon_vsubhnv4si */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1644:  /* neon_vsubhnv8hi */
    case 1512:  /* neon_vraddhnv2di */
    case 1511:  /* neon_vaddhnv2di */
    case 1510:  /* neon_vraddhnv4si */
    case 1509:  /* neon_vaddhnv4si */
    case 1508:  /* neon_vraddhnv8hi */
    case 1507:  /* neon_vaddhnv8hi */
    case 1506:  /* neon_vqadduv2di */
    case 1505:  /* neon_vqaddsv2di */
    case 1504:  /* neon_vqaddudi */
    case 1503:  /* neon_vqaddsdi */
    case 1502:  /* neon_vqadduv4si */
    case 1501:  /* neon_vqaddsv4si */
    case 1500:  /* neon_vqadduv2si */
    case 1499:  /* neon_vqaddsv2si */
    case 1498:  /* neon_vqadduv8hi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1496:  /* neon_vqadduv4hi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1494:  /* neon_vqadduv16qi */
    case 1493:  /* neon_vqaddsv16qi */
    case 1492:  /* neon_vqadduv8qi */
    case 1491:  /* neon_vqaddsv8qi */
    case 1490:  /* neon_vhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1486:  /* neon_vhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1483:  /* neon_vrhaddsv2si */
    case 1482:  /* neon_vhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1474:  /* neon_vhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1467:  /* neon_vrhaddsv8qi */
    case 1444:  /* *us_addv2sf_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1437:  /* *ss_addv8qi_neon */
    case 1311:  /* neon_negv4hf2 */
    case 1310:  /* neon_absv4hf2 */
    case 1309:  /* neon_negv8hf2 */
    case 1308:  /* neon_absv8hf2 */
      return CORTEX_A8_NEON_TYPE_NEON_INT_4;

    case 1867:  /* neon_vpaddluv4si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1865:  /* neon_vpaddluv2si */
    case 1864:  /* neon_vpaddlsv2si */
    case 1863:  /* neon_vpaddluv8hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1856:  /* neon_vpaddlsv8qi */
    case 1609:  /* neon_vsubluv2si */
    case 1608:  /* neon_vsublsv2si */
    case 1607:  /* neon_vsubluv4hi */
    case 1606:  /* neon_vsublsv4hi */
    case 1605:  /* neon_vsubluv8qi */
    case 1604:  /* neon_vsublsv8qi */
    case 1460:  /* neon_vaddluv2si */
    case 1459:  /* neon_vaddlsv2si */
    case 1458:  /* neon_vaddluv4hi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1456:  /* neon_vaddluv8qi */
    case 1455:  /* neon_vaddlsv8qi */
    case 1422:  /* neon_vpaddv4hf */
    case 1412:  /* quad_halves_plusv16qi */
    case 1407:  /* quad_halves_plusv8hi */
    case 1399:  /* quad_halves_plusv4si */
      return CORTEX_A8_NEON_TYPE_NEON_INT_3;

    case 1615:  /* neon_vsubwuv2si */
    case 1614:  /* neon_vsubwsv2si */
    case 1613:  /* neon_vsubwuv4hi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1610:  /* neon_vsubwsv8qi */
    case 1466:  /* neon_vaddwuv2si */
    case 1465:  /* neon_vaddwsv2si */
    case 1464:  /* neon_vaddwuv4hi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1461:  /* neon_vaddwsv8qi */
    case 1398:  /* widen_usumv2si3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
      return CORTEX_A8_NEON_TYPE_NEON_INT_2;

    case 2260:  /* neon_vbsldi_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2248:  /* neon_vbslv8qi_internal */
    case 2011:  /* popcountv8qi2 */
    case 2009:  /* neon_vclzv2si */
    case 2007:  /* neon_vclzv4hi */
    case 2005:  /* neon_vclzv8qi */
    case 2003:  /* neon_vclsv2si */
    case 2001:  /* neon_vclsv4hi */
    case 1999:  /* neon_vclsv8qi */
    case 1417:  /* arm_reduc_plus_internal_v2di */
    case 1280:  /* xorv2di3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1278:  /* xorv2sf3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1247:  /* andv2di3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1242:  /* andv4si3_neon */
    case 1241:  /* andv2si3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1227:  /* iorv16qi3_neon */
    case 1226:  /* iorv8qi3_neon */
      return CORTEX_A8_NEON_TYPE_NEON_INT_1;

    default:
      return CORTEX_A8_NEON_TYPE_UNKNOWN;

    }
}

enum attr_cortex_a7_neon_type
get_attr_cortex_a7_neon_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_MUL_S_LONG) || (cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q))
        {
	  return CORTEX_A7_NEON_TYPE_NEON_MUL;
        }
      else if ((cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_H_Q) || (cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_FP_MLA_S) || (cached_type == TYPE_NEON_FP_MLA_S_Q) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q))
        {
	  return CORTEX_A7_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return CORTEX_A7_NEON_TYPE_NEON_OTHER;
        }

    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2210:  /* neon_vmls_lanev4sf */
    case 2209:  /* neon_vmls_lanev4si */
    case 2208:  /* neon_vmls_lanev8hi */
    case 2207:  /* neon_vmls_lanev2sf */
    case 2206:  /* neon_vmls_lanev2si */
    case 2205:  /* neon_vmls_lanev4hi */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2198:  /* neon_vmla_lanev4sf */
    case 2197:  /* neon_vmla_lanev4si */
    case 2196:  /* neon_vmla_lanev8hi */
    case 2195:  /* neon_vmla_lanev2sf */
    case 2194:  /* neon_vmla_lanev2si */
    case 2193:  /* neon_vmla_lanev4hi */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1588:  /* neon_vqdmlalv2si */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1562:  /* neon_vmlsv4si_unspec */
    case 1561:  /* neon_vmlsv2si_unspec */
    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1190:  /* fmav2sf4 */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1181:  /* mulv4hf3addv4hf_neon */
    case 1180:  /* mulv8hf3addv8hf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
    case 1177:  /* mulv4si3addv4si_neon */
    case 1176:  /* mulv2si3addv2si_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
      return CORTEX_A7_NEON_TYPE_NEON_MLA;

    case 2810:  /* neon_vec_umult_v2si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2808:  /* neon_vec_umult_v4hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2806:  /* neon_vec_umult_v8qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 2184:  /* neon_vqrdmulh_lanev2si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
    case 2170:  /* neon_vmul_lanev4hf */
    case 2169:  /* neon_vmul_lanev8hf */
    case 2168:  /* neon_vmul_lanev4sf */
    case 2167:  /* neon_vmul_lanev4si */
    case 2166:  /* neon_vmul_lanev8hi */
    case 2165:  /* neon_vmul_lanev2sf */
    case 2164:  /* neon_vmul_lanev2si */
    case 2163:  /* neon_vmul_lanev4hi */
    case 1601:  /* neon_vqdmullv2si */
    case 1600:  /* neon_vqdmullv4hi */
    case 1599:  /* neon_vmullpv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1597:  /* neon_vmullsv2si */
    case 1596:  /* neon_vmullpv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1594:  /* neon_vmullsv4hi */
    case 1593:  /* neon_vmullpv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1591:  /* neon_vmullsv8qi */
    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
    case 1518:  /* neon_vmulfv4hf */
    case 1517:  /* neon_vmulfv8hf */
    case 1516:  /* neon_vmulfv4sf */
    case 1515:  /* neon_vmulfv2sf */
    case 1514:  /* neon_vmulpv16qi */
    case 1513:  /* neon_vmulpv8qi */
    case 1171:  /* *mulv4sf3_neon */
    case 1170:  /* *mulv2sf3_neon */
    case 1169:  /* *mulv4si3_neon */
    case 1168:  /* *mulv2si3_neon */
    case 1167:  /* *mulv8hi3_neon */
    case 1166:  /* *mulv4hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
    case 1164:  /* *mulv8qi3_neon */
      return CORTEX_A7_NEON_TYPE_NEON_MUL;

    default:
      return CORTEX_A7_NEON_TYPE_NEON_OTHER;

    }
}

int
get_attr_ce_count (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 428:  /* *arm_ldrd */
    case 429:  /* *arm_strd */
    case 760:  /* *movdi_vfp */
    case 6565:  /* *p *arm_ldrd */
    case 6566:  /* *p *arm_strd */
    case 6850:  /* *p *movdi_vfp */
      extract_constrain_insn_cached (insn);
      return 
#line 396 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(get_attr_length (insn) / 4);

    case 116:  /* *andsi_iorsi3_notsi */
    case 864:  /* *combine_vcvt_f64_u32 */
    case 865:  /* *combine_vcvt_f64_s32 */
    case 1004:  /* *thumb2_abssi2 */
    case 1005:  /* *thumb2_neg_abssi2 */
    case 6411:  /* *p *andsi_iorsi3_notsi */
    case 6914:  /* *p *combine_vcvt_f64_u32 */
    case 6915:  /* *p *combine_vcvt_f64_s32 */
    case 6923:  /* *p *thumb2_abssi2 */
    case 6924:  /* *p *thumb2_neg_abssi2 */
      return 2;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 1;

    }
}

enum attr_core_cycles
get_attr_core_cycles (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 1053:  /* *thumb2_addsi3_compare0_scratch */
    case 1052:  /* thumb2_addsi3_compare0 */
      if (((cached_type = get_attr_type (insn)) == TYPE_ALUS_IMM) || (cached_type == TYPE_ALUS_SREG))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 7)
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 935:  /* *thumb1_addsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7fULL))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 6542:  /* *p *and_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6538:  /* *p *add_multsi */
    case 323:  /* *and_multsi */
    case 322:  /* *eor_multsi */
    case 321:  /* *orr_multsi */
    case 320:  /* *rsb_multsi */
    case 319:  /* *add_multsi */
      if (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 6930:  /* *p thumb2_zero_extendqisi2_v6 */
    case 6929:  /* *p *thumb2_zero_extendhisi2_v6 */
    case 6928:  /* *p *thumb2_extendqisi_v6 */
    case 6453:  /* *p *arm_extendqisi_v6 */
    case 6452:  /* *p *arm_extendqisi */
    case 6450:  /* *p *arm_extendhisi2_v6 */
    case 6449:  /* *p *arm_extendhisi2 */
    case 6446:  /* *p *arm_zero_extendqisi2_v6 */
    case 6445:  /* *p *arm_zero_extendqisi2 */
    case 6443:  /* *p *arm_zero_extendhisi2_v6 */
    case 6442:  /* *p *arm_zero_extendhisi2 */
    case 1039:  /* thumb2_zero_extendqisi2_v6 */
    case 1038:  /* *thumb2_zero_extendhisi2_v6 */
    case 1037:  /* *thumb2_extendqisi_v6 */
    case 963:  /* *thumb1_movsf_insn */
    case 961:  /* *thumb1_movqi_insn */
    case 960:  /* *thumb1_movhi_insn */
    case 957:  /* thumb1_extendqisi2 */
    case 956:  /* thumb1_extendhisi2 */
    case 955:  /* *thumb1_zero_extendqisi2_v6 */
    case 954:  /* *thumb1_zero_extendqisi2 */
    case 953:  /* *thumb1_zero_extendhisi2 */
    case 946:  /* *thumb1_lshrsi3 */
    case 945:  /* *thumb1_ashrsi3 */
    case 944:  /* *thumb1_ashlsi3 */
    case 335:  /* *ior_scc */
    case 188:  /* *arm_extendqisi_v6 */
    case 187:  /* *arm_extendqisi */
    case 184:  /* *arm_extendhisi2_v6 */
    case 183:  /* *arm_extendhisi2 */
    case 180:  /* *arm_zero_extendqisi2_v6 */
    case 179:  /* *arm_zero_extendqisi2 */
    case 177:  /* *arm_zero_extendhisi2_v6 */
    case 176:  /* *arm_zero_extendhisi2 */
    case 153:  /* *shiftsi3_compare0_scratch */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 6410:  /* *p *arm_xorsi3 */
    case 113:  /* *arm_xorsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 6370:  /* *p *arm_subsi3_insn */
    case 45:  /* *arm_subsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xffULL))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 7025:  /* *p arm_ssatsihi_shift */
    case 6942:  /* *p *orsi_not_shiftsi_si */
    case 6932:  /* *p *thumb2_shiftsi3_short */
    case 6547:  /* *p *and_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6543:  /* *p *add_shiftsi */
    case 6427:  /* *p *arm_shiftsi3 */
    case 6369:  /* *p *rsbsi3_carryin_shift_alt */
    case 6368:  /* *p *rsbsi3_carryin_shift */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6365:  /* *p add_not_shift_cin */
    case 6361:  /* *p *addsi3_carryin_shift */
    case 3036:  /* arm_ssatsihi_shift */
    case 1062:  /* *orsi_not_shiftsi_si */
    case 1046:  /* *thumb2_shiftsi3_short */
    case 361:  /* *if_move_arith */
    case 359:  /* *if_arith_move */
    case 328:  /* *and_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 324:  /* *add_shiftsi */
    case 151:  /* *arm_shiftsi3 */
    case 44:  /* *rsbsi3_carryin_shift_alt */
    case 43:  /* *rsbsi3_carryin_shift */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 41:  /* *subsi3_carryin_shift */
    case 32:  /* add_not_shift_cin */
    case 24:  /* *addsi3_carryin_shift */
      if (((cached_type = get_attr_type (insn)) == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALU_SHIFT_REG))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 6936:  /* *p *thumb2_addsi_short */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 6353:  /* *p *arm_addsi3 */
    case 1050:  /* *thumb2_addsi_short */
    case 355:  /* *if_move_plus */
    case 353:  /* *if_plus_move */
    case 20:  /* *compare_addsi2_op1 */
    case 19:  /* *compare_addsi2_op0 */
    case 18:  /* *addsi3_compare_op2 */
    case 17:  /* addsi3_compare_op1 */
    case 7:  /* *arm_addsi3 */
      if (((cached_type = get_attr_type (insn)) == TYPE_ALU_IMM) || (cached_type == TYPE_ALU_SREG))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_ADC_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_ALU_EXT) || (cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_ALUS_EXT) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CSEL) || (cached_type == TYPE_REV) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_FLOAT) || (cached_type == TYPE_FCSEL) || (cached_type == TYPE_WMMX_WOR) || (cached_type == TYPE_WMMX_WXOR) || (cached_type == TYPE_WMMX_WAND) || (cached_type == TYPE_WMMX_WANDN) || (cached_type == TYPE_WMMX_WMOV) || (cached_type == TYPE_WMMX_TMCRR) || (cached_type == TYPE_WMMX_TMRRC) || (cached_type == TYPE_WMMX_WLDR) || (cached_type == TYPE_WMMX_WSTR) || (cached_type == TYPE_WMMX_TMCR) || (cached_type == TYPE_WMMX_TMRC) || (cached_type == TYPE_WMMX_WADD) || (cached_type == TYPE_WMMX_WSUB) || (cached_type == TYPE_WMMX_WMUL) || (cached_type == TYPE_WMMX_WMAC) || (cached_type == TYPE_WMMX_WAVG2) || (cached_type == TYPE_WMMX_TINSR) || (cached_type == TYPE_WMMX_TEXTRM) || (cached_type == TYPE_WMMX_WSHUFH) || (cached_type == TYPE_WMMX_WCMPEQ) || (cached_type == TYPE_WMMX_WCMPGT) || (cached_type == TYPE_WMMX_WMAX) || (cached_type == TYPE_WMMX_WMIN) || (cached_type == TYPE_WMMX_WPACK) || (cached_type == TYPE_WMMX_WUNPCKIH) || (cached_type == TYPE_WMMX_WUNPCKIL) || (cached_type == TYPE_WMMX_WUNPCKEH) || (cached_type == TYPE_WMMX_WUNPCKEL) || (cached_type == TYPE_WMMX_WROR) || (cached_type == TYPE_WMMX_WSRA) || (cached_type == TYPE_WMMX_WSRL) || (cached_type == TYPE_WMMX_WSLL) || (cached_type == TYPE_WMMX_WMADD) || (cached_type == TYPE_WMMX_TMIA) || (cached_type == TYPE_WMMX_TMIAPH) || (cached_type == TYPE_WMMX_TMIAXY) || (cached_type == TYPE_WMMX_TBCST) || (cached_type == TYPE_WMMX_TMOVMSK) || (cached_type == TYPE_WMMX_WACC) || (cached_type == TYPE_WMMX_WALIGNI) || (cached_type == TYPE_WMMX_WALIGNR) || (cached_type == TYPE_WMMX_TANDC) || (cached_type == TYPE_WMMX_TEXTRC) || (cached_type == TYPE_WMMX_TORC) || (cached_type == TYPE_WMMX_TORVSC) || (cached_type == TYPE_WMMX_WSAD) || (cached_type == TYPE_WMMX_WABS) || (cached_type == TYPE_WMMX_WABSDIFF) || (cached_type == TYPE_WMMX_WADDSUBHX) || (cached_type == TYPE_WMMX_WSUBADDHX) || (cached_type == TYPE_WMMX_WAVG4) || (cached_type == TYPE_WMMX_WMULW) || (cached_type == TYPE_WMMX_WQMULM) || (cached_type == TYPE_WMMX_WQMULWM) || (cached_type == TYPE_WMMX_WADDBHUS) || (cached_type == TYPE_WMMX_WQMIAXY) || (cached_type == TYPE_WMMX_WMIAXY) || (cached_type == TYPE_WMMX_WMIAWXY) || (cached_type == TYPE_WMMX_WMERGE))
        {
	  return CORE_CYCLES_SINGLE;
        }
      else
        {
	  return CORE_CYCLES_MULTI;
        }

    case 7026:  /* *p arm_usatsihi */
    case 7024:  /* *p *arm_sssubsa3 */
    case 7023:  /* *p *arm_sssubsq3 */
    case 7022:  /* *p *arm_sssubha3 */
    case 7021:  /* *p *arm_sssubv2ha3 */
    case 7020:  /* *p *arm_sssubhq3 */
    case 7019:  /* *p *arm_sssubqq3 */
    case 7018:  /* *p *arm_sssubv2hq3 */
    case 7017:  /* *p *arm_sssubv4qq3 */
    case 7016:  /* *p ussubuha3 */
    case 7015:  /* *p ussubv2uha3 */
    case 7014:  /* *p ussubuhq3 */
    case 7013:  /* *p ussubuqq3 */
    case 7012:  /* *p ussubv2uhq3 */
    case 7011:  /* *p ussubv4uqq3 */
    case 7010:  /* *p *arm_subv2ha3 */
    case 7009:  /* *p *arm_subv2hq3 */
    case 7008:  /* *p *arm_subv4qq3 */
    case 7007:  /* *p subusa3 */
    case 7006:  /* *p subuha3 */
    case 7005:  /* *p subsa3 */
    case 7004:  /* *p subha3 */
    case 7003:  /* *p subusq3 */
    case 7002:  /* *p subuhq3 */
    case 7001:  /* *p subuqq3 */
    case 7000:  /* *p subsq3 */
    case 6999:  /* *p subhq3 */
    case 6998:  /* *p subqq3 */
    case 6997:  /* *p *arm_ssaddsa3 */
    case 6996:  /* *p *arm_ssaddsq3 */
    case 6995:  /* *p *arm_ssaddha3 */
    case 6994:  /* *p *arm_ssaddv2ha3 */
    case 6993:  /* *p *arm_ssaddhq3 */
    case 6992:  /* *p *arm_ssaddqq3 */
    case 6991:  /* *p *arm_ssaddv2hq3 */
    case 6990:  /* *p *arm_ssaddv4qq3 */
    case 6989:  /* *p usadduha3 */
    case 6988:  /* *p usaddv2uha3 */
    case 6987:  /* *p usadduhq3 */
    case 6986:  /* *p usadduqq3 */
    case 6985:  /* *p usaddv2uhq3 */
    case 6984:  /* *p usaddv4uqq3 */
    case 6983:  /* *p *arm_addv2ha3 */
    case 6982:  /* *p *arm_addv2hq3 */
    case 6981:  /* *p *arm_addv4qq3 */
    case 6980:  /* *p addusa3 */
    case 6979:  /* *p adduha3 */
    case 6978:  /* *p addsa3 */
    case 6977:  /* *p addha3 */
    case 6976:  /* *p addusq3 */
    case 6975:  /* *p adduhq3 */
    case 6974:  /* *p adduqq3 */
    case 6973:  /* *p addsq3 */
    case 6972:  /* *p addhq3 */
    case 6971:  /* *p addqq3 */
    case 6941:  /* *p *orsi_notsi_si */
    case 6940:  /* *p *thumb2_negsi2_short */
    case 6937:  /* *p *thumb2_subsi_short */
    case 6931:  /* *p *thumb2_alusi3_short */
    case 6835:  /* *p iwmmxt_textrcv8qi3 */
    case 6834:  /* *p iwmmxt_textrcv4hi3 */
    case 6833:  /* *p iwmmxt_textrcv2si3 */
    case 6832:  /* *p iwmmxt_torvscv8qi3 */
    case 6831:  /* *p iwmmxt_torvscv4hi3 */
    case 6830:  /* *p iwmmxt_torvscv2si3 */
    case 6829:  /* *p iwmmxt_torcv8qi3 */
    case 6828:  /* *p iwmmxt_torcv4hi3 */
    case 6827:  /* *p iwmmxt_torcv2si3 */
    case 6826:  /* *p iwmmxt_tandcv8qi3 */
    case 6825:  /* *p iwmmxt_tandcv4hi3 */
    case 6824:  /* *p iwmmxt_tandcv2si3 */
    case 6823:  /* *p iwmmxt_wmerge */
    case 6822:  /* *p iwmmxt_wmiawttn */
    case 6821:  /* *p iwmmxt_wmiawtbn */
    case 6820:  /* *p iwmmxt_wmiawbtn */
    case 6819:  /* *p iwmmxt_wmiawbbn */
    case 6818:  /* *p iwmmxt_wmiawtt */
    case 6817:  /* *p iwmmxt_wmiawtb */
    case 6816:  /* *p iwmmxt_wmiawbt */
    case 6815:  /* *p iwmmxt_wmiawbb */
    case 6814:  /* *p iwmmxt_wmiattn */
    case 6813:  /* *p iwmmxt_wmiatbn */
    case 6812:  /* *p iwmmxt_wmiabtn */
    case 6811:  /* *p iwmmxt_wmiabbn */
    case 6810:  /* *p iwmmxt_wmiatt */
    case 6809:  /* *p iwmmxt_wmiatb */
    case 6808:  /* *p iwmmxt_wmiabt */
    case 6807:  /* *p iwmmxt_wmiabb */
    case 6806:  /* *p iwmmxt_wqmiattn */
    case 6805:  /* *p iwmmxt_wqmiatbn */
    case 6804:  /* *p iwmmxt_wqmiabtn */
    case 6803:  /* *p iwmmxt_wqmiabbn */
    case 6802:  /* *p iwmmxt_wqmiatt */
    case 6801:  /* *p iwmmxt_wqmiatb */
    case 6800:  /* *p iwmmxt_wqmiabt */
    case 6799:  /* *p iwmmxt_wqmiabb */
    case 6798:  /* *p iwmmxt_waddbhusl */
    case 6797:  /* *p iwmmxt_waddbhusm */
    case 6796:  /* *p iwmmxt_wqmulwmr */
    case 6795:  /* *p iwmmxt_wqmulmr */
    case 6794:  /* *p iwmmxt_wqmulwm */
    case 6793:  /* *p iwmmxt_wqmulm */
    case 6792:  /* *p iwmmxt_wmulwl */
    case 6791:  /* *p iwmmxt_wmulwumr */
    case 6790:  /* *p iwmmxt_wmulwsmr */
    case 6789:  /* *p iwmmxt_wmulumr */
    case 6788:  /* *p iwmmxt_wmulsmr */
    case 6787:  /* *p iwmmxt_wmulwum */
    case 6786:  /* *p iwmmxt_wmulwsm */
    case 6785:  /* *p iwmmxt_wmaddun */
    case 6784:  /* *p iwmmxt_wmaddsn */
    case 6783:  /* *p iwmmxt_wmaddux */
    case 6782:  /* *p iwmmxt_wmaddsx */
    case 6781:  /* *p iwmmxt_avg4r */
    case 6780:  /* *p iwmmxt_avg4 */
    case 6779:  /* *p addcv2si3 */
    case 6778:  /* *p addcv4hi3 */
    case 6777:  /* *p iwmmxt_wsubaddhx */
    case 6776:  /* *p iwmmxt_waddsubhx */
    case 6775:  /* *p iwmmxt_wabsdiffw */
    case 6774:  /* *p iwmmxt_wabsdiffh */
    case 6773:  /* *p iwmmxt_wabsdiffb */
    case 6772:  /* *p iwmmxt_wabsv8qi3 */
    case 6771:  /* *p iwmmxt_wabsv4hi3 */
    case 6770:  /* *p iwmmxt_wabsv2si3 */
    case 6769:  /* *p iwmmxt_wsadhz */
    case 6768:  /* *p iwmmxt_wsadbz */
    case 6767:  /* *p iwmmxt_wsadh */
    case 6766:  /* *p iwmmxt_wsadb */
    case 6765:  /* *p iwmmxt_walignr3 */
    case 6764:  /* *p iwmmxt_walignr2 */
    case 6763:  /* *p iwmmxt_walignr1 */
    case 6762:  /* *p iwmmxt_walignr0 */
    case 6761:  /* *p iwmmxt_walignr */
    case 6760:  /* *p iwmmxt_waligni */
    case 6759:  /* *p iwmmxt_waccw */
    case 6758:  /* *p iwmmxt_wacch */
    case 6757:  /* *p iwmmxt_waccb */
    case 6756:  /* *p iwmmxt_tmovmskw */
    case 6755:  /* *p iwmmxt_tmovmskh */
    case 6754:  /* *p iwmmxt_tmovmskb */
    case 6753:  /* *p iwmmxt_tmiatt */
    case 6752:  /* *p iwmmxt_tmiabt */
    case 6751:  /* *p iwmmxt_tmiatb */
    case 6750:  /* *p iwmmxt_tmiabb */
    case 6749:  /* *p iwmmxt_tmiaph */
    case 6748:  /* *p iwmmxt_tmia */
    case 6747:  /* *p iwmmxt_wmaddu */
    case 6746:  /* *p iwmmxt_wmadds */
    case 6745:  /* *p ashldi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6736:  /* *p rordi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6734:  /* *p rorv4hi3_di */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6724:  /* *p rordi3 */
    case 6723:  /* *p rorv2si3 */
    case 6722:  /* *p rorv4hi3 */
    case 6721:  /* *p iwmmxt_wunpckelsw */
    case 6720:  /* *p iwmmxt_wunpckelsh */
    case 6719:  /* *p iwmmxt_wunpckelsb */
    case 6718:  /* *p iwmmxt_wunpckeluw */
    case 6717:  /* *p iwmmxt_wunpckeluh */
    case 6716:  /* *p iwmmxt_wunpckelub */
    case 6715:  /* *p iwmmxt_wunpckehsw */
    case 6714:  /* *p iwmmxt_wunpckehsh */
    case 6713:  /* *p iwmmxt_wunpckehsb */
    case 6712:  /* *p iwmmxt_wunpckehuw */
    case 6711:  /* *p iwmmxt_wunpckehuh */
    case 6710:  /* *p iwmmxt_wunpckehub */
    case 6709:  /* *p iwmmxt_wunpckilw */
    case 6708:  /* *p iwmmxt_wunpckilh */
    case 6707:  /* *p iwmmxt_wunpckilb */
    case 6706:  /* *p iwmmxt_wunpckihw */
    case 6705:  /* *p iwmmxt_wunpckihh */
    case 6704:  /* *p iwmmxt_wunpckihb */
    case 6703:  /* *p iwmmxt_wpackdus */
    case 6702:  /* *p iwmmxt_wpackwus */
    case 6701:  /* *p iwmmxt_wpackhus */
    case 6700:  /* *p iwmmxt_wpackdss */
    case 6699:  /* *p iwmmxt_wpackwss */
    case 6698:  /* *p iwmmxt_wpackhss */
    case 6697:  /* *p *uminv8qi3_iwmmxt */
    case 6696:  /* *p *uminv4hi3_iwmmxt */
    case 6695:  /* *p *uminv2si3_iwmmxt */
    case 6694:  /* *p *sminv8qi3_iwmmxt */
    case 6693:  /* *p *sminv4hi3_iwmmxt */
    case 6692:  /* *p *sminv2si3_iwmmxt */
    case 6691:  /* *p *umaxv8qi3_iwmmxt */
    case 6690:  /* *p *umaxv4hi3_iwmmxt */
    case 6689:  /* *p *umaxv2si3_iwmmxt */
    case 6688:  /* *p *smaxv8qi3_iwmmxt */
    case 6687:  /* *p *smaxv4hi3_iwmmxt */
    case 6686:  /* *p *smaxv2si3_iwmmxt */
    case 6685:  /* *p gtv2si3 */
    case 6684:  /* *p gtv4hi3 */
    case 6683:  /* *p gtv8qi3 */
    case 6682:  /* *p gtuv2si3 */
    case 6681:  /* *p gtuv4hi3 */
    case 6680:  /* *p gtuv8qi3 */
    case 6679:  /* *p eqv2si3 */
    case 6678:  /* *p eqv4hi3 */
    case 6677:  /* *p eqv8qi3 */
    case 6676:  /* *p iwmmxt_wshufh */
    case 6675:  /* *p iwmmxt_textrmw */
    case 6674:  /* *p iwmmxt_textrmsh */
    case 6673:  /* *p iwmmxt_textrmuh */
    case 6672:  /* *p iwmmxt_textrmsb */
    case 6671:  /* *p iwmmxt_textrmub */
    case 6670:  /* *p iwmmxt_tinsrw */
    case 6669:  /* *p iwmmxt_tinsrh */
    case 6668:  /* *p iwmmxt_tinsrb */
    case 6667:  /* *p iwmmxt_uavgv4hi3 */
    case 6666:  /* *p iwmmxt_uavgv8qi3 */
    case 6665:  /* *p iwmmxt_uavgrndv4hi3 */
    case 6664:  /* *p iwmmxt_uavgrndv8qi3 */
    case 6663:  /* *p iwmmxt_clrv2si */
    case 6662:  /* *p iwmmxt_clrv4hi */
    case 6661:  /* *p iwmmxt_clrv8qi */
    case 6660:  /* *p iwmmxt_clrdi */
    case 6659:  /* *p iwmmxt_wmacuz */
    case 6658:  /* *p iwmmxt_wmacu */
    case 6657:  /* *p iwmmxt_wmacsz */
    case 6656:  /* *p iwmmxt_wmacs */
    case 6655:  /* *p umulv4hi3_highpart */
    case 6654:  /* *p smulv4hi3_highpart */
    case 6653:  /* *p *mulv4hi3_iwmmxt */
    case 6652:  /* *p ussubv2si3 */
    case 6651:  /* *p ussubv4hi3 */
    case 6650:  /* *p ussubv8qi3 */
    case 6649:  /* *p sssubv2si3 */
    case 6648:  /* *p sssubv4hi3 */
    case 6647:  /* *p sssubv8qi3 */
    case 6646:  /* *p *subv8qi3_iwmmxt */
    case 6645:  /* *p *subv4hi3_iwmmxt */
    case 6644:  /* *p *subv2si3_iwmmxt */
    case 6643:  /* *p usaddv2si3 */
    case 6642:  /* *p usaddv4hi3 */
    case 6641:  /* *p usaddv8qi3 */
    case 6640:  /* *p ssaddv2si3 */
    case 6639:  /* *p ssaddv4hi3 */
    case 6638:  /* *p ssaddv8qi3 */
    case 6637:  /* *p *addv8qi3_iwmmxt */
    case 6636:  /* *p *addv4hi3_iwmmxt */
    case 6635:  /* *p *addv2si3_iwmmxt */
    case 6634:  /* *p *xorv8qi3_iwmmxt */
    case 6633:  /* *p *xorv4hi3_iwmmxt */
    case 6632:  /* *p *xorv2si3_iwmmxt */
    case 6631:  /* *p *iorv8qi3_iwmmxt */
    case 6630:  /* *p *iorv4hi3_iwmmxt */
    case 6629:  /* *p *iorv2si3_iwmmxt */
    case 6628:  /* *p *andv8qi3_iwmmxt */
    case 6627:  /* *p *andv4hi3_iwmmxt */
    case 6626:  /* *p *andv2si3_iwmmxt */
    case 6622:  /* *p iwmmxt_nanddi3 */
    case 6621:  /* *p iwmmxt_anddi3 */
    case 6620:  /* *p iwmmxt_xordi3 */
    case 6619:  /* *p iwmmxt_iordi3 */
    case 6618:  /* *p tbcstv2si */
    case 6617:  /* *p tbcstv4hi */
    case 6616:  /* *p tbcstv8qi */
    case 6558:  /* *p *arm_rev */
    case 6557:  /* *p *arm_movtas_ze */
    case 6548:  /* *p *sub_shiftsi */
    case 6531:  /* *p *arm_cmpsi_negshiftsi_si */
    case 6530:  /* *p *arm_cmpsi_insn */
    case 6522:  /* *p pic_add_dot_plus_eight */
    case 6520:  /* *p *arm_movt */
    case 6519:  /* *p arm_sel */
    case 6518:  /* *p arm_usat16_setq_insn */
    case 6517:  /* *p arm_usat16_insn */
    case 6516:  /* *p arm_ssat16_setq_insn */
    case 6515:  /* *p arm_ssat16_insn */
    case 6514:  /* *p arm_smuadx_setq_insn */
    case 6513:  /* *p arm_smuadx_insn */
    case 6512:  /* *p arm_smuad_setq_insn */
    case 6511:  /* *p arm_smuad_insn */
    case 6510:  /* *p arm_smlsdx_setq_insn */
    case 6509:  /* *p arm_smlsdx_insn */
    case 6508:  /* *p arm_smlsd_setq_insn */
    case 6507:  /* *p arm_smlsd_insn */
    case 6506:  /* *p arm_smladx_setq_insn */
    case 6505:  /* *p arm_smladx_insn */
    case 6504:  /* *p arm_smlad_setq_insn */
    case 6503:  /* *p arm_smlad_insn */
    case 6502:  /* *p arm_usub16 */
    case 6501:  /* *p arm_usax */
    case 6500:  /* *p arm_uasx */
    case 6499:  /* *p arm_uadd16 */
    case 6498:  /* *p arm_ssub16 */
    case 6497:  /* *p arm_ssax */
    case 6496:  /* *p arm_sasx */
    case 6495:  /* *p arm_sadd16 */
    case 6494:  /* *p arm_usub8 */
    case 6493:  /* *p arm_uadd8 */
    case 6492:  /* *p arm_ssub8 */
    case 6491:  /* *p arm_sadd8 */
    case 6486:  /* *p arm_usada8 */
    case 6485:  /* *p arm_usad8 */
    case 6484:  /* *p arm_uxtab16 */
    case 6483:  /* *p arm_sxtab16 */
    case 6482:  /* *p arm_smusdx */
    case 6481:  /* *p arm_smusd */
    case 6480:  /* *p arm_uqsub16 */
    case 6479:  /* *p arm_uqsax */
    case 6478:  /* *p arm_uqasx */
    case 6477:  /* *p arm_uqadd16 */
    case 6476:  /* *p arm_uhsub16 */
    case 6475:  /* *p arm_uhsax */
    case 6474:  /* *p arm_uhasx */
    case 6473:  /* *p arm_uhadd16 */
    case 6472:  /* *p arm_shsub16 */
    case 6471:  /* *p arm_shsax */
    case 6470:  /* *p arm_shasx */
    case 6469:  /* *p arm_shadd16 */
    case 6468:  /* *p arm_qsub16 */
    case 6467:  /* *p arm_qsax */
    case 6466:  /* *p arm_qasx */
    case 6465:  /* *p arm_qadd16 */
    case 6464:  /* *p arm_uqsub8 */
    case 6463:  /* *p arm_uqadd8 */
    case 6462:  /* *p arm_uhsub8 */
    case 6461:  /* *p arm_uhadd8 */
    case 6460:  /* *p arm_shsub8 */
    case 6459:  /* *p arm_shadd8 */
    case 6458:  /* *p arm_qsub8 */
    case 6457:  /* *p arm_qadd8 */
    case 6456:  /* *p arm_uxtb16 */
    case 6455:  /* *p arm_sxtb16 */
    case 6454:  /* *p *arm_extendqisi2addsi */
    case 6448:  /* *p *compareqi_eq0 */
    case 6447:  /* *p *arm_zero_extendqisi2addsi */
    case 6444:  /* *p *arm_zero_extendhisi2addsi */
    case 6438:  /* *p *arm_negsi2 */
    case 6435:  /* *p extzv_t2 */
    case 6434:  /* *p *extv_reg */
    case 6426:  /* *p *satsi_smax_shift */
    case 6425:  /* *p *satsi_smin_shift */
    case 6424:  /* *p satsi_smax_setq */
    case 6423:  /* *p satsi_smax */
    case 6422:  /* *p satsi_smin_setq */
    case 6421:  /* *p satsi_smin */
    case 6418:  /* *p arm_qsub_setq_insn */
    case 6417:  /* *p arm_qsub_insn */
    case 6416:  /* *p arm_qadd_setq_insn */
    case 6415:  /* *p arm_qadd_insn */
    case 6414:  /* *p *smin_0 */
    case 6413:  /* *p *smax_m1 */
    case 6412:  /* *p *smax_0 */
    case 6409:  /* *p *iorsi3_insn */
    case 6408:  /* *p andsi_not_shiftsi_si_scc */
    case 6407:  /* *p andsi_not_shiftsi_si_scc_no_reuse */
    case 6406:  /* *p andsi_not_shiftsi_si */
    case 6405:  /* *p andsi_notsi_si */
    case 6404:  /* *p *bfi_alt3 */
    case 6403:  /* *p *bfi_alt2 */
    case 6402:  /* *p *bfi_alt1 */
    case 6401:  /* *p *bfi */
    case 6400:  /* *p insv_t2 */
    case 6399:  /* *p insv_zero */
    case 6398:  /* *p *zeroextractsi_compare0_scratch */
    case 6397:  /* *p *arm_andsi3_insn */
    case 6364:  /* *p *add_not_cin */
    case 6363:  /* *p rsbsi_carryin_reg */
    case 6362:  /* *p subsi3_carryin */
    case 6360:  /* *p *addsi3_carryin_alt2 */
    case 6359:  /* *p add0si3_carryin */
    case 6358:  /* *p addsi3_carryin */
    case 6355:  /* *p *compare_negsi_si */
    case 6354:  /* *p *addsi3_compare0_scratch */
    case 3037:  /* arm_usatsihi */
    case 3033:  /* *arm_sssubsa3 */
    case 3032:  /* *arm_sssubsq3 */
    case 3031:  /* *arm_sssubha3 */
    case 3030:  /* *arm_sssubv2ha3 */
    case 3029:  /* *arm_sssubhq3 */
    case 3028:  /* *arm_sssubqq3 */
    case 3027:  /* *arm_sssubv2hq3 */
    case 3026:  /* *arm_sssubv4qq3 */
    case 3025:  /* ussubuha3 */
    case 3024:  /* ussubv2uha3 */
    case 3023:  /* ussubuhq3 */
    case 3022:  /* ussubuqq3 */
    case 3021:  /* ussubv2uhq3 */
    case 3020:  /* ussubv4uqq3 */
    case 3019:  /* *arm_subv2ha3 */
    case 3018:  /* *arm_subv2hq3 */
    case 3017:  /* *arm_subv4qq3 */
    case 3016:  /* subusa3 */
    case 3015:  /* subuha3 */
    case 3014:  /* subsa3 */
    case 3013:  /* subha3 */
    case 3012:  /* subusq3 */
    case 3011:  /* subuhq3 */
    case 3010:  /* subuqq3 */
    case 3009:  /* subsq3 */
    case 3008:  /* subhq3 */
    case 3007:  /* subqq3 */
    case 3006:  /* *arm_ssaddsa3 */
    case 3005:  /* *arm_ssaddsq3 */
    case 3004:  /* *arm_ssaddha3 */
    case 3003:  /* *arm_ssaddv2ha3 */
    case 3002:  /* *arm_ssaddhq3 */
    case 3001:  /* *arm_ssaddqq3 */
    case 3000:  /* *arm_ssaddv2hq3 */
    case 2999:  /* *arm_ssaddv4qq3 */
    case 2998:  /* usadduha3 */
    case 2997:  /* usaddv2uha3 */
    case 2996:  /* usadduhq3 */
    case 2995:  /* usadduqq3 */
    case 2994:  /* usaddv2uhq3 */
    case 2993:  /* usaddv4uqq3 */
    case 2992:  /* *arm_addv2ha3 */
    case 2991:  /* *arm_addv2hq3 */
    case 2990:  /* *arm_addv4qq3 */
    case 2989:  /* addusa3 */
    case 2988:  /* adduha3 */
    case 2987:  /* addsa3 */
    case 2986:  /* addha3 */
    case 2985:  /* addusq3 */
    case 2984:  /* adduhq3 */
    case 2983:  /* adduqq3 */
    case 2982:  /* addsq3 */
    case 2981:  /* addhq3 */
    case 2980:  /* addqq3 */
    case 1061:  /* *orsi_notsi_si */
    case 1060:  /* *thumb2_negsi2_short */
    case 1051:  /* *thumb2_subsi_short */
    case 1045:  /* *thumb2_alusi3_short */
    case 1035:  /* *thumb2_csneg */
    case 1034:  /* *thumb2_csinc */
    case 1033:  /* *thumb2_csinv */
    case 977:  /* *thumb_cmpdi_zero */
    case 949:  /* *thumb1_negsi2 */
    case 943:  /* *thumb1_xorsi3_insn */
    case 942:  /* *thumb1_iorsi3_insn */
    case 941:  /* thumb1_bicsi3 */
    case 940:  /* *thumb1_andsi3_insn */
    case 937:  /* thumb1_subsi3_insn */
    case 745:  /* iwmmxt_textrcv8qi3 */
    case 744:  /* iwmmxt_textrcv4hi3 */
    case 743:  /* iwmmxt_textrcv2si3 */
    case 742:  /* iwmmxt_torvscv8qi3 */
    case 741:  /* iwmmxt_torvscv4hi3 */
    case 740:  /* iwmmxt_torvscv2si3 */
    case 739:  /* iwmmxt_torcv8qi3 */
    case 738:  /* iwmmxt_torcv4hi3 */
    case 737:  /* iwmmxt_torcv2si3 */
    case 736:  /* iwmmxt_tandcv8qi3 */
    case 735:  /* iwmmxt_tandcv4hi3 */
    case 734:  /* iwmmxt_tandcv2si3 */
    case 733:  /* iwmmxt_wmerge */
    case 732:  /* iwmmxt_wmiawttn */
    case 731:  /* iwmmxt_wmiawtbn */
    case 730:  /* iwmmxt_wmiawbtn */
    case 729:  /* iwmmxt_wmiawbbn */
    case 728:  /* iwmmxt_wmiawtt */
    case 727:  /* iwmmxt_wmiawtb */
    case 726:  /* iwmmxt_wmiawbt */
    case 725:  /* iwmmxt_wmiawbb */
    case 724:  /* iwmmxt_wmiattn */
    case 723:  /* iwmmxt_wmiatbn */
    case 722:  /* iwmmxt_wmiabtn */
    case 721:  /* iwmmxt_wmiabbn */
    case 720:  /* iwmmxt_wmiatt */
    case 719:  /* iwmmxt_wmiatb */
    case 718:  /* iwmmxt_wmiabt */
    case 717:  /* iwmmxt_wmiabb */
    case 716:  /* iwmmxt_wqmiattn */
    case 715:  /* iwmmxt_wqmiatbn */
    case 714:  /* iwmmxt_wqmiabtn */
    case 713:  /* iwmmxt_wqmiabbn */
    case 712:  /* iwmmxt_wqmiatt */
    case 711:  /* iwmmxt_wqmiatb */
    case 710:  /* iwmmxt_wqmiabt */
    case 709:  /* iwmmxt_wqmiabb */
    case 708:  /* iwmmxt_waddbhusl */
    case 707:  /* iwmmxt_waddbhusm */
    case 706:  /* iwmmxt_wqmulwmr */
    case 705:  /* iwmmxt_wqmulmr */
    case 704:  /* iwmmxt_wqmulwm */
    case 703:  /* iwmmxt_wqmulm */
    case 702:  /* iwmmxt_wmulwl */
    case 701:  /* iwmmxt_wmulwumr */
    case 700:  /* iwmmxt_wmulwsmr */
    case 699:  /* iwmmxt_wmulumr */
    case 698:  /* iwmmxt_wmulsmr */
    case 697:  /* iwmmxt_wmulwum */
    case 696:  /* iwmmxt_wmulwsm */
    case 695:  /* iwmmxt_wmaddun */
    case 694:  /* iwmmxt_wmaddsn */
    case 693:  /* iwmmxt_wmaddux */
    case 692:  /* iwmmxt_wmaddsx */
    case 691:  /* iwmmxt_avg4r */
    case 690:  /* iwmmxt_avg4 */
    case 689:  /* addcv2si3 */
    case 688:  /* addcv4hi3 */
    case 687:  /* iwmmxt_wsubaddhx */
    case 686:  /* iwmmxt_waddsubhx */
    case 685:  /* iwmmxt_wabsdiffw */
    case 684:  /* iwmmxt_wabsdiffh */
    case 683:  /* iwmmxt_wabsdiffb */
    case 682:  /* iwmmxt_wabsv8qi3 */
    case 681:  /* iwmmxt_wabsv4hi3 */
    case 680:  /* iwmmxt_wabsv2si3 */
    case 679:  /* iwmmxt_wsadhz */
    case 678:  /* iwmmxt_wsadbz */
    case 677:  /* iwmmxt_wsadh */
    case 676:  /* iwmmxt_wsadb */
    case 675:  /* iwmmxt_walignr3 */
    case 674:  /* iwmmxt_walignr2 */
    case 673:  /* iwmmxt_walignr1 */
    case 672:  /* iwmmxt_walignr0 */
    case 671:  /* iwmmxt_walignr */
    case 670:  /* iwmmxt_waligni */
    case 669:  /* iwmmxt_waccw */
    case 668:  /* iwmmxt_wacch */
    case 667:  /* iwmmxt_waccb */
    case 666:  /* iwmmxt_tmovmskw */
    case 665:  /* iwmmxt_tmovmskh */
    case 664:  /* iwmmxt_tmovmskb */
    case 663:  /* iwmmxt_tmiatt */
    case 662:  /* iwmmxt_tmiabt */
    case 661:  /* iwmmxt_tmiatb */
    case 660:  /* iwmmxt_tmiabb */
    case 659:  /* iwmmxt_tmiaph */
    case 658:  /* iwmmxt_tmia */
    case 657:  /* iwmmxt_wmaddu */
    case 656:  /* iwmmxt_wmadds */
    case 655:  /* ashldi3_di */
    case 654:  /* ashlv2si3_di */
    case 653:  /* ashlv4hi3_di */
    case 652:  /* lshrdi3_di */
    case 651:  /* lshrv2si3_di */
    case 650:  /* lshrv4hi3_di */
    case 649:  /* ashrdi3_di */
    case 648:  /* ashrv2si3_di */
    case 647:  /* ashrv4hi3_di */
    case 646:  /* rordi3_di */
    case 645:  /* rorv2si3_di */
    case 644:  /* rorv4hi3_di */
    case 643:  /* ashldi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 634:  /* rordi3 */
    case 633:  /* rorv2si3 */
    case 632:  /* rorv4hi3 */
    case 631:  /* iwmmxt_wunpckelsw */
    case 630:  /* iwmmxt_wunpckelsh */
    case 629:  /* iwmmxt_wunpckelsb */
    case 628:  /* iwmmxt_wunpckeluw */
    case 627:  /* iwmmxt_wunpckeluh */
    case 626:  /* iwmmxt_wunpckelub */
    case 625:  /* iwmmxt_wunpckehsw */
    case 624:  /* iwmmxt_wunpckehsh */
    case 623:  /* iwmmxt_wunpckehsb */
    case 622:  /* iwmmxt_wunpckehuw */
    case 621:  /* iwmmxt_wunpckehuh */
    case 620:  /* iwmmxt_wunpckehub */
    case 619:  /* iwmmxt_wunpckilw */
    case 618:  /* iwmmxt_wunpckilh */
    case 617:  /* iwmmxt_wunpckilb */
    case 616:  /* iwmmxt_wunpckihw */
    case 615:  /* iwmmxt_wunpckihh */
    case 614:  /* iwmmxt_wunpckihb */
    case 613:  /* iwmmxt_wpackdus */
    case 612:  /* iwmmxt_wpackwus */
    case 611:  /* iwmmxt_wpackhus */
    case 610:  /* iwmmxt_wpackdss */
    case 609:  /* iwmmxt_wpackwss */
    case 608:  /* iwmmxt_wpackhss */
    case 607:  /* *uminv8qi3_iwmmxt */
    case 606:  /* *uminv4hi3_iwmmxt */
    case 605:  /* *uminv2si3_iwmmxt */
    case 604:  /* *sminv8qi3_iwmmxt */
    case 603:  /* *sminv4hi3_iwmmxt */
    case 602:  /* *sminv2si3_iwmmxt */
    case 601:  /* *umaxv8qi3_iwmmxt */
    case 600:  /* *umaxv4hi3_iwmmxt */
    case 599:  /* *umaxv2si3_iwmmxt */
    case 598:  /* *smaxv8qi3_iwmmxt */
    case 597:  /* *smaxv4hi3_iwmmxt */
    case 596:  /* *smaxv2si3_iwmmxt */
    case 595:  /* gtv2si3 */
    case 594:  /* gtv4hi3 */
    case 593:  /* gtv8qi3 */
    case 592:  /* gtuv2si3 */
    case 591:  /* gtuv4hi3 */
    case 590:  /* gtuv8qi3 */
    case 589:  /* eqv2si3 */
    case 588:  /* eqv4hi3 */
    case 587:  /* eqv8qi3 */
    case 586:  /* iwmmxt_wshufh */
    case 585:  /* iwmmxt_textrmw */
    case 584:  /* iwmmxt_textrmsh */
    case 583:  /* iwmmxt_textrmuh */
    case 582:  /* iwmmxt_textrmsb */
    case 581:  /* iwmmxt_textrmub */
    case 580:  /* iwmmxt_tinsrw */
    case 579:  /* iwmmxt_tinsrh */
    case 578:  /* iwmmxt_tinsrb */
    case 577:  /* iwmmxt_uavgv4hi3 */
    case 576:  /* iwmmxt_uavgv8qi3 */
    case 575:  /* iwmmxt_uavgrndv4hi3 */
    case 574:  /* iwmmxt_uavgrndv8qi3 */
    case 573:  /* iwmmxt_clrv2si */
    case 572:  /* iwmmxt_clrv4hi */
    case 571:  /* iwmmxt_clrv8qi */
    case 570:  /* iwmmxt_clrdi */
    case 569:  /* iwmmxt_wmacuz */
    case 568:  /* iwmmxt_wmacu */
    case 567:  /* iwmmxt_wmacsz */
    case 566:  /* iwmmxt_wmacs */
    case 565:  /* umulv4hi3_highpart */
    case 564:  /* smulv4hi3_highpart */
    case 563:  /* *mulv4hi3_iwmmxt */
    case 562:  /* ussubv2si3 */
    case 561:  /* ussubv4hi3 */
    case 560:  /* ussubv8qi3 */
    case 559:  /* sssubv2si3 */
    case 558:  /* sssubv4hi3 */
    case 557:  /* sssubv8qi3 */
    case 556:  /* *subv8qi3_iwmmxt */
    case 555:  /* *subv4hi3_iwmmxt */
    case 554:  /* *subv2si3_iwmmxt */
    case 553:  /* usaddv2si3 */
    case 552:  /* usaddv4hi3 */
    case 551:  /* usaddv8qi3 */
    case 550:  /* ssaddv2si3 */
    case 549:  /* ssaddv4hi3 */
    case 548:  /* ssaddv8qi3 */
    case 547:  /* *addv8qi3_iwmmxt */
    case 546:  /* *addv4hi3_iwmmxt */
    case 545:  /* *addv2si3_iwmmxt */
    case 544:  /* *xorv8qi3_iwmmxt */
    case 543:  /* *xorv4hi3_iwmmxt */
    case 542:  /* *xorv2si3_iwmmxt */
    case 541:  /* *iorv8qi3_iwmmxt */
    case 540:  /* *iorv4hi3_iwmmxt */
    case 539:  /* *iorv2si3_iwmmxt */
    case 538:  /* *andv8qi3_iwmmxt */
    case 537:  /* *andv4hi3_iwmmxt */
    case 536:  /* *andv2si3_iwmmxt */
    case 529:  /* iwmmxt_nanddi3 */
    case 528:  /* iwmmxt_anddi3 */
    case 527:  /* iwmmxt_xordi3 */
    case 526:  /* iwmmxt_iordi3 */
    case 525:  /* tbcstv2si */
    case 524:  /* tbcstv4hi */
    case 523:  /* tbcstv8qi */
    case 415:  /* arm_rev16si2_alt */
    case 414:  /* arm_rev16si2 */
    case 413:  /* *arm_rev16 */
    case 412:  /* *arm_revsh */
    case 411:  /* *arm_rev */
    case 410:  /* *arm_movtas_ze */
    case 379:  /* *if_move_neg */
    case 377:  /* *if_neg_move */
    case 333:  /* *sub_shiftsi_compare0_scratch */
    case 332:  /* *sub_shiftsi_compare0 */
    case 331:  /* *sub_shiftsi */
    case 330:  /* *arith_shiftsi_compare0_scratch */
    case 329:  /* *arith_shiftsi_compare0 */
    case 285:  /* *cmovhf */
    case 284:  /* *cmovdf */
    case 283:  /* *cmovsf */
    case 280:  /* *negscc_borrow */
    case 275:  /* *arm_cmpsi_negshiftsi_si */
    case 274:  /* *cmpsi_shiftsi_swp */
    case 273:  /* *cmpsi_shiftsi */
    case 272:  /* *arm_cmpsi_insn */
    case 264:  /* *movsi_compare0 */
    case 262:  /* pic_add_dot_plus_eight */
    case 261:  /* pic_add_dot_plus_four */
    case 256:  /* *arm_movt */
    case 254:  /* arm_sel */
    case 253:  /* arm_usat16_setq_insn */
    case 252:  /* arm_usat16_insn */
    case 251:  /* arm_ssat16_setq_insn */
    case 250:  /* arm_ssat16_insn */
    case 249:  /* arm_smuadx_setq_insn */
    case 248:  /* arm_smuadx_insn */
    case 247:  /* arm_smuad_setq_insn */
    case 246:  /* arm_smuad_insn */
    case 245:  /* arm_smlsdx_setq_insn */
    case 244:  /* arm_smlsdx_insn */
    case 243:  /* arm_smlsd_setq_insn */
    case 242:  /* arm_smlsd_insn */
    case 241:  /* arm_smladx_setq_insn */
    case 240:  /* arm_smladx_insn */
    case 239:  /* arm_smlad_setq_insn */
    case 238:  /* arm_smlad_insn */
    case 237:  /* arm_usub16 */
    case 236:  /* arm_usax */
    case 235:  /* arm_uasx */
    case 234:  /* arm_uadd16 */
    case 233:  /* arm_ssub16 */
    case 232:  /* arm_ssax */
    case 231:  /* arm_sasx */
    case 230:  /* arm_sadd16 */
    case 229:  /* arm_usub8 */
    case 228:  /* arm_uadd8 */
    case 227:  /* arm_ssub8 */
    case 226:  /* arm_sadd8 */
    case 221:  /* arm_usada8 */
    case 220:  /* arm_usad8 */
    case 219:  /* arm_uxtab16 */
    case 218:  /* arm_sxtab16 */
    case 217:  /* arm_smusdx */
    case 216:  /* arm_smusd */
    case 215:  /* arm_uqsub16 */
    case 214:  /* arm_uqsax */
    case 213:  /* arm_uqasx */
    case 212:  /* arm_uqadd16 */
    case 211:  /* arm_uhsub16 */
    case 210:  /* arm_uhsax */
    case 209:  /* arm_uhasx */
    case 208:  /* arm_uhadd16 */
    case 207:  /* arm_shsub16 */
    case 206:  /* arm_shsax */
    case 205:  /* arm_shasx */
    case 204:  /* arm_shadd16 */
    case 203:  /* arm_qsub16 */
    case 202:  /* arm_qsax */
    case 201:  /* arm_qasx */
    case 200:  /* arm_qadd16 */
    case 199:  /* arm_uqsub8 */
    case 198:  /* arm_uqadd8 */
    case 197:  /* arm_uhsub8 */
    case 196:  /* arm_uhadd8 */
    case 195:  /* arm_shsub8 */
    case 194:  /* arm_shadd8 */
    case 193:  /* arm_qsub8 */
    case 192:  /* arm_qadd8 */
    case 191:  /* arm_uxtb16 */
    case 190:  /* arm_sxtb16 */
    case 189:  /* *arm_extendqisi2addsi */
    case 185:  /* *arm_extendhisi2addsi */
    case 182:  /* *compareqi_eq0 */
    case 181:  /* *arm_zero_extendqisi2addsi */
    case 178:  /* *arm_zero_extendhisi2addsi */
    case 170:  /* negsi2_carryin */
    case 169:  /* negsi2_0compare */
    case 168:  /* *arm_negsi2 */
    case 165:  /* extzv_t2 */
    case 164:  /* *extv_reg */
    case 152:  /* *shiftsi3_compare0 */
    case 138:  /* *satsi_smax_shift */
    case 137:  /* *satsi_smin_shift */
    case 136:  /* satsi_smax_setq */
    case 135:  /* satsi_smax */
    case 134:  /* satsi_smin_setq */
    case 133:  /* satsi_smin */
    case 130:  /* arm_qsub_setq_insn */
    case 129:  /* arm_qsub_insn */
    case 128:  /* arm_qadd_setq_insn */
    case 127:  /* arm_qadd_insn */
    case 120:  /* *smin_0 */
    case 118:  /* *smax_m1 */
    case 117:  /* *smax_0 */
    case 115:  /* *xorsi3_compare0_scratch */
    case 114:  /* *xorsi3_compare0 */
    case 112:  /* *iorsi3_compare0_scratch */
    case 111:  /* *iorsi3_compare0 */
    case 110:  /* *iorsi3_insn */
    case 109:  /* *andsi_notsi_si_compare0_scratch */
    case 108:  /* *andsi_notsi_si_compare0 */
    case 107:  /* andsi_not_shiftsi_si_scc */
    case 106:  /* andsi_not_shiftsi_si_scc_no_reuse */
    case 105:  /* andsi_not_shiftsi_si */
    case 104:  /* andsi_notsi_si */
    case 103:  /* *bfi_alt3 */
    case 102:  /* *bfi_alt2 */
    case 101:  /* *bfi_alt1 */
    case 100:  /* *bfi */
    case 99:  /* insv_t2 */
    case 98:  /* insv_zero */
    case 93:  /* *zeroextractsi_compare0_scratch */
    case 92:  /* *andsi3_compare0_scratch */
    case 91:  /* *andsi3_compare0 */
    case 90:  /* *arm_andsi3_insn */
    case 55:  /* subvsi3_borrow_imm */
    case 53:  /* usubvsi3_borrow_imm */
    case 51:  /* rscsi3_CC_Bout_scratch */
    case 50:  /* rscsi3_CC_NVout_scratch */
    case 49:  /* rsb_imm_compare_scratch */
    case 48:  /* rsb_imm_compare */
    case 47:  /* subsi3_compare */
    case 46:  /* subsi3_compare0 */
    case 40:  /* *subsi3_carryin_const0 */
    case 39:  /* *subsi3_carryin_const */
    case 38:  /* cmpsi3_0_carryin_CC_Bout */
    case 37:  /* cmpsi3_0_carryin_CC_NVout */
    case 36:  /* cmpsi3_imm_carryin_CC_Bout */
    case 35:  /* cmpsi3_imm_carryin_CC_NVout */
    case 34:  /* cmpsi3_carryin_CC_Bout */
    case 33:  /* cmpsi3_carryin_CC_NVout */
    case 31:  /* *add_not_cin */
    case 30:  /* rsbsi_carryin_reg */
    case 29:  /* subsi3_carryin */
    case 28:  /* subvsi3_imm1 */
    case 27:  /* subvsi3 */
    case 26:  /* subsi3_compare1 */
    case 25:  /* *addsi3_carryin_clobercc */
    case 23:  /* *addsi3_carryin_alt2 */
    case 22:  /* add0si3_carryin */
    case 21:  /* addsi3_carryin */
    case 16:  /* cmpsi2_addneg */
    case 15:  /* *compare_negsi_si */
    case 14:  /* *addsi3_compare0_scratch */
    case 13:  /* addsi3_compare0 */
    case 12:  /* addsi3_compareV_imm_nosum */
    case 11:  /* addsi3_compareV_imm */
    case 10:  /* subvsi3_intmin */
    case 9:  /* *addsi3_compareV_reg_nosum */
    case 8:  /* addsi3_compareV_reg */
    case 6:  /* *addsi3_cin_cout_0_insn */
    case 5:  /* *addsi3_cin_cout_imm_insn */
    case 4:  /* *addsi3_cin_cout_reg_insn */
    case 3:  /* *addsi3_cin_vout_0_insn */
    case 2:  /* *addsi3_cin_vout_imm_insn */
    case 1:  /* *addsi3_cin_vout_reg_insn */
      return CORE_CYCLES_SINGLE;

    default:
      return CORE_CYCLES_MULTI;

    }
}

enum attr_conds
get_attr_conds (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 3045:  /* *mve_movv2df */
    case 3044:  /* *mve_movv4sf */
    case 3043:  /* *mve_movv8hf */
    case 3042:  /* *mve_movti */
    case 3041:  /* *mve_movv2di */
    case 3040:  /* *mve_movv4si */
    case 3039:  /* *mve_movv8hi */
    case 3038:  /* *mve_movv16qi */
      extract_constrain_insn_cached (insn);
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  if (which_alternative != 5)
	    {
	      return CONDS_UNCONDITIONAL;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  if (get_attr_is_neon_type (insn) == IS_NEON_TYPE_YES)
	    {
	      return CONDS_UNCONDITIONAL;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  if (which_alternative != 7)
	    {
	      return CONDS_UNCONDITIONAL;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  if (((1ULL << which_alternative) & 0x1ffULL))
	    {
	      return CONDS_UNCONDITIONAL;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }

    case 6924:  /* *p *thumb2_neg_abssi2 */
    case 6923:  /* *p *thumb2_abssi2 */
    case 1005:  /* *thumb2_neg_abssi2 */
    case 1004:  /* *thumb2_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
	    {
	      return CONDS_CLOB;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }
      else
        {
	  return CONDS_CLOB;
        }

    case 961:  /* *thumb1_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CONDS_CLOB;
        }
      else if (((1ULL << which_alternative) & 0x1eULL))
        {
	  return CONDS_NOCOND;
        }
      else
        {
	  return CONDS_CLOB;
        }

    case 960:  /* *thumb1_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CONDS_CLOB;
        }
      else if (((1ULL << which_alternative) & 0x1eULL))
        {
	  return CONDS_NOCOND;
        }
      else if (which_alternative == 5)
        {
	  return CONDS_CLOB;
        }
      else
        {
	  return CONDS_NOCOND;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CONDS_SET;
        }
      else if (which_alternative == 1)
        {
	  return CONDS_CLOB;
        }
      else if (which_alternative == 2)
        {
	  return CONDS_NOCOND;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
	    {
	      return CONDS_CLOB;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return CONDS_NOCOND;
        }
      else if (which_alternative == 7)
        {
	  return CONDS_CLOB;
        }
      else
        {
	  return CONDS_NOCOND;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  if (which_alternative == 3)
	    {
	      return CONDS_UNCONDITIONAL;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  if (!((1ULL << which_alternative) & 0x3fffULL))
	    {
	      return CONDS_UNCONDITIONAL;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  if (!((1ULL << which_alternative) & 0x1ffULL))
	    {
	      return CONDS_UNCONDITIONAL;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }

    case 6440:  /* *p *arm_neg_abssi2 */
    case 6439:  /* *p *arm_abssi2 */
    case 172:  /* *arm_neg_abssi2 */
    case 171:  /* *arm_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CONDS_CLOB;
        }
      else
        {
	  if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
	    {
	      return CONDS_CLOB;
	    }
	  else
	    {
	      return CONDS_NOCOND;
	    }
        }

    case 7040:  /* *p mve_sqshll_di */
    case 7039:  /* *p mve_srshrl_di */
    case 7038:  /* *p mve_srshr_si */
    case 7037:  /* *p mve_sqshl_si */
    case 7036:  /* *p mve_urshr_si */
    case 7035:  /* *p mve_uqshl_si */
    case 7034:  /* *p mve_urshrl_di */
    case 7033:  /* *p mve_uqshll_di */
    case 7032:  /* *p mve_sqrshr_si */
    case 7031:  /* *p mve_uqrshl_si */
    case 7030:  /* *p mve_sqrshrl_sat48_di */
    case 7029:  /* *p mve_sqrshrl_sat64_di */
    case 7028:  /* *p mve_uqrshll_sat48_di */
    case 7027:  /* *p mve_uqrshll_sat64_di */
    case 7026:  /* *p arm_usatsihi */
    case 7025:  /* *p arm_ssatsihi_shift */
    case 7024:  /* *p *arm_sssubsa3 */
    case 7023:  /* *p *arm_sssubsq3 */
    case 7022:  /* *p *arm_sssubha3 */
    case 7021:  /* *p *arm_sssubv2ha3 */
    case 7020:  /* *p *arm_sssubhq3 */
    case 7019:  /* *p *arm_sssubqq3 */
    case 7018:  /* *p *arm_sssubv2hq3 */
    case 7017:  /* *p *arm_sssubv4qq3 */
    case 7016:  /* *p ussubuha3 */
    case 7015:  /* *p ussubv2uha3 */
    case 7014:  /* *p ussubuhq3 */
    case 7013:  /* *p ussubuqq3 */
    case 7012:  /* *p ussubv2uhq3 */
    case 7011:  /* *p ussubv4uqq3 */
    case 7010:  /* *p *arm_subv2ha3 */
    case 7009:  /* *p *arm_subv2hq3 */
    case 7008:  /* *p *arm_subv4qq3 */
    case 7007:  /* *p subusa3 */
    case 7006:  /* *p subuha3 */
    case 7005:  /* *p subsa3 */
    case 7004:  /* *p subha3 */
    case 7003:  /* *p subusq3 */
    case 7002:  /* *p subuhq3 */
    case 7001:  /* *p subuqq3 */
    case 7000:  /* *p subsq3 */
    case 6999:  /* *p subhq3 */
    case 6998:  /* *p subqq3 */
    case 6997:  /* *p *arm_ssaddsa3 */
    case 6996:  /* *p *arm_ssaddsq3 */
    case 6995:  /* *p *arm_ssaddha3 */
    case 6994:  /* *p *arm_ssaddv2ha3 */
    case 6993:  /* *p *arm_ssaddhq3 */
    case 6992:  /* *p *arm_ssaddqq3 */
    case 6991:  /* *p *arm_ssaddv2hq3 */
    case 6990:  /* *p *arm_ssaddv4qq3 */
    case 6989:  /* *p usadduha3 */
    case 6988:  /* *p usaddv2uha3 */
    case 6987:  /* *p usadduhq3 */
    case 6986:  /* *p usadduqq3 */
    case 6985:  /* *p usaddv2uhq3 */
    case 6984:  /* *p usaddv4uqq3 */
    case 6983:  /* *p *arm_addv2ha3 */
    case 6982:  /* *p *arm_addv2hq3 */
    case 6981:  /* *p *arm_addv4qq3 */
    case 6980:  /* *p addusa3 */
    case 6979:  /* *p adduha3 */
    case 6978:  /* *p addsa3 */
    case 6977:  /* *p addha3 */
    case 6976:  /* *p addusq3 */
    case 6975:  /* *p adduhq3 */
    case 6974:  /* *p adduqq3 */
    case 6973:  /* *p addsq3 */
    case 6972:  /* *p addhq3 */
    case 6971:  /* *p addqq3 */
    case 6970:  /* *p arm_store_release_exclusivesi */
    case 6969:  /* *p arm_store_release_exclusivehi */
    case 6968:  /* *p arm_store_release_exclusiveqi */
    case 6967:  /* *p arm_store_release_exclusivedi */
    case 6966:  /* *p arm_store_exclusivedi */
    case 6965:  /* *p arm_store_exclusivesi */
    case 6964:  /* *p arm_store_exclusivehi */
    case 6963:  /* *p arm_store_exclusiveqi */
    case 6962:  /* *p arm_load_acquire_exclusivedi */
    case 6961:  /* *p arm_load_exclusivedi */
    case 6960:  /* *p arm_load_acquire_exclusivesi */
    case 6959:  /* *p arm_load_exclusivesi */
    case 6958:  /* *p arm_load_acquire_exclusivehi */
    case 6957:  /* *p arm_load_acquire_exclusiveqi */
    case 6956:  /* *p arm_load_exclusivehi */
    case 6955:  /* *p arm_load_exclusiveqi */
    case 6954:  /* *p arm_atomic_loaddi2_ldrd */
    case 6953:  /* *p atomic_storesi */
    case 6952:  /* *p atomic_storehi */
    case 6951:  /* *p atomic_storeqi */
    case 6950:  /* *p atomic_loadsi */
    case 6949:  /* *p atomic_loadhi */
    case 6948:  /* *p atomic_loadqi */
    case 6947:  /* *p thumb2_lsrl */
    case 6946:  /* *p thumb2_lsll */
    case 6945:  /* *p thumb2_asrl */
    case 6944:  /* *p *clear_multiple */
    case 6943:  /* *p *clear_apsr */
    case 6942:  /* *p *orsi_not_shiftsi_si */
    case 6941:  /* *p *orsi_notsi_si */
    case 6940:  /* *p *thumb2_negsi2_short */
    case 6939:  /* *p *thumb2_one_cmplsi2_short */
    case 6938:  /* *p *thumb2_mulsi_short */
    case 6937:  /* *p *thumb2_subsi_short */
    case 6936:  /* *p *thumb2_addsi_short */
    case 6935:  /* *p *thumb2_movsi_shortim */
    case 6934:  /* *p *thumb2_movhi_shortim */
    case 6933:  /* *p *thumb2_movqi_shortim */
    case 6932:  /* *p *thumb2_shiftsi3_short */
    case 6931:  /* *p *thumb2_alusi3_short */
    case 6930:  /* *p thumb2_zero_extendqisi2_v6 */
    case 6929:  /* *p *thumb2_zero_extendhisi2_v6 */
    case 6928:  /* *p *thumb2_extendqisi_v6 */
    case 6927:  /* *p *thumb2_movhi_insn */
    case 6926:  /* *p *thumb2_movsi_insn */
    case 6925:  /* *p *thumb2_pop_single */
    case 6916:  /* *p *combine_vcvtf2i */
    case 6915:  /* *p *combine_vcvt_f64_s32 */
    case 6914:  /* *p *combine_vcvt_f64_u32 */
    case 6913:  /* *p *combine_vcvt_f32_s32 */
    case 6912:  /* *p *combine_vcvt_f32_u32 */
    case 6911:  /* *p *cmpdf_trap_vfp */
    case 6910:  /* *p *cmpdf_vfp */
    case 6909:  /* *p *cmpsf_trap_vfp */
    case 6908:  /* *p *cmpsf_vfp */
    case 6907:  /* *p lazy_store_multiple_insn */
    case 6906:  /* *p *clear_vfp_multiple */
    case 6905:  /* *p pop_fpsysreg_insn */
    case 6904:  /* *p push_fpsysreg_insn */
    case 6903:  /* *p *sqrtdf2_vfp */
    case 6902:  /* *p *sqrtsf2_vfp */
    case 6901:  /* *p floatunssidf2 */
    case 6900:  /* *p floatunssisf2 */
    case 6899:  /* *p *floatsidf2_vfp */
    case 6898:  /* *p *floatsisf2_vfp */
    case 6897:  /* *p fixuns_truncdfsi2 */
    case 6896:  /* *p fixuns_truncsfsi2 */
    case 6895:  /* *p *truncsidf2_vfp */
    case 6894:  /* *p *truncsisf2_vfp */
    case 6893:  /* *p truncsfhf2 */
    case 6892:  /* *p *extendhfdf2 */
    case 6891:  /* *p *truncdfhf2 */
    case 6890:  /* *p extendhfsf2 */
    case 6889:  /* *p *truncdfsf2_vfp */
    case 6888:  /* *p *extendsfdf2_vfp */
    case 6887:  /* *p *fnmadddf4 */
    case 6886:  /* *p *fnmaddsf4 */
    case 6885:  /* *p *fnmsubdf4 */
    case 6884:  /* *p *fnmsubsf4 */
    case 6883:  /* *p *fmsubdf4 */
    case 6882:  /* *p *fmsubsf4 */
    case 6881:  /* *p fmadf4 */
    case 6880:  /* *p fmasf4 */
    case 6879:  /* *p *muldf3negdfsubdf_vfp */
    case 6878:  /* *p *mulsf3negsfsubsf_vfp */
    case 6877:  /* *p *fmuldf3negdfadddf_vfp */
    case 6876:  /* *p *mulsf3negsfaddsf_vfp */
    case 6875:  /* *p *muldf3subdf_vfp */
    case 6874:  /* *p *mulsf3subsf_vfp */
    case 6873:  /* *p *muldf3adddf_vfp */
    case 6872:  /* *p *mulsf3addsf_vfp */
    case 6871:  /* *p *negmuldf3_vfp */
    case 6870:  /* *p *muldf3negdf_vfp */
    case 6869:  /* *p *negmulsf3_vfp */
    case 6868:  /* *p *mulsf3negsf_vfp */
    case 6867:  /* *p *muldf3_vfp */
    case 6866:  /* *p *mulsf3_vfp */
    case 6865:  /* *p *divdf3_vfp */
    case 6864:  /* *p *divsf3_vfp */
    case 6863:  /* *p *subdf3_vfp */
    case 6862:  /* *p *subsf3_vfp */
    case 6861:  /* *p *adddf3_vfp */
    case 6860:  /* *p *addsf3_vfp */
    case 6859:  /* *p *negdf2_vfp */
    case 6858:  /* *p *negsf2_vfp */
    case 6857:  /* *p *absdf2_vfp */
    case 6856:  /* *p *abssf2_vfp */
    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 6850:  /* *p *movdi_vfp */
    case 6848:  /* *p *arm_movsi_vfp */
    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 6835:  /* *p iwmmxt_textrcv8qi3 */
    case 6834:  /* *p iwmmxt_textrcv4hi3 */
    case 6833:  /* *p iwmmxt_textrcv2si3 */
    case 6832:  /* *p iwmmxt_torvscv8qi3 */
    case 6831:  /* *p iwmmxt_torvscv4hi3 */
    case 6830:  /* *p iwmmxt_torvscv2si3 */
    case 6829:  /* *p iwmmxt_torcv8qi3 */
    case 6828:  /* *p iwmmxt_torcv4hi3 */
    case 6827:  /* *p iwmmxt_torcv2si3 */
    case 6826:  /* *p iwmmxt_tandcv8qi3 */
    case 6825:  /* *p iwmmxt_tandcv4hi3 */
    case 6824:  /* *p iwmmxt_tandcv2si3 */
    case 6823:  /* *p iwmmxt_wmerge */
    case 6822:  /* *p iwmmxt_wmiawttn */
    case 6821:  /* *p iwmmxt_wmiawtbn */
    case 6820:  /* *p iwmmxt_wmiawbtn */
    case 6819:  /* *p iwmmxt_wmiawbbn */
    case 6818:  /* *p iwmmxt_wmiawtt */
    case 6817:  /* *p iwmmxt_wmiawtb */
    case 6816:  /* *p iwmmxt_wmiawbt */
    case 6815:  /* *p iwmmxt_wmiawbb */
    case 6814:  /* *p iwmmxt_wmiattn */
    case 6813:  /* *p iwmmxt_wmiatbn */
    case 6812:  /* *p iwmmxt_wmiabtn */
    case 6811:  /* *p iwmmxt_wmiabbn */
    case 6810:  /* *p iwmmxt_wmiatt */
    case 6809:  /* *p iwmmxt_wmiatb */
    case 6808:  /* *p iwmmxt_wmiabt */
    case 6807:  /* *p iwmmxt_wmiabb */
    case 6806:  /* *p iwmmxt_wqmiattn */
    case 6805:  /* *p iwmmxt_wqmiatbn */
    case 6804:  /* *p iwmmxt_wqmiabtn */
    case 6803:  /* *p iwmmxt_wqmiabbn */
    case 6802:  /* *p iwmmxt_wqmiatt */
    case 6801:  /* *p iwmmxt_wqmiatb */
    case 6800:  /* *p iwmmxt_wqmiabt */
    case 6799:  /* *p iwmmxt_wqmiabb */
    case 6798:  /* *p iwmmxt_waddbhusl */
    case 6797:  /* *p iwmmxt_waddbhusm */
    case 6796:  /* *p iwmmxt_wqmulwmr */
    case 6795:  /* *p iwmmxt_wqmulmr */
    case 6794:  /* *p iwmmxt_wqmulwm */
    case 6793:  /* *p iwmmxt_wqmulm */
    case 6792:  /* *p iwmmxt_wmulwl */
    case 6791:  /* *p iwmmxt_wmulwumr */
    case 6790:  /* *p iwmmxt_wmulwsmr */
    case 6789:  /* *p iwmmxt_wmulumr */
    case 6788:  /* *p iwmmxt_wmulsmr */
    case 6787:  /* *p iwmmxt_wmulwum */
    case 6786:  /* *p iwmmxt_wmulwsm */
    case 6785:  /* *p iwmmxt_wmaddun */
    case 6784:  /* *p iwmmxt_wmaddsn */
    case 6783:  /* *p iwmmxt_wmaddux */
    case 6782:  /* *p iwmmxt_wmaddsx */
    case 6781:  /* *p iwmmxt_avg4r */
    case 6780:  /* *p iwmmxt_avg4 */
    case 6779:  /* *p addcv2si3 */
    case 6778:  /* *p addcv4hi3 */
    case 6777:  /* *p iwmmxt_wsubaddhx */
    case 6776:  /* *p iwmmxt_waddsubhx */
    case 6775:  /* *p iwmmxt_wabsdiffw */
    case 6774:  /* *p iwmmxt_wabsdiffh */
    case 6773:  /* *p iwmmxt_wabsdiffb */
    case 6772:  /* *p iwmmxt_wabsv8qi3 */
    case 6771:  /* *p iwmmxt_wabsv4hi3 */
    case 6770:  /* *p iwmmxt_wabsv2si3 */
    case 6769:  /* *p iwmmxt_wsadhz */
    case 6768:  /* *p iwmmxt_wsadbz */
    case 6767:  /* *p iwmmxt_wsadh */
    case 6766:  /* *p iwmmxt_wsadb */
    case 6765:  /* *p iwmmxt_walignr3 */
    case 6764:  /* *p iwmmxt_walignr2 */
    case 6763:  /* *p iwmmxt_walignr1 */
    case 6762:  /* *p iwmmxt_walignr0 */
    case 6761:  /* *p iwmmxt_walignr */
    case 6760:  /* *p iwmmxt_waligni */
    case 6759:  /* *p iwmmxt_waccw */
    case 6758:  /* *p iwmmxt_wacch */
    case 6757:  /* *p iwmmxt_waccb */
    case 6756:  /* *p iwmmxt_tmovmskw */
    case 6755:  /* *p iwmmxt_tmovmskh */
    case 6754:  /* *p iwmmxt_tmovmskb */
    case 6753:  /* *p iwmmxt_tmiatt */
    case 6752:  /* *p iwmmxt_tmiabt */
    case 6751:  /* *p iwmmxt_tmiatb */
    case 6750:  /* *p iwmmxt_tmiabb */
    case 6749:  /* *p iwmmxt_tmiaph */
    case 6748:  /* *p iwmmxt_tmia */
    case 6747:  /* *p iwmmxt_wmaddu */
    case 6746:  /* *p iwmmxt_wmadds */
    case 6745:  /* *p ashldi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6736:  /* *p rordi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6734:  /* *p rorv4hi3_di */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6724:  /* *p rordi3 */
    case 6723:  /* *p rorv2si3 */
    case 6722:  /* *p rorv4hi3 */
    case 6721:  /* *p iwmmxt_wunpckelsw */
    case 6720:  /* *p iwmmxt_wunpckelsh */
    case 6719:  /* *p iwmmxt_wunpckelsb */
    case 6718:  /* *p iwmmxt_wunpckeluw */
    case 6717:  /* *p iwmmxt_wunpckeluh */
    case 6716:  /* *p iwmmxt_wunpckelub */
    case 6715:  /* *p iwmmxt_wunpckehsw */
    case 6714:  /* *p iwmmxt_wunpckehsh */
    case 6713:  /* *p iwmmxt_wunpckehsb */
    case 6712:  /* *p iwmmxt_wunpckehuw */
    case 6711:  /* *p iwmmxt_wunpckehuh */
    case 6710:  /* *p iwmmxt_wunpckehub */
    case 6709:  /* *p iwmmxt_wunpckilw */
    case 6708:  /* *p iwmmxt_wunpckilh */
    case 6707:  /* *p iwmmxt_wunpckilb */
    case 6706:  /* *p iwmmxt_wunpckihw */
    case 6705:  /* *p iwmmxt_wunpckihh */
    case 6704:  /* *p iwmmxt_wunpckihb */
    case 6703:  /* *p iwmmxt_wpackdus */
    case 6702:  /* *p iwmmxt_wpackwus */
    case 6701:  /* *p iwmmxt_wpackhus */
    case 6700:  /* *p iwmmxt_wpackdss */
    case 6699:  /* *p iwmmxt_wpackwss */
    case 6698:  /* *p iwmmxt_wpackhss */
    case 6697:  /* *p *uminv8qi3_iwmmxt */
    case 6696:  /* *p *uminv4hi3_iwmmxt */
    case 6695:  /* *p *uminv2si3_iwmmxt */
    case 6694:  /* *p *sminv8qi3_iwmmxt */
    case 6693:  /* *p *sminv4hi3_iwmmxt */
    case 6692:  /* *p *sminv2si3_iwmmxt */
    case 6691:  /* *p *umaxv8qi3_iwmmxt */
    case 6690:  /* *p *umaxv4hi3_iwmmxt */
    case 6689:  /* *p *umaxv2si3_iwmmxt */
    case 6688:  /* *p *smaxv8qi3_iwmmxt */
    case 6687:  /* *p *smaxv4hi3_iwmmxt */
    case 6686:  /* *p *smaxv2si3_iwmmxt */
    case 6685:  /* *p gtv2si3 */
    case 6684:  /* *p gtv4hi3 */
    case 6683:  /* *p gtv8qi3 */
    case 6682:  /* *p gtuv2si3 */
    case 6681:  /* *p gtuv4hi3 */
    case 6680:  /* *p gtuv8qi3 */
    case 6679:  /* *p eqv2si3 */
    case 6678:  /* *p eqv4hi3 */
    case 6677:  /* *p eqv8qi3 */
    case 6676:  /* *p iwmmxt_wshufh */
    case 6675:  /* *p iwmmxt_textrmw */
    case 6674:  /* *p iwmmxt_textrmsh */
    case 6673:  /* *p iwmmxt_textrmuh */
    case 6672:  /* *p iwmmxt_textrmsb */
    case 6671:  /* *p iwmmxt_textrmub */
    case 6670:  /* *p iwmmxt_tinsrw */
    case 6669:  /* *p iwmmxt_tinsrh */
    case 6668:  /* *p iwmmxt_tinsrb */
    case 6667:  /* *p iwmmxt_uavgv4hi3 */
    case 6666:  /* *p iwmmxt_uavgv8qi3 */
    case 6665:  /* *p iwmmxt_uavgrndv4hi3 */
    case 6664:  /* *p iwmmxt_uavgrndv8qi3 */
    case 6663:  /* *p iwmmxt_clrv2si */
    case 6662:  /* *p iwmmxt_clrv4hi */
    case 6661:  /* *p iwmmxt_clrv8qi */
    case 6660:  /* *p iwmmxt_clrdi */
    case 6659:  /* *p iwmmxt_wmacuz */
    case 6658:  /* *p iwmmxt_wmacu */
    case 6657:  /* *p iwmmxt_wmacsz */
    case 6656:  /* *p iwmmxt_wmacs */
    case 6655:  /* *p umulv4hi3_highpart */
    case 6654:  /* *p smulv4hi3_highpart */
    case 6653:  /* *p *mulv4hi3_iwmmxt */
    case 6652:  /* *p ussubv2si3 */
    case 6651:  /* *p ussubv4hi3 */
    case 6650:  /* *p ussubv8qi3 */
    case 6649:  /* *p sssubv2si3 */
    case 6648:  /* *p sssubv4hi3 */
    case 6647:  /* *p sssubv8qi3 */
    case 6646:  /* *p *subv8qi3_iwmmxt */
    case 6645:  /* *p *subv4hi3_iwmmxt */
    case 6644:  /* *p *subv2si3_iwmmxt */
    case 6643:  /* *p usaddv2si3 */
    case 6642:  /* *p usaddv4hi3 */
    case 6641:  /* *p usaddv8qi3 */
    case 6640:  /* *p ssaddv2si3 */
    case 6639:  /* *p ssaddv4hi3 */
    case 6638:  /* *p ssaddv8qi3 */
    case 6637:  /* *p *addv8qi3_iwmmxt */
    case 6636:  /* *p *addv4hi3_iwmmxt */
    case 6635:  /* *p *addv2si3_iwmmxt */
    case 6634:  /* *p *xorv8qi3_iwmmxt */
    case 6633:  /* *p *xorv4hi3_iwmmxt */
    case 6632:  /* *p *xorv2si3_iwmmxt */
    case 6631:  /* *p *iorv8qi3_iwmmxt */
    case 6630:  /* *p *iorv4hi3_iwmmxt */
    case 6629:  /* *p *iorv2si3_iwmmxt */
    case 6628:  /* *p *andv8qi3_iwmmxt */
    case 6627:  /* *p *andv4hi3_iwmmxt */
    case 6626:  /* *p *andv2si3_iwmmxt */
    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 6622:  /* *p iwmmxt_nanddi3 */
    case 6621:  /* *p iwmmxt_anddi3 */
    case 6620:  /* *p iwmmxt_xordi3 */
    case 6619:  /* *p iwmmxt_iordi3 */
    case 6618:  /* *p tbcstv2si */
    case 6617:  /* *p tbcstv4hi */
    case 6616:  /* *p tbcstv8qi */
    case 6615:  /* *p *load_multiple */
    case 6614:  /* *p *stm2_db_update */
    case 6613:  /* *p *stm2_db */
    case 6612:  /* *p *ldm2_db_update */
    case 6611:  /* *p *ldm2_db */
    case 6610:  /* *p *stm2_da_update */
    case 6609:  /* *p *stm2_da */
    case 6608:  /* *p *ldm2_da_update */
    case 6607:  /* *p *ldm2_da */
    case 6606:  /* *p *stm2_ib_update */
    case 6605:  /* *p *stm2_ib */
    case 6604:  /* *p *ldm2_ib_update */
    case 6603:  /* *p *ldm2_ib */
    case 6602:  /* *p *stm2_ia_update */
    case 6601:  /* *p *stm2_ */
    case 6600:  /* *p *ldm2_ia_update */
    case 6599:  /* *p *ldm2_ */
    case 6598:  /* *p *stm3_db_update */
    case 6597:  /* *p *stm3_db */
    case 6596:  /* *p *ldm3_db_update */
    case 6595:  /* *p *ldm3_db */
    case 6594:  /* *p *stm3_da_update */
    case 6593:  /* *p *stm3_da */
    case 6592:  /* *p *ldm3_da_update */
    case 6591:  /* *p *ldm3_da */
    case 6590:  /* *p *stm3_ib_update */
    case 6589:  /* *p *stm3_ib */
    case 6588:  /* *p *ldm3_ib_update */
    case 6587:  /* *p *ldm3_ib */
    case 6586:  /* *p *stm3_ia_update */
    case 6585:  /* *p *stm3_ */
    case 6584:  /* *p *ldm3_ia_update */
    case 6583:  /* *p *ldm3_ */
    case 6582:  /* *p *stm4_db_update */
    case 6581:  /* *p *stm4_db */
    case 6580:  /* *p *ldm4_db_update */
    case 6579:  /* *p *ldm4_db */
    case 6578:  /* *p *stm4_da_update */
    case 6577:  /* *p *stm4_da */
    case 6576:  /* *p *ldm4_da_update */
    case 6575:  /* *p *ldm4_da */
    case 6574:  /* *p *stm4_ib_update */
    case 6573:  /* *p *stm4_ib */
    case 6572:  /* *p *ldm4_ib_update */
    case 6571:  /* *p *ldm4_ib */
    case 6570:  /* *p *stm4_ia_update */
    case 6569:  /* *p *stm4_ */
    case 6568:  /* *p *ldm4_ia_update */
    case 6567:  /* *p *ldm4_ */
    case 6566:  /* *p *arm_strd */
    case 6565:  /* *p *arm_ldrd */
    case 6564:  /* *p *thumb2_strd_base_neg */
    case 6563:  /* *p *thumb2_strd_base */
    case 6562:  /* *p *thumb2_strd */
    case 6561:  /* *p *thumb2_ldrd_base_neg */
    case 6560:  /* *p *thumb2_ldrd_base */
    case 6559:  /* *p *thumb2_ldrd */
    case 6558:  /* *p *arm_rev */
    case 6557:  /* *p *arm_movtas_ze */
    case 6555:  /* *p rbitsi2 */
    case 6554:  /* *p clzsi2 */
    case 6553:  /* *p *ldr_with_return */
    case 6552:  /* *p *pop_multiple_with_return */
    case 6551:  /* *p *pop_multiple_with_writeback_and_return */
    case 6550:  /* *p *load_multiple_with_writeback */
    case 6549:  /* *p *arith_adjacentmem */
    case 6548:  /* *p *sub_shiftsi */
    case 6547:  /* *p *and_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6543:  /* *p *add_shiftsi */
    case 6542:  /* *p *and_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6538:  /* *p *add_multsi */
    case 6537:  /* *p *load_indirect_jump */
    case 6536:  /* *p *arm_indirect_jump */
    case 6535:  /* *p probe_stack */
    case 6534:  /* *p *arm_simple_return */
    case 6533:  /* *p *arm_return */
    case 6532:  /* *p *arm_jump */
    case 6529:  /* *p *arm_movsf_soft_insn */
    case 6526:  /* *p *arm_movqi_insn */
    case 6525:  /* *p *movhi_bytes */
    case 6524:  /* *p *movhi_insn_arch4 */
    case 6523:  /* *p tls_load_dot_plus_eight */
    case 6522:  /* *p pic_add_dot_plus_eight */
    case 6521:  /* *p *arm_movsi_insn */
    case 6520:  /* *p *arm_movt */
    case 6519:  /* *p arm_sel */
    case 6518:  /* *p arm_usat16_setq_insn */
    case 6517:  /* *p arm_usat16_insn */
    case 6516:  /* *p arm_ssat16_setq_insn */
    case 6515:  /* *p arm_ssat16_insn */
    case 6514:  /* *p arm_smuadx_setq_insn */
    case 6513:  /* *p arm_smuadx_insn */
    case 6512:  /* *p arm_smuad_setq_insn */
    case 6511:  /* *p arm_smuad_insn */
    case 6510:  /* *p arm_smlsdx_setq_insn */
    case 6509:  /* *p arm_smlsdx_insn */
    case 6508:  /* *p arm_smlsd_setq_insn */
    case 6507:  /* *p arm_smlsd_insn */
    case 6506:  /* *p arm_smladx_setq_insn */
    case 6505:  /* *p arm_smladx_insn */
    case 6504:  /* *p arm_smlad_setq_insn */
    case 6503:  /* *p arm_smlad_insn */
    case 6502:  /* *p arm_usub16 */
    case 6501:  /* *p arm_usax */
    case 6500:  /* *p arm_uasx */
    case 6499:  /* *p arm_uadd16 */
    case 6498:  /* *p arm_ssub16 */
    case 6497:  /* *p arm_ssax */
    case 6496:  /* *p arm_sasx */
    case 6495:  /* *p arm_sadd16 */
    case 6494:  /* *p arm_usub8 */
    case 6493:  /* *p arm_uadd8 */
    case 6492:  /* *p arm_ssub8 */
    case 6491:  /* *p arm_sadd8 */
    case 6490:  /* *p arm_smlsldx */
    case 6489:  /* *p arm_smlsld */
    case 6488:  /* *p arm_smlaldx */
    case 6487:  /* *p arm_smlald */
    case 6486:  /* *p arm_usada8 */
    case 6485:  /* *p arm_usad8 */
    case 6484:  /* *p arm_uxtab16 */
    case 6483:  /* *p arm_sxtab16 */
    case 6482:  /* *p arm_smusdx */
    case 6481:  /* *p arm_smusd */
    case 6480:  /* *p arm_uqsub16 */
    case 6479:  /* *p arm_uqsax */
    case 6478:  /* *p arm_uqasx */
    case 6477:  /* *p arm_uqadd16 */
    case 6476:  /* *p arm_uhsub16 */
    case 6475:  /* *p arm_uhsax */
    case 6474:  /* *p arm_uhasx */
    case 6473:  /* *p arm_uhadd16 */
    case 6472:  /* *p arm_shsub16 */
    case 6471:  /* *p arm_shsax */
    case 6470:  /* *p arm_shasx */
    case 6469:  /* *p arm_shadd16 */
    case 6468:  /* *p arm_qsub16 */
    case 6467:  /* *p arm_qsax */
    case 6466:  /* *p arm_qasx */
    case 6465:  /* *p arm_qadd16 */
    case 6464:  /* *p arm_uqsub8 */
    case 6463:  /* *p arm_uqadd8 */
    case 6462:  /* *p arm_uhsub8 */
    case 6461:  /* *p arm_uhadd8 */
    case 6460:  /* *p arm_shsub8 */
    case 6459:  /* *p arm_shadd8 */
    case 6458:  /* *p arm_qsub8 */
    case 6457:  /* *p arm_qadd8 */
    case 6456:  /* *p arm_uxtb16 */
    case 6455:  /* *p arm_sxtb16 */
    case 6454:  /* *p *arm_extendqisi2addsi */
    case 6453:  /* *p *arm_extendqisi_v6 */
    case 6452:  /* *p *arm_extendqisi */
    case 6451:  /* *p *arm_extendqihi_insn */
    case 6450:  /* *p *arm_extendhisi2_v6 */
    case 6449:  /* *p *arm_extendhisi2 */
    case 6447:  /* *p *arm_zero_extendqisi2addsi */
    case 6446:  /* *p *arm_zero_extendqisi2_v6 */
    case 6445:  /* *p *arm_zero_extendqisi2 */
    case 6444:  /* *p *arm_zero_extendhisi2addsi */
    case 6443:  /* *p *arm_zero_extendhisi2_v6 */
    case 6442:  /* *p *arm_zero_extendhisi2 */
    case 6441:  /* *p *arm_one_cmplsi2 */
    case 6438:  /* *p *arm_negsi2 */
    case 6437:  /* *p udivsi3 */
    case 6436:  /* *p divsi3 */
    case 6435:  /* *p extzv_t2 */
    case 6434:  /* *p *extv_reg */
    case 6433:  /* *p unaligned_storehi */
    case 6432:  /* *p unaligned_storesi */
    case 6431:  /* *p unaligned_loadhiu */
    case 6430:  /* *p unaligned_loadhis */
    case 6429:  /* *p unaligned_loadsi */
    case 6428:  /* *p *not_shiftsi */
    case 6427:  /* *p *arm_shiftsi3 */
    case 6426:  /* *p *satsi_smax_shift */
    case 6425:  /* *p *satsi_smin_shift */
    case 6424:  /* *p satsi_smax_setq */
    case 6423:  /* *p satsi_smax */
    case 6422:  /* *p satsi_smin_setq */
    case 6421:  /* *p satsi_smin */
    case 6418:  /* *p arm_qsub_setq_insn */
    case 6417:  /* *p arm_qsub_insn */
    case 6416:  /* *p arm_qadd_setq_insn */
    case 6415:  /* *p arm_qadd_insn */
    case 6414:  /* *p *smin_0 */
    case 6413:  /* *p *smax_m1 */
    case 6412:  /* *p *smax_0 */
    case 6411:  /* *p *andsi_iorsi3_notsi */
    case 6410:  /* *p *arm_xorsi3 */
    case 6409:  /* *p *iorsi3_insn */
    case 6406:  /* *p andsi_not_shiftsi_si */
    case 6405:  /* *p andsi_notsi_si */
    case 6404:  /* *p *bfi_alt3 */
    case 6403:  /* *p *bfi_alt2 */
    case 6402:  /* *p *bfi_alt1 */
    case 6401:  /* *p *bfi */
    case 6400:  /* *p insv_t2 */
    case 6399:  /* *p insv_zero */
    case 6397:  /* *p *arm_andsi3_insn */
    case 6396:  /* *p arm_smlawt_setq_insn */
    case 6395:  /* *p arm_smlawt_insn */
    case 6394:  /* *p arm_smlawb_setq_insn */
    case 6393:  /* *p arm_smlawb_insn */
    case 6392:  /* *p *maddhidi4tt */
    case 6391:  /* *p *maddhidi4tb */
    case 6390:  /* *p maddhidi4 */
    case 6389:  /* *p arm_smlatt_setq */
    case 6388:  /* *p maddhisi4tt */
    case 6387:  /* *p arm_smlatb_setq */
    case 6386:  /* *p maddhisi4tb */
    case 6385:  /* *p arm_smlabb_setq */
    case 6384:  /* *p *arm_maddhisi4 */
    case 6383:  /* *p *mulhisi3tt */
    case 6382:  /* *p *mulhisi3bt */
    case 6381:  /* *p *mulhisi3tb */
    case 6380:  /* *p mulhisi3 */
    case 6379:  /* *p *umull_high */
    case 6378:  /* *p *smull_high */
    case 6377:  /* *p umlal */
    case 6376:  /* *p smlal */
    case 6375:  /* *p umull */
    case 6374:  /* *p smull */
    case 6373:  /* *p *mls */
    case 6372:  /* *p *mla */
    case 6371:  /* *p *mul */
    case 6370:  /* *p *arm_subsi3_insn */
    case 6353:  /* *p *arm_addsi3 */
    case 4953:  /* arm_vcx3qa_p_v16qi */
    case 4952:  /* arm_vcx3q_p_v16qi */
    case 4951:  /* arm_vcx2qa_p_v16qi */
    case 4950:  /* arm_vcx2q_p_v16qi */
    case 4949:  /* arm_vcx1qa_p_v16qi */
    case 4948:  /* arm_vcx1q_p_v16qi */
    case 4947:  /* arm_vcx3qav16qi */
    case 4946:  /* arm_vcx3qv16qi */
    case 4945:  /* arm_vcx2qav16qi */
    case 4944:  /* arm_vcx2qv16qi */
    case 4943:  /* arm_vcx1qav16qi */
    case 4942:  /* arm_vcx1qv16qi */
    case 4935:  /* mve_sqshll_di */
    case 4934:  /* mve_srshrl_di */
    case 4933:  /* mve_srshr_si */
    case 4932:  /* mve_sqshl_si */
    case 4931:  /* mve_urshr_si */
    case 4930:  /* mve_uqshl_si */
    case 4929:  /* mve_urshrl_di */
    case 4928:  /* mve_uqshll_di */
    case 4927:  /* mve_sqrshr_si */
    case 4926:  /* mve_uqrshl_si */
    case 4925:  /* mve_sqrshrl_sat48_di */
    case 4924:  /* mve_sqrshrl_sat64_di */
    case 4923:  /* mve_uqrshll_sat48_di */
    case 4922:  /* mve_uqrshll_sat64_di */
    case 4903:  /* mve_vld4qv4sf */
    case 4902:  /* mve_vld4qv8hf */
    case 4901:  /* mve_vld4qv4si */
    case 4900:  /* mve_vld4qv8hi */
    case 4899:  /* mve_vld4qv16qi */
    case 4898:  /* mve_vld2qv4sf */
    case 4897:  /* mve_vld2qv8hf */
    case 4896:  /* mve_vld2qv4si */
    case 4895:  /* mve_vld2qv8hi */
    case 4894:  /* mve_vld2qv16qi */
    case 4893:  /* mve_vst2qv4sf */
    case 4892:  /* mve_vst2qv8hf */
    case 4891:  /* mve_vst2qv4si */
    case 4890:  /* mve_vst2qv8hi */
    case 4889:  /* mve_vst2qv16qi */
    case 4872:  /* mve_vldrdq_gather_base_wb_z_uv2di_insn */
    case 4871:  /* mve_vldrdq_gather_base_wb_z_sv2di_insn */
    case 4868:  /* mve_vldrdq_gather_base_wb_uv2di_insn */
    case 4867:  /* mve_vldrdq_gather_base_wb_sv2di_insn */
    case 4866:  /* mve_vldrwq_gather_base_wb_z_fv4sf_insn */
    case 4865:  /* mve_vldrwq_gather_base_wb_fv4sf_insn */
    case 4864:  /* mve_vldrwq_gather_base_wb_z_uv4si_insn */
    case 4863:  /* mve_vldrwq_gather_base_wb_z_sv4si_insn */
    case 4862:  /* mve_vldrwq_gather_base_wb_uv4si_insn */
    case 4861:  /* mve_vldrwq_gather_base_wb_sv4si_insn */
    case 4860:  /* mve_vstrdq_scatter_base_wb_p_uv2di */
    case 4859:  /* mve_vstrdq_scatter_base_wb_p_sv2di */
    case 4858:  /* mve_vstrdq_scatter_base_wb_uv2di */
    case 4857:  /* mve_vstrdq_scatter_base_wb_sv2di */
    case 4856:  /* mve_vstrwq_scatter_base_wb_p_fv4sf */
    case 4855:  /* mve_vstrwq_scatter_base_wb_fv4sf */
    case 4854:  /* mve_vstrwq_scatter_base_wb_p_uv4si */
    case 4853:  /* mve_vstrwq_scatter_base_wb_p_sv4si */
    case 4852:  /* mve_vstrwq_scatter_base_wb_uv4si */
    case 4851:  /* mve_vstrwq_scatter_base_wb_sv4si */
    case 4847:  /* mve_viwdupq_wb_uv4si_insn */
    case 4846:  /* mve_viwdupq_wb_uv8hi_insn */
    case 4845:  /* mve_viwdupq_wb_uv16qi_insn */
    case 4841:  /* mve_vdwdupq_wb_uv4si_insn */
    case 4840:  /* mve_vdwdupq_wb_uv8hi_insn */
    case 4839:  /* mve_vdwdupq_wb_uv16qi_insn */
    case 4838:  /* mve_vddupq_m_wb_uv4si_insn */
    case 4837:  /* mve_vddupq_m_wb_uv8hi_insn */
    case 4836:  /* mve_vddupq_m_wb_uv16qi_insn */
    case 4835:  /* mve_vddupq_uv4si_insn */
    case 4834:  /* mve_vddupq_uv8hi_insn */
    case 4833:  /* mve_vddupq_uv16qi_insn */
    case 4832:  /* mve_vidupq_m_wb_uv4si_insn */
    case 4831:  /* mve_vidupq_m_wb_uv8hi_insn */
    case 4830:  /* mve_vidupq_m_wb_uv16qi_insn */
    case 4829:  /* mve_vidupq_uv4si_insn */
    case 4828:  /* mve_vidupq_uv8hi_insn */
    case 4827:  /* mve_vidupq_uv16qi_insn */
    case 4821:  /* mve_vstrwq_scatter_shifted_offset_uv4si_insn */
    case 4820:  /* mve_vstrwq_scatter_shifted_offset_sv4si_insn */
    case 4819:  /* mve_vstrwq_scatter_shifted_offset_p_uv4si_insn */
    case 4818:  /* mve_vstrwq_scatter_shifted_offset_p_sv4si_insn */
    case 4817:  /* mve_vstrwq_scatter_shifted_offset_p_fv4sf_insn */
    case 4816:  /* mve_vstrwq_scatter_shifted_offset_fv4sf_insn */
    case 4815:  /* mve_vstrwq_scatter_offset_uv4si_insn */
    case 4814:  /* mve_vstrwq_scatter_offset_sv4si_insn */
    case 4813:  /* mve_vstrwq_scatter_offset_p_uv4si_insn */
    case 4812:  /* mve_vstrwq_scatter_offset_p_sv4si_insn */
    case 4811:  /* mve_vstrwq_scatter_offset_p_fv4sf_insn */
    case 4810:  /* mve_vstrwq_scatter_offset_fv4sf_insn */
    case 4809:  /* mve_vstrwq_scatter_base_p_fv4sf */
    case 4808:  /* mve_vstrwq_scatter_base_fv4sf */
    case 4807:  /* mve_vstrhq_scatter_shifted_offset_p_fv8hf_insn */
    case 4806:  /* mve_vstrhq_scatter_shifted_offset_fv8hf_insn */
    case 4805:  /* mve_vstrhq_scatter_offset_p_fv8hf_insn */
    case 4804:  /* mve_vstrhq_scatter_offset_fv8hf_insn */
    case 4803:  /* mve_vstrdq_scatter_shifted_offset_uv2di_insn */
    case 4802:  /* mve_vstrdq_scatter_shifted_offset_sv2di_insn */
    case 4801:  /* mve_vstrdq_scatter_shifted_offset_p_uv2di_insn */
    case 4800:  /* mve_vstrdq_scatter_shifted_offset_p_sv2di_insn */
    case 4799:  /* mve_vstrdq_scatter_offset_uv2di_insn */
    case 4798:  /* mve_vstrdq_scatter_offset_sv2di_insn */
    case 4797:  /* mve_vstrdq_scatter_offset_p_uv2di_insn */
    case 4796:  /* mve_vstrdq_scatter_offset_p_sv2di_insn */
    case 4795:  /* mve_vstrdq_scatter_base_uv2di */
    case 4794:  /* mve_vstrdq_scatter_base_sv2di */
    case 4793:  /* mve_vstrdq_scatter_base_p_uv2di */
    case 4792:  /* mve_vstrdq_scatter_base_p_sv2di */
    case 4791:  /* mve_vstrwq_uv4si */
    case 4790:  /* mve_vstrwq_sv4si */
    case 4789:  /* mve_vstrwq_p_uv4si */
    case 4788:  /* mve_vstrwq_p_sv4si */
    case 4787:  /* mve_vstrwq_p_fv4sf */
    case 4786:  /* mve_vstrwq_fv4sf */
    case 4785:  /* mve_vstrhq_uv4si */
    case 4784:  /* mve_vstrhq_sv4si */
    case 4783:  /* mve_vstrhq_uv8hi */
    case 4782:  /* mve_vstrhq_sv8hi */
    case 4781:  /* mve_vstrhq_scatter_shifted_offset_uv4si_insn */
    case 4780:  /* mve_vstrhq_scatter_shifted_offset_sv4si_insn */
    case 4779:  /* mve_vstrhq_scatter_shifted_offset_uv8hi_insn */
    case 4778:  /* mve_vstrhq_scatter_shifted_offset_sv8hi_insn */
    case 4777:  /* mve_vstrhq_scatter_shifted_offset_p_uv4si_insn */
    case 4776:  /* mve_vstrhq_scatter_shifted_offset_p_sv4si_insn */
    case 4775:  /* mve_vstrhq_scatter_shifted_offset_p_uv8hi_insn */
    case 4774:  /* mve_vstrhq_scatter_shifted_offset_p_sv8hi_insn */
    case 4773:  /* mve_vstrhq_scatter_offset_uv4si_insn */
    case 4772:  /* mve_vstrhq_scatter_offset_sv4si_insn */
    case 4771:  /* mve_vstrhq_scatter_offset_uv8hi_insn */
    case 4770:  /* mve_vstrhq_scatter_offset_sv8hi_insn */
    case 4769:  /* mve_vstrhq_scatter_offset_p_uv4si_insn */
    case 4768:  /* mve_vstrhq_scatter_offset_p_sv4si_insn */
    case 4767:  /* mve_vstrhq_scatter_offset_p_uv8hi_insn */
    case 4766:  /* mve_vstrhq_scatter_offset_p_sv8hi_insn */
    case 4765:  /* mve_vstrhq_p_uv4si */
    case 4764:  /* mve_vstrhq_p_sv4si */
    case 4763:  /* mve_vstrhq_p_uv8hi */
    case 4762:  /* mve_vstrhq_p_sv8hi */
    case 4761:  /* mve_vstrhq_p_fv8hf */
    case 4760:  /* mve_vstrhq_fv8hf */
    case 4759:  /* mve_vldrwq_gather_shifted_offset_z_uv4si */
    case 4758:  /* mve_vldrwq_gather_shifted_offset_z_sv4si */
    case 4757:  /* mve_vldrwq_gather_shifted_offset_z_fv4sf */
    case 4756:  /* mve_vldrwq_gather_shifted_offset_uv4si */
    case 4755:  /* mve_vldrwq_gather_shifted_offset_sv4si */
    case 4754:  /* mve_vldrwq_gather_shifted_offset_fv4sf */
    case 4753:  /* mve_vldrwq_gather_offset_z_uv4si */
    case 4752:  /* mve_vldrwq_gather_offset_z_sv4si */
    case 4751:  /* mve_vldrwq_gather_offset_z_fv4sf */
    case 4750:  /* mve_vldrwq_gather_offset_uv4si */
    case 4749:  /* mve_vldrwq_gather_offset_sv4si */
    case 4748:  /* mve_vldrwq_gather_offset_fv4sf */
    case 4747:  /* mve_vldrwq_gather_base_z_fv4sf */
    case 4746:  /* mve_vldrwq_gather_base_fv4sf */
    case 4745:  /* mve_vldrhq_gather_shifted_offset_z_fv8hf */
    case 4744:  /* mve_vldrhq_gather_shifted_offset_fv8hf */
    case 4743:  /* mve_vldrhq_gather_offset_z_fv8hf */
    case 4742:  /* mve_vldrhq_gather_offset_fv8hf */
    case 4741:  /* mve_vldrdq_gather_shifted_offset_z_uv2di */
    case 4740:  /* mve_vldrdq_gather_shifted_offset_z_sv2di */
    case 4739:  /* mve_vldrdq_gather_shifted_offset_uv2di */
    case 4738:  /* mve_vldrdq_gather_shifted_offset_sv2di */
    case 4737:  /* mve_vldrdq_gather_offset_z_uv2di */
    case 4736:  /* mve_vldrdq_gather_offset_z_sv2di */
    case 4735:  /* mve_vldrdq_gather_offset_uv2di */
    case 4734:  /* mve_vldrdq_gather_offset_sv2di */
    case 4733:  /* mve_vldrdq_gather_base_z_uv2di */
    case 4732:  /* mve_vldrdq_gather_base_z_sv2di */
    case 4731:  /* mve_vldrdq_gather_base_uv2di */
    case 4730:  /* mve_vldrdq_gather_base_sv2di */
    case 4729:  /* mve_vldrwq_z_uv4si */
    case 4728:  /* mve_vldrwq_z_sv4si */
    case 4727:  /* mve_vldrwq_z_fv4sf */
    case 4726:  /* mve_vldrwq_uv4si */
    case 4725:  /* mve_vldrwq_sv4si */
    case 4724:  /* mve_vldrwq_fv4sf */
    case 4723:  /* mve_vldrhq_z_uv4si */
    case 4722:  /* mve_vldrhq_z_sv4si */
    case 4721:  /* mve_vldrhq_z_uv8hi */
    case 4720:  /* mve_vldrhq_z_sv8hi */
    case 4719:  /* mve_vldrhq_z_fv8hf */
    case 4718:  /* mve_vldrhq_uv4si */
    case 4717:  /* mve_vldrhq_sv4si */
    case 4716:  /* mve_vldrhq_uv8hi */
    case 4715:  /* mve_vldrhq_sv8hi */
    case 4714:  /* mve_vldrhq_gather_shifted_offset_z_uv4si */
    case 4713:  /* mve_vldrhq_gather_shifted_offset_z_sv4si */
    case 4712:  /* mve_vldrhq_gather_shifted_offset_z_uv8hi */
    case 4711:  /* mve_vldrhq_gather_shifted_offset_z_sv8hi */
    case 4710:  /* mve_vldrhq_gather_shifted_offset_uv4si */
    case 4709:  /* mve_vldrhq_gather_shifted_offset_sv4si */
    case 4708:  /* mve_vldrhq_gather_shifted_offset_uv8hi */
    case 4707:  /* mve_vldrhq_gather_shifted_offset_sv8hi */
    case 4706:  /* mve_vldrhq_gather_offset_z_uv4si */
    case 4705:  /* mve_vldrhq_gather_offset_z_sv4si */
    case 4704:  /* mve_vldrhq_gather_offset_z_uv8hi */
    case 4703:  /* mve_vldrhq_gather_offset_z_sv8hi */
    case 4702:  /* mve_vldrhq_gather_offset_uv4si */
    case 4701:  /* mve_vldrhq_gather_offset_sv4si */
    case 4700:  /* mve_vldrhq_gather_offset_uv8hi */
    case 4699:  /* mve_vldrhq_gather_offset_sv8hi */
    case 4698:  /* mve_vldrhq_fv8hf */
    case 4697:  /* mve_vldrwq_gather_base_z_uv4si */
    case 4696:  /* mve_vldrwq_gather_base_z_sv4si */
    case 4695:  /* mve_vldrbq_z_uv4si */
    case 4694:  /* mve_vldrbq_z_sv4si */
    case 4693:  /* mve_vldrbq_z_uv8hi */
    case 4692:  /* mve_vldrbq_z_sv8hi */
    case 4691:  /* mve_vldrbq_z_uv16qi */
    case 4690:  /* mve_vldrbq_z_sv16qi */
    case 4689:  /* mve_vldrbq_gather_offset_z_uv4si */
    case 4688:  /* mve_vldrbq_gather_offset_z_sv4si */
    case 4687:  /* mve_vldrbq_gather_offset_z_uv8hi */
    case 4686:  /* mve_vldrbq_gather_offset_z_sv8hi */
    case 4685:  /* mve_vldrbq_gather_offset_z_uv16qi */
    case 4684:  /* mve_vldrbq_gather_offset_z_sv16qi */
    case 4683:  /* mve_vstrbq_p_uv4si */
    case 4682:  /* mve_vstrbq_p_sv4si */
    case 4681:  /* mve_vstrbq_p_uv8hi */
    case 4680:  /* mve_vstrbq_p_sv8hi */
    case 4679:  /* mve_vstrbq_p_uv16qi */
    case 4678:  /* mve_vstrbq_p_sv16qi */
    case 4677:  /* mve_vstrwq_scatter_base_p_uv4si */
    case 4676:  /* mve_vstrwq_scatter_base_p_sv4si */
    case 4675:  /* mve_vstrbq_scatter_offset_p_uv4si_insn */
    case 4674:  /* mve_vstrbq_scatter_offset_p_sv4si_insn */
    case 4673:  /* mve_vstrbq_scatter_offset_p_uv8hi_insn */
    case 4672:  /* mve_vstrbq_scatter_offset_p_sv8hi_insn */
    case 4671:  /* mve_vstrbq_scatter_offset_p_uv16qi_insn */
    case 4670:  /* mve_vstrbq_scatter_offset_p_sv16qi_insn */
    case 4669:  /* mve_vldrwq_gather_base_uv4si */
    case 4668:  /* mve_vldrwq_gather_base_sv4si */
    case 4667:  /* mve_vldrbq_uv4si */
    case 4666:  /* mve_vldrbq_sv4si */
    case 4665:  /* mve_vldrbq_uv8hi */
    case 4664:  /* mve_vldrbq_sv8hi */
    case 4663:  /* mve_vldrbq_uv16qi */
    case 4662:  /* mve_vldrbq_sv16qi */
    case 4661:  /* mve_vldrbq_gather_offset_uv4si */
    case 4660:  /* mve_vldrbq_gather_offset_sv4si */
    case 4659:  /* mve_vldrbq_gather_offset_uv8hi */
    case 4658:  /* mve_vldrbq_gather_offset_sv8hi */
    case 4657:  /* mve_vldrbq_gather_offset_uv16qi */
    case 4656:  /* mve_vldrbq_gather_offset_sv16qi */
    case 4655:  /* mve_vstrwq_scatter_base_uv4si */
    case 4654:  /* mve_vstrwq_scatter_base_sv4si */
    case 4653:  /* mve_vstrbq_scatter_offset_uv4si_insn */
    case 4652:  /* mve_vstrbq_scatter_offset_sv4si_insn */
    case 4651:  /* mve_vstrbq_scatter_offset_uv8hi_insn */
    case 4650:  /* mve_vstrbq_scatter_offset_sv8hi_insn */
    case 4649:  /* mve_vstrbq_scatter_offset_uv16qi_insn */
    case 4648:  /* mve_vstrbq_scatter_offset_sv16qi_insn */
    case 4647:  /* mve_vstrbq_uv4si */
    case 4646:  /* mve_vstrbq_sv4si */
    case 4645:  /* mve_vstrbq_uv8hi */
    case 4644:  /* mve_vstrbq_sv8hi */
    case 4643:  /* mve_vstrbq_uv16qi */
    case 4642:  /* mve_vstrbq_sv16qi */
    case 3722:  /* mve_vshlcq_uv4si */
    case 3721:  /* mve_vshlcq_sv4si */
    case 3720:  /* mve_vshlcq_uv8hi */
    case 3719:  /* mve_vshlcq_sv8hi */
    case 3718:  /* mve_vshlcq_uv16qi */
    case 3717:  /* mve_vshlcq_sv16qi */
    case 3057:  /* mve_vst4qv4sf */
    case 3056:  /* mve_vst4qv8hf */
    case 3055:  /* mve_vst4qv4si */
    case 3054:  /* mve_vst4qv8hi */
    case 3053:  /* mve_vst4qv16qi */
    case 3037:  /* arm_usatsihi */
    case 3036:  /* arm_ssatsihi_shift */
    case 3033:  /* *arm_sssubsa3 */
    case 3032:  /* *arm_sssubsq3 */
    case 3031:  /* *arm_sssubha3 */
    case 3030:  /* *arm_sssubv2ha3 */
    case 3029:  /* *arm_sssubhq3 */
    case 3028:  /* *arm_sssubqq3 */
    case 3027:  /* *arm_sssubv2hq3 */
    case 3026:  /* *arm_sssubv4qq3 */
    case 3025:  /* ussubuha3 */
    case 3024:  /* ussubv2uha3 */
    case 3023:  /* ussubuhq3 */
    case 3022:  /* ussubuqq3 */
    case 3021:  /* ussubv2uhq3 */
    case 3020:  /* ussubv4uqq3 */
    case 3019:  /* *arm_subv2ha3 */
    case 3018:  /* *arm_subv2hq3 */
    case 3017:  /* *arm_subv4qq3 */
    case 3016:  /* subusa3 */
    case 3015:  /* subuha3 */
    case 3014:  /* subsa3 */
    case 3013:  /* subha3 */
    case 3012:  /* subusq3 */
    case 3011:  /* subuhq3 */
    case 3010:  /* subuqq3 */
    case 3009:  /* subsq3 */
    case 3008:  /* subhq3 */
    case 3007:  /* subqq3 */
    case 3006:  /* *arm_ssaddsa3 */
    case 3005:  /* *arm_ssaddsq3 */
    case 3004:  /* *arm_ssaddha3 */
    case 3003:  /* *arm_ssaddv2ha3 */
    case 3002:  /* *arm_ssaddhq3 */
    case 3001:  /* *arm_ssaddqq3 */
    case 3000:  /* *arm_ssaddv2hq3 */
    case 2999:  /* *arm_ssaddv4qq3 */
    case 2998:  /* usadduha3 */
    case 2997:  /* usaddv2uha3 */
    case 2996:  /* usadduhq3 */
    case 2995:  /* usadduqq3 */
    case 2994:  /* usaddv2uhq3 */
    case 2993:  /* usaddv4uqq3 */
    case 2992:  /* *arm_addv2ha3 */
    case 2991:  /* *arm_addv2hq3 */
    case 2990:  /* *arm_addv4qq3 */
    case 2989:  /* addusa3 */
    case 2988:  /* adduha3 */
    case 2987:  /* addsa3 */
    case 2986:  /* addha3 */
    case 2985:  /* addusq3 */
    case 2984:  /* adduhq3 */
    case 2983:  /* adduqq3 */
    case 2982:  /* addsq3 */
    case 2981:  /* addhq3 */
    case 2980:  /* addqq3 */
    case 2979:  /* arm_store_release_exclusivesi */
    case 2978:  /* arm_store_release_exclusivehi */
    case 2977:  /* arm_store_release_exclusiveqi */
    case 2976:  /* arm_store_release_exclusivedi */
    case 2975:  /* arm_store_exclusivedi */
    case 2974:  /* arm_store_exclusivesi */
    case 2973:  /* arm_store_exclusivehi */
    case 2972:  /* arm_store_exclusiveqi */
    case 2971:  /* arm_load_acquire_exclusivedi */
    case 2970:  /* arm_load_exclusivedi */
    case 2969:  /* arm_load_acquire_exclusivesi */
    case 2968:  /* arm_load_exclusivesi */
    case 2967:  /* arm_load_acquire_exclusivehi */
    case 2966:  /* arm_load_acquire_exclusiveqi */
    case 2965:  /* arm_load_exclusivehi */
    case 2964:  /* arm_load_exclusiveqi */
    case 2963:  /* atomic_nand_fetchdi */
    case 2962:  /* atomic_nand_fetchsi */
    case 2961:  /* atomic_nand_fetchhi */
    case 2960:  /* atomic_nand_fetchqi */
    case 2959:  /* atomic_and_fetchdi */
    case 2958:  /* atomic_xor_fetchdi */
    case 2957:  /* atomic_or_fetchdi */
    case 2956:  /* atomic_sub_fetchdi */
    case 2955:  /* atomic_add_fetchdi */
    case 2954:  /* atomic_and_fetchsi */
    case 2953:  /* atomic_xor_fetchsi */
    case 2952:  /* atomic_or_fetchsi */
    case 2951:  /* atomic_sub_fetchsi */
    case 2950:  /* atomic_add_fetchsi */
    case 2949:  /* atomic_and_fetchhi */
    case 2948:  /* atomic_xor_fetchhi */
    case 2947:  /* atomic_or_fetchhi */
    case 2946:  /* atomic_sub_fetchhi */
    case 2945:  /* atomic_add_fetchhi */
    case 2944:  /* atomic_and_fetchqi */
    case 2943:  /* atomic_xor_fetchqi */
    case 2942:  /* atomic_or_fetchqi */
    case 2941:  /* atomic_sub_fetchqi */
    case 2940:  /* atomic_add_fetchqi */
    case 2939:  /* atomic_fetch_nanddi */
    case 2938:  /* atomic_fetch_nandsi */
    case 2937:  /* atomic_fetch_nandhi */
    case 2936:  /* atomic_fetch_nandqi */
    case 2935:  /* atomic_fetch_anddi */
    case 2934:  /* atomic_fetch_xordi */
    case 2933:  /* atomic_fetch_ordi */
    case 2932:  /* atomic_fetch_subdi */
    case 2931:  /* atomic_fetch_adddi */
    case 2930:  /* atomic_fetch_andsi */
    case 2929:  /* atomic_fetch_xorsi */
    case 2928:  /* atomic_fetch_orsi */
    case 2927:  /* atomic_fetch_subsi */
    case 2926:  /* atomic_fetch_addsi */
    case 2925:  /* atomic_fetch_andhi */
    case 2924:  /* atomic_fetch_xorhi */
    case 2923:  /* atomic_fetch_orhi */
    case 2922:  /* atomic_fetch_subhi */
    case 2921:  /* atomic_fetch_addhi */
    case 2920:  /* atomic_fetch_andqi */
    case 2919:  /* atomic_fetch_xorqi */
    case 2918:  /* atomic_fetch_orqi */
    case 2917:  /* atomic_fetch_subqi */
    case 2916:  /* atomic_fetch_addqi */
    case 2915:  /* atomic_nanddi */
    case 2914:  /* atomic_nandsi */
    case 2913:  /* atomic_nandhi */
    case 2912:  /* atomic_nandqi */
    case 2911:  /* atomic_anddi */
    case 2910:  /* atomic_xordi */
    case 2909:  /* atomic_ordi */
    case 2908:  /* atomic_subdi */
    case 2907:  /* atomic_adddi */
    case 2906:  /* atomic_andsi */
    case 2905:  /* atomic_xorsi */
    case 2904:  /* atomic_orsi */
    case 2903:  /* atomic_subsi */
    case 2902:  /* atomic_addsi */
    case 2901:  /* atomic_andhi */
    case 2900:  /* atomic_xorhi */
    case 2899:  /* atomic_orhi */
    case 2898:  /* atomic_subhi */
    case 2897:  /* atomic_addhi */
    case 2896:  /* atomic_andqi */
    case 2895:  /* atomic_xorqi */
    case 2894:  /* atomic_orqi */
    case 2893:  /* atomic_subqi */
    case 2892:  /* atomic_addqi */
    case 2891:  /* atomic_exchangedi */
    case 2890:  /* atomic_exchangesi */
    case 2889:  /* atomic_exchangehi */
    case 2888:  /* atomic_exchangeqi */
    case 2887:  /* atomic_compare_and_swapt1di_1 */
    case 2886:  /* atomic_compare_and_swapt1si_1 */
    case 2885:  /* atomic_compare_and_swap32di_1 */
    case 2884:  /* atomic_compare_and_swap32si_1 */
    case 2883:  /* atomic_compare_and_swapt1hi_1 */
    case 2882:  /* atomic_compare_and_swapt1qi_1 */
    case 2881:  /* atomic_compare_and_swap32hi_1 */
    case 2880:  /* atomic_compare_and_swap32qi_1 */
    case 2879:  /* arm_atomic_loaddi2_ldrd */
    case 2878:  /* atomic_storesi */
    case 2877:  /* atomic_storehi */
    case 2876:  /* atomic_storeqi */
    case 2875:  /* atomic_loadsi */
    case 2874:  /* atomic_loadhi */
    case 2873:  /* atomic_loadqi */
    case 2868:  /* crypto_vmullp64 */
    case 2842:  /* neon_vbfcvtbf_cvtmodesf */
    case 2841:  /* neon_vbfcvtbf_cvtmodev2si */
    case 2837:  /* neon_vbfcvtsf */
    case 2813:  /* vec_pack_trunc_v2di */
    case 2812:  /* vec_pack_trunc_v4si */
    case 2811:  /* vec_pack_trunc_v8hi */
    case 2474:  /* neon_vcombinev16qi */
    case 2473:  /* neon_vtbl2v16qi */
    case 2472:  /* neon_vtbl1v16qi */
    case 2086:  /* neon_vcombinedi */
    case 2085:  /* neon_vcombinev2sf */
    case 2084:  /* neon_vcombinev2si */
    case 2083:  /* neon_vcombinev4bf */
    case 2082:  /* neon_vcombinev4hf */
    case 2081:  /* neon_vcombinev4hi */
    case 2080:  /* neon_vcombinev8qi */
    case 2053:  /* neon_vdup_nv2di */
    case 1069:  /* dls_insn */
    case 1068:  /* *doloop_end_internal */
    case 1067:  /* thumb2_lsrl */
    case 1066:  /* thumb2_lsll */
    case 1065:  /* thumb2_asrl */
    case 1064:  /* *clear_multiple */
    case 1063:  /* *clear_apsr */
    case 1062:  /* *orsi_not_shiftsi_si */
    case 1061:  /* *orsi_notsi_si */
    case 1060:  /* *thumb2_negsi2_short */
    case 1059:  /* *thumb2_one_cmplsi2_short */
    case 1058:  /* *thumb2_cbnz */
    case 1057:  /* *thumb2_cbz */
    case 1056:  /* *thumb2_mulsi_short_compare0_scratch */
    case 1055:  /* *thumb2_mulsi_short_compare0 */
    case 1054:  /* *thumb2_mulsi_short */
    case 1051:  /* *thumb2_subsi_short */
    case 1050:  /* *thumb2_addsi_short */
    case 1049:  /* *thumb2_movsi_shortim */
    case 1048:  /* *thumb2_movhi_shortim */
    case 1047:  /* *thumb2_movqi_shortim */
    case 1046:  /* *thumb2_shiftsi3_short */
    case 1045:  /* *thumb2_alusi3_short */
    case 1044:  /* thumb2_eh_return */
    case 1043:  /* *thumb2_cmse_entry_return */
    case 1042:  /* *thumb2_return */
    case 1039:  /* thumb2_zero_extendqisi2_v6 */
    case 1038:  /* *thumb2_zero_extendhisi2_v6 */
    case 1037:  /* *thumb2_extendqisi_v6 */
    case 1035:  /* *thumb2_csneg */
    case 1034:  /* *thumb2_csinc */
    case 1033:  /* *thumb2_csinv */
    case 1010:  /* *thumb2_storewb_pairsi */
    case 1009:  /* *thumb2_movhi_insn */
    case 1008:  /* tls_load_dot_plus_four */
    case 1007:  /* *thumb2_movsi_insn */
    case 1006:  /* *thumb2_pop_single */
    case 998:  /* thumb_eh_return */
    case 997:  /* *thumb1_tablejump */
    case 994:  /* prologue_thumb1_interwork */
    case 992:  /* thumb1_casesi_dispatch */
    case 983:  /* *thumb_jump */
    case 982:  /* thumb1_addsi3_addgeu */
    case 981:  /* cstoresi_ltu_thumb1 */
    case 980:  /* cstoresi_nltu_thumb1 */
    case 979:  /* *cstoresi_ne0_thumb1_insn */
    case 978:  /* *cstoresi_eq0_thumb1_insn */
    case 976:  /* *addsi3_cbranch_scratch */
    case 975:  /* *addsi3_cbranch */
    case 974:  /* *cbranchne_decr1 */
    case 973:  /* *tstsi3_cbranch */
    case 972:  /* *tlobits_cbranch */
    case 971:  /* *tbit_cbranch */
    case 970:  /* *negated_cbranchsi4 */
    case 969:  /* cbranchsi4_scratch */
    case 968:  /* cbranchsi4_insn */
    case 967:  /* thumb1_cbz */
    case 966:  /* cpymem8b */
    case 965:  /* cpymem12b */
    case 964:  /* *thumb_movdf_insn */
    case 958:  /* *thumb1_movdi_insn */
    case 957:  /* thumb1_extendqisi2 */
    case 956:  /* thumb1_extendhisi2 */
    case 955:  /* *thumb1_zero_extendqisi2_v6 */
    case 954:  /* *thumb1_zero_extendqisi2 */
    case 953:  /* *thumb1_zero_extendhisi2 */
    case 952:  /* *thumb1_one_cmplsi2 */
    case 951:  /* *thumb1_neg_abssi2 */
    case 950:  /* *thumb1_abssi2 */
    case 949:  /* *thumb1_negsi2 */
    case 948:  /* *thumb1_negdi2 */
    case 947:  /* *thumb1_rotrsi3 */
    case 939:  /* *thumb_mulsi3_v6 */
    case 938:  /* *thumb_mulsi3 */
    case 936:  /* *thumb_subdi3 */
    case 935:  /* *thumb1_addsi3 */
    case 934:  /* *thumb1_adddi3 */
    case 933:  /* arm_vcx3adi */
    case 932:  /* arm_vcx3asi */
    case 931:  /* arm_vcx3di */
    case 930:  /* arm_vcx3si */
    case 929:  /* arm_vcx2adi */
    case 928:  /* arm_vcx2asi */
    case 927:  /* arm_vcx2di */
    case 926:  /* arm_vcx2si */
    case 925:  /* arm_vcx1adi */
    case 924:  /* arm_vcx1asi */
    case 923:  /* arm_vcx1di */
    case 922:  /* arm_vcx1si */
    case 921:  /* no_literal_pool_sf_immediate */
    case 920:  /* no_literal_pool_df_immediate */
    case 883:  /* *push_multi_vfp */
    case 866:  /* *combine_vcvtf2i */
    case 865:  /* *combine_vcvt_f64_s32 */
    case 864:  /* *combine_vcvt_f64_u32 */
    case 863:  /* *combine_vcvt_f32_s32 */
    case 862:  /* *combine_vcvt_f32_u32 */
    case 861:  /* *cmpdf_trap_vfp */
    case 860:  /* *cmpdf_vfp */
    case 859:  /* *cmpsf_trap_vfp */
    case 858:  /* *cmpsf_vfp */
    case 857:  /* *cmpdf_trap_split_vfp */
    case 856:  /* *cmpdf_split_vfp */
    case 855:  /* *cmpsf_trap_split_vfp */
    case 854:  /* *cmpsf_split_vfp */
    case 853:  /* lazy_load_multiple_insn */
    case 852:  /* lazy_store_multiple_insn */
    case 851:  /* *clear_vfp_multiple */
    case 850:  /* pop_fpsysreg_insn */
    case 849:  /* push_fpsysreg_insn */
    case 847:  /* *sqrtdf2_vfp */
    case 846:  /* *sqrtsf2_vfp */
    case 843:  /* floatunssidf2 */
    case 842:  /* floatunssisf2 */
    case 841:  /* *floatsidf2_vfp */
    case 840:  /* *floatsisf2_vfp */
    case 839:  /* fixuns_truncdfsi2 */
    case 838:  /* fixuns_truncsfsi2 */
    case 837:  /* *truncsidf2_vfp */
    case 836:  /* *truncsisf2_vfp */
    case 835:  /* truncsfhf2 */
    case 834:  /* *extendhfdf2 */
    case 833:  /* *truncdfhf2 */
    case 832:  /* extendhfsf2 */
    case 831:  /* *truncdfsf2_vfp */
    case 830:  /* *extendsfdf2_vfp */
    case 829:  /* *fnmadddf4 */
    case 828:  /* *fnmaddsf4 */
    case 826:  /* *fnmsubdf4 */
    case 825:  /* *fnmsubsf4 */
    case 823:  /* *fmsubdf4 */
    case 822:  /* *fmsubsf4 */
    case 820:  /* fmadf4 */
    case 819:  /* fmasf4 */
    case 817:  /* *muldf3negdfsubdf_vfp */
    case 816:  /* *mulsf3negsfsubsf_vfp */
    case 814:  /* *fmuldf3negdfadddf_vfp */
    case 813:  /* *mulsf3negsfaddsf_vfp */
    case 811:  /* *muldf3subdf_vfp */
    case 810:  /* *mulsf3subsf_vfp */
    case 808:  /* *muldf3adddf_vfp */
    case 807:  /* *mulsf3addsf_vfp */
    case 805:  /* *negmuldf3_vfp */
    case 804:  /* *muldf3negdf_vfp */
    case 803:  /* *negmulsf3_vfp */
    case 802:  /* *mulsf3negsf_vfp */
    case 799:  /* *muldf3_vfp */
    case 798:  /* *mulsf3_vfp */
    case 796:  /* *divdf3_vfp */
    case 795:  /* *divsf3_vfp */
    case 793:  /* *subdf3_vfp */
    case 792:  /* *subsf3_vfp */
    case 790:  /* *adddf3_vfp */
    case 789:  /* *addsf3_vfp */
    case 778:  /* *negdf2_vfp */
    case 777:  /* *negsf2_vfp */
    case 776:  /* *absdf2_vfp */
    case 775:  /* *abssf2_vfp */
    case 768:  /* *thumb2_movsf_vfp */
    case 767:  /* *movsf_vfp */
    case 760:  /* *movdi_vfp */
    case 758:  /* *arm_movsi_vfp */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
    case 745:  /* iwmmxt_textrcv8qi3 */
    case 744:  /* iwmmxt_textrcv4hi3 */
    case 743:  /* iwmmxt_textrcv2si3 */
    case 742:  /* iwmmxt_torvscv8qi3 */
    case 741:  /* iwmmxt_torvscv4hi3 */
    case 740:  /* iwmmxt_torvscv2si3 */
    case 739:  /* iwmmxt_torcv8qi3 */
    case 738:  /* iwmmxt_torcv4hi3 */
    case 737:  /* iwmmxt_torcv2si3 */
    case 736:  /* iwmmxt_tandcv8qi3 */
    case 735:  /* iwmmxt_tandcv4hi3 */
    case 734:  /* iwmmxt_tandcv2si3 */
    case 733:  /* iwmmxt_wmerge */
    case 732:  /* iwmmxt_wmiawttn */
    case 731:  /* iwmmxt_wmiawtbn */
    case 730:  /* iwmmxt_wmiawbtn */
    case 729:  /* iwmmxt_wmiawbbn */
    case 728:  /* iwmmxt_wmiawtt */
    case 727:  /* iwmmxt_wmiawtb */
    case 726:  /* iwmmxt_wmiawbt */
    case 725:  /* iwmmxt_wmiawbb */
    case 724:  /* iwmmxt_wmiattn */
    case 723:  /* iwmmxt_wmiatbn */
    case 722:  /* iwmmxt_wmiabtn */
    case 721:  /* iwmmxt_wmiabbn */
    case 720:  /* iwmmxt_wmiatt */
    case 719:  /* iwmmxt_wmiatb */
    case 718:  /* iwmmxt_wmiabt */
    case 717:  /* iwmmxt_wmiabb */
    case 716:  /* iwmmxt_wqmiattn */
    case 715:  /* iwmmxt_wqmiatbn */
    case 714:  /* iwmmxt_wqmiabtn */
    case 713:  /* iwmmxt_wqmiabbn */
    case 712:  /* iwmmxt_wqmiatt */
    case 711:  /* iwmmxt_wqmiatb */
    case 710:  /* iwmmxt_wqmiabt */
    case 709:  /* iwmmxt_wqmiabb */
    case 708:  /* iwmmxt_waddbhusl */
    case 707:  /* iwmmxt_waddbhusm */
    case 706:  /* iwmmxt_wqmulwmr */
    case 705:  /* iwmmxt_wqmulmr */
    case 704:  /* iwmmxt_wqmulwm */
    case 703:  /* iwmmxt_wqmulm */
    case 702:  /* iwmmxt_wmulwl */
    case 701:  /* iwmmxt_wmulwumr */
    case 700:  /* iwmmxt_wmulwsmr */
    case 699:  /* iwmmxt_wmulumr */
    case 698:  /* iwmmxt_wmulsmr */
    case 697:  /* iwmmxt_wmulwum */
    case 696:  /* iwmmxt_wmulwsm */
    case 695:  /* iwmmxt_wmaddun */
    case 694:  /* iwmmxt_wmaddsn */
    case 693:  /* iwmmxt_wmaddux */
    case 692:  /* iwmmxt_wmaddsx */
    case 691:  /* iwmmxt_avg4r */
    case 690:  /* iwmmxt_avg4 */
    case 689:  /* addcv2si3 */
    case 688:  /* addcv4hi3 */
    case 687:  /* iwmmxt_wsubaddhx */
    case 686:  /* iwmmxt_waddsubhx */
    case 685:  /* iwmmxt_wabsdiffw */
    case 684:  /* iwmmxt_wabsdiffh */
    case 683:  /* iwmmxt_wabsdiffb */
    case 682:  /* iwmmxt_wabsv8qi3 */
    case 681:  /* iwmmxt_wabsv4hi3 */
    case 680:  /* iwmmxt_wabsv2si3 */
    case 679:  /* iwmmxt_wsadhz */
    case 678:  /* iwmmxt_wsadbz */
    case 677:  /* iwmmxt_wsadh */
    case 676:  /* iwmmxt_wsadb */
    case 675:  /* iwmmxt_walignr3 */
    case 674:  /* iwmmxt_walignr2 */
    case 673:  /* iwmmxt_walignr1 */
    case 672:  /* iwmmxt_walignr0 */
    case 671:  /* iwmmxt_walignr */
    case 670:  /* iwmmxt_waligni */
    case 669:  /* iwmmxt_waccw */
    case 668:  /* iwmmxt_wacch */
    case 667:  /* iwmmxt_waccb */
    case 666:  /* iwmmxt_tmovmskw */
    case 665:  /* iwmmxt_tmovmskh */
    case 664:  /* iwmmxt_tmovmskb */
    case 663:  /* iwmmxt_tmiatt */
    case 662:  /* iwmmxt_tmiabt */
    case 661:  /* iwmmxt_tmiatb */
    case 660:  /* iwmmxt_tmiabb */
    case 659:  /* iwmmxt_tmiaph */
    case 658:  /* iwmmxt_tmia */
    case 657:  /* iwmmxt_wmaddu */
    case 656:  /* iwmmxt_wmadds */
    case 655:  /* ashldi3_di */
    case 654:  /* ashlv2si3_di */
    case 653:  /* ashlv4hi3_di */
    case 652:  /* lshrdi3_di */
    case 651:  /* lshrv2si3_di */
    case 650:  /* lshrv4hi3_di */
    case 649:  /* ashrdi3_di */
    case 648:  /* ashrv2si3_di */
    case 647:  /* ashrv4hi3_di */
    case 646:  /* rordi3_di */
    case 645:  /* rorv2si3_di */
    case 644:  /* rorv4hi3_di */
    case 643:  /* ashldi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 634:  /* rordi3 */
    case 633:  /* rorv2si3 */
    case 632:  /* rorv4hi3 */
    case 631:  /* iwmmxt_wunpckelsw */
    case 630:  /* iwmmxt_wunpckelsh */
    case 629:  /* iwmmxt_wunpckelsb */
    case 628:  /* iwmmxt_wunpckeluw */
    case 627:  /* iwmmxt_wunpckeluh */
    case 626:  /* iwmmxt_wunpckelub */
    case 625:  /* iwmmxt_wunpckehsw */
    case 624:  /* iwmmxt_wunpckehsh */
    case 623:  /* iwmmxt_wunpckehsb */
    case 622:  /* iwmmxt_wunpckehuw */
    case 621:  /* iwmmxt_wunpckehuh */
    case 620:  /* iwmmxt_wunpckehub */
    case 619:  /* iwmmxt_wunpckilw */
    case 618:  /* iwmmxt_wunpckilh */
    case 617:  /* iwmmxt_wunpckilb */
    case 616:  /* iwmmxt_wunpckihw */
    case 615:  /* iwmmxt_wunpckihh */
    case 614:  /* iwmmxt_wunpckihb */
    case 613:  /* iwmmxt_wpackdus */
    case 612:  /* iwmmxt_wpackwus */
    case 611:  /* iwmmxt_wpackhus */
    case 610:  /* iwmmxt_wpackdss */
    case 609:  /* iwmmxt_wpackwss */
    case 608:  /* iwmmxt_wpackhss */
    case 607:  /* *uminv8qi3_iwmmxt */
    case 606:  /* *uminv4hi3_iwmmxt */
    case 605:  /* *uminv2si3_iwmmxt */
    case 604:  /* *sminv8qi3_iwmmxt */
    case 603:  /* *sminv4hi3_iwmmxt */
    case 602:  /* *sminv2si3_iwmmxt */
    case 601:  /* *umaxv8qi3_iwmmxt */
    case 600:  /* *umaxv4hi3_iwmmxt */
    case 599:  /* *umaxv2si3_iwmmxt */
    case 598:  /* *smaxv8qi3_iwmmxt */
    case 597:  /* *smaxv4hi3_iwmmxt */
    case 596:  /* *smaxv2si3_iwmmxt */
    case 595:  /* gtv2si3 */
    case 594:  /* gtv4hi3 */
    case 593:  /* gtv8qi3 */
    case 592:  /* gtuv2si3 */
    case 591:  /* gtuv4hi3 */
    case 590:  /* gtuv8qi3 */
    case 589:  /* eqv2si3 */
    case 588:  /* eqv4hi3 */
    case 587:  /* eqv8qi3 */
    case 586:  /* iwmmxt_wshufh */
    case 585:  /* iwmmxt_textrmw */
    case 584:  /* iwmmxt_textrmsh */
    case 583:  /* iwmmxt_textrmuh */
    case 582:  /* iwmmxt_textrmsb */
    case 581:  /* iwmmxt_textrmub */
    case 580:  /* iwmmxt_tinsrw */
    case 579:  /* iwmmxt_tinsrh */
    case 578:  /* iwmmxt_tinsrb */
    case 577:  /* iwmmxt_uavgv4hi3 */
    case 576:  /* iwmmxt_uavgv8qi3 */
    case 575:  /* iwmmxt_uavgrndv4hi3 */
    case 574:  /* iwmmxt_uavgrndv8qi3 */
    case 573:  /* iwmmxt_clrv2si */
    case 572:  /* iwmmxt_clrv4hi */
    case 571:  /* iwmmxt_clrv8qi */
    case 570:  /* iwmmxt_clrdi */
    case 569:  /* iwmmxt_wmacuz */
    case 568:  /* iwmmxt_wmacu */
    case 567:  /* iwmmxt_wmacsz */
    case 566:  /* iwmmxt_wmacs */
    case 565:  /* umulv4hi3_highpart */
    case 564:  /* smulv4hi3_highpart */
    case 563:  /* *mulv4hi3_iwmmxt */
    case 562:  /* ussubv2si3 */
    case 561:  /* ussubv4hi3 */
    case 560:  /* ussubv8qi3 */
    case 559:  /* sssubv2si3 */
    case 558:  /* sssubv4hi3 */
    case 557:  /* sssubv8qi3 */
    case 556:  /* *subv8qi3_iwmmxt */
    case 555:  /* *subv4hi3_iwmmxt */
    case 554:  /* *subv2si3_iwmmxt */
    case 553:  /* usaddv2si3 */
    case 552:  /* usaddv4hi3 */
    case 551:  /* usaddv8qi3 */
    case 550:  /* ssaddv2si3 */
    case 549:  /* ssaddv4hi3 */
    case 548:  /* ssaddv8qi3 */
    case 547:  /* *addv8qi3_iwmmxt */
    case 546:  /* *addv4hi3_iwmmxt */
    case 545:  /* *addv2si3_iwmmxt */
    case 544:  /* *xorv8qi3_iwmmxt */
    case 543:  /* *xorv4hi3_iwmmxt */
    case 542:  /* *xorv2si3_iwmmxt */
    case 541:  /* *iorv8qi3_iwmmxt */
    case 540:  /* *iorv4hi3_iwmmxt */
    case 539:  /* *iorv2si3_iwmmxt */
    case 538:  /* *andv8qi3_iwmmxt */
    case 537:  /* *andv4hi3_iwmmxt */
    case 536:  /* *andv2si3_iwmmxt */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
    case 532:  /* *cond_iwmmxt_movsi_insn */
    case 530:  /* *iwmmxt_arm_movdi */
    case 529:  /* iwmmxt_nanddi3 */
    case 528:  /* iwmmxt_anddi3 */
    case 527:  /* iwmmxt_xordi3 */
    case 526:  /* iwmmxt_iordi3 */
    case 525:  /* tbcstv2si */
    case 524:  /* tbcstv4hi */
    case 523:  /* tbcstv8qi */
    case 506:  /* *speculation_barrier_insn */
    case 505:  /* arm_mrrc2 */
    case 504:  /* arm_mrrc */
    case 503:  /* arm_mcrr2 */
    case 502:  /* arm_mcrr */
    case 501:  /* arm_mrc2 */
    case 500:  /* arm_mrc */
    case 499:  /* arm_mcr2 */
    case 498:  /* arm_mcr */
    case 497:  /* *stc */
    case 496:  /* *stc */
    case 495:  /* *stc */
    case 494:  /* *stc */
    case 493:  /* *ldc */
    case 492:  /* *ldc */
    case 491:  /* *ldc */
    case 490:  /* *ldc */
    case 489:  /* arm_cdp2 */
    case 488:  /* arm_cdp */
    case 487:  /* *load_multiple */
    case 486:  /* *stm2_db_update */
    case 485:  /* *stm2_db */
    case 484:  /* *ldm2_db_update */
    case 483:  /* *ldm2_db */
    case 482:  /* *stm2_da_update */
    case 481:  /* *stm2_da */
    case 480:  /* *ldm2_da_update */
    case 479:  /* *ldm2_da */
    case 478:  /* *stm2_ib_update */
    case 477:  /* *stm2_ib */
    case 476:  /* *ldm2_ib_update */
    case 475:  /* *ldm2_ib */
    case 474:  /* *thumb_stm2_ia_update */
    case 473:  /* *stm2_ia_update */
    case 472:  /* *stm2_ */
    case 471:  /* *thumb_ldm2_ia_update */
    case 470:  /* *ldm2_ia_update */
    case 469:  /* *thumb_ldm2_ia */
    case 468:  /* *ldm2_ */
    case 467:  /* *stm3_db_update */
    case 466:  /* *stm3_db */
    case 465:  /* *ldm3_db_update */
    case 464:  /* *ldm3_db */
    case 463:  /* *stm3_da_update */
    case 462:  /* *stm3_da */
    case 461:  /* *ldm3_da_update */
    case 460:  /* *ldm3_da */
    case 459:  /* *stm3_ib_update */
    case 458:  /* *stm3_ib */
    case 457:  /* *ldm3_ib_update */
    case 456:  /* *ldm3_ib */
    case 455:  /* *thumb_stm3_ia_update */
    case 454:  /* *stm3_ia_update */
    case 453:  /* *stm3_ */
    case 452:  /* *thumb_ldm3_ia_update */
    case 451:  /* *ldm3_ia_update */
    case 450:  /* *thumb_ldm3_ia */
    case 449:  /* *ldm3_ */
    case 448:  /* *stm4_db_update */
    case 447:  /* *stm4_db */
    case 446:  /* *ldm4_db_update */
    case 445:  /* *ldm4_db */
    case 444:  /* *stm4_da_update */
    case 443:  /* *stm4_da */
    case 442:  /* *ldm4_da_update */
    case 441:  /* *ldm4_da */
    case 440:  /* *stm4_ib_update */
    case 439:  /* *stm4_ib */
    case 438:  /* *ldm4_ib_update */
    case 437:  /* *ldm4_ib */
    case 436:  /* *thumb_stm4_ia_update */
    case 435:  /* *stm4_ia_update */
    case 434:  /* *stm4_ */
    case 433:  /* *thumb_ldm4_ia_update */
    case 432:  /* *ldm4_ia_update */
    case 431:  /* *thumb_ldm4_ia */
    case 430:  /* *ldm4_ */
    case 429:  /* *arm_strd */
    case 428:  /* *arm_ldrd */
    case 421:  /* *thumb2_strd_base_neg */
    case 420:  /* *thumb2_strd_base */
    case 419:  /* *thumb2_strd */
    case 418:  /* *thumb2_ldrd_base_neg */
    case 417:  /* *thumb2_ldrd_base */
    case 416:  /* *thumb2_ldrd */
    case 415:  /* arm_rev16si2_alt */
    case 414:  /* arm_rev16si2 */
    case 413:  /* *arm_rev16 */
    case 412:  /* *arm_revsh */
    case 411:  /* *arm_rev */
    case 410:  /* *arm_movtas_ze */
    case 404:  /* arm_eh_return */
    case 403:  /* force_register_use */
    case 402:  /* prefetch */
    case 401:  /* ctzsi2 */
    case 400:  /* rbitsi2 */
    case 399:  /* clzsi2 */
    case 398:  /* consttable_16 */
    case 397:  /* consttable_8 */
    case 396:  /* consttable_4 */
    case 395:  /* consttable_2 */
    case 394:  /* consttable_1 */
    case 393:  /* consttable_end */
    case 392:  /* align_8 */
    case 391:  /* align_4 */
    case 389:  /* *ldr_with_return */
    case 388:  /* *pop_multiple_with_return */
    case 387:  /* *pop_multiple_with_writeback_and_return */
    case 386:  /* *load_multiple_with_writeback */
    case 385:  /* stack_tie */
    case 384:  /* *push_multi */
    case 380:  /* *arith_adjacentmem */
    case 336:  /* *compare_scc */
    case 331:  /* *sub_shiftsi */
    case 328:  /* *and_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 324:  /* *add_shiftsi */
    case 323:  /* *and_multsi */
    case 322:  /* *eor_multsi */
    case 321:  /* *orr_multsi */
    case 320:  /* *rsb_multsi */
    case 319:  /* *add_multsi */
    case 317:  /* nop */
    case 316:  /* *load_indirect_jump */
    case 315:  /* *arm_indirect_jump */
    case 310:  /* *stack_protect_combined_test_insn */
    case 308:  /* *stack_protect_combined_set_insn */
    case 306:  /* probe_stack */
    case 305:  /* blockage */
    case 303:  /* *arm_simple_return */
    case 298:  /* *arm_return */
    case 289:  /* restore_pic_register_after_call */
    case 288:  /* *arm_jump */
    case 271:  /* *movdf_soft_insn */
    case 270:  /* *arm_movsf_soft_insn */
    case 267:  /* *arm_movqi_insn */
    case 266:  /* *movhi_bytes */
    case 265:  /* *movhi_insn_arch4 */
    case 263:  /* tls_load_dot_plus_eight */
    case 262:  /* pic_add_dot_plus_eight */
    case 261:  /* pic_add_dot_plus_four */
    case 260:  /* pic_load_addr_thumb1 */
    case 259:  /* pic_load_addr_32bit */
    case 258:  /* pic_load_addr_unified */
    case 257:  /* *arm_movsi_insn */
    case 256:  /* *arm_movt */
    case 255:  /* *arm_movdi */
    case 254:  /* arm_sel */
    case 253:  /* arm_usat16_setq_insn */
    case 252:  /* arm_usat16_insn */
    case 251:  /* arm_ssat16_setq_insn */
    case 250:  /* arm_ssat16_insn */
    case 249:  /* arm_smuadx_setq_insn */
    case 248:  /* arm_smuadx_insn */
    case 247:  /* arm_smuad_setq_insn */
    case 246:  /* arm_smuad_insn */
    case 245:  /* arm_smlsdx_setq_insn */
    case 244:  /* arm_smlsdx_insn */
    case 243:  /* arm_smlsd_setq_insn */
    case 242:  /* arm_smlsd_insn */
    case 241:  /* arm_smladx_setq_insn */
    case 240:  /* arm_smladx_insn */
    case 239:  /* arm_smlad_setq_insn */
    case 238:  /* arm_smlad_insn */
    case 237:  /* arm_usub16 */
    case 236:  /* arm_usax */
    case 235:  /* arm_uasx */
    case 234:  /* arm_uadd16 */
    case 233:  /* arm_ssub16 */
    case 232:  /* arm_ssax */
    case 231:  /* arm_sasx */
    case 230:  /* arm_sadd16 */
    case 229:  /* arm_usub8 */
    case 228:  /* arm_uadd8 */
    case 227:  /* arm_ssub8 */
    case 226:  /* arm_sadd8 */
    case 225:  /* arm_smlsldx */
    case 224:  /* arm_smlsld */
    case 223:  /* arm_smlaldx */
    case 222:  /* arm_smlald */
    case 221:  /* arm_usada8 */
    case 220:  /* arm_usad8 */
    case 219:  /* arm_uxtab16 */
    case 218:  /* arm_sxtab16 */
    case 217:  /* arm_smusdx */
    case 216:  /* arm_smusd */
    case 215:  /* arm_uqsub16 */
    case 214:  /* arm_uqsax */
    case 213:  /* arm_uqasx */
    case 212:  /* arm_uqadd16 */
    case 211:  /* arm_uhsub16 */
    case 210:  /* arm_uhsax */
    case 209:  /* arm_uhasx */
    case 208:  /* arm_uhadd16 */
    case 207:  /* arm_shsub16 */
    case 206:  /* arm_shsax */
    case 205:  /* arm_shasx */
    case 204:  /* arm_shadd16 */
    case 203:  /* arm_qsub16 */
    case 202:  /* arm_qsax */
    case 201:  /* arm_qasx */
    case 200:  /* arm_qadd16 */
    case 199:  /* arm_uqsub8 */
    case 198:  /* arm_uqadd8 */
    case 197:  /* arm_uhsub8 */
    case 196:  /* arm_uhadd8 */
    case 195:  /* arm_shsub8 */
    case 194:  /* arm_shadd8 */
    case 193:  /* arm_qsub8 */
    case 192:  /* arm_qadd8 */
    case 191:  /* arm_uxtb16 */
    case 190:  /* arm_sxtb16 */
    case 189:  /* *arm_extendqisi2addsi */
    case 188:  /* *arm_extendqisi_v6 */
    case 187:  /* *arm_extendqisi */
    case 186:  /* *arm_extendqihi_insn */
    case 185:  /* *arm_extendhisi2addsi */
    case 184:  /* *arm_extendhisi2_v6 */
    case 183:  /* *arm_extendhisi2 */
    case 181:  /* *arm_zero_extendqisi2addsi */
    case 180:  /* *arm_zero_extendqisi2_v6 */
    case 179:  /* *arm_zero_extendqisi2 */
    case 178:  /* *arm_zero_extendhisi2addsi */
    case 177:  /* *arm_zero_extendhisi2_v6 */
    case 176:  /* *arm_zero_extendhisi2 */
    case 173:  /* *arm_one_cmplsi2 */
    case 168:  /* *arm_negsi2 */
    case 167:  /* udivsi3 */
    case 166:  /* divsi3 */
    case 165:  /* extzv_t2 */
    case 164:  /* *extv_reg */
    case 163:  /* unaligned_storehi */
    case 162:  /* unaligned_storesi */
    case 161:  /* unaligned_storedi */
    case 160:  /* unaligned_loadhiu */
    case 159:  /* unaligned_loadhis */
    case 158:  /* unaligned_loadsi */
    case 157:  /* unaligned_loaddi */
    case 154:  /* *not_shiftsi */
    case 151:  /* *arm_shiftsi3 */
    case 150:  /* arm_cx3adi */
    case 149:  /* arm_cx3asi */
    case 148:  /* arm_cx3di */
    case 147:  /* arm_cx3si */
    case 146:  /* arm_cx2adi */
    case 145:  /* arm_cx2asi */
    case 144:  /* arm_cx2di */
    case 143:  /* arm_cx2si */
    case 142:  /* arm_cx1adi */
    case 141:  /* arm_cx1asi */
    case 140:  /* arm_cx1di */
    case 139:  /* arm_cx1si */
    case 138:  /* *satsi_smax_shift */
    case 137:  /* *satsi_smin_shift */
    case 136:  /* satsi_smax_setq */
    case 135:  /* satsi_smax */
    case 134:  /* satsi_smin_setq */
    case 133:  /* satsi_smin */
    case 130:  /* arm_qsub_setq_insn */
    case 129:  /* arm_qsub_insn */
    case 128:  /* arm_qadd_setq_insn */
    case 127:  /* arm_qadd_insn */
    case 120:  /* *smin_0 */
    case 118:  /* *smax_m1 */
    case 117:  /* *smax_0 */
    case 116:  /* *andsi_iorsi3_notsi */
    case 113:  /* *arm_xorsi3 */
    case 110:  /* *iorsi3_insn */
    case 105:  /* andsi_not_shiftsi_si */
    case 104:  /* andsi_notsi_si */
    case 103:  /* *bfi_alt3 */
    case 102:  /* *bfi_alt2 */
    case 101:  /* *bfi_alt1 */
    case 100:  /* *bfi */
    case 99:  /* insv_t2 */
    case 98:  /* insv_zero */
    case 90:  /* *arm_andsi3_insn */
    case 89:  /* arm_smlawt_setq_insn */
    case 88:  /* arm_smlawt_insn */
    case 87:  /* arm_smlawb_setq_insn */
    case 86:  /* arm_smlawb_insn */
    case 85:  /* *maddhidi4tt */
    case 84:  /* *maddhidi4tb */
    case 83:  /* maddhidi4 */
    case 82:  /* arm_smlatt_setq */
    case 81:  /* maddhisi4tt */
    case 80:  /* arm_smlatb_setq */
    case 79:  /* maddhisi4tb */
    case 78:  /* arm_smlabb_setq */
    case 77:  /* *arm_maddhisi4 */
    case 76:  /* *mulhisi3tt */
    case 75:  /* *mulhisi3bt */
    case 74:  /* *mulhisi3tb */
    case 73:  /* mulhisi3 */
    case 72:  /* *umull_high */
    case 71:  /* *smull_high */
    case 70:  /* umlal */
    case 69:  /* smlal */
    case 68:  /* umull */
    case 67:  /* smull */
    case 58:  /* *mls */
    case 57:  /* *mla */
    case 56:  /* *mul */
    case 45:  /* *arm_subsi3_insn */
    case 7:  /* *arm_addsi3 */
    case 6:  /* *addsi3_cin_cout_0_insn */
    case 5:  /* *addsi3_cin_cout_imm_insn */
    case 4:  /* *addsi3_cin_cout_reg_insn */
    case 3:  /* *addsi3_cin_vout_0_insn */
    case 2:  /* *addsi3_cin_vout_imm_insn */
    case 1:  /* *addsi3_cin_vout_reg_insn */
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  return CONDS_NOCOND;
        }

    case 963:  /* *thumb1_movsf_insn */
    case 962:  /* *thumb1_movhf */
    case 309:  /* *stack_protect_set_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CONDS_CLOB;
        }
      else
        {
	  return CONDS_NOCOND;
        }

    case 761:  /* *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 6852:  /* *p *movbf_vfp_bf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || (get_attr_type (insn) == TYPE_CALL))
	    {
	      return CONDS_CLOB;
	    }
	  else
	    {
	      if ((get_attr_is_neon_type (insn) == IS_NEON_TYPE_YES) || (get_attr_is_mve_type (insn) == IS_MVE_TYPE_YES))
	        {
		  return CONDS_UNCONDITIONAL;
	        }
	      else
	        {
		  return CONDS_NOCOND;
	        }
	    }
        }
      else if (which_alternative == 1)
        {
	  if (((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || (get_attr_type (insn) == TYPE_CALL))
	    {
	      return CONDS_CLOB;
	    }
	  else
	    {
	      if ((get_attr_is_neon_type (insn) == IS_NEON_TYPE_YES) || (get_attr_is_mve_type (insn) == IS_MVE_TYPE_YES))
	        {
		  return CONDS_UNCONDITIONAL;
	        }
	      else
	        {
		  return CONDS_NOCOND;
	        }
	    }
        }
      else if (which_alternative == 2)
        {
	  return CONDS_UNCONDITIONAL;
        }
      else if (which_alternative == 3)
        {
	  if (((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1))) || (get_attr_type (insn) == TYPE_CALL))
	    {
	      return CONDS_CLOB;
	    }
	  else
	    {
	      if ((get_attr_is_neon_type (insn) == IS_NEON_TYPE_YES) || (get_attr_is_mve_type (insn) == IS_MVE_TYPE_YES))
	        {
		  return CONDS_UNCONDITIONAL;
	        }
	      else
	        {
		  return CONDS_NOCOND;
	        }
	    }
        }
      else if (which_alternative == 4)
        {
	  return CONDS_UNCONDITIONAL;
        }
      else if (which_alternative == 5)
        {
	  return CONDS_UNCONDITIONAL;
        }
      else if (which_alternative == 6)
        {
	  return CONDS_UNCONDITIONAL;
        }
      else if (which_alternative == 7)
        {
	  return CONDS_UNCONDITIONAL;
        }
      else if (which_alternative == 8)
        {
	  return CONDS_UNCONDITIONAL;
        }
      else
        {
	  return CONDS_UNCONDITIONAL;
        }

    case 884:  /* btruncsf2 */
    case 887:  /* nearbyintsf2 */
    case 888:  /* rintsf2 */
    case 890:  /* btruncdf2 */
    case 893:  /* nearbyintdf2 */
    case 894:  /* rintdf2 */
    case 996:  /* *thumb1_movpc_insn */
    case 6917:  /* *p btruncsf2 */
    case 6918:  /* *p nearbyintsf2 */
    case 6919:  /* *p rintsf2 */
    case 6920:  /* *p btruncdf2 */
    case 6921:  /* *p nearbyintdf2 */
    case 6922:  /* *p rintdf2 */
      return CONDS_NOCOND;

    case 268:  /* *arm32_movhf */
    case 269:  /* *arm32_movbf */
    case 312:  /* stack_protect_set_tls */
    case 318:  /* trap */
    case 390:  /* *vfp_pop_multiple_with_writeback */
    case 422:  /* arm_crc32b */
    case 423:  /* arm_crc32h */
    case 424:  /* arm_crc32w */
    case 425:  /* arm_crc32cb */
    case 426:  /* arm_crc32ch */
    case 427:  /* arm_crc32cw */
    case 507:  /* pac_nop */
    case 508:  /* pacbti_nop */
    case 509:  /* aut_nop */
    case 510:  /* bti_nop */
    case 763:  /* *movhf_vfp_neon */
    case 764:  /* *movbf_vfp_neon */
    case 765:  /* *movhf_vfp */
    case 766:  /* *movbf_vfp */
    case 779:  /* abshf2 */
    case 780:  /* neghf2 */
    case 781:  /* neon_vrndhf */
    case 782:  /* neon_vrndahf */
    case 783:  /* neon_vrndmhf */
    case 784:  /* neon_vrndnhf */
    case 785:  /* neon_vrndphf */
    case 786:  /* neon_vrndxhf */
    case 787:  /* neon_vrndihf */
    case 788:  /* addhf3 */
    case 791:  /* subhf3 */
    case 794:  /* divhf3 */
    case 797:  /* mulhf3 */
    case 800:  /* *mulsf3neghf_vfp */
    case 801:  /* *negmulhf3_vfp */
    case 806:  /* *mulsf3addhf_vfp */
    case 809:  /* *mulhf3subhf_vfp */
    case 812:  /* *mulhf3neghfaddhf_vfp */
    case 815:  /* *mulhf3neghfsubhf_vfp */
    case 818:  /* fmahf4 */
    case 821:  /* fmsubhf4_fp16 */
    case 824:  /* *fnmsubhf4 */
    case 827:  /* *fnmaddhf4 */
    case 844:  /* neon_vsqrthf */
    case 845:  /* neon_vrsqrtshf */
    case 867:  /* neon_vcvthshf */
    case 868:  /* neon_vcvthuhf */
    case 869:  /* neon_vcvthssi */
    case 870:  /* neon_vcvthusi */
    case 871:  /* neon_vcvths_nhf_unspec */
    case 872:  /* neon_vcvthu_nhf_unspec */
    case 873:  /* neon_vcvths_nsi_unspec */
    case 874:  /* neon_vcvthu_nsi_unspec */
    case 875:  /* neon_vcvtahssi */
    case 876:  /* neon_vcvtahusi */
    case 877:  /* neon_vcvtmhssi */
    case 878:  /* neon_vcvtmhusi */
    case 879:  /* neon_vcvtnhssi */
    case 880:  /* neon_vcvtnhusi */
    case 881:  /* neon_vcvtphssi */
    case 882:  /* neon_vcvtphusi */
    case 885:  /* ceilsf2 */
    case 886:  /* floorsf2 */
    case 889:  /* roundsf2 */
    case 891:  /* ceildf2 */
    case 892:  /* floordf2 */
    case 895:  /* rounddf2 */
    case 896:  /* lceilsfsi2 */
    case 897:  /* lfloorsfsi2 */
    case 898:  /* lroundsfsi2 */
    case 899:  /* lceilusfsi2 */
    case 900:  /* lfloorusfsi2 */
    case 901:  /* lroundusfsi2 */
    case 902:  /* lceildfsi2 */
    case 903:  /* lfloordfsi2 */
    case 904:  /* lrounddfsi2 */
    case 905:  /* lceiludfsi2 */
    case 906:  /* lfloorudfsi2 */
    case 907:  /* lroundudfsi2 */
    case 908:  /* smaxsf3 */
    case 909:  /* smaxdf3 */
    case 910:  /* sminsf3 */
    case 911:  /* smindf3 */
    case 912:  /* neon_vmaxnmhf */
    case 913:  /* neon_vminnmhf */
    case 914:  /* fmaxsf3 */
    case 915:  /* fminsf3 */
    case 916:  /* fmaxdf3 */
    case 917:  /* fmindf3 */
    case 2872:  /* *memory_barrier */
    case 6527:  /* *p *arm32_movhf */
    case 6528:  /* *p *arm32_movbf */
      return CONDS_UNCONDITIONAL;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    case 1023:  /* *nonsecure_call_value_reg_thumb2 */
    case 1022:  /* *nonsecure_call_value_reg_thumb2_fpcxt */
    case 1021:  /* *call_value_reg_thumb2 */
    case 1020:  /* *nonsecure_call_reg_thumb2 */
    case 1019:  /* *nonsecure_call_reg_thumb2_fpcxt */
    case 1018:  /* *call_reg_thumb2 */
    case 991:  /* *call_value_insn */
    case 990:  /* *call_insn */
    case 989:  /* *call_value_reg_thumb1 */
    case 988:  /* *nonsecure_call_value_reg_thumb1_v5 */
    case 987:  /* *call_value_reg_thumb1_v5 */
    case 986:  /* *call_reg_thumb1 */
    case 985:  /* *nonsecure_call_reg_thumb1_v5 */
    case 984:  /* *call_reg_thumb1_v5 */
    case 297:  /* *sibcall_value_insn */
    case 296:  /* *sibcall_insn */
    case 295:  /* *call_value_symbol */
    case 294:  /* *call_symbol */
    case 293:  /* *call_value_reg_arm */
    case 292:  /* *call_value_reg_armv5 */
    case 291:  /* *call_reg_arm */
    case 290:  /* *call_reg_armv5 */
    case 94:  /* *ne_zeroextractsi */
    case 95:  /* *ne_zeroextractsi_shifted */
    case 96:  /* *ite_ne_zeroextractsi */
    case 97:  /* *ite_ne_zeroextractsi_shifted */
    case 119:  /* *arm_smax_insn */
    case 121:  /* *arm_smin_insn */
    case 122:  /* *arm_umaxsi3 */
    case 123:  /* *arm_uminsi3 */
    case 124:  /* *store_minmaxsi */
    case 125:  /* *minmax_arithsi */
    case 126:  /* *minmax_arithsi_non_canon */
    case 307:  /* probe_stack_range */
    case 314:  /* *arm_casesi_internal */
    case 338:  /* *cond_arith */
    case 339:  /* *cond_sub */
    case 344:  /* *ior_scc_scc */
    case 346:  /* *and_scc_scc */
    case 348:  /* *and_scc_scc_nodom */
    case 349:  /* *negscc */
    case 350:  /* movcond_addsi */
    case 351:  /* movcond */
    case 352:  /* *ifcompare_plus_move */
    case 354:  /* *ifcompare_move_plus */
    case 356:  /* *ifcompare_arith_arith */
    case 358:  /* *ifcompare_arith_move */
    case 360:  /* *ifcompare_move_arith */
    case 362:  /* *ifcompare_move_not */
    case 364:  /* *ifcompare_not_move */
    case 366:  /* *ifcompare_shift_move */
    case 368:  /* *ifcompare_move_shift */
    case 370:  /* *ifcompare_shift_shift */
    case 372:  /* *ifcompare_not_arith */
    case 374:  /* *ifcompare_arith_not */
    case 376:  /* *ifcompare_neg_move */
    case 378:  /* *ifcompare_move_neg */
    case 382:  /* *sign_extract_onebit */
    case 383:  /* *not_signextract_onebit */
    case 407:  /* load_tp_soft_fdpic */
    case 408:  /* load_tp_soft */
    case 409:  /* tlscall */
    case 531:  /* *iwmmxt_movsi_insn */
    case 993:  /* *thumb1_indirect_jump */
    case 995:  /* *epilogue_insns */
    case 999:  /* thumb1_stack_protect_test_insn */
    case 1000:  /* *thumb2_smaxsi3 */
    case 1001:  /* *thumb2_sminsi3 */
    case 1002:  /* *thumb32_umaxsi3 */
    case 1003:  /* *thumb2_uminsi3 */
    case 1024:  /* *thumb2_indirect_jump */
    case 1029:  /* *thumb2_cond_arith */
    case 1030:  /* *thumb2_cond_arith_strict_it */
    case 1031:  /* *thumb2_cond_sub */
    case 1032:  /* *thumb2_negscc */
    case 1036:  /* *thumb2_movcond */
    case 1040:  /* *thumb2_casesi_internal */
    case 1041:  /* *thumb2_casesi_internal_pic */
    case 3034:  /* *arm_ssmulsa3 */
    case 3035:  /* *arm_usmulusa3 */
      return CONDS_CLOB;

    case 8:  /* addsi3_compareV_reg */
    case 9:  /* *addsi3_compareV_reg_nosum */
    case 10:  /* subvsi3_intmin */
    case 11:  /* addsi3_compareV_imm */
    case 12:  /* addsi3_compareV_imm_nosum */
    case 13:  /* addsi3_compare0 */
    case 14:  /* *addsi3_compare0_scratch */
    case 15:  /* *compare_negsi_si */
    case 16:  /* cmpsi2_addneg */
    case 17:  /* addsi3_compare_op1 */
    case 18:  /* *addsi3_compare_op2 */
    case 19:  /* *compare_addsi2_op0 */
    case 20:  /* *compare_addsi2_op1 */
    case 25:  /* *addsi3_carryin_clobercc */
    case 26:  /* subsi3_compare1 */
    case 27:  /* subvsi3 */
    case 28:  /* subvsi3_imm1 */
    case 33:  /* cmpsi3_carryin_CC_NVout */
    case 34:  /* cmpsi3_carryin_CC_Bout */
    case 35:  /* cmpsi3_imm_carryin_CC_NVout */
    case 36:  /* cmpsi3_imm_carryin_CC_Bout */
    case 37:  /* cmpsi3_0_carryin_CC_NVout */
    case 38:  /* cmpsi3_0_carryin_CC_Bout */
    case 46:  /* subsi3_compare0 */
    case 47:  /* subsi3_compare */
    case 48:  /* rsb_imm_compare */
    case 49:  /* rsb_imm_compare_scratch */
    case 50:  /* rscsi3_CC_NVout_scratch */
    case 51:  /* rscsi3_CC_Bout_scratch */
    case 52:  /* usubvsi3_borrow */
    case 53:  /* usubvsi3_borrow_imm */
    case 54:  /* subvsi3_borrow */
    case 55:  /* subvsi3_borrow_imm */
    case 59:  /* *mulsi3_compare0 */
    case 60:  /* *mulsi3_compare0_v6 */
    case 61:  /* *mulsi_compare0_scratch */
    case 62:  /* *mulsi_compare0_scratch_v6 */
    case 63:  /* *mulsi3addsi_compare0 */
    case 64:  /* *mulsi3addsi_compare0_v6 */
    case 65:  /* *mulsi3addsi_compare0_scratch */
    case 66:  /* *mulsi3addsi_compare0_scratch_v6 */
    case 91:  /* *andsi3_compare0 */
    case 92:  /* *andsi3_compare0_scratch */
    case 93:  /* *zeroextractsi_compare0_scratch */
    case 106:  /* andsi_not_shiftsi_si_scc_no_reuse */
    case 107:  /* andsi_not_shiftsi_si_scc */
    case 108:  /* *andsi_notsi_si_compare0 */
    case 109:  /* *andsi_notsi_si_compare0_scratch */
    case 111:  /* *iorsi3_compare0 */
    case 112:  /* *iorsi3_compare0_scratch */
    case 114:  /* *xorsi3_compare0 */
    case 115:  /* *xorsi3_compare0_scratch */
    case 132:  /* arm_set_apsr */
    case 152:  /* *shiftsi3_compare0 */
    case 153:  /* *shiftsi3_compare0_scratch */
    case 155:  /* *not_shiftsi_compare0 */
    case 156:  /* *not_shiftsi_compare0_scratch */
    case 169:  /* negsi2_0compare */
    case 174:  /* *notsi_compare0 */
    case 175:  /* *notsi_compare0_scratch */
    case 182:  /* *compareqi_eq0 */
    case 264:  /* *movsi_compare0 */
    case 272:  /* *arm_cmpsi_insn */
    case 273:  /* *cmpsi_shiftsi */
    case 274:  /* *cmpsi_shiftsi_swp */
    case 275:  /* *arm_cmpsi_negshiftsi_si */
    case 276:  /* *deleted_compare */
    case 304:  /* *check_arch2 */
    case 311:  /* arm_stack_protect_test_insn */
    case 313:  /* stack_protect_test_tls */
    case 329:  /* *arith_shiftsi_compare0 */
    case 330:  /* *arith_shiftsi_compare0_scratch */
    case 332:  /* *sub_shiftsi_compare0 */
    case 333:  /* *sub_shiftsi_compare0_scratch */
    case 340:  /* *cmp_ite0 */
    case 341:  /* *cmp_ite1 */
    case 342:  /* *cmp_and */
    case 343:  /* *cmp_ior */
    case 345:  /* *ior_scc_scc_cmp */
    case 347:  /* *and_scc_scc_cmp */
    case 848:  /* *movcc_vfp */
    case 937:  /* thumb1_subsi3_insn */
    case 940:  /* *thumb1_andsi3_insn */
    case 941:  /* thumb1_bicsi3 */
    case 942:  /* *thumb1_iorsi3_insn */
    case 943:  /* *thumb1_xorsi3_insn */
    case 944:  /* *thumb1_ashlsi3 */
    case 945:  /* *thumb1_ashrsi3 */
    case 946:  /* *thumb1_lshrsi3 */
    case 977:  /* *thumb_cmpdi_zero */
    case 1052:  /* thumb2_addsi3_compare0 */
    case 1053:  /* *thumb2_addsi3_compare0_scratch */
    case 4879:  /* mve_vadcq_uv4si */
    case 4880:  /* mve_vadcq_sv4si */
    case 6354:  /* *p *addsi3_compare0_scratch */
    case 6355:  /* *p *compare_negsi_si */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6398:  /* *p *zeroextractsi_compare0_scratch */
    case 6407:  /* *p andsi_not_shiftsi_si_scc_no_reuse */
    case 6408:  /* *p andsi_not_shiftsi_si_scc */
    case 6420:  /* *p arm_set_apsr */
    case 6448:  /* *p *compareqi_eq0 */
    case 6530:  /* *p *arm_cmpsi_insn */
    case 6531:  /* *p *arm_cmpsi_negshiftsi_si */
      return CONDS_SET;

    case 21:  /* addsi3_carryin */
    case 22:  /* add0si3_carryin */
    case 23:  /* *addsi3_carryin_alt2 */
    case 24:  /* *addsi3_carryin_shift */
    case 29:  /* subsi3_carryin */
    case 30:  /* rsbsi_carryin_reg */
    case 31:  /* *add_not_cin */
    case 32:  /* add_not_shift_cin */
    case 39:  /* *subsi3_carryin_const */
    case 40:  /* *subsi3_carryin_const0 */
    case 41:  /* *subsi3_carryin_shift */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 43:  /* *rsbsi3_carryin_shift */
    case 44:  /* *rsbsi3_carryin_shift_alt */
    case 131:  /* arm_get_apsr */
    case 170:  /* negsi2_carryin */
    case 277:  /* arm_cond_branch */
    case 278:  /* *arm_cond_branch_reversed */
    case 279:  /* *mov_scc */
    case 280:  /* *negscc_borrow */
    case 281:  /* *mov_negscc */
    case 282:  /* *mov_notscc */
    case 283:  /* *cmovsf */
    case 284:  /* *cmovdf */
    case 285:  /* *cmovhf */
    case 286:  /* *movsicc_insn */
    case 287:  /* *movsfcc_soft_insn */
    case 299:  /* *cond_return */
    case 300:  /* *cond_simple_return */
    case 301:  /* *cond_return_inverted */
    case 302:  /* *cond_simple_return_inverted */
    case 334:  /* *and_scc */
    case 335:  /* *ior_scc */
    case 337:  /* *cond_move */
    case 353:  /* *if_plus_move */
    case 355:  /* *if_move_plus */
    case 357:  /* *if_arith_arith */
    case 359:  /* *if_arith_move */
    case 361:  /* *if_move_arith */
    case 363:  /* *if_move_not */
    case 365:  /* *if_not_move */
    case 367:  /* *if_shift_move */
    case 369:  /* *if_move_shift */
    case 371:  /* *if_shift_shift */
    case 373:  /* *if_not_arith */
    case 375:  /* *if_arith_not */
    case 377:  /* *if_neg_move */
    case 379:  /* *if_move_neg */
    case 381:  /* *cond_move_not */
    case 771:  /* *movsfcc_vfp */
    case 772:  /* *thumb2_movsfcc_vfp */
    case 773:  /* *movdfcc_vfp */
    case 774:  /* *thumb2_movdfcc_vfp */
    case 1011:  /* *thumb2_mov_scc */
    case 1012:  /* *thumb2_mov_negscc */
    case 1013:  /* *thumb2_mov_negscc_strict_it */
    case 1014:  /* *thumb2_mov_notscc */
    case 1015:  /* *thumb2_mov_notscc_strict_it */
    case 1016:  /* *thumb2_movsicc_insn */
    case 1017:  /* *thumb2_movsfcc_soft_insn */
    case 1025:  /* *thumb2_and_scc */
    case 1026:  /* *thumb2_ior_scc */
    case 1027:  /* *thumb2_ior_scc_strict_it */
    case 1028:  /* *thumb2_cond_move */
    case 6358:  /* *p addsi3_carryin */
    case 6359:  /* *p add0si3_carryin */
    case 6360:  /* *p *addsi3_carryin_alt2 */
    case 6361:  /* *p *addsi3_carryin_shift */
    case 6362:  /* *p subsi3_carryin */
    case 6363:  /* *p rsbsi_carryin_reg */
    case 6364:  /* *p *add_not_cin */
    case 6365:  /* *p add_not_shift_cin */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6368:  /* *p *rsbsi3_carryin_shift */
    case 6369:  /* *p *rsbsi3_carryin_shift_alt */
    case 6419:  /* *p arm_get_apsr */
      return CONDS_USE;

    default:
      if ((
#line 87 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB1)))
        {
	  return CONDS_CLOB;
        }
      else
        {
	  return CONDS_UNCONDITIONAL;
        }

    }
}

enum attr_ce_enabled
get_attr_ce_enabled (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 6924:  /* *p *thumb2_neg_abssi2 */
    case 6923:  /* *p *thumb2_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CE_ENABLED_YES;
        }
      else
        {
	  return CE_ENABLED_NO;
        }

    case 6855:  /* *p *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return CE_ENABLED_YES;
        }
      else if (which_alternative == 3)
        {
	  return CE_ENABLED_NO;
        }
      else
        {
	  return CE_ENABLED_YES;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return CE_ENABLED_YES;
        }
      else if (which_alternative == 2)
        {
	  return CE_ENABLED_NO;
        }
      else if (which_alternative == 3)
        {
	  return CE_ENABLED_YES;
        }
      else
        {
	  return CE_ENABLED_NO;
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3fULL))
        {
	  return CE_ENABLED_YES;
        }
      else if (((1ULL << which_alternative) & 0xc0ULL))
        {
	  return CE_ENABLED_NO;
        }
      else
        {
	  return CE_ENABLED_YES;
        }

    case 6842:  /* *p *arm_movhi_fp16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  return CE_ENABLED_YES;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return CE_ENABLED_NO;
        }
      else
        {
	  return CE_ENABLED_YES;
        }

    case 6558:  /* *p *arm_rev */
    case 6433:  /* *p unaligned_storehi */
    case 6432:  /* *p unaligned_storesi */
    case 6431:  /* *p unaligned_loadhiu */
    case 6429:  /* *p unaligned_loadsi */
    case 6439:  /* *p *arm_abssi2 */
    case 6440:  /* *p *arm_neg_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return CE_ENABLED_NO;
        }
      else
        {
	  return CE_ENABLED_YES;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return CE_ENABLED_YES;

    }
}

enum attr_exynos_m1_neon_type
get_attr_exynos_m1_neon_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 1)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4;
        }

    case 2745:  /* neon_vst4di */
      if ((64) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_4;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE4_4;
        }

    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
      if ((32) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_4;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE4_4;
        }

    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
      if ((16) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_4;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE4_4;
        }

    case 2739:  /* neon_vst4v8qi */
      if ((8) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_4;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE4_4;
        }

    case 2737:  /* neon_vld4_dupdi */
      if (! ((1) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ALL;
        }

    case 2736:  /* neon_vld4_dupv2sf */
    case 2735:  /* neon_vld4_dupv2si */
      if (! ((2) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ALL;
        }

    case 2734:  /* neon_vld4_dupv4bf */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2732:  /* neon_vld4_dupv4hi */
      if (! ((4) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ALL;
        }

    case 2731:  /* neon_vld4_dupv8qi */
      if (! ((8) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ALL;
        }

    case 2707:  /* neon_vld4di */
      if ((64) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_4;
        }

    case 2706:  /* neon_vld4v2sf */
    case 2705:  /* neon_vld4v2si */
      if ((32) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_4;
        }

    case 2704:  /* neon_vld4v4bf */
    case 2703:  /* neon_vld4v4hf */
    case 2702:  /* neon_vld4v4hi */
      if ((16) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_4;
        }

    case 2701:  /* neon_vld4v8qi */
      if ((8) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_4;
        }

    case 2677:  /* neon_vst3di */
      if ((64) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_3;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE3_ONE;
        }

    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
      if ((32) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_3;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE3_ONE;
        }

    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
      if ((16) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_3;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE3_ONE;
        }

    case 2671:  /* neon_vst3v8qi */
      if ((8) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_3;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE3_ONE;
        }

    case 2669:  /* neon_vld3_dupdi */
      if (! ((1) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ALL;
        }

    case 2668:  /* neon_vld3_dupv2sf */
    case 2667:  /* neon_vld3_dupv2si */
      if (! ((2) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ALL;
        }

    case 2666:  /* neon_vld3_dupv4bf */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2664:  /* neon_vld3_dupv4hi */
      if (! ((4) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ALL;
        }

    case 2663:  /* neon_vld3_dupv8qi */
      if (! ((8) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ALL;
        }

    case 2639:  /* neon_vld3di */
      if ((64) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_3;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_3;
        }

    case 2638:  /* neon_vld3v2sf */
    case 2637:  /* neon_vld3v2si */
      if ((32) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_3;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_3;
        }

    case 2636:  /* neon_vld3v4bf */
    case 2635:  /* neon_vld3v4hf */
    case 2634:  /* neon_vld3v4hi */
      if ((16) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_3;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_3;
        }

    case 2633:  /* neon_vld3v8qi */
      if ((8) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_3;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_3;
        }

    case 2615:  /* neon_vst2di */
      if ((64) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE2_ONE;
        }

    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
      if ((32) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE2_ONE;
        }

    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
      if ((16) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE2_ONE;
        }

    case 2609:  /* neon_vst2v8qi */
      if ((8) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE2_ONE;
        }

    case 2607:  /* neon_vld2_dupdi */
      if (! ((1) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ALL;
        }

    case 2606:  /* neon_vld2_dupv2sf */
    case 2605:  /* neon_vld2_dupv2si */
      if (! ((2) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ALL;
        }

    case 2604:  /* neon_vld2_dupv4bf */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2602:  /* neon_vld2_dupv4hi */
      if (! ((4) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ALL;
        }

    case 2601:  /* neon_vld2_dupv8qi */
      if (! ((8) > (1)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ALL;
        }

    case 2583:  /* neon_vld2di */
      if ((64) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2;
        }

    case 2582:  /* neon_vld2v2sf */
    case 2581:  /* neon_vld2v2si */
      if ((32) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2;
        }

    case 2580:  /* neon_vld2v4bf */
    case 2579:  /* neon_vld2v4hf */
    case 2578:  /* neon_vld2v4hi */
      if ((16) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2;
        }

    case 2577:  /* neon_vld2v8qi */
      if ((8) == (64))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2;
        }

    case 2052:  /* neon_vdup_nv4sf */
    case 2051:  /* neon_vdup_nv4si */
    case 2050:  /* neon_vdup_nv2sf */
    case 2049:  /* neon_vdup_nv2si */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITOPS;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }

    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
      if ((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_ZERO_Q)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else if (cached_type == TYPE_NEON_COMPARE_Q)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if ((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_ZERO)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else if (cached_type == TYPE_NEON_COMPARE)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 1430:  /* neon_vpsmaxv2sf */
    case 1426:  /* neon_vpsminv2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_MINMAX;
        }

    case 1429:  /* neon_vpsmaxv2si */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1425:  /* neon_vpsminv2si */
    case 1424:  /* neon_vpsminv4hi */
    case 1423:  /* neon_vpsminv8qi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_MINMAX;
        }

    case 1421:  /* neon_vpadd_internalv2sf */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_ADD;
        }

    case 1420:  /* neon_vpadd_internalv2si */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1418:  /* neon_vpadd_internalv8qi */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_ADD;
        }

    case 1380:  /* neon_load_count */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }

    case 1353:  /* *smaxv4sf3_neon */
    case 1352:  /* *smaxv2sf3_neon */
    case 1345:  /* *sminv4sf3_neon */
    case 1344:  /* *sminv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_SIMPLE;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_COMPARE;
        }

    case 1351:  /* *smaxv4si3_neon */
    case 1350:  /* *smaxv2si3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1339:  /* *sminv16qi3_neon */
    case 1338:  /* *sminv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_SIMPLE;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_COMPARE;
        }

    case 1307:  /* neon_negv4sf2 */
    case 1306:  /* neon_negv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_UNARY;
        }

    case 1305:  /* neon_negv4si2 */
    case 1304:  /* neon_negv2si2 */
    case 1303:  /* neon_negv8hi2 */
    case 1302:  /* neon_negv4hi2 */
    case 1301:  /* neon_negv16qi2 */
    case 1300:  /* neon_negv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_UNARY;
        }

    case 1299:  /* neon_absv4sf2 */
    case 1298:  /* neon_absv2sf2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_SIMPLE;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_UNARY;
        }

    case 1297:  /* neon_absv4si2 */
    case 1296:  /* neon_absv2si2 */
    case 1295:  /* neon_absv8hi2 */
    case 1294:  /* neon_absv4hi2 */
    case 1293:  /* neon_absv16qi2 */
    case 1292:  /* neon_absv8qi2 */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_SIMPLE;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_UNARY;
        }

    case 2210:  /* neon_vmls_lanev4sf */
    case 2207:  /* neon_vmls_lanev2sf */
    case 2198:  /* neon_vmla_lanev4sf */
    case 2195:  /* neon_vmla_lanev2sf */
    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_MLA;
        }

    case 2209:  /* neon_vmls_lanev4si */
    case 2208:  /* neon_vmls_lanev8hi */
    case 2206:  /* neon_vmls_lanev2si */
    case 2205:  /* neon_vmls_lanev4hi */
    case 2197:  /* neon_vmla_lanev4si */
    case 2196:  /* neon_vmla_lanev8hi */
    case 2194:  /* neon_vmla_lanev2si */
    case 2193:  /* neon_vmla_lanev4hi */
    case 1562:  /* neon_vmlsv4si_unspec */
    case 1561:  /* neon_vmlsv2si_unspec */
    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1177:  /* mulv4si3addv4si_neon */
    case 1176:  /* mulv2si3addv2si_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_MLA;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_MLA;
        }

    case 2168:  /* neon_vmul_lanev4sf */
    case 2165:  /* neon_vmul_lanev2sf */
    case 1516:  /* neon_vmulfv4sf */
    case 1515:  /* neon_vmulfv2sf */
    case 1171:  /* *mulv4sf3_neon */
    case 1170:  /* *mulv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_MULTIPLY;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_MUL;
        }

    case 2167:  /* neon_vmul_lanev4si */
    case 2166:  /* neon_vmul_lanev8hi */
    case 2164:  /* neon_vmul_lanev2si */
    case 2163:  /* neon_vmul_lanev4hi */
    case 1514:  /* neon_vmulpv16qi */
    case 1513:  /* neon_vmulpv8qi */
    case 1169:  /* *mulv4si3_neon */
    case 1168:  /* *mulv2si3_neon */
    case 1167:  /* *mulv8hi3_neon */
    case 1166:  /* *mulv4hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
    case 1164:  /* *mulv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_MULTIPLY;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_MUL;
        }

    case 1603:  /* neon_vsubv4sf_unspec */
    case 1602:  /* neon_vsubv2sf_unspec */
    case 1454:  /* neon_vaddv4sf_unspec */
    case 1453:  /* neon_vaddv2sf_unspec */
    case 1162:  /* *subv4sf3_neon */
    case 1161:  /* *subv2sf3_neon */
    case 1160:  /* *subv8hf3_neon */
    case 1159:  /* *subv4hf3_neon */
    case 1151:  /* *addv4sf3_neon */
    case 1150:  /* *addv2sf3_neon */
    case 1149:  /* *addv8hf3_neon */
    case 1148:  /* *addv4hf3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_ADD;
        }

    case 1163:  /* *subv2di3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1157:  /* *subv2si3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1154:  /* *subv16qi3_neon */
    case 1153:  /* *subv8qi3_neon */
    case 1152:  /* *addv2di3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1146:  /* *addv2si3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1143:  /* *addv16qi3_neon */
    case 1142:  /* *addv8qi3_neon */
      extract_constrain_insn_cached (insn);
      if (! (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false)))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_ADD;
        }

    case 1141:  /* neon_vec_extractv2didi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1136:  /* neon_vec_extractv16qiqi */
    case 1135:  /* vec_extractv2sfsf */
    case 1134:  /* vec_extractv2sisi */
    case 1133:  /* vec_extractv4bfbf */
    case 1132:  /* vec_extractv4hfhf */
    case 1131:  /* vec_extractv4hihi */
    case 1130:  /* vec_extractv8qiqi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_ONE;
        }

    case 1129:  /* vec_setv2di_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1124:  /* vec_setv16qi_internal */
    case 1123:  /* vec_setv2sf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1118:  /* vec_setv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ALL;
        }

    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITOPS;
        }
      else if (!((1ULL << which_alternative) & 0x3ULL))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE2_2;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 6)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 8)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4;
        }
      else if (which_alternative == 4)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2;
        }
      else if (!((1ULL << which_alternative) & 0x1ffULL))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_4;
        }
      else if (which_alternative == 1)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE2_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xdULL))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 6)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 4)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else if (which_alternative == 7)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_2;
        }
      else if (which_alternative == 1)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_1;
        }
      else if (which_alternative == 8)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_2;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 774:  /* *thumb2_movdfcc_vfp */
    case 773:  /* *movdfcc_vfp */
    case 772:  /* *thumb2_movsfcc_vfp */
    case 771:  /* *movsfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x38ULL))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (!((1ULL << which_alternative) & 0x3fULL))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITOPS;
        }
      else if (which_alternative == 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 1)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 768:  /* *thumb2_movsf_vfp */
    case 767:  /* *movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 1)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 766:  /* *movbf_vfp */
    case 765:  /* *movhf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 4)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 6)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 7)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else if (which_alternative == 1)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 4)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 5)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 7)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else if (which_alternative == 8)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_1;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 7)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 8)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 9)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 10)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 6848:  /* *p *arm_movsi_vfp */
    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 758:  /* *arm_movsi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 6)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 7)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 5)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 6)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 531:  /* *iwmmxt_movsi_insn */
    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 10)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 11)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 522:  /* mve_vshlq_uv4si */
    case 521:  /* mve_vshlq_sv4si */
    case 520:  /* mve_vshlq_uv2si */
    case 519:  /* mve_vshlq_sv2si */
    case 518:  /* mve_vshlq_uv8hi */
    case 517:  /* mve_vshlq_sv8hi */
    case 516:  /* mve_vshlq_uv4hi */
    case 515:  /* mve_vshlq_sv4hi */
    case 514:  /* mve_vshlq_uv16qi */
    case 513:  /* mve_vshlq_sv16qi */
    case 512:  /* mve_vshlq_uv8qi */
    case 511:  /* mve_vshlq_sv8qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_REG_BASIC;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_ABD) || (cached_type == TYPE_NEON_ABD_Q) || (cached_type == TYPE_NEON_ABD_LONG) || (cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_MINMAX_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_SIMPLE;
        }
      else if ((cached_type == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_ADD_Q) || (cached_type == TYPE_NEON_ADD_LONG) || (cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_SUB_Q) || (cached_type == TYPE_NEON_SUB_LONG) || (cached_type == TYPE_NEON_SUB_WIDEN) || (cached_type == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_TST_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC;
        }
      else if ((cached_type == TYPE_NEON_ADD_WIDEN) || (cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_ARITH_ACC_Q) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_REDUC_ADD_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC_Q) || (cached_type == TYPE_NEON_REDUC_ADD_LONG) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_QABS) || (cached_type == TYPE_NEON_QABS_Q) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_QNEG) || (cached_type == TYPE_NEON_QNEG_Q) || (cached_type == TYPE_NEON_QSUB) || (cached_type == TYPE_NEON_QSUB_Q) || (cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_REDUC_MINMAX) || (cached_type == TYPE_NEON_REDUC_MINMAX_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX;
        }
      else if ((cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG) || (cached_type == TYPE_CRYPTO_PMULL))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_MULTIPLY;
        }
      else if ((cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H_Q) || (cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_MLA;
        }
      else if ((cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_SAT_MLA_LONG;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SHIFT_ACC_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_ACC;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_BASIC;
        }
      else if ((cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX;
        }
      else if ((cached_type == TYPE_NEON_SHIFT_REG) || (cached_type == TYPE_NEON_SHIFT_REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_REG_BASIC;
        }
      else if ((cached_type == TYPE_NEON_SAT_SHIFT_REG) || (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_REG_COMPLEX;
        }
      else if ((cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_ABS_S_Q) || (cached_type == TYPE_NEON_FP_NEG_D) || (cached_type == TYPE_NEON_FP_NEG_D_Q) || (cached_type == TYPE_NEON_FP_ABS_D) || (cached_type == TYPE_NEON_FP_ABS_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_UNARY;
        }
      else if ((cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_D) || (cached_type == TYPE_NEON_FP_ADDSUB_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_ADD;
        }
      else if ((cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_ABD_D) || (cached_type == TYPE_NEON_FP_ABD_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_ABD;
        }
      else if ((cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_D) || (cached_type == TYPE_NEON_FP_COMPARE_D_Q) || (cached_type == TYPE_NEON_FP_MINMAX_S) || (cached_type == TYPE_NEON_FP_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_MINMAX_D) || (cached_type == TYPE_NEON_FP_MINMAX_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_COMPARE;
        }
      else if ((cached_type == TYPE_NEON_FP_REDUC_MINMAX_S) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_D) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_MINMAX;
        }
      else if ((cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_ADD;
        }
      else if ((cached_type == TYPE_NEON_FP_ROUND_S) || (cached_type == TYPE_NEON_FP_ROUND_S_Q) || (cached_type == TYPE_NEON_FP_ROUND_D) || (cached_type == TYPE_NEON_FP_ROUND_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_ROUND;
        }
      else if ((cached_type == TYPE_NEON_FP_CVT_NARROW_S_Q) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_H) || (cached_type == TYPE_NEON_FP_TO_INT_S) || (cached_type == TYPE_NEON_FP_TO_INT_S_Q) || (cached_type == TYPE_NEON_FP_TO_INT_D_Q) || (cached_type == TYPE_NEON_FP_TO_INT_D) || (cached_type == TYPE_NEON_INT_TO_FP_S) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_D) || (cached_type == TYPE_NEON_INT_TO_FP_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_CVT;
        }
      else if ((cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MUL_D) || (cached_type == TYPE_NEON_FP_MUL_D_Q) || (cached_type == TYPE_NEON_FP_MUL_D_SCALAR_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_MUL;
        }
      else if ((cached_type == TYPE_NEON_FP_MLA_S) || (cached_type == TYPE_NEON_FP_MLA_S_Q) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MLA_D) || (cached_type == TYPE_NEON_FP_MLA_D_Q) || (cached_type == TYPE_NEON_FP_MLA_D_SCALAR_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_MLA;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_S) || (cached_type == TYPE_NEON_FP_RSQRTE_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_D) || (cached_type == TYPE_NEON_FP_RECPE_D_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_D) || (cached_type == TYPE_NEON_FP_RSQRTE_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_ESTIMATE;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPX_S) || (cached_type == TYPE_NEON_FP_RECPX_S_Q) || (cached_type == TYPE_NEON_FP_RECPX_D) || (cached_type == TYPE_NEON_FP_RECPX_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_ESTIMATEX;
        }
      else if ((cached_type == TYPE_NEON_FP_RECPS_S) || (cached_type == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_S) || (cached_type == TYPE_NEON_FP_RSQRTS_S_Q) || (cached_type == TYPE_NEON_FP_RECPS_D) || (cached_type == TYPE_NEON_FP_RECPS_D_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_D) || (cached_type == TYPE_NEON_FP_RSQRTS_D_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FP_STEP;
        }
      else if ((cached_type == TYPE_NEON_RBIT) || (cached_type == TYPE_NEON_RBIT_Q) || (cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CLS_Q) || (cached_type == TYPE_NEON_CNT) || (cached_type == TYPE_NEON_CNT_Q) || (cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_DUP_Q) || (cached_type == TYPE_NEON_REV) || (cached_type == TYPE_NEON_REV_Q) || (cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_MOVE_Q) || (cached_type == TYPE_NEON_EXT) || (cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_ZIP))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITOPS;
        }
      else if ((cached_type == TYPE_NEON_EXT_Q) || (cached_type == TYPE_NEON_PERMUTE_Q) || (cached_type == TYPE_NEON_ZIP_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITOPS_Q;
        }
      else if ((cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_BSL_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_BITINS;
        }
      else if ((cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL2) || (cached_type == TYPE_NEON_TBL3) || (cached_type == TYPE_NEON_TBL4))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TBL;
        }
      else if ((cached_type == TYPE_NEON_FROM_GP) || (cached_type == TYPE_NEON_FROM_GP_Q) || (cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;
        }
      else if ((cached_type == TYPE_NEON_TO_GP) || (cached_type == TYPE_NEON_TO_GP_Q) || (cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_1REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_2REG) || (cached_type == TYPE_NEON_LOAD1_2REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_2;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_3REG) || (cached_type == TYPE_NEON_LOAD1_3REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_3;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_4REG) || (cached_type == TYPE_NEON_LOAD1_4REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_ONE_LANE) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ONE;
        }
      else if ((cached_type == TYPE_NEON_LOAD1_ALL_LANES) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ALL;
        }
      else if ((cached_type == TYPE_NEON_LOAD2_2REG) || (cached_type == TYPE_NEON_LOAD2_2REG_Q) || (cached_type == TYPE_NEON_LOAD2_4REG) || (cached_type == TYPE_NEON_LOAD2_4REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2;
        }
      else if ((cached_type == TYPE_NEON_LOAD2_ONE_LANE) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ONE;
        }
      else if ((cached_type == TYPE_NEON_LOAD2_ALL_LANES) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ALL;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_3REG) || (cached_type == TYPE_NEON_LOAD3_3REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_3;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_ONE_LANE) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ONE;
        }
      else if ((cached_type == TYPE_NEON_LOAD3_ALL_LANES) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ALL;
        }
      else if ((cached_type == TYPE_NEON_LOAD4_4REG) || (cached_type == TYPE_NEON_LOAD4_4REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_4;
        }
      else if ((cached_type == TYPE_NEON_LOAD4_ONE_LANE) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ONE;
        }
      else if ((cached_type == TYPE_NEON_LOAD4_ALL_LANES) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ALL;
        }
      else if ((cached_type == TYPE_NEON_STORE1_1REG) || (cached_type == TYPE_NEON_STORE1_1REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_1;
        }
      else if ((cached_type == TYPE_NEON_STORE1_2REG) || (cached_type == TYPE_NEON_STORE1_2REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_2;
        }
      else if ((cached_type == TYPE_NEON_STORE1_3REG) || (cached_type == TYPE_NEON_STORE1_3REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_3;
        }
      else if ((cached_type == TYPE_NEON_STORE1_4REG) || (cached_type == TYPE_NEON_STORE1_4REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_4;
        }
      else if ((cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE1_ONE;
        }
      else if ((cached_type == TYPE_NEON_STORE2_2REG) || (cached_type == TYPE_NEON_STORE2_2REG_Q) || (cached_type == TYPE_NEON_STORE2_4REG) || (cached_type == TYPE_NEON_STORE2_4REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE2_2;
        }
      else if ((cached_type == TYPE_NEON_STORE2_ONE_LANE) || (cached_type == TYPE_NEON_STORE2_ONE_LANE_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE2_ONE;
        }
      else if ((cached_type == TYPE_NEON_STORE3_3REG) || (cached_type == TYPE_NEON_STORE3_3REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE3_3;
        }
      else if ((cached_type == TYPE_NEON_STORE3_ONE_LANE) || (cached_type == TYPE_NEON_STORE3_ONE_LANE_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE3_ONE;
        }
      else if ((cached_type == TYPE_NEON_STORE4_4REG) || (cached_type == TYPE_NEON_STORE4_4REG_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE4_4;
        }
      else if ((cached_type == TYPE_NEON_STORE4_ONE_LANE) || (cached_type == TYPE_NEON_STORE4_ONE_LANE_Q))
        {
	  return EXYNOS_M1_NEON_TYPE_NEON_STORE4_ONE;
        }
      else
        {
	  return EXYNOS_M1_NEON_TYPE_UNKNOWN;
        }

    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_STORE4_ONE;

    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
      return EXYNOS_M1_NEON_TYPE_NEON_STORE4_4;

    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_STORE3_ONE;

    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
      return EXYNOS_M1_NEON_TYPE_NEON_STORE3_3;

    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_STORE2_ONE;

    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
      return EXYNOS_M1_NEON_TYPE_NEON_STORE2_2;

    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_STORE1_ONE;

    case 2562:  /* neon_vst1v2di */
    case 2561:  /* neon_vst1di */
    case 2560:  /* neon_vst1v4sf */
    case 2559:  /* neon_vst1v2sf */
    case 2558:  /* neon_vst1v8bf */
    case 2557:  /* neon_vst1v4bf */
    case 2556:  /* neon_vst1v8hf */
    case 2555:  /* neon_vst1v4hf */
    case 2554:  /* neon_vst1v4si */
    case 2553:  /* neon_vst1v2si */
    case 2552:  /* neon_vst1v8hi */
    case 2551:  /* neon_vst1v4hi */
    case 2550:  /* neon_vst1v16qi */
    case 2549:  /* neon_vst1v8qi */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1070:  /* unaligned_storev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_STORE1_1;

    case 2738:  /* neon_vld4_dupv8bf */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ALL;

    case 2730:  /* neon_vld4_lanev8bf */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2726:  /* neon_vld4_lanev8hi */
    case 2725:  /* neon_vld4_lanev2sf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2720:  /* neon_vld4_lanev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ONE;

    case 2719:  /* neon_vld4qbv4sf */
    case 2718:  /* neon_vld4qbv4si */
    case 2717:  /* neon_vld4qbv8bf */
    case 2716:  /* neon_vld4qbv8hf */
    case 2715:  /* neon_vld4qbv8hi */
    case 2714:  /* neon_vld4qbv16qi */
    case 2713:  /* neon_vld4qav4sf */
    case 2712:  /* neon_vld4qav4si */
    case 2711:  /* neon_vld4qav8bf */
    case 2710:  /* neon_vld4qav8hf */
    case 2709:  /* neon_vld4qav8hi */
    case 2708:  /* neon_vld4qav16qi */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD4_4;

    case 2670:  /* neon_vld3_dupv8bf */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ALL;

    case 2662:  /* neon_vld3_lanev8bf */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2658:  /* neon_vld3_lanev8hi */
    case 2657:  /* neon_vld3_lanev2sf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2652:  /* neon_vld3_lanev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ONE;

    case 2651:  /* neon_vld3qbv4sf */
    case 2650:  /* neon_vld3qbv4si */
    case 2649:  /* neon_vld3qbv8bf */
    case 2648:  /* neon_vld3qbv8hf */
    case 2647:  /* neon_vld3qbv8hi */
    case 2646:  /* neon_vld3qbv16qi */
    case 2645:  /* neon_vld3qav4sf */
    case 2644:  /* neon_vld3qav4si */
    case 2643:  /* neon_vld3qav8bf */
    case 2642:  /* neon_vld3qav8hf */
    case 2641:  /* neon_vld3qav8hi */
    case 2640:  /* neon_vld3qav16qi */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD3_3;

    case 2608:  /* neon_vld2_dupv8bf */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ALL;

    case 2600:  /* neon_vld2_lanev8bf */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2596:  /* neon_vld2_lanev8hi */
    case 2595:  /* neon_vld2_lanev2sf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2590:  /* neon_vld2_lanev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ONE;

    case 2589:  /* neon_vld2v4sf */
    case 2588:  /* neon_vld2v4si */
    case 2587:  /* neon_vld2v8bf */
    case 2586:  /* neon_vld2v8hf */
    case 2585:  /* neon_vld2v8hi */
    case 2584:  /* neon_vld2v16qi */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2;

    case 2548:  /* neon_vld1_dupv2di */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2543:  /* neon_vld1_dupv16qi */
    case 2542:  /* neon_vld1_dupv2sf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2537:  /* neon_vld1_dupv8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ALL;

    case 2536:  /* neon_vld1_lanev2di */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2530:  /* neon_vld1_lanev16qi */
    case 2529:  /* neon_vld1_lanedi */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2523:  /* neon_vld1_lanev8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ONE;

    case 2854:  /* aes_op_protect_neon_vld1v16qi */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2522:  /* neon_vld1v2di */
    case 2521:  /* neon_vld1di */
    case 2520:  /* neon_vld1v4sf */
    case 2519:  /* neon_vld1v2sf */
    case 2518:  /* neon_vld1v8bf */
    case 2517:  /* neon_vld1v4bf */
    case 2516:  /* neon_vld1v8hf */
    case 2515:  /* neon_vld1v4hf */
    case 2514:  /* neon_vld1v4si */
    case 2513:  /* neon_vld1v2si */
    case 2512:  /* neon_vld1v8hi */
    case 2511:  /* neon_vld1v4hi */
    case 2510:  /* neon_vld1v16qi */
    case 2509:  /* neon_vld1v8qi */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1111:  /* *movmisalignv16qi_neon_load */
    case 1103:  /* *movmisaligndi_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1097:  /* *movmisalignv8qi_neon_load */
      return EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1;

    case 2478:  /* neon_vtbx4v8qi */
    case 2477:  /* neon_vtbx3v8qi */
    case 2476:  /* neon_vtbx2v8qi */
    case 2475:  /* neon_vtbx1v8qi */
    case 2471:  /* neon_vtbl4v8qi */
    case 2470:  /* neon_vtbl3v8qi */
    case 2469:  /* neon_vtbl2v8qi */
    case 2468:  /* neon_vtbl1v8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_TBL;

    case 2048:  /* neon_vdup_nv8bf */
    case 2047:  /* neon_vdup_nv4bf */
    case 2046:  /* neon_vdup_nv8hf */
    case 2045:  /* neon_vdup_nv4hf */
    case 2044:  /* neon_vdup_nv8hi */
    case 2043:  /* neon_vdup_nv16qi */
    case 2042:  /* neon_vdup_nv4hi */
    case 2041:  /* neon_vdup_nv8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_FROM_GP;

    case 2040:  /* neon_vget_lanev4sf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2031:  /* neon_vget_lanev16qi_sext_internal */
    case 2030:  /* neon_vget_lanev2sf_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2023:  /* neon_vget_lanev8qi_sext_internal */
      return EXYNOS_M1_NEON_TYPE_NEON_TO_GP;

    case 2261:  /* neon_vbslv2di_internal */
    case 2260:  /* neon_vbsldi_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2249:  /* neon_vbslv16qi_internal */
    case 2248:  /* neon_vbslv8qi_internal */
      return EXYNOS_M1_NEON_TYPE_NEON_BITINS;

    case 2507:  /* *neon_vuzpv8hf_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2490:  /* *neon_vzipv16qi_insn */
    case 2487:  /* *neon_vtrnv8hf_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2230:  /* neon_vextv2di */
    case 2228:  /* neon_vextv4sf */
    case 2226:  /* neon_vextv8bf */
    case 2224:  /* neon_vextv8hf */
    case 2222:  /* neon_vextv4si */
    case 2220:  /* neon_vextv8hi */
    case 2218:  /* neon_vextv16qi */
    case 2079:  /* *neon_vswpv2di */
    case 2077:  /* *neon_vswpv4sf */
    case 2075:  /* *neon_vswpv8bf */
    case 2073:  /* *neon_vswpv8hf */
    case 2071:  /* *neon_vswpv4si */
    case 2069:  /* *neon_vswpv8hi */
    case 2067:  /* *neon_vswpv16qi */
      return EXYNOS_M1_NEON_TYPE_NEON_BITOPS_Q;

    case 2804:  /* neon_unpacku_v2si */
    case 2803:  /* neon_unpacks_v2si */
    case 2802:  /* neon_unpacku_v4hi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2799:  /* neon_unpacks_v8qi */
    case 2508:  /* *neon_vuzpv4hf_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2489:  /* *neon_vzipv8qi_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2247:  /* neon_vrev16v16qi */
    case 2246:  /* neon_vrev16v8qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2244:  /* neon_vrev32v16qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2242:  /* neon_vrev32v8qi */
    case 2241:  /* neon_vrev64v2di */
    case 2240:  /* neon_vrev64v4sf */
    case 2239:  /* neon_vrev64v2sf */
    case 2238:  /* neon_vrev64v8hf */
    case 2237:  /* neon_vrev64v4hf */
    case 2236:  /* neon_vrev64v4si */
    case 2235:  /* neon_vrev64v2si */
    case 2234:  /* neon_vrev64v8hi */
    case 2233:  /* neon_vrev64v4hi */
    case 2232:  /* neon_vrev64v16qi */
    case 2231:  /* neon_vrev64v8qi */
    case 2229:  /* neon_vextdi */
    case 2227:  /* neon_vextv2sf */
    case 2225:  /* neon_vextv4bf */
    case 2223:  /* neon_vextv4hf */
    case 2221:  /* neon_vextv2si */
    case 2219:  /* neon_vextv4hi */
    case 2217:  /* neon_vextv8qi */
    case 2078:  /* *neon_vswpdi */
    case 2076:  /* *neon_vswpv2sf */
    case 2074:  /* *neon_vswpv4bf */
    case 2072:  /* *neon_vswpv4hf */
    case 2070:  /* *neon_vswpv2si */
    case 2068:  /* *neon_vswpv4hi */
    case 2066:  /* *neon_vswpv8qi */
    case 2065:  /* neon_vdup_lanev8bf_internal */
    case 2064:  /* neon_vdup_lanev4bf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 2012:  /* popcountv16qi2 */
    case 2011:  /* popcountv8qi2 */
    case 2010:  /* neon_vclzv4si */
    case 2009:  /* neon_vclzv2si */
    case 2008:  /* neon_vclzv8hi */
    case 2007:  /* neon_vclzv4hi */
    case 2006:  /* neon_vclzv16qi */
    case 2005:  /* neon_vclzv8qi */
    case 2004:  /* neon_vclsv4si */
    case 2003:  /* neon_vclsv2si */
    case 2002:  /* neon_vclsv8hi */
    case 2001:  /* neon_vclsv4hi */
    case 2000:  /* neon_vclsv16qi */
    case 1999:  /* neon_vclsv8qi */
    case 1914:  /* neon_bswapv2di */
    case 1913:  /* neon_bswapv4si */
    case 1912:  /* neon_bswapv2si */
    case 1911:  /* neon_bswapv8hi */
    case 1910:  /* neon_bswapv4hi */
    case 1291:  /* one_cmplv2di2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1289:  /* one_cmplv2sf2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1282:  /* one_cmplv16qi2_neon */
    case 1281:  /* one_cmplv8qi2_neon */
      return EXYNOS_M1_NEON_TYPE_NEON_BITOPS;

    case 1903:  /* neon_vrsqrtsv4hf */
    case 1902:  /* neon_vrsqrtsv8hf */
    case 1901:  /* neon_vrsqrtsv4sf */
    case 1900:  /* neon_vrsqrtsv2sf */
    case 1899:  /* neon_vrecpsv4hf */
    case 1898:  /* neon_vrecpsv8hf */
    case 1897:  /* neon_vrecpsv4sf */
    case 1896:  /* neon_vrecpsv2sf */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_STEP;

    case 2022:  /* neon_vrsqrtev4sf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2020:  /* neon_vrsqrtev2sf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2018:  /* neon_vrecpev4sf */
    case 2017:  /* neon_vrecpev4si */
    case 2016:  /* neon_vrecpev2sf */
    case 2015:  /* neon_vrecpev2si */
    case 2014:  /* neon_vrecpev4hf */
    case 2013:  /* neon_vrecpev8hf */
    case 1325:  /* neon_vrsqrtev4hf */
    case 1324:  /* neon_vrsqrtev8hf */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_ESTIMATE;

    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1190:  /* fmav2sf4 */
    case 1181:  /* mulv4hf3addv4hf_neon */
    case 1180:  /* mulv8hf3addv8hf_neon */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_MLA;

    case 2170:  /* neon_vmul_lanev4hf */
    case 2169:  /* neon_vmul_lanev8hf */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_MUL;

    case 2836:  /* neon_vbfcvtv4sf_highv8bf */
    case 2835:  /* neon_vbfcvtv4sfv8bf */
    case 2834:  /* neon_vbfcvtv4sfv4bf */
    case 2144:  /* neon_vcvtpuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2136:  /* neon_vcvtpuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2128:  /* neon_vcvtu_nv8hi */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2126:  /* neon_vcvtu_nv4hi */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2123:  /* neon_vcvts_nv4si */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2121:  /* neon_vcvts_nv2si */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2108:  /* neon_vcvtuv8hi */
    case 2107:  /* neon_vcvtsv8hi */
    case 2106:  /* neon_vcvtuv4hi */
    case 2105:  /* neon_vcvtsv4hi */
    case 2104:  /* neon_vcvtv4hfv4sf */
    case 2103:  /* neon_vcvtv4sfv4hf */
    case 2102:  /* neon_vcvtuv4si */
    case 2101:  /* neon_vcvtsv4si */
    case 2100:  /* neon_vcvtuv2si */
    case 2099:  /* neon_vcvtsv2si */
    case 2098:  /* neon_vcvtuv4sf */
    case 2097:  /* neon_vcvtsv4sf */
    case 2096:  /* neon_vcvtuv2sf */
    case 2095:  /* neon_vcvtsv2sf */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2088:  /* floatv4siv4sf2 */
    case 2087:  /* floatv2siv2sf2 */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1220:  /* neon_vcvtpv4sfv4si */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1214:  /* neon_vcvtpv2sfv2si */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_CVT;

    case 1323:  /* neon_vrndxv4hf */
    case 1322:  /* neon_vrndpv4hf */
    case 1321:  /* neon_vrndnv4hf */
    case 1320:  /* neon_vrndmv4hf */
    case 1319:  /* neon_vrndav4hf */
    case 1318:  /* neon_vrndv4hf */
    case 1317:  /* neon_vrndxv8hf */
    case 1316:  /* neon_vrndpv8hf */
    case 1315:  /* neon_vrndnv8hf */
    case 1314:  /* neon_vrndmv8hf */
    case 1313:  /* neon_vrndav8hf */
    case 1312:  /* neon_vrndv8hf */
    case 1213:  /* neon_vrintnv4sf */
    case 1212:  /* neon_vrintav4sf */
    case 1211:  /* neon_vrintxv4sf */
    case 1210:  /* neon_vrintmv4sf */
    case 1209:  /* neon_vrintzv4sf */
    case 1208:  /* neon_vrintpv4sf */
    case 1207:  /* neon_vrintnv2sf */
    case 1206:  /* neon_vrintav2sf */
    case 1205:  /* neon_vrintxv2sf */
    case 1204:  /* neon_vrintmv2sf */
    case 1203:  /* neon_vrintzv2sf */
    case 1202:  /* neon_vrintpv2sf */
    case 787:  /* neon_vrndihf */
    case 786:  /* neon_vrndxhf */
    case 785:  /* neon_vrndphf */
    case 784:  /* neon_vrndnhf */
    case 783:  /* neon_vrndmhf */
    case 782:  /* neon_vrndahf */
    case 781:  /* neon_vrndhf */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_ROUND;

    case 1404:  /* quad_halves_plusv4sf */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_ADD;

    case 1895:  /* neon_vpminfv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1893:  /* neon_vpminfv2sf */
    case 1892:  /* neon_vpmaxfv2sf */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1405:  /* quad_halves_sminv4sf */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_MINMAX;

    case 1855:  /* fminv4sf3 */
    case 1854:  /* fmaxv4sf3 */
    case 1853:  /* fminv2sf3 */
    case 1852:  /* fmaxv2sf3 */
    case 1851:  /* neon_vminnmv4sf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1849:  /* neon_vminnmv2sf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1847:  /* neon_vminnmv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1845:  /* neon_vminnmv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1841:  /* neon_vminfv4hf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1839:  /* neon_vminfv8hf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1837:  /* neon_vminfv4sf */
    case 1836:  /* neon_vmaxfv4sf */
    case 1835:  /* neon_vminfv2sf */
    case 1834:  /* neon_vmaxfv2sf */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1690:  /* neon_vceqv2sf_insn_unspec */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_COMPARE;

    case 2824:  /* neon_vabdv4sf_3 */
    case 2823:  /* neon_vabdv2sf_3 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2818:  /* neon_vabdv8hf_2 */
    case 2817:  /* neon_vabdv4hf_2 */
    case 1785:  /* neon_vabdfv4sf */
    case 1784:  /* neon_vabdfv2sf */
      return EXYNOS_M1_NEON_TYPE_NEON_FP_ABD;

    case 2467:  /* neon_vsli_nv2di */
    case 2466:  /* neon_vsli_ndi */
    case 2465:  /* neon_vsli_nv4si */
    case 2464:  /* neon_vsli_nv2si */
    case 2463:  /* neon_vsli_nv8hi */
    case 2462:  /* neon_vsli_nv4hi */
    case 2461:  /* neon_vsli_nv16qi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2459:  /* neon_vsri_nv2di */
    case 2458:  /* neon_vsri_ndi */
    case 2457:  /* neon_vsri_nv4si */
    case 2456:  /* neon_vsri_nv2si */
    case 2455:  /* neon_vsri_nv8hi */
    case 2454:  /* neon_vsri_nv4hi */
    case 2453:  /* neon_vsri_nv16qi */
    case 2452:  /* neon_vsri_nv8qi */
    case 1379:  /* ashlv2di3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1377:  /* ashlv2si3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1372:  /* ashlv2di3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1370:  /* ashlv2si3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1367:  /* ashlv16qi3_signed */
    case 1366:  /* ashlv8qi3_signed */
      return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_REG_BASIC;

    case 2413:  /* neon_vqshlu_nv2di */
    case 2412:  /* neon_vqshlu_ndi */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2381:  /* neon_vqrshrun_nv2di */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2325:  /* neon_vqrshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2322:  /* neon_vqshlsv2di */
    case 2321:  /* neon_vqrshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2318:  /* neon_vqshlsdi */
    case 2317:  /* neon_vqrshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2314:  /* neon_vqshlsv4si */
    case 2313:  /* neon_vqrshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2310:  /* neon_vqshlsv2si */
    case 2309:  /* neon_vqrshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2305:  /* neon_vqrshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2298:  /* neon_vqshlsv16qi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2294:  /* neon_vqshlsv8qi */
    case 2156:  /* neon_vqmovunv2di */
    case 2155:  /* neon_vqmovunv4si */
    case 2154:  /* neon_vqmovunv8hi */
    case 2153:  /* neon_vqmovnuv2di */
    case 2152:  /* neon_vqmovnsv2di */
    case 2151:  /* neon_vqmovnuv4si */
    case 2150:  /* neon_vqmovnsv4si */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2148:  /* neon_vqmovnsv8hi */
      return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX;

    case 2840:  /* neon_vbfcvt_highv8bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2798:  /* neon_vec_ushiftl_v2si */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2419:  /* neon_vshllu_nv2si */
    case 2418:  /* neon_vshlls_nv2si */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2389:  /* neon_vshl_nv2di */
    case 2388:  /* neon_vshl_ndi */
    case 2387:  /* neon_vshl_nv4si */
    case 2386:  /* neon_vshl_nv2si */
    case 2385:  /* neon_vshl_nv8hi */
    case 2384:  /* neon_vshl_nv4hi */
    case 2383:  /* neon_vshl_nv16qi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2363:  /* neon_vrshrn_nv2di */
    case 2362:  /* neon_vshrn_nv2di */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2360:  /* neon_vshrn_nv4si */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2357:  /* neon_vrshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2354:  /* neon_vshrs_nv2di */
    case 2353:  /* neon_vrshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2350:  /* neon_vshrs_ndi */
    case 2349:  /* neon_vrshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2346:  /* neon_vshrs_nv4si */
    case 2345:  /* neon_vrshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2342:  /* neon_vshrs_nv2si */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2293:  /* neon_vrshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2290:  /* neon_vshlsv2di */
    case 2289:  /* neon_vrshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2287:  /* neon_vshludi */
    case 2286:  /* neon_vshlsdi */
    case 2285:  /* neon_vrshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2282:  /* neon_vshlsv4si */
    case 2281:  /* neon_vrshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2278:  /* neon_vshlsv2si */
    case 2277:  /* neon_vrshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2274:  /* neon_vshlsv8hi */
    case 2273:  /* neon_vrshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2270:  /* neon_vshlsv4hi */
    case 2269:  /* neon_vrshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2266:  /* neon_vshlsv16qi */
    case 2265:  /* neon_vrshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2262:  /* neon_vshlsv8qi */
    case 2162:  /* neon_vmovluv2si */
    case 2161:  /* neon_vmovlsv2si */
    case 2160:  /* neon_vmovluv4hi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2158:  /* neon_vmovluv8qi */
    case 2157:  /* neon_vmovlsv8qi */
    case 2147:  /* neon_vmovnv2di */
    case 2146:  /* neon_vmovnv4si */
    case 2145:  /* neon_vmovnv8hi */
    case 1365:  /* vlshrv4si3_imm */
    case 1364:  /* vlshrv2si3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1355:  /* vashrv16qi3_imm */
    case 1354:  /* vashrv8qi3_imm */
      return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_BASIC;

    case 2451:  /* neon_vrsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2448:  /* neon_vsras_nv2di */
    case 2447:  /* neon_vrsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2444:  /* neon_vsras_ndi */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2440:  /* neon_vsras_nv4si */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2436:  /* neon_vsras_nv2si */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2424:  /* neon_vsras_nv16qi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2420:  /* neon_vsras_nv8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_SHIFT_ACC;

    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1588:  /* neon_vqdmlalv2si */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
      return EXYNOS_M1_NEON_TYPE_NEON_SAT_MLA_LONG;

    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
      return EXYNOS_M1_NEON_TYPE_NEON_MLA;

    case 2868:  /* crypto_vmullp64 */
    case 2184:  /* neon_vqrdmulh_lanev2si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
    case 1601:  /* neon_vqdmullv2si */
    case 1600:  /* neon_vqdmullv4hi */
    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
    case 1518:  /* neon_vmulfv4hf */
    case 1517:  /* neon_vmulfv8hf */
      return EXYNOS_M1_NEON_TYPE_NEON_MULTIPLY;

    case 1998:  /* neon_vqnegv4si */
    case 1997:  /* neon_vqnegv2si */
    case 1996:  /* neon_vqnegv8hi */
    case 1995:  /* neon_vqnegv4hi */
    case 1994:  /* neon_vqnegv16qi */
    case 1993:  /* neon_vqnegv8qi */
    case 1909:  /* neon_vqabsv4si */
    case 1908:  /* neon_vqabsv2si */
    case 1907:  /* neon_vqabsv8hi */
    case 1906:  /* neon_vqabsv4hi */
    case 1905:  /* neon_vqabsv16qi */
    case 1904:  /* neon_vqabsv8qi */
    case 1891:  /* neon_vpminuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1888:  /* neon_vpmaxsv2si */
    case 1887:  /* neon_vpminuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1883:  /* neon_vpminuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1879:  /* neon_vpadaluv4si */
    case 1878:  /* neon_vpadalsv4si */
    case 1877:  /* neon_vpadaluv2si */
    case 1876:  /* neon_vpadalsv2si */
    case 1875:  /* neon_vpadaluv8hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1868:  /* neon_vpadalsv8qi */
    case 1867:  /* neon_vpaddluv4si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1865:  /* neon_vpaddluv2si */
    case 1864:  /* neon_vpaddlsv2si */
    case 1863:  /* neon_vpaddluv8hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1856:  /* neon_vpaddlsv8qi */
    case 1843:  /* neon_vpminfv4hf */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1809:  /* neon_vabaluv2si */
    case 1808:  /* neon_vabalsv2si */
    case 1807:  /* neon_vabaluv4hi */
    case 1806:  /* neon_vabalsv4hi */
    case 1805:  /* neon_vabaluv8qi */
    case 1804:  /* neon_vabalsv8qi */
    case 1803:  /* neon_vabauv4si */
    case 1802:  /* neon_vabasv4si */
    case 1801:  /* neon_vabauv2si */
    case 1800:  /* neon_vabasv2si */
    case 1799:  /* neon_vabauv8hi */
    case 1798:  /* neon_vabasv8hi */
    case 1797:  /* neon_vabauv4hi */
    case 1796:  /* neon_vabasv4hi */
    case 1795:  /* neon_vabauv16qi */
    case 1794:  /* neon_vabasv16qi */
    case 1793:  /* neon_vabauv8qi */
    case 1792:  /* neon_vabasv8qi */
    case 1731:  /* neon_vcgeuv4si */
    case 1730:  /* neon_vcgtuv4si */
    case 1729:  /* neon_vcgeuv2si */
    case 1728:  /* neon_vcgtuv2si */
    case 1727:  /* neon_vcgeuv8hi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1725:  /* neon_vcgeuv4hi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1722:  /* neon_vcgtuv16qi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1720:  /* neon_vcgtuv8qi */
    case 1649:  /* neon_vrsubhnv2di */
    case 1648:  /* neon_vsubhnv2di */
    case 1647:  /* neon_vrsubhnv4si */
    case 1646:  /* neon_vsubhnv4si */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1644:  /* neon_vsubhnv8hi */
    case 1643:  /* neon_vhsubuv4si */
    case 1642:  /* neon_vhsubsv4si */
    case 1641:  /* neon_vhsubuv2si */
    case 1640:  /* neon_vhsubsv2si */
    case 1639:  /* neon_vhsubuv8hi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1637:  /* neon_vhsubuv4hi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1634:  /* neon_vhsubsv16qi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1632:  /* neon_vhsubsv8qi */
    case 1631:  /* neon_vqsubuv2di */
    case 1630:  /* neon_vqsubsv2di */
    case 1629:  /* neon_vqsubudi */
    case 1628:  /* neon_vqsubsdi */
    case 1627:  /* neon_vqsubuv4si */
    case 1626:  /* neon_vqsubsv4si */
    case 1625:  /* neon_vqsubuv2si */
    case 1624:  /* neon_vqsubsv2si */
    case 1623:  /* neon_vqsubuv8hi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1621:  /* neon_vqsubuv4hi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1618:  /* neon_vqsubsv16qi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1616:  /* neon_vqsubsv8qi */
    case 1512:  /* neon_vraddhnv2di */
    case 1511:  /* neon_vaddhnv2di */
    case 1510:  /* neon_vraddhnv4si */
    case 1509:  /* neon_vaddhnv4si */
    case 1508:  /* neon_vraddhnv8hi */
    case 1507:  /* neon_vaddhnv8hi */
    case 1506:  /* neon_vqadduv2di */
    case 1505:  /* neon_vqaddsv2di */
    case 1504:  /* neon_vqaddudi */
    case 1503:  /* neon_vqaddsdi */
    case 1502:  /* neon_vqadduv4si */
    case 1501:  /* neon_vqaddsv4si */
    case 1500:  /* neon_vqadduv2si */
    case 1499:  /* neon_vqaddsv2si */
    case 1498:  /* neon_vqadduv8hi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1496:  /* neon_vqadduv4hi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1494:  /* neon_vqadduv16qi */
    case 1493:  /* neon_vqaddsv16qi */
    case 1492:  /* neon_vqadduv8qi */
    case 1491:  /* neon_vqaddsv8qi */
    case 1490:  /* neon_vhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1486:  /* neon_vhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1483:  /* neon_vrhaddsv2si */
    case 1482:  /* neon_vhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1474:  /* neon_vhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1467:  /* neon_vrhaddsv8qi */
    case 1466:  /* neon_vaddwuv2si */
    case 1465:  /* neon_vaddwsv2si */
    case 1464:  /* neon_vaddwuv4hi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1461:  /* neon_vaddwsv8qi */
    case 1452:  /* *us_subv2sf_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1445:  /* *ss_subv8qi_neon */
    case 1444:  /* *us_addv2sf_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1437:  /* *ss_addv8qi_neon */
    case 1436:  /* neon_vpumaxv2si */
    case 1435:  /* neon_vpumaxv4hi */
    case 1434:  /* neon_vpumaxv8qi */
    case 1433:  /* neon_vpuminv2si */
    case 1432:  /* neon_vpuminv4hi */
    case 1431:  /* neon_vpuminv8qi */
    case 1422:  /* neon_vpaddv4hf */
    case 1416:  /* quad_halves_umaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1412:  /* quad_halves_plusv16qi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1408:  /* quad_halves_sminv8hi */
    case 1407:  /* quad_halves_plusv8hi */
    case 1403:  /* quad_halves_umaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1400:  /* quad_halves_sminv4si */
    case 1399:  /* quad_halves_plusv4si */
    case 1398:  /* widen_usumv2si3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
      return EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX;

    case 1769:  /* neon_vtst_combinev4si */
    case 1768:  /* neon_vtst_combinev2si */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1765:  /* neon_vtst_combinev16qi */
    case 1764:  /* neon_vtst_combinev8qi */
    case 1615:  /* neon_vsubwuv2si */
    case 1614:  /* neon_vsubwsv2si */
    case 1613:  /* neon_vsubwuv4hi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1610:  /* neon_vsubwsv8qi */
    case 1609:  /* neon_vsubluv2si */
    case 1608:  /* neon_vsublsv2si */
    case 1607:  /* neon_vsubluv4hi */
    case 1606:  /* neon_vsublsv4hi */
    case 1605:  /* neon_vsubluv8qi */
    case 1604:  /* neon_vsublsv8qi */
    case 1460:  /* neon_vaddluv2si */
    case 1459:  /* neon_vaddlsv2si */
    case 1458:  /* neon_vaddluv4hi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1456:  /* neon_vaddluv8qi */
    case 1455:  /* neon_vaddlsv8qi */
    case 1417:  /* arm_reduc_plus_internal_v2di */
    case 1280:  /* xorv2di3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1278:  /* xorv2sf3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1247:  /* andv2di3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1242:  /* andv4si3_neon */
    case 1241:  /* andv2si3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1227:  /* iorv16qi3_neon */
    case 1226:  /* iorv8qi3_neon */
      return EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC;

    case 1833:  /* neon_vminuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1830:  /* neon_vmaxsv4si */
    case 1829:  /* neon_vminuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1826:  /* neon_vmaxsv2si */
    case 1825:  /* neon_vminuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1821:  /* neon_vminuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1817:  /* neon_vminuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1814:  /* neon_vmaxsv16qi */
    case 1813:  /* neon_vminuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1810:  /* neon_vmaxsv8qi */
    case 1791:  /* neon_vabdluv2si */
    case 1790:  /* neon_vabdlsv2si */
    case 1789:  /* neon_vabdluv4hi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1787:  /* neon_vabdluv8qi */
    case 1786:  /* neon_vabdlsv8qi */
    case 1783:  /* neon_vabdv4hf */
    case 1782:  /* neon_vabdv8hf */
    case 1781:  /* neon_vabduv4si */
    case 1780:  /* neon_vabdsv4si */
    case 1779:  /* neon_vabduv2si */
    case 1778:  /* neon_vabdsv2si */
    case 1777:  /* neon_vabduv8hi */
    case 1776:  /* neon_vabdsv8hi */
    case 1775:  /* neon_vabduv4hi */
    case 1774:  /* neon_vabdsv4hi */
    case 1773:  /* neon_vabduv16qi */
    case 1772:  /* neon_vabdsv16qi */
    case 1771:  /* neon_vabduv8qi */
    case 1770:  /* neon_vabdsv8qi */
    case 1337:  /* *umaxv4si3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1327:  /* *uminv16qi3_neon */
    case 1326:  /* *uminv8qi3_neon */
    case 1311:  /* neon_negv4hf2 */
    case 1310:  /* neon_absv4hf2 */
    case 1309:  /* neon_negv8hf2 */
    case 1308:  /* neon_absv8hf2 */
      return EXYNOS_M1_NEON_TYPE_NEON_ARITH_SIMPLE;

    default:
      return EXYNOS_M1_NEON_TYPE_UNKNOWN;

    }
}

enum attr_enabled
get_attr_enabled (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 6927:  /* *p *thumb2_movhi_insn */
    case 6926:  /* *p *thumb2_movsi_insn */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x5ULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6924:  /* *p *thumb2_neg_abssi2 */
    case 6923:  /* *p *thumb2_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    case 6903:  /* *p *sqrtdf2_vfp */
    case 6902:  /* *p *sqrtsf2_vfp */
    case 6865:  /* *p *divdf3_vfp */
    case 6864:  /* *p *divsf3_vfp */
      extract_constrain_insn_cached (insn);
      if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)) || ((which_alternative == 1) && (! (
#line 193 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6 || TARGET_VFP3)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6855:  /* *p *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 3)
        {
	  if (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xbULL))
        {
	  if ((which_alternative != 3) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (((!((1ULL << which_alternative) & 0x5ULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((!((1ULL << which_alternative) & 0x3fffULL)) && (! (
#line 201 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_HAVE_MVE)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xc0ULL))
        {
	  if (((!((1ULL << which_alternative) & 0x5ULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    case 6842:  /* *p *arm_movhi_fp16 */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x60ULL))
        {
	  if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)) || ((which_alternative == 2) && (! (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2)))))
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (((!((1ULL << which_alternative) & 0x5ULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6745:  /* *p ashldi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6736:  /* *p rordi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6734:  /* *p rorv4hi3_di */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6724:  /* *p rordi3 */
    case 6723:  /* *p rorv2si3 */
    case 6722:  /* *p rorv4hi3 */
      extract_constrain_insn_cached (insn);
      if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)) || ((which_alternative == 1) && (! (
#line 189 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_REALLY_IWMMXT2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6558:  /* *p *arm_rev */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    case 6530:  /* *p *arm_cmpsi_insn */
      extract_constrain_insn_cached (insn);
      if (((!((1ULL << which_alternative) & 0x7ULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((((1ULL << which_alternative) & 0x3ULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6526:  /* *p *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (((!((1ULL << which_alternative) & 0xbULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((((1ULL << which_alternative) & 0x69ULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6836:  /* *p *arm_movhi_vfp */
    case 6524:  /* *p *movhi_insn_arch4 */
      extract_constrain_insn_cached (insn);
      if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)) || ((which_alternative == 2) && (! (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6521:  /* *p *arm_movsi_insn */
      extract_constrain_insn_cached (insn);
      if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)) || ((which_alternative == 3) && (! (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6440:  /* *p *arm_neg_abssi2 */
    case 6439:  /* *p *arm_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  if (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    case 6433:  /* *p unaligned_storehi */
    case 6432:  /* *p unaligned_storesi */
    case 6431:  /* *p unaligned_loadhiu */
    case 6429:  /* *p unaligned_loadsi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 0)
        {
	  if (((which_alternative != 1) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    case 6410:  /* *p *arm_xorsi3 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative != 1) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6409:  /* *p *iorsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((which_alternative != 1) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6397:  /* *p *arm_andsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((which_alternative != 1) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((which_alternative == 4) && (! (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6371:  /* *p *mul */
      extract_constrain_insn_cached (insn);
      if (((which_alternative != 0) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6370:  /* *p *arm_subsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((!((1ULL << which_alternative) & 0xfULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((((1ULL << which_alternative) & 0xfULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6364:  /* *p *add_not_cin */
      extract_constrain_insn_cached (insn);
      if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)) || ((which_alternative == 1) && (! (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6970:  /* *p arm_store_release_exclusivesi */
    case 6969:  /* *p arm_store_release_exclusivehi */
    case 6968:  /* *p arm_store_release_exclusiveqi */
    case 6960:  /* *p arm_load_acquire_exclusivesi */
    case 6959:  /* *p arm_load_exclusivesi */
    case 6958:  /* *p arm_load_acquire_exclusivehi */
    case 6957:  /* *p arm_load_acquire_exclusiveqi */
    case 6956:  /* *p arm_load_exclusivehi */
    case 6955:  /* *p arm_load_exclusiveqi */
    case 6953:  /* *p atomic_storesi */
    case 6952:  /* *p atomic_storehi */
    case 6951:  /* *p atomic_storeqi */
    case 6950:  /* *p atomic_loadsi */
    case 6949:  /* *p atomic_loadhi */
    case 6948:  /* *p atomic_loadqi */
    case 6850:  /* *p *movdi_vfp */
    case 6557:  /* *p *arm_movtas_ze */
    case 6548:  /* *p *sub_shiftsi */
    case 6547:  /* *p *and_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6543:  /* *p *add_shiftsi */
    case 6542:  /* *p *and_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6538:  /* *p *add_multsi */
    case 6531:  /* *p *arm_cmpsi_negshiftsi_si */
    case 6520:  /* *p *arm_movt */
    case 6437:  /* *p udivsi3 */
    case 6436:  /* *p divsi3 */
    case 6428:  /* *p *not_shiftsi */
    case 6408:  /* *p andsi_not_shiftsi_si_scc */
    case 6407:  /* *p andsi_not_shiftsi_si_scc_no_reuse */
    case 6406:  /* *p andsi_not_shiftsi_si */
    case 6379:  /* *p *umull_high */
    case 6378:  /* *p *smull_high */
    case 6377:  /* *p umlal */
    case 6376:  /* *p smlal */
    case 6375:  /* *p umull */
    case 6374:  /* *p smull */
    case 6372:  /* *p *mla */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6362:  /* *p subsi3_carryin */
    case 6361:  /* *p *addsi3_carryin_shift */
      extract_constrain_insn_cached (insn);
      if ((
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6360:  /* *p *addsi3_carryin_alt2 */
    case 6358:  /* *p addsi3_carryin */
      extract_constrain_insn_cached (insn);
      if (((which_alternative != 0) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((which_alternative == 0) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6427:  /* *p *arm_shiftsi3 */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6356:  /* *p *compare_addsi2_op0 */
      extract_constrain_insn_cached (insn);
      if (((!((1ULL << which_alternative) & 0x3ULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((((1ULL << which_alternative) & 0x3ULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6441:  /* *p *arm_one_cmplsi2 */
    case 6438:  /* *p *arm_negsi2 */
    case 6355:  /* *p *compare_negsi_si */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 1) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((which_alternative == 0) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 7040:  /* *p mve_sqshll_di */
    case 7039:  /* *p mve_srshrl_di */
    case 7038:  /* *p mve_srshr_si */
    case 7037:  /* *p mve_sqshl_si */
    case 7036:  /* *p mve_urshr_si */
    case 7035:  /* *p mve_uqshl_si */
    case 7034:  /* *p mve_urshrl_di */
    case 7033:  /* *p mve_uqshll_di */
    case 7032:  /* *p mve_sqrshr_si */
    case 7031:  /* *p mve_uqrshl_si */
    case 7030:  /* *p mve_sqrshrl_sat48_di */
    case 7029:  /* *p mve_sqrshrl_sat64_di */
    case 7028:  /* *p mve_uqrshll_sat48_di */
    case 7027:  /* *p mve_uqrshll_sat64_di */
    case 7026:  /* *p arm_usatsihi */
    case 7025:  /* *p arm_ssatsihi_shift */
    case 7024:  /* *p *arm_sssubsa3 */
    case 7023:  /* *p *arm_sssubsq3 */
    case 7022:  /* *p *arm_sssubha3 */
    case 7021:  /* *p *arm_sssubv2ha3 */
    case 7020:  /* *p *arm_sssubhq3 */
    case 7019:  /* *p *arm_sssubqq3 */
    case 7018:  /* *p *arm_sssubv2hq3 */
    case 7017:  /* *p *arm_sssubv4qq3 */
    case 7016:  /* *p ussubuha3 */
    case 7015:  /* *p ussubv2uha3 */
    case 7014:  /* *p ussubuhq3 */
    case 7013:  /* *p ussubuqq3 */
    case 7012:  /* *p ussubv2uhq3 */
    case 7011:  /* *p ussubv4uqq3 */
    case 7010:  /* *p *arm_subv2ha3 */
    case 7009:  /* *p *arm_subv2hq3 */
    case 7008:  /* *p *arm_subv4qq3 */
    case 6997:  /* *p *arm_ssaddsa3 */
    case 6996:  /* *p *arm_ssaddsq3 */
    case 6995:  /* *p *arm_ssaddha3 */
    case 6994:  /* *p *arm_ssaddv2ha3 */
    case 6993:  /* *p *arm_ssaddhq3 */
    case 6992:  /* *p *arm_ssaddqq3 */
    case 6991:  /* *p *arm_ssaddv2hq3 */
    case 6990:  /* *p *arm_ssaddv4qq3 */
    case 6989:  /* *p usadduha3 */
    case 6988:  /* *p usaddv2uha3 */
    case 6987:  /* *p usadduhq3 */
    case 6986:  /* *p usadduqq3 */
    case 6985:  /* *p usaddv2uhq3 */
    case 6984:  /* *p usaddv4uqq3 */
    case 6983:  /* *p *arm_addv2ha3 */
    case 6982:  /* *p *arm_addv2hq3 */
    case 6981:  /* *p *arm_addv4qq3 */
    case 6967:  /* *p arm_store_release_exclusivedi */
    case 6966:  /* *p arm_store_exclusivedi */
    case 6965:  /* *p arm_store_exclusivesi */
    case 6964:  /* *p arm_store_exclusivehi */
    case 6963:  /* *p arm_store_exclusiveqi */
    case 6962:  /* *p arm_load_acquire_exclusivedi */
    case 6961:  /* *p arm_load_exclusivedi */
    case 6954:  /* *p arm_atomic_loaddi2_ldrd */
    case 6947:  /* *p thumb2_lsrl */
    case 6946:  /* *p thumb2_lsll */
    case 6945:  /* *p thumb2_asrl */
    case 6944:  /* *p *clear_multiple */
    case 6943:  /* *p *clear_apsr */
    case 6942:  /* *p *orsi_not_shiftsi_si */
    case 6941:  /* *p *orsi_notsi_si */
    case 6940:  /* *p *thumb2_negsi2_short */
    case 6939:  /* *p *thumb2_one_cmplsi2_short */
    case 6938:  /* *p *thumb2_mulsi_short */
    case 6937:  /* *p *thumb2_subsi_short */
    case 6936:  /* *p *thumb2_addsi_short */
    case 6935:  /* *p *thumb2_movsi_shortim */
    case 6934:  /* *p *thumb2_movhi_shortim */
    case 6933:  /* *p *thumb2_movqi_shortim */
    case 6932:  /* *p *thumb2_shiftsi3_short */
    case 6931:  /* *p *thumb2_alusi3_short */
    case 6930:  /* *p thumb2_zero_extendqisi2_v6 */
    case 6929:  /* *p *thumb2_zero_extendhisi2_v6 */
    case 6928:  /* *p *thumb2_extendqisi_v6 */
    case 6925:  /* *p *thumb2_pop_single */
    case 6922:  /* *p rintdf2 */
    case 6921:  /* *p nearbyintdf2 */
    case 6920:  /* *p btruncdf2 */
    case 6919:  /* *p rintsf2 */
    case 6918:  /* *p nearbyintsf2 */
    case 6917:  /* *p btruncsf2 */
    case 6916:  /* *p *combine_vcvtf2i */
    case 6915:  /* *p *combine_vcvt_f64_s32 */
    case 6914:  /* *p *combine_vcvt_f64_u32 */
    case 6913:  /* *p *combine_vcvt_f32_s32 */
    case 6912:  /* *p *combine_vcvt_f32_u32 */
    case 6911:  /* *p *cmpdf_trap_vfp */
    case 6910:  /* *p *cmpdf_vfp */
    case 6909:  /* *p *cmpsf_trap_vfp */
    case 6908:  /* *p *cmpsf_vfp */
    case 6907:  /* *p lazy_store_multiple_insn */
    case 6906:  /* *p *clear_vfp_multiple */
    case 6905:  /* *p pop_fpsysreg_insn */
    case 6904:  /* *p push_fpsysreg_insn */
    case 6901:  /* *p floatunssidf2 */
    case 6900:  /* *p floatunssisf2 */
    case 6899:  /* *p *floatsidf2_vfp */
    case 6898:  /* *p *floatsisf2_vfp */
    case 6897:  /* *p fixuns_truncdfsi2 */
    case 6896:  /* *p fixuns_truncsfsi2 */
    case 6895:  /* *p *truncsidf2_vfp */
    case 6894:  /* *p *truncsisf2_vfp */
    case 6893:  /* *p truncsfhf2 */
    case 6892:  /* *p *extendhfdf2 */
    case 6891:  /* *p *truncdfhf2 */
    case 6890:  /* *p extendhfsf2 */
    case 6889:  /* *p *truncdfsf2_vfp */
    case 6888:  /* *p *extendsfdf2_vfp */
    case 6887:  /* *p *fnmadddf4 */
    case 6886:  /* *p *fnmaddsf4 */
    case 6885:  /* *p *fnmsubdf4 */
    case 6884:  /* *p *fnmsubsf4 */
    case 6883:  /* *p *fmsubdf4 */
    case 6882:  /* *p *fmsubsf4 */
    case 6881:  /* *p fmadf4 */
    case 6880:  /* *p fmasf4 */
    case 6879:  /* *p *muldf3negdfsubdf_vfp */
    case 6878:  /* *p *mulsf3negsfsubsf_vfp */
    case 6877:  /* *p *fmuldf3negdfadddf_vfp */
    case 6876:  /* *p *mulsf3negsfaddsf_vfp */
    case 6875:  /* *p *muldf3subdf_vfp */
    case 6874:  /* *p *mulsf3subsf_vfp */
    case 6873:  /* *p *muldf3adddf_vfp */
    case 6872:  /* *p *mulsf3addsf_vfp */
    case 6871:  /* *p *negmuldf3_vfp */
    case 6870:  /* *p *muldf3negdf_vfp */
    case 6869:  /* *p *negmulsf3_vfp */
    case 6868:  /* *p *mulsf3negsf_vfp */
    case 6867:  /* *p *muldf3_vfp */
    case 6866:  /* *p *mulsf3_vfp */
    case 6863:  /* *p *subdf3_vfp */
    case 6862:  /* *p *subsf3_vfp */
    case 6861:  /* *p *adddf3_vfp */
    case 6860:  /* *p *addsf3_vfp */
    case 6859:  /* *p *negdf2_vfp */
    case 6858:  /* *p *negsf2_vfp */
    case 6857:  /* *p *absdf2_vfp */
    case 6856:  /* *p *abssf2_vfp */
    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 6848:  /* *p *arm_movsi_vfp */
    case 6835:  /* *p iwmmxt_textrcv8qi3 */
    case 6834:  /* *p iwmmxt_textrcv4hi3 */
    case 6833:  /* *p iwmmxt_textrcv2si3 */
    case 6832:  /* *p iwmmxt_torvscv8qi3 */
    case 6831:  /* *p iwmmxt_torvscv4hi3 */
    case 6830:  /* *p iwmmxt_torvscv2si3 */
    case 6829:  /* *p iwmmxt_torcv8qi3 */
    case 6828:  /* *p iwmmxt_torcv4hi3 */
    case 6827:  /* *p iwmmxt_torcv2si3 */
    case 6826:  /* *p iwmmxt_tandcv8qi3 */
    case 6825:  /* *p iwmmxt_tandcv4hi3 */
    case 6824:  /* *p iwmmxt_tandcv2si3 */
    case 6823:  /* *p iwmmxt_wmerge */
    case 6822:  /* *p iwmmxt_wmiawttn */
    case 6821:  /* *p iwmmxt_wmiawtbn */
    case 6820:  /* *p iwmmxt_wmiawbtn */
    case 6819:  /* *p iwmmxt_wmiawbbn */
    case 6818:  /* *p iwmmxt_wmiawtt */
    case 6817:  /* *p iwmmxt_wmiawtb */
    case 6816:  /* *p iwmmxt_wmiawbt */
    case 6815:  /* *p iwmmxt_wmiawbb */
    case 6814:  /* *p iwmmxt_wmiattn */
    case 6813:  /* *p iwmmxt_wmiatbn */
    case 6812:  /* *p iwmmxt_wmiabtn */
    case 6811:  /* *p iwmmxt_wmiabbn */
    case 6810:  /* *p iwmmxt_wmiatt */
    case 6809:  /* *p iwmmxt_wmiatb */
    case 6808:  /* *p iwmmxt_wmiabt */
    case 6807:  /* *p iwmmxt_wmiabb */
    case 6806:  /* *p iwmmxt_wqmiattn */
    case 6805:  /* *p iwmmxt_wqmiatbn */
    case 6804:  /* *p iwmmxt_wqmiabtn */
    case 6803:  /* *p iwmmxt_wqmiabbn */
    case 6802:  /* *p iwmmxt_wqmiatt */
    case 6801:  /* *p iwmmxt_wqmiatb */
    case 6800:  /* *p iwmmxt_wqmiabt */
    case 6799:  /* *p iwmmxt_wqmiabb */
    case 6798:  /* *p iwmmxt_waddbhusl */
    case 6797:  /* *p iwmmxt_waddbhusm */
    case 6796:  /* *p iwmmxt_wqmulwmr */
    case 6795:  /* *p iwmmxt_wqmulmr */
    case 6794:  /* *p iwmmxt_wqmulwm */
    case 6793:  /* *p iwmmxt_wqmulm */
    case 6792:  /* *p iwmmxt_wmulwl */
    case 6791:  /* *p iwmmxt_wmulwumr */
    case 6790:  /* *p iwmmxt_wmulwsmr */
    case 6789:  /* *p iwmmxt_wmulumr */
    case 6788:  /* *p iwmmxt_wmulsmr */
    case 6787:  /* *p iwmmxt_wmulwum */
    case 6786:  /* *p iwmmxt_wmulwsm */
    case 6785:  /* *p iwmmxt_wmaddun */
    case 6784:  /* *p iwmmxt_wmaddsn */
    case 6783:  /* *p iwmmxt_wmaddux */
    case 6782:  /* *p iwmmxt_wmaddsx */
    case 6781:  /* *p iwmmxt_avg4r */
    case 6780:  /* *p iwmmxt_avg4 */
    case 6779:  /* *p addcv2si3 */
    case 6778:  /* *p addcv4hi3 */
    case 6777:  /* *p iwmmxt_wsubaddhx */
    case 6776:  /* *p iwmmxt_waddsubhx */
    case 6775:  /* *p iwmmxt_wabsdiffw */
    case 6774:  /* *p iwmmxt_wabsdiffh */
    case 6773:  /* *p iwmmxt_wabsdiffb */
    case 6772:  /* *p iwmmxt_wabsv8qi3 */
    case 6771:  /* *p iwmmxt_wabsv4hi3 */
    case 6770:  /* *p iwmmxt_wabsv2si3 */
    case 6769:  /* *p iwmmxt_wsadhz */
    case 6768:  /* *p iwmmxt_wsadbz */
    case 6767:  /* *p iwmmxt_wsadh */
    case 6766:  /* *p iwmmxt_wsadb */
    case 6765:  /* *p iwmmxt_walignr3 */
    case 6764:  /* *p iwmmxt_walignr2 */
    case 6763:  /* *p iwmmxt_walignr1 */
    case 6762:  /* *p iwmmxt_walignr0 */
    case 6761:  /* *p iwmmxt_walignr */
    case 6760:  /* *p iwmmxt_waligni */
    case 6759:  /* *p iwmmxt_waccw */
    case 6758:  /* *p iwmmxt_wacch */
    case 6757:  /* *p iwmmxt_waccb */
    case 6756:  /* *p iwmmxt_tmovmskw */
    case 6755:  /* *p iwmmxt_tmovmskh */
    case 6754:  /* *p iwmmxt_tmovmskb */
    case 6753:  /* *p iwmmxt_tmiatt */
    case 6752:  /* *p iwmmxt_tmiabt */
    case 6751:  /* *p iwmmxt_tmiatb */
    case 6750:  /* *p iwmmxt_tmiabb */
    case 6749:  /* *p iwmmxt_tmiaph */
    case 6748:  /* *p iwmmxt_tmia */
    case 6747:  /* *p iwmmxt_wmaddu */
    case 6746:  /* *p iwmmxt_wmadds */
    case 6721:  /* *p iwmmxt_wunpckelsw */
    case 6720:  /* *p iwmmxt_wunpckelsh */
    case 6719:  /* *p iwmmxt_wunpckelsb */
    case 6718:  /* *p iwmmxt_wunpckeluw */
    case 6717:  /* *p iwmmxt_wunpckeluh */
    case 6716:  /* *p iwmmxt_wunpckelub */
    case 6715:  /* *p iwmmxt_wunpckehsw */
    case 6714:  /* *p iwmmxt_wunpckehsh */
    case 6713:  /* *p iwmmxt_wunpckehsb */
    case 6712:  /* *p iwmmxt_wunpckehuw */
    case 6711:  /* *p iwmmxt_wunpckehuh */
    case 6710:  /* *p iwmmxt_wunpckehub */
    case 6709:  /* *p iwmmxt_wunpckilw */
    case 6708:  /* *p iwmmxt_wunpckilh */
    case 6707:  /* *p iwmmxt_wunpckilb */
    case 6706:  /* *p iwmmxt_wunpckihw */
    case 6705:  /* *p iwmmxt_wunpckihh */
    case 6704:  /* *p iwmmxt_wunpckihb */
    case 6703:  /* *p iwmmxt_wpackdus */
    case 6702:  /* *p iwmmxt_wpackwus */
    case 6701:  /* *p iwmmxt_wpackhus */
    case 6700:  /* *p iwmmxt_wpackdss */
    case 6699:  /* *p iwmmxt_wpackwss */
    case 6698:  /* *p iwmmxt_wpackhss */
    case 6697:  /* *p *uminv8qi3_iwmmxt */
    case 6696:  /* *p *uminv4hi3_iwmmxt */
    case 6695:  /* *p *uminv2si3_iwmmxt */
    case 6694:  /* *p *sminv8qi3_iwmmxt */
    case 6693:  /* *p *sminv4hi3_iwmmxt */
    case 6692:  /* *p *sminv2si3_iwmmxt */
    case 6691:  /* *p *umaxv8qi3_iwmmxt */
    case 6690:  /* *p *umaxv4hi3_iwmmxt */
    case 6689:  /* *p *umaxv2si3_iwmmxt */
    case 6688:  /* *p *smaxv8qi3_iwmmxt */
    case 6687:  /* *p *smaxv4hi3_iwmmxt */
    case 6686:  /* *p *smaxv2si3_iwmmxt */
    case 6685:  /* *p gtv2si3 */
    case 6684:  /* *p gtv4hi3 */
    case 6683:  /* *p gtv8qi3 */
    case 6682:  /* *p gtuv2si3 */
    case 6681:  /* *p gtuv4hi3 */
    case 6680:  /* *p gtuv8qi3 */
    case 6679:  /* *p eqv2si3 */
    case 6678:  /* *p eqv4hi3 */
    case 6677:  /* *p eqv8qi3 */
    case 6676:  /* *p iwmmxt_wshufh */
    case 6675:  /* *p iwmmxt_textrmw */
    case 6674:  /* *p iwmmxt_textrmsh */
    case 6673:  /* *p iwmmxt_textrmuh */
    case 6672:  /* *p iwmmxt_textrmsb */
    case 6671:  /* *p iwmmxt_textrmub */
    case 6670:  /* *p iwmmxt_tinsrw */
    case 6669:  /* *p iwmmxt_tinsrh */
    case 6668:  /* *p iwmmxt_tinsrb */
    case 6667:  /* *p iwmmxt_uavgv4hi3 */
    case 6666:  /* *p iwmmxt_uavgv8qi3 */
    case 6665:  /* *p iwmmxt_uavgrndv4hi3 */
    case 6664:  /* *p iwmmxt_uavgrndv8qi3 */
    case 6663:  /* *p iwmmxt_clrv2si */
    case 6662:  /* *p iwmmxt_clrv4hi */
    case 6661:  /* *p iwmmxt_clrv8qi */
    case 6660:  /* *p iwmmxt_clrdi */
    case 6659:  /* *p iwmmxt_wmacuz */
    case 6658:  /* *p iwmmxt_wmacu */
    case 6657:  /* *p iwmmxt_wmacsz */
    case 6656:  /* *p iwmmxt_wmacs */
    case 6655:  /* *p umulv4hi3_highpart */
    case 6654:  /* *p smulv4hi3_highpart */
    case 6653:  /* *p *mulv4hi3_iwmmxt */
    case 6652:  /* *p ussubv2si3 */
    case 6651:  /* *p ussubv4hi3 */
    case 6650:  /* *p ussubv8qi3 */
    case 6649:  /* *p sssubv2si3 */
    case 6648:  /* *p sssubv4hi3 */
    case 6647:  /* *p sssubv8qi3 */
    case 6646:  /* *p *subv8qi3_iwmmxt */
    case 6645:  /* *p *subv4hi3_iwmmxt */
    case 6644:  /* *p *subv2si3_iwmmxt */
    case 6643:  /* *p usaddv2si3 */
    case 6642:  /* *p usaddv4hi3 */
    case 6641:  /* *p usaddv8qi3 */
    case 6640:  /* *p ssaddv2si3 */
    case 6639:  /* *p ssaddv4hi3 */
    case 6638:  /* *p ssaddv8qi3 */
    case 6637:  /* *p *addv8qi3_iwmmxt */
    case 6636:  /* *p *addv4hi3_iwmmxt */
    case 6635:  /* *p *addv2si3_iwmmxt */
    case 6634:  /* *p *xorv8qi3_iwmmxt */
    case 6633:  /* *p *xorv4hi3_iwmmxt */
    case 6632:  /* *p *xorv2si3_iwmmxt */
    case 6631:  /* *p *iorv8qi3_iwmmxt */
    case 6630:  /* *p *iorv4hi3_iwmmxt */
    case 6629:  /* *p *iorv2si3_iwmmxt */
    case 6628:  /* *p *andv8qi3_iwmmxt */
    case 6627:  /* *p *andv4hi3_iwmmxt */
    case 6626:  /* *p *andv2si3_iwmmxt */
    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 6622:  /* *p iwmmxt_nanddi3 */
    case 6621:  /* *p iwmmxt_anddi3 */
    case 6620:  /* *p iwmmxt_xordi3 */
    case 6619:  /* *p iwmmxt_iordi3 */
    case 6618:  /* *p tbcstv2si */
    case 6617:  /* *p tbcstv4hi */
    case 6616:  /* *p tbcstv8qi */
    case 6615:  /* *p *load_multiple */
    case 6614:  /* *p *stm2_db_update */
    case 6613:  /* *p *stm2_db */
    case 6612:  /* *p *ldm2_db_update */
    case 6611:  /* *p *ldm2_db */
    case 6610:  /* *p *stm2_da_update */
    case 6609:  /* *p *stm2_da */
    case 6608:  /* *p *ldm2_da_update */
    case 6607:  /* *p *ldm2_da */
    case 6606:  /* *p *stm2_ib_update */
    case 6605:  /* *p *stm2_ib */
    case 6604:  /* *p *ldm2_ib_update */
    case 6603:  /* *p *ldm2_ib */
    case 6602:  /* *p *stm2_ia_update */
    case 6601:  /* *p *stm2_ */
    case 6600:  /* *p *ldm2_ia_update */
    case 6599:  /* *p *ldm2_ */
    case 6598:  /* *p *stm3_db_update */
    case 6597:  /* *p *stm3_db */
    case 6596:  /* *p *ldm3_db_update */
    case 6595:  /* *p *ldm3_db */
    case 6594:  /* *p *stm3_da_update */
    case 6593:  /* *p *stm3_da */
    case 6592:  /* *p *ldm3_da_update */
    case 6591:  /* *p *ldm3_da */
    case 6590:  /* *p *stm3_ib_update */
    case 6589:  /* *p *stm3_ib */
    case 6588:  /* *p *ldm3_ib_update */
    case 6587:  /* *p *ldm3_ib */
    case 6586:  /* *p *stm3_ia_update */
    case 6585:  /* *p *stm3_ */
    case 6584:  /* *p *ldm3_ia_update */
    case 6583:  /* *p *ldm3_ */
    case 6582:  /* *p *stm4_db_update */
    case 6581:  /* *p *stm4_db */
    case 6580:  /* *p *ldm4_db_update */
    case 6579:  /* *p *ldm4_db */
    case 6578:  /* *p *stm4_da_update */
    case 6577:  /* *p *stm4_da */
    case 6576:  /* *p *ldm4_da_update */
    case 6575:  /* *p *ldm4_da */
    case 6574:  /* *p *stm4_ib_update */
    case 6573:  /* *p *stm4_ib */
    case 6572:  /* *p *ldm4_ib_update */
    case 6571:  /* *p *ldm4_ib */
    case 6570:  /* *p *stm4_ia_update */
    case 6569:  /* *p *stm4_ */
    case 6568:  /* *p *ldm4_ia_update */
    case 6567:  /* *p *ldm4_ */
    case 6566:  /* *p *arm_strd */
    case 6565:  /* *p *arm_ldrd */
    case 6564:  /* *p *thumb2_strd_base_neg */
    case 6563:  /* *p *thumb2_strd_base */
    case 6562:  /* *p *thumb2_strd */
    case 6561:  /* *p *thumb2_ldrd_base_neg */
    case 6560:  /* *p *thumb2_ldrd_base */
    case 6559:  /* *p *thumb2_ldrd */
    case 6556:  /* *p load_tp_hard */
    case 6555:  /* *p rbitsi2 */
    case 6554:  /* *p clzsi2 */
    case 6553:  /* *p *ldr_with_return */
    case 6552:  /* *p *pop_multiple_with_return */
    case 6551:  /* *p *pop_multiple_with_writeback_and_return */
    case 6550:  /* *p *load_multiple_with_writeback */
    case 6549:  /* *p *arith_adjacentmem */
    case 6537:  /* *p *load_indirect_jump */
    case 6536:  /* *p *arm_indirect_jump */
    case 6535:  /* *p probe_stack */
    case 6534:  /* *p *arm_simple_return */
    case 6533:  /* *p *arm_return */
    case 6532:  /* *p *arm_jump */
    case 6529:  /* *p *arm_movsf_soft_insn */
    case 6528:  /* *p *arm32_movbf */
    case 6527:  /* *p *arm32_movhf */
    case 6525:  /* *p *movhi_bytes */
    case 6523:  /* *p tls_load_dot_plus_eight */
    case 6522:  /* *p pic_add_dot_plus_eight */
    case 6519:  /* *p arm_sel */
    case 6518:  /* *p arm_usat16_setq_insn */
    case 6517:  /* *p arm_usat16_insn */
    case 6516:  /* *p arm_ssat16_setq_insn */
    case 6515:  /* *p arm_ssat16_insn */
    case 6514:  /* *p arm_smuadx_setq_insn */
    case 6513:  /* *p arm_smuadx_insn */
    case 6512:  /* *p arm_smuad_setq_insn */
    case 6511:  /* *p arm_smuad_insn */
    case 6510:  /* *p arm_smlsdx_setq_insn */
    case 6509:  /* *p arm_smlsdx_insn */
    case 6508:  /* *p arm_smlsd_setq_insn */
    case 6507:  /* *p arm_smlsd_insn */
    case 6506:  /* *p arm_smladx_setq_insn */
    case 6505:  /* *p arm_smladx_insn */
    case 6504:  /* *p arm_smlad_setq_insn */
    case 6503:  /* *p arm_smlad_insn */
    case 6502:  /* *p arm_usub16 */
    case 6501:  /* *p arm_usax */
    case 6500:  /* *p arm_uasx */
    case 6499:  /* *p arm_uadd16 */
    case 6498:  /* *p arm_ssub16 */
    case 6497:  /* *p arm_ssax */
    case 6496:  /* *p arm_sasx */
    case 6495:  /* *p arm_sadd16 */
    case 6494:  /* *p arm_usub8 */
    case 6493:  /* *p arm_uadd8 */
    case 6492:  /* *p arm_ssub8 */
    case 6491:  /* *p arm_sadd8 */
    case 6490:  /* *p arm_smlsldx */
    case 6489:  /* *p arm_smlsld */
    case 6488:  /* *p arm_smlaldx */
    case 6487:  /* *p arm_smlald */
    case 6486:  /* *p arm_usada8 */
    case 6485:  /* *p arm_usad8 */
    case 6484:  /* *p arm_uxtab16 */
    case 6483:  /* *p arm_sxtab16 */
    case 6482:  /* *p arm_smusdx */
    case 6481:  /* *p arm_smusd */
    case 6480:  /* *p arm_uqsub16 */
    case 6479:  /* *p arm_uqsax */
    case 6478:  /* *p arm_uqasx */
    case 6477:  /* *p arm_uqadd16 */
    case 6476:  /* *p arm_uhsub16 */
    case 6475:  /* *p arm_uhsax */
    case 6474:  /* *p arm_uhasx */
    case 6473:  /* *p arm_uhadd16 */
    case 6472:  /* *p arm_shsub16 */
    case 6471:  /* *p arm_shsax */
    case 6470:  /* *p arm_shasx */
    case 6469:  /* *p arm_shadd16 */
    case 6468:  /* *p arm_qsub16 */
    case 6467:  /* *p arm_qsax */
    case 6466:  /* *p arm_qasx */
    case 6465:  /* *p arm_qadd16 */
    case 6464:  /* *p arm_uqsub8 */
    case 6463:  /* *p arm_uqadd8 */
    case 6462:  /* *p arm_uhsub8 */
    case 6461:  /* *p arm_uhadd8 */
    case 6460:  /* *p arm_shsub8 */
    case 6459:  /* *p arm_shadd8 */
    case 6458:  /* *p arm_qsub8 */
    case 6457:  /* *p arm_qadd8 */
    case 6456:  /* *p arm_uxtb16 */
    case 6455:  /* *p arm_sxtb16 */
    case 6454:  /* *p *arm_extendqisi2addsi */
    case 6453:  /* *p *arm_extendqisi_v6 */
    case 6452:  /* *p *arm_extendqisi */
    case 6451:  /* *p *arm_extendqihi_insn */
    case 6450:  /* *p *arm_extendhisi2_v6 */
    case 6449:  /* *p *arm_extendhisi2 */
    case 6448:  /* *p *compareqi_eq0 */
    case 6447:  /* *p *arm_zero_extendqisi2addsi */
    case 6446:  /* *p *arm_zero_extendqisi2_v6 */
    case 6445:  /* *p *arm_zero_extendqisi2 */
    case 6444:  /* *p *arm_zero_extendhisi2addsi */
    case 6443:  /* *p *arm_zero_extendhisi2_v6 */
    case 6442:  /* *p *arm_zero_extendhisi2 */
    case 6435:  /* *p extzv_t2 */
    case 6434:  /* *p *extv_reg */
    case 6430:  /* *p unaligned_loadhis */
    case 6426:  /* *p *satsi_smax_shift */
    case 6425:  /* *p *satsi_smin_shift */
    case 6424:  /* *p satsi_smax_setq */
    case 6423:  /* *p satsi_smax */
    case 6422:  /* *p satsi_smin_setq */
    case 6421:  /* *p satsi_smin */
    case 6420:  /* *p arm_set_apsr */
    case 6419:  /* *p arm_get_apsr */
    case 6418:  /* *p arm_qsub_setq_insn */
    case 6417:  /* *p arm_qsub_insn */
    case 6416:  /* *p arm_qadd_setq_insn */
    case 6415:  /* *p arm_qadd_insn */
    case 6414:  /* *p *smin_0 */
    case 6413:  /* *p *smax_m1 */
    case 6412:  /* *p *smax_0 */
    case 6411:  /* *p *andsi_iorsi3_notsi */
    case 6405:  /* *p andsi_notsi_si */
    case 6404:  /* *p *bfi_alt3 */
    case 6403:  /* *p *bfi_alt2 */
    case 6402:  /* *p *bfi_alt1 */
    case 6401:  /* *p *bfi */
    case 6400:  /* *p insv_t2 */
    case 6399:  /* *p insv_zero */
    case 6398:  /* *p *zeroextractsi_compare0_scratch */
    case 6396:  /* *p arm_smlawt_setq_insn */
    case 6395:  /* *p arm_smlawt_insn */
    case 6394:  /* *p arm_smlawb_setq_insn */
    case 6393:  /* *p arm_smlawb_insn */
    case 6392:  /* *p *maddhidi4tt */
    case 6391:  /* *p *maddhidi4tb */
    case 6390:  /* *p maddhidi4 */
    case 6389:  /* *p arm_smlatt_setq */
    case 6388:  /* *p maddhisi4tt */
    case 6387:  /* *p arm_smlatb_setq */
    case 6386:  /* *p maddhisi4tb */
    case 6385:  /* *p arm_smlabb_setq */
    case 6384:  /* *p *arm_maddhisi4 */
    case 6383:  /* *p *mulhisi3tt */
    case 6382:  /* *p *mulhisi3bt */
    case 6381:  /* *p *mulhisi3tb */
    case 6380:  /* *p mulhisi3 */
    case 6373:  /* *p *mls */
    case 6369:  /* *p *rsbsi3_carryin_shift_alt */
    case 6368:  /* *p *rsbsi3_carryin_shift */
    case 6365:  /* *p add_not_shift_cin */
    case 6363:  /* *p rsbsi_carryin_reg */
    case 6359:  /* *p add0si3_carryin */
    case 6354:  /* *p *addsi3_compare0_scratch */
      extract_constrain_insn_cached (insn);
      if (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 6353:  /* *p *arm_addsi3 */
      extract_constrain_insn_cached (insn);
      if (((!((1ULL << which_alternative) & 0xfULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 1016:  /* *thumb2_movsicc_insn */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0x7fcULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 1005:  /* *thumb2_neg_abssi2 */
    case 1004:  /* *thumb2_abssi2 */
    case 1003:  /* *thumb2_uminsi3 */
    case 1002:  /* *thumb32_umaxsi3 */
    case 1001:  /* *thumb2_sminsi3 */
    case 1000:  /* *thumb2_smaxsi3 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 2) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 7) && (! (
#line 252 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_disable_literal_pool)))) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 853:  /* lazy_load_multiple_insn */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 0) && (! (
(fix_vlldm))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 847:  /* *sqrtdf2_vfp */
    case 846:  /* *sqrtsf2_vfp */
    case 796:  /* *divdf3_vfp */
    case 795:  /* *divsf3_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 1) && (! (
#line 193 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_arch6 || TARGET_VFP3))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 3) && (! (
#line 197 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_NEON))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if ((!((1ULL << which_alternative) & 0x3fffULL)) && (! (
#line 201 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_HAVE_MVE))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 655:  /* ashldi3_di */
    case 654:  /* ashlv2si3_di */
    case 653:  /* ashlv4hi3_di */
    case 652:  /* lshrdi3_di */
    case 651:  /* lshrv2si3_di */
    case 650:  /* lshrv4hi3_di */
    case 649:  /* ashrdi3_di */
    case 648:  /* ashrv2si3_di */
    case 647:  /* ashrv4hi3_di */
    case 646:  /* rordi3_di */
    case 645:  /* rorv2si3_di */
    case 644:  /* rorv4hi3_di */
    case 643:  /* ashldi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 634:  /* rordi3 */
    case 633:  /* rorv2si3 */
    case 632:  /* rorv4hi3 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 1) && (! (
#line 189 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_REALLY_IWMMXT2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 379:  /* *if_move_neg */
    case 377:  /* *if_neg_move */
      extract_constrain_insn_cached (insn);
      if (((which_alternative == 1) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 350:  /* movcond_addsi */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 0) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 7007:  /* *p subusa3 */
    case 7006:  /* *p subuha3 */
    case 7005:  /* *p subsa3 */
    case 7004:  /* *p subha3 */
    case 7003:  /* *p subusq3 */
    case 7002:  /* *p subuhq3 */
    case 7001:  /* *p subuqq3 */
    case 7000:  /* *p subsq3 */
    case 6999:  /* *p subhq3 */
    case 6998:  /* *p subqq3 */
    case 6980:  /* *p addusa3 */
    case 6979:  /* *p adduha3 */
    case 6978:  /* *p addsa3 */
    case 6977:  /* *p addha3 */
    case 6976:  /* *p addusq3 */
    case 6975:  /* *p adduhq3 */
    case 6974:  /* *p adduqq3 */
    case 6973:  /* *p addsq3 */
    case 6972:  /* *p addhq3 */
    case 6971:  /* *p addqq3 */
    case 1011:  /* *thumb2_mov_scc */
    case 347:  /* *and_scc_scc_cmp */
    case 346:  /* *and_scc_scc */
    case 345:  /* *ior_scc_scc_cmp */
    case 344:  /* *ior_scc_scc */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 1) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 343:  /* *cmp_ior */
    case 342:  /* *cmp_and */
      extract_constrain_insn_cached (insn);
      if (((!((1ULL << which_alternative) & 0x21ULL)) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((((1ULL << which_alternative) & 0x3fULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 341:  /* *cmp_ite1 */
    case 340:  /* *cmp_ite0 */
      extract_constrain_insn_cached (insn);
      if (((which_alternative != 0) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it))) || ((((1ULL << which_alternative) & 0x1fULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2)))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 267:  /* *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0x69ULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
    case 265:  /* *movhi_insn_arch4 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 2) && (! (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 257:  /* *arm_movsi_insn */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 3) && (! (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 112:  /* *iorsi3_compare0_scratch */
    case 111:  /* *iorsi3_compare0 */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 1) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 90:  /* *arm_andsi3_insn */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 4) && (! (
#line 177 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_32BIT && arm_arch6 && arm_arch_thumb2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 31:  /* *add_not_cin */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 1) && (! (
#line 149 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_ARM))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 45:  /* *arm_subsi3_insn */
    case 18:  /* *addsi3_compare_op2 */
    case 17:  /* addsi3_compare_op1 */
    case 11:  /* addsi3_compareV_imm */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0xfULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 272:  /* *arm_cmpsi_insn */
    case 151:  /* *arm_shiftsi3 */
    case 20:  /* *compare_addsi2_op1 */
    case 19:  /* *compare_addsi2_op0 */
    case 8:  /* addsi3_compareV_reg */
      extract_constrain_insn_cached (insn);
      if ((((1ULL << which_alternative) & 0x3ULL)) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 2979:  /* arm_store_release_exclusivesi */
    case 2978:  /* arm_store_release_exclusivehi */
    case 2977:  /* arm_store_release_exclusiveqi */
    case 2969:  /* arm_load_acquire_exclusivesi */
    case 2968:  /* arm_load_exclusivesi */
    case 2967:  /* arm_load_acquire_exclusivehi */
    case 2966:  /* arm_load_acquire_exclusiveqi */
    case 2965:  /* arm_load_exclusivehi */
    case 2964:  /* arm_load_exclusiveqi */
    case 2963:  /* atomic_nand_fetchdi */
    case 2962:  /* atomic_nand_fetchsi */
    case 2961:  /* atomic_nand_fetchhi */
    case 2960:  /* atomic_nand_fetchqi */
    case 2959:  /* atomic_and_fetchdi */
    case 2958:  /* atomic_xor_fetchdi */
    case 2957:  /* atomic_or_fetchdi */
    case 2956:  /* atomic_sub_fetchdi */
    case 2955:  /* atomic_add_fetchdi */
    case 2954:  /* atomic_and_fetchsi */
    case 2953:  /* atomic_xor_fetchsi */
    case 2952:  /* atomic_or_fetchsi */
    case 2951:  /* atomic_sub_fetchsi */
    case 2950:  /* atomic_add_fetchsi */
    case 2949:  /* atomic_and_fetchhi */
    case 2948:  /* atomic_xor_fetchhi */
    case 2947:  /* atomic_or_fetchhi */
    case 2946:  /* atomic_sub_fetchhi */
    case 2945:  /* atomic_add_fetchhi */
    case 2944:  /* atomic_and_fetchqi */
    case 2943:  /* atomic_xor_fetchqi */
    case 2942:  /* atomic_or_fetchqi */
    case 2941:  /* atomic_sub_fetchqi */
    case 2940:  /* atomic_add_fetchqi */
    case 2939:  /* atomic_fetch_nanddi */
    case 2938:  /* atomic_fetch_nandsi */
    case 2937:  /* atomic_fetch_nandhi */
    case 2936:  /* atomic_fetch_nandqi */
    case 2935:  /* atomic_fetch_anddi */
    case 2934:  /* atomic_fetch_xordi */
    case 2933:  /* atomic_fetch_ordi */
    case 2932:  /* atomic_fetch_subdi */
    case 2931:  /* atomic_fetch_adddi */
    case 2930:  /* atomic_fetch_andsi */
    case 2929:  /* atomic_fetch_xorsi */
    case 2928:  /* atomic_fetch_orsi */
    case 2927:  /* atomic_fetch_subsi */
    case 2926:  /* atomic_fetch_addsi */
    case 2925:  /* atomic_fetch_andhi */
    case 2924:  /* atomic_fetch_xorhi */
    case 2923:  /* atomic_fetch_orhi */
    case 2922:  /* atomic_fetch_subhi */
    case 2921:  /* atomic_fetch_addhi */
    case 2920:  /* atomic_fetch_andqi */
    case 2919:  /* atomic_fetch_xorqi */
    case 2918:  /* atomic_fetch_orqi */
    case 2917:  /* atomic_fetch_subqi */
    case 2916:  /* atomic_fetch_addqi */
    case 2915:  /* atomic_nanddi */
    case 2914:  /* atomic_nandsi */
    case 2913:  /* atomic_nandhi */
    case 2912:  /* atomic_nandqi */
    case 2911:  /* atomic_anddi */
    case 2910:  /* atomic_xordi */
    case 2909:  /* atomic_ordi */
    case 2908:  /* atomic_subdi */
    case 2907:  /* atomic_adddi */
    case 2906:  /* atomic_andsi */
    case 2905:  /* atomic_xorsi */
    case 2904:  /* atomic_orsi */
    case 2903:  /* atomic_subsi */
    case 2902:  /* atomic_addsi */
    case 2901:  /* atomic_andhi */
    case 2900:  /* atomic_xorhi */
    case 2899:  /* atomic_orhi */
    case 2898:  /* atomic_subhi */
    case 2897:  /* atomic_addhi */
    case 2896:  /* atomic_andqi */
    case 2895:  /* atomic_xorqi */
    case 2894:  /* atomic_orqi */
    case 2893:  /* atomic_subqi */
    case 2892:  /* atomic_addqi */
    case 2891:  /* atomic_exchangedi */
    case 2890:  /* atomic_exchangesi */
    case 2889:  /* atomic_exchangehi */
    case 2888:  /* atomic_exchangeqi */
    case 2887:  /* atomic_compare_and_swapt1di_1 */
    case 2886:  /* atomic_compare_and_swapt1si_1 */
    case 2885:  /* atomic_compare_and_swap32di_1 */
    case 2884:  /* atomic_compare_and_swap32si_1 */
    case 2883:  /* atomic_compare_and_swapt1hi_1 */
    case 2882:  /* atomic_compare_and_swapt1qi_1 */
    case 2881:  /* atomic_compare_and_swap32hi_1 */
    case 2880:  /* atomic_compare_and_swap32qi_1 */
    case 2878:  /* atomic_storesi */
    case 2877:  /* atomic_storehi */
    case 2876:  /* atomic_storeqi */
    case 2875:  /* atomic_loadsi */
    case 2874:  /* atomic_loadhi */
    case 2873:  /* atomic_loadqi */
    case 960:  /* *thumb1_movhi_insn */
    case 958:  /* *thumb1_movdi_insn */
    case 760:  /* *movdi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
    case 415:  /* arm_rev16si2_alt */
    case 414:  /* arm_rev16si2 */
    case 413:  /* *arm_rev16 */
    case 412:  /* *arm_revsh */
    case 411:  /* *arm_rev */
    case 410:  /* *arm_movtas_ze */
    case 333:  /* *sub_shiftsi_compare0_scratch */
    case 332:  /* *sub_shiftsi_compare0 */
    case 331:  /* *sub_shiftsi */
    case 330:  /* *arith_shiftsi_compare0_scratch */
    case 329:  /* *arith_shiftsi_compare0 */
    case 328:  /* *and_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 324:  /* *add_shiftsi */
    case 323:  /* *and_multsi */
    case 322:  /* *eor_multsi */
    case 321:  /* *orr_multsi */
    case 320:  /* *rsb_multsi */
    case 319:  /* *add_multsi */
    case 311:  /* arm_stack_protect_test_insn */
    case 310:  /* *stack_protect_combined_test_insn */
    case 309:  /* *stack_protect_set_insn */
    case 308:  /* *stack_protect_combined_set_insn */
    case 275:  /* *arm_cmpsi_negshiftsi_si */
    case 274:  /* *cmpsi_shiftsi_swp */
    case 273:  /* *cmpsi_shiftsi */
    case 264:  /* *movsi_compare0 */
    case 258:  /* pic_load_addr_unified */
    case 256:  /* *arm_movt */
    case 170:  /* negsi2_carryin */
    case 167:  /* udivsi3 */
    case 166:  /* divsi3 */
    case 163:  /* unaligned_storehi */
    case 162:  /* unaligned_storesi */
    case 160:  /* unaligned_loadhiu */
    case 158:  /* unaligned_loadsi */
    case 156:  /* *not_shiftsi_compare0_scratch */
    case 155:  /* *not_shiftsi_compare0 */
    case 154:  /* *not_shiftsi */
    case 110:  /* *iorsi3_insn */
    case 107:  /* andsi_not_shiftsi_si_scc */
    case 106:  /* andsi_not_shiftsi_si_scc_no_reuse */
    case 105:  /* andsi_not_shiftsi_si */
    case 72:  /* *umull_high */
    case 71:  /* *smull_high */
    case 70:  /* umlal */
    case 69:  /* smlal */
    case 68:  /* umull */
    case 67:  /* smull */
    case 57:  /* *mla */
    case 56:  /* *mul */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 41:  /* *subsi3_carryin_shift */
    case 29:  /* subsi3_carryin */
    case 24:  /* *addsi3_carryin_shift */
    case 7:  /* *arm_addsi3 */
      if (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO)
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case 173:  /* *arm_one_cmplsi2 */
    case 169:  /* negsi2_0compare */
    case 168:  /* *arm_negsi2 */
    case 54:  /* subvsi3_borrow */
    case 52:  /* usubvsi3_borrow */
    case 34:  /* cmpsi3_carryin_CC_Bout */
    case 33:  /* cmpsi3_carryin_CC_NVout */
    case 27:  /* subvsi3 */
    case 23:  /* *addsi3_carryin_alt2 */
    case 21:  /* addsi3_carryin */
    case 15:  /* *compare_negsi_si */
    case 12:  /* addsi3_compareV_imm_nosum */
    case 9:  /* *addsi3_compareV_reg_nosum */
    case 4:  /* *addsi3_cin_cout_reg_insn */
    case 1:  /* *addsi3_cin_vout_reg_insn */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 0) && (! (
#line 161 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB2))))
        {
	  return ENABLED_NO;
        }
      else
        {
	  return ENABLED_YES;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if (get_attr_ce_enabled (insn) == CE_ENABLED_YES)
        {
	  if ((get_attr_predicable_short_it (insn) == PREDICABLE_SHORT_IT_NO) && (get_attr_predicated (insn) == PREDICATED_YES) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
	    {
	      return ENABLED_NO;
	    }
	  else if ((get_attr_enabled_for_short_it (insn) == ENABLED_FOR_SHORT_IT_NO) && (
#line 244 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_restrict_it)))
	    {
	      return ENABLED_NO;
	    }
	  else if ((get_attr_required_for_purecode (insn) == REQUIRED_FOR_PURECODE_YES) && (! (
#line 252 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(arm_disable_literal_pool))))
	    {
	      return ENABLED_NO;
	    }
	  else if (get_attr_arch_enabled (insn) == ARCH_ENABLED_NO)
	    {
	      return ENABLED_NO;
	    }
	  else
	    {
	      return ENABLED_YES;
	    }
        }
      else
        {
	  return ENABLED_NO;
        }

    default:
      return ENABLED_YES;

    }
}

enum attr_enabled_for_short_it
get_attr_enabled_for_short_it (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 1016:  /* *thumb2_movsicc_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return ENABLED_FOR_SHORT_IT_YES;
        }
      else if (((1ULL << which_alternative) & 0x7fcULL))
        {
	  return ENABLED_FOR_SHORT_IT_NO;
        }
      else
        {
	  return ENABLED_FOR_SHORT_IT_YES;
        }

    case 6924:  /* *p *thumb2_neg_abssi2 */
    case 6923:  /* *p *thumb2_abssi2 */
    case 1005:  /* *thumb2_neg_abssi2 */
    case 1004:  /* *thumb2_abssi2 */
    case 1003:  /* *thumb2_uminsi3 */
    case 1002:  /* *thumb32_umaxsi3 */
    case 1001:  /* *thumb2_sminsi3 */
    case 1000:  /* *thumb2_smaxsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return ENABLED_FOR_SHORT_IT_YES;
        }
      else
        {
	  return ENABLED_FOR_SHORT_IT_NO;
        }

    case 350:  /* movcond_addsi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ENABLED_FOR_SHORT_IT_NO;
        }
      else
        {
	  return ENABLED_FOR_SHORT_IT_YES;
        }

    case 343:  /* *cmp_ior */
    case 342:  /* *cmp_and */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ENABLED_FOR_SHORT_IT_YES;
        }
      else if (((1ULL << which_alternative) & 0x1eULL))
        {
	  return ENABLED_FOR_SHORT_IT_NO;
        }
      else if (which_alternative == 5)
        {
	  return ENABLED_FOR_SHORT_IT_YES;
        }
      else
        {
	  return ENABLED_FOR_SHORT_IT_NO;
        }

    case 341:  /* *cmp_ite1 */
    case 340:  /* *cmp_ite0 */
    case 344:  /* *ior_scc_scc */
    case 345:  /* *ior_scc_scc_cmp */
    case 346:  /* *and_scc_scc */
    case 347:  /* *and_scc_scc_cmp */
    case 377:  /* *if_neg_move */
    case 379:  /* *if_move_neg */
    case 1011:  /* *thumb2_mov_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return ENABLED_FOR_SHORT_IT_YES;
        }
      else
        {
	  return ENABLED_FOR_SHORT_IT_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return ENABLED_FOR_SHORT_IT_YES;

    }
}

enum attr_far_jump
get_attr_far_jump (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  int cached_length ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 974:  /* *cbranchne_decr1 */
      extract_constrain_insn_cached (insn);
      if ((((
#line 1481 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb1.md"
(which_alternative)) == (0)) && ((cached_length = get_attr_length (insn)) == 8)) || ((cached_length = get_attr_length (insn)) == 10 /* 0xa */))
        {
	  return FAR_JUMP_YES;
        }
      else
        {
	  return FAR_JUMP_NO;
        }

    case 975:  /* *addsi3_cbranch */
      extract_constrain_insn_cached (insn);
      if ((((
#line 1583 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/thumb1.md"
(which_alternative)) < (2)) && ((cached_length = get_attr_length (insn)) == 8)) || ((cached_length = get_attr_length (insn)) == 10 /* 0xa */))
        {
	  return FAR_JUMP_YES;
        }
      else
        {
	  return FAR_JUMP_NO;
        }

    case 967:  /* thumb1_cbz */
    case 968:  /* cbranchsi4_insn */
    case 969:  /* cbranchsi4_scratch */
    case 970:  /* *negated_cbranchsi4 */
    case 971:  /* *tbit_cbranch */
    case 972:  /* *tlobits_cbranch */
    case 973:  /* *tstsi3_cbranch */
    case 976:  /* *addsi3_cbranch_scratch */
      if (get_attr_length (insn) == 8)
        {
	  return FAR_JUMP_YES;
        }
      else
        {
	  return FAR_JUMP_NO;
        }

    case 983:  /* *thumb_jump */
      if (get_attr_length (insn) == 4)
        {
	  return FAR_JUMP_YES;
        }
      else
        {
	  return FAR_JUMP_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return FAR_JUMP_NO;

    }
}

enum attr_fp
get_attr_fp (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return FP_NO;

    }
}

enum attr_is_mve_type
get_attr_is_mve_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 3045:  /* *mve_movv2df */
    case 3044:  /* *mve_movv4sf */
    case 3043:  /* *mve_movv8hf */
    case 3042:  /* *mve_movti */
    case 3041:  /* *mve_movv2di */
    case 3040:  /* *mve_movv4si */
    case 3039:  /* *mve_movv8hi */
    case 3038:  /* *mve_movv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 5)
        {
	  return IS_MVE_TYPE_YES;
        }
      else
        {
	  return IS_MVE_TYPE_NO;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x3fffULL))
        {
	  return IS_MVE_TYPE_YES;
        }
      else
        {
	  return IS_MVE_TYPE_NO;
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x1ffULL))
        {
	  return IS_MVE_TYPE_YES;
        }
      else
        {
	  return IS_MVE_TYPE_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_MVE_MOVE) || (cached_type == TYPE_MVE_LOAD) || (cached_type == TYPE_MVE_STORE) || (cached_type == TYPE_MRS))
        {
	  return IS_MVE_TYPE_YES;
        }
      else
        {
	  return IS_MVE_TYPE_NO;
        }

    case 6556:  /* *p load_tp_hard */
    case 4963:  /* *movmisalignv4sf_mve_load */
    case 4962:  /* *movmisalignv8hf_mve_load */
    case 4961:  /* *movmisalignv4si_mve_load */
    case 4960:  /* *movmisalignv8hi_mve_load */
    case 4959:  /* *movmisalignv16qi_mve_load */
    case 4958:  /* *movmisalignv4sf_mve_store */
    case 4957:  /* *movmisalignv8hf_mve_store */
    case 4956:  /* *movmisalignv4si_mve_store */
    case 4955:  /* *movmisalignv8hi_mve_store */
    case 4954:  /* *movmisalignv16qi_mve_store */
    case 4941:  /* mve_vshlcq_m_uv4si */
    case 4940:  /* mve_vshlcq_m_sv4si */
    case 4939:  /* mve_vshlcq_m_uv8hi */
    case 4938:  /* mve_vshlcq_m_sv8hi */
    case 4937:  /* mve_vshlcq_m_uv16qi */
    case 4936:  /* mve_vshlcq_m_sv16qi */
    case 4921:  /* mve_vec_setv2di_internal */
    case 4920:  /* mve_vec_setv4sf_internal */
    case 4919:  /* mve_vec_setv4si_internal */
    case 4918:  /* mve_vec_setv8hf_internal */
    case 4917:  /* mve_vec_setv8hi_internal */
    case 4916:  /* mve_vec_setv16qi_internal */
    case 4915:  /* *mve_vec_extract_zext_internalv4si */
    case 4914:  /* *mve_vec_extract_zext_internalv8hi */
    case 4913:  /* *mve_vec_extract_zext_internalv16qi */
    case 4912:  /* *mve_vec_extract_sext_internalv4si */
    case 4911:  /* *mve_vec_extract_sext_internalv8hi */
    case 4910:  /* *mve_vec_extract_sext_internalv16qi */
    case 4909:  /* mve_vec_extractv2didi */
    case 4908:  /* mve_vec_extractv4sfsf */
    case 4907:  /* mve_vec_extractv8hfhf */
    case 4906:  /* mve_vec_extractv4sisi */
    case 4905:  /* mve_vec_extractv8hihi */
    case 4904:  /* mve_vec_extractv16qiqi */
    case 4888:  /* mve_vsbcq_sv4si */
    case 4887:  /* mve_vsbcq_uv4si */
    case 4886:  /* mve_vsbcq_m_sv4si */
    case 4885:  /* mve_vsbcq_m_uv4si */
    case 4884:  /* mve_vsbciq_sv4si */
    case 4883:  /* mve_vsbciq_uv4si */
    case 4882:  /* mve_vsbciq_m_sv4si */
    case 4881:  /* mve_vsbciq_m_uv4si */
    case 4880:  /* mve_vadcq_sv4si */
    case 4879:  /* mve_vadcq_uv4si */
    case 4878:  /* mve_vadcq_m_sv4si */
    case 4877:  /* mve_vadcq_m_uv4si */
    case 4876:  /* mve_vadciq_sv4si */
    case 4875:  /* mve_vadciq_uv4si */
    case 4874:  /* mve_vadciq_m_sv4si */
    case 4873:  /* mve_vadciq_m_uv4si */
    case 4870:  /* set_fpscr_nzcvqc */
    case 4869:  /* get_fpscr_nzcvqc */
    case 4850:  /* mve_viwdupq_m_wb_uv4si_insn */
    case 4849:  /* mve_viwdupq_m_wb_uv8hi_insn */
    case 4848:  /* mve_viwdupq_m_wb_uv16qi_insn */
    case 4844:  /* mve_vdwdupq_m_wb_uv4si_insn */
    case 4843:  /* mve_vdwdupq_m_wb_uv8hi_insn */
    case 4842:  /* mve_vdwdupq_m_wb_uv16qi_insn */
    case 4826:  /* mve_vaddq_fv4sf */
    case 4825:  /* mve_vaddq_fv8hf */
    case 4824:  /* mve_vaddqv4si */
    case 4823:  /* mve_vaddqv8hi */
    case 4822:  /* mve_vaddqv16qi */
    case 4641:  /* mve_vsubq_m_n_fv4sf */
    case 4640:  /* mve_vsubq_m_n_fv8hf */
    case 4639:  /* mve_vsubq_m_fv4sf */
    case 4638:  /* mve_vsubq_m_fv8hf */
    case 4637:  /* mve_vorrq_m_fv4sf */
    case 4636:  /* mve_vorrq_m_fv8hf */
    case 4635:  /* mve_vornq_m_fv4sf */
    case 4634:  /* mve_vornq_m_fv8hf */
    case 4633:  /* mve_vmulq_m_n_fv4sf */
    case 4632:  /* mve_vmulq_m_n_fv8hf */
    case 4631:  /* mve_vmulq_m_fv4sf */
    case 4630:  /* mve_vmulq_m_fv8hf */
    case 4629:  /* mve_vminnmq_m_fv4sf */
    case 4628:  /* mve_vminnmq_m_fv8hf */
    case 4627:  /* mve_vmaxnmq_m_fv4sf */
    case 4626:  /* mve_vmaxnmq_m_fv8hf */
    case 4625:  /* mve_vfmsq_m_fv4sf */
    case 4624:  /* mve_vfmsq_m_fv8hf */
    case 4623:  /* mve_vfmasq_m_n_fv4sf */
    case 4622:  /* mve_vfmasq_m_n_fv8hf */
    case 4621:  /* mve_vfmaq_m_n_fv4sf */
    case 4620:  /* mve_vfmaq_m_n_fv8hf */
    case 4619:  /* mve_vfmaq_m_fv4sf */
    case 4618:  /* mve_vfmaq_m_fv8hf */
    case 4617:  /* mve_veorq_m_fv4sf */
    case 4616:  /* mve_veorq_m_fv8hf */
    case 4615:  /* mve_vcmulq_rot90_m_fv4sf */
    case 4614:  /* mve_vcmulq_rot90_m_fv8hf */
    case 4613:  /* mve_vcmulq_rot270_m_fv4sf */
    case 4612:  /* mve_vcmulq_rot270_m_fv8hf */
    case 4611:  /* mve_vcmulq_rot180_m_fv4sf */
    case 4610:  /* mve_vcmulq_rot180_m_fv8hf */
    case 4609:  /* mve_vcmulq_m_fv4sf */
    case 4608:  /* mve_vcmulq_m_fv8hf */
    case 4607:  /* mve_vcmlaq_rot90_m_fv4sf */
    case 4606:  /* mve_vcmlaq_rot90_m_fv8hf */
    case 4605:  /* mve_vcmlaq_rot270_m_fv4sf */
    case 4604:  /* mve_vcmlaq_rot270_m_fv8hf */
    case 4603:  /* mve_vcmlaq_rot180_m_fv4sf */
    case 4602:  /* mve_vcmlaq_rot180_m_fv8hf */
    case 4601:  /* mve_vcmlaq_m_fv4sf */
    case 4600:  /* mve_vcmlaq_m_fv8hf */
    case 4599:  /* mve_vcaddq_rot90_m_fv4sf */
    case 4598:  /* mve_vcaddq_rot90_m_fv8hf */
    case 4597:  /* mve_vcaddq_rot270_m_fv4sf */
    case 4596:  /* mve_vcaddq_rot270_m_fv8hf */
    case 4595:  /* mve_vbrsrq_m_n_fv4sf */
    case 4594:  /* mve_vbrsrq_m_n_fv8hf */
    case 4593:  /* mve_vbicq_m_fv4sf */
    case 4592:  /* mve_vbicq_m_fv8hf */
    case 4591:  /* mve_vandq_m_fv4sf */
    case 4590:  /* mve_vandq_m_fv8hf */
    case 4589:  /* mve_vaddq_m_n_fv4sf */
    case 4588:  /* mve_vaddq_m_n_fv8hf */
    case 4587:  /* mve_vaddq_m_fv4sf */
    case 4586:  /* mve_vaddq_m_fv8hf */
    case 4585:  /* mve_vabdq_m_fv4sf */
    case 4584:  /* mve_vabdq_m_fv8hf */
    case 4583:  /* mve_vrmlsldavhaxq_p_sv4si */
    case 4582:  /* mve_vrmlsldavhaq_p_sv4si */
    case 4581:  /* mve_vrmlaldavhaxq_p_sv4si */
    case 4580:  /* mve_vrmlaldavhaq_p_uv4si */
    case 4579:  /* mve_vqshruntq_m_n_sv4si */
    case 4578:  /* mve_vqshruntq_m_n_sv8hi */
    case 4577:  /* mve_vqshrunbq_m_n_sv4si */
    case 4576:  /* mve_vqshrunbq_m_n_sv8hi */
    case 4575:  /* mve_vqrshruntq_m_n_sv4si */
    case 4574:  /* mve_vqrshruntq_m_n_sv8hi */
    case 4573:  /* mve_vqrshrunbq_m_n_sv4si */
    case 4572:  /* mve_vqrshrunbq_m_n_sv8hi */
    case 4571:  /* mve_vqdmulltq_m_sv4si */
    case 4570:  /* mve_vqdmulltq_m_sv8hi */
    case 4569:  /* mve_vqdmulltq_m_n_sv4si */
    case 4568:  /* mve_vqdmulltq_m_n_sv8hi */
    case 4567:  /* mve_vqdmullbq_m_sv4si */
    case 4566:  /* mve_vqdmullbq_m_sv8hi */
    case 4565:  /* mve_vqdmullbq_m_n_sv4si */
    case 4564:  /* mve_vqdmullbq_m_n_sv8hi */
    case 4563:  /* mve_vmulltq_poly_m_pv8hi */
    case 4562:  /* mve_vmulltq_poly_m_pv16qi */
    case 4561:  /* mve_vmullbq_poly_m_pv8hi */
    case 4560:  /* mve_vmullbq_poly_m_pv16qi */
    case 4559:  /* mve_vmlsldavaxq_p_sv4si */
    case 4558:  /* mve_vmlsldavaxq_p_sv8hi */
    case 4557:  /* mve_vmlsldavaq_p_sv4si */
    case 4556:  /* mve_vmlsldavaq_p_sv8hi */
    case 4555:  /* mve_vshrntq_m_n_uv4si */
    case 4554:  /* mve_vshrntq_m_n_sv4si */
    case 4553:  /* mve_vshrntq_m_n_uv8hi */
    case 4552:  /* mve_vshrntq_m_n_sv8hi */
    case 4551:  /* mve_vshrnbq_m_n_uv4si */
    case 4550:  /* mve_vshrnbq_m_n_sv4si */
    case 4549:  /* mve_vshrnbq_m_n_uv8hi */
    case 4548:  /* mve_vshrnbq_m_n_sv8hi */
    case 4547:  /* mve_vshlltq_m_n_sv8hi */
    case 4546:  /* mve_vshlltq_m_n_uv8hi */
    case 4545:  /* mve_vshlltq_m_n_sv16qi */
    case 4544:  /* mve_vshlltq_m_n_uv16qi */
    case 4543:  /* mve_vshllbq_m_n_sv8hi */
    case 4542:  /* mve_vshllbq_m_n_uv8hi */
    case 4541:  /* mve_vshllbq_m_n_sv16qi */
    case 4540:  /* mve_vshllbq_m_n_uv16qi */
    case 4539:  /* mve_vrshrntq_m_n_sv4si */
    case 4538:  /* mve_vrshrntq_m_n_uv4si */
    case 4537:  /* mve_vrshrntq_m_n_sv8hi */
    case 4536:  /* mve_vrshrntq_m_n_uv8hi */
    case 4535:  /* mve_vrshrnbq_m_n_sv4si */
    case 4534:  /* mve_vrshrnbq_m_n_uv4si */
    case 4533:  /* mve_vrshrnbq_m_n_sv8hi */
    case 4532:  /* mve_vrshrnbq_m_n_uv8hi */
    case 4531:  /* mve_vrmlaldavhaq_p_sv4si */
    case 4530:  /* mve_vqshrntq_m_n_uv4si */
    case 4529:  /* mve_vqshrntq_m_n_sv4si */
    case 4528:  /* mve_vqshrntq_m_n_uv8hi */
    case 4527:  /* mve_vqshrntq_m_n_sv8hi */
    case 4526:  /* mve_vqshrnbq_m_n_sv4si */
    case 4525:  /* mve_vqshrnbq_m_n_uv4si */
    case 4524:  /* mve_vqshrnbq_m_n_sv8hi */
    case 4523:  /* mve_vqshrnbq_m_n_uv8hi */
    case 4522:  /* mve_vqrshrntq_m_n_uv4si */
    case 4521:  /* mve_vqrshrntq_m_n_sv4si */
    case 4520:  /* mve_vqrshrntq_m_n_uv8hi */
    case 4519:  /* mve_vqrshrntq_m_n_sv8hi */
    case 4518:  /* mve_vqrshrnbq_m_n_sv4si */
    case 4517:  /* mve_vqrshrnbq_m_n_uv4si */
    case 4516:  /* mve_vqrshrnbq_m_n_sv8hi */
    case 4515:  /* mve_vqrshrnbq_m_n_uv8hi */
    case 4514:  /* mve_vmlaldavaxq_p_sv4si */
    case 4513:  /* mve_vmlaldavaxq_p_sv8hi */
    case 4512:  /* mve_vmlaldavaq_p_sv4si */
    case 4511:  /* mve_vmlaldavaq_p_uv4si */
    case 4510:  /* mve_vmlaldavaq_p_sv8hi */
    case 4509:  /* mve_vmlaldavaq_p_uv8hi */
    case 4508:  /* mve_vqrdmulhq_m_sv4si */
    case 4507:  /* mve_vqrdmulhq_m_sv8hi */
    case 4506:  /* mve_vqrdmulhq_m_sv16qi */
    case 4505:  /* mve_vqrdmulhq_m_n_sv4si */
    case 4504:  /* mve_vqrdmulhq_m_n_sv8hi */
    case 4503:  /* mve_vqrdmulhq_m_n_sv16qi */
    case 4502:  /* mve_vqrdmlsdhxq_m_sv4si */
    case 4501:  /* mve_vqrdmlsdhxq_m_sv8hi */
    case 4500:  /* mve_vqrdmlsdhxq_m_sv16qi */
    case 4499:  /* mve_vqrdmlsdhq_m_sv4si */
    case 4498:  /* mve_vqrdmlsdhq_m_sv8hi */
    case 4497:  /* mve_vqrdmlsdhq_m_sv16qi */
    case 4496:  /* mve_vqrdmladhxq_m_sv4si */
    case 4495:  /* mve_vqrdmladhxq_m_sv8hi */
    case 4494:  /* mve_vqrdmladhxq_m_sv16qi */
    case 4493:  /* mve_vqrdmladhq_m_sv4si */
    case 4492:  /* mve_vqrdmladhq_m_sv8hi */
    case 4491:  /* mve_vqrdmladhq_m_sv16qi */
    case 4490:  /* mve_vqdmulhq_m_sv4si */
    case 4489:  /* mve_vqdmulhq_m_sv8hi */
    case 4488:  /* mve_vqdmulhq_m_sv16qi */
    case 4487:  /* mve_vqdmulhq_m_n_sv4si */
    case 4486:  /* mve_vqdmulhq_m_n_sv8hi */
    case 4485:  /* mve_vqdmulhq_m_n_sv16qi */
    case 4484:  /* mve_vqdmlsdhxq_m_sv4si */
    case 4483:  /* mve_vqdmlsdhxq_m_sv8hi */
    case 4482:  /* mve_vqdmlsdhxq_m_sv16qi */
    case 4481:  /* mve_vqdmlsdhq_m_sv4si */
    case 4480:  /* mve_vqdmlsdhq_m_sv8hi */
    case 4479:  /* mve_vqdmlsdhq_m_sv16qi */
    case 4478:  /* mve_vqdmladhxq_m_sv4si */
    case 4477:  /* mve_vqdmladhxq_m_sv8hi */
    case 4476:  /* mve_vqdmladhxq_m_sv16qi */
    case 4475:  /* mve_vqdmladhq_m_sv4si */
    case 4474:  /* mve_vqdmladhq_m_sv8hi */
    case 4473:  /* mve_vqdmladhq_m_sv16qi */
    case 4472:  /* mve_vmlsdavaxq_p_sv4si */
    case 4471:  /* mve_vmlsdavaxq_p_sv8hi */
    case 4470:  /* mve_vmlsdavaxq_p_sv16qi */
    case 4469:  /* mve_vmlsdavaq_p_sv4si */
    case 4468:  /* mve_vmlsdavaq_p_sv8hi */
    case 4467:  /* mve_vmlsdavaq_p_sv16qi */
    case 4466:  /* mve_vmladavaxq_p_sv4si */
    case 4465:  /* mve_vmladavaxq_p_sv8hi */
    case 4464:  /* mve_vmladavaxq_p_sv16qi */
    case 4463:  /* mve_vhcaddq_rot90_m_sv4si */
    case 4462:  /* mve_vhcaddq_rot90_m_sv8hi */
    case 4461:  /* mve_vhcaddq_rot90_m_sv16qi */
    case 4460:  /* mve_vhcaddq_rot270_m_sv4si */
    case 4459:  /* mve_vhcaddq_rot270_m_sv8hi */
    case 4458:  /* mve_vhcaddq_rot270_m_sv16qi */
    case 4457:  /* mve_vsubq_m_n_uv4si */
    case 4456:  /* mve_vsubq_m_n_sv4si */
    case 4455:  /* mve_vsubq_m_n_uv8hi */
    case 4454:  /* mve_vsubq_m_n_sv8hi */
    case 4453:  /* mve_vsubq_m_n_uv16qi */
    case 4452:  /* mve_vsubq_m_n_sv16qi */
    case 4451:  /* mve_vsliq_m_n_sv4si */
    case 4450:  /* mve_vsliq_m_n_uv4si */
    case 4449:  /* mve_vsliq_m_n_sv8hi */
    case 4448:  /* mve_vsliq_m_n_uv8hi */
    case 4447:  /* mve_vsliq_m_n_sv16qi */
    case 4446:  /* mve_vsliq_m_n_uv16qi */
    case 4445:  /* mve_vshrq_m_n_uv4si */
    case 4444:  /* mve_vshrq_m_n_sv4si */
    case 4443:  /* mve_vshrq_m_n_uv8hi */
    case 4442:  /* mve_vshrq_m_n_sv8hi */
    case 4441:  /* mve_vshrq_m_n_uv16qi */
    case 4440:  /* mve_vshrq_m_n_sv16qi */
    case 4439:  /* mve_vshlq_m_n_uv4si */
    case 4438:  /* mve_vshlq_m_n_sv4si */
    case 4437:  /* mve_vshlq_m_n_uv8hi */
    case 4436:  /* mve_vshlq_m_n_sv8hi */
    case 4435:  /* mve_vshlq_m_n_uv16qi */
    case 4434:  /* mve_vshlq_m_n_sv16qi */
    case 4433:  /* mve_vrshrq_m_n_uv4si */
    case 4432:  /* mve_vrshrq_m_n_sv4si */
    case 4431:  /* mve_vrshrq_m_n_uv8hi */
    case 4430:  /* mve_vrshrq_m_n_sv8hi */
    case 4429:  /* mve_vrshrq_m_n_uv16qi */
    case 4428:  /* mve_vrshrq_m_n_sv16qi */
    case 4427:  /* mve_vrshlq_m_uv4si */
    case 4426:  /* mve_vrshlq_m_sv4si */
    case 4425:  /* mve_vrshlq_m_uv8hi */
    case 4424:  /* mve_vrshlq_m_sv8hi */
    case 4423:  /* mve_vrshlq_m_uv16qi */
    case 4422:  /* mve_vrshlq_m_sv16qi */
    case 4421:  /* mve_vrmulhq_m_sv4si */
    case 4420:  /* mve_vrmulhq_m_uv4si */
    case 4419:  /* mve_vrmulhq_m_sv8hi */
    case 4418:  /* mve_vrmulhq_m_uv8hi */
    case 4417:  /* mve_vrmulhq_m_sv16qi */
    case 4416:  /* mve_vrmulhq_m_uv16qi */
    case 4415:  /* mve_vrhaddq_m_sv4si */
    case 4414:  /* mve_vrhaddq_m_uv4si */
    case 4413:  /* mve_vrhaddq_m_sv8hi */
    case 4412:  /* mve_vrhaddq_m_uv8hi */
    case 4411:  /* mve_vrhaddq_m_sv16qi */
    case 4410:  /* mve_vrhaddq_m_uv16qi */
    case 4409:  /* mve_vqsubq_m_sv4si */
    case 4408:  /* mve_vqsubq_m_uv4si */
    case 4407:  /* mve_vqsubq_m_sv8hi */
    case 4406:  /* mve_vqsubq_m_uv8hi */
    case 4405:  /* mve_vqsubq_m_sv16qi */
    case 4404:  /* mve_vqsubq_m_uv16qi */
    case 4403:  /* mve_vqsubq_m_n_sv4si */
    case 4402:  /* mve_vqsubq_m_n_uv4si */
    case 4401:  /* mve_vqsubq_m_n_sv8hi */
    case 4400:  /* mve_vqsubq_m_n_uv8hi */
    case 4399:  /* mve_vqsubq_m_n_sv16qi */
    case 4398:  /* mve_vqsubq_m_n_uv16qi */
    case 4397:  /* mve_vqshlq_m_sv4si */
    case 4396:  /* mve_vqshlq_m_uv4si */
    case 4395:  /* mve_vqshlq_m_sv8hi */
    case 4394:  /* mve_vqshlq_m_uv8hi */
    case 4393:  /* mve_vqshlq_m_sv16qi */
    case 4392:  /* mve_vqshlq_m_uv16qi */
    case 4391:  /* mve_vqshlq_m_n_uv4si */
    case 4390:  /* mve_vqshlq_m_n_sv4si */
    case 4389:  /* mve_vqshlq_m_n_uv8hi */
    case 4388:  /* mve_vqshlq_m_n_sv8hi */
    case 4387:  /* mve_vqshlq_m_n_uv16qi */
    case 4386:  /* mve_vqshlq_m_n_sv16qi */
    case 4385:  /* mve_vqrshlq_m_sv4si */
    case 4384:  /* mve_vqrshlq_m_uv4si */
    case 4383:  /* mve_vqrshlq_m_sv8hi */
    case 4382:  /* mve_vqrshlq_m_uv8hi */
    case 4381:  /* mve_vqrshlq_m_sv16qi */
    case 4380:  /* mve_vqrshlq_m_uv16qi */
    case 4379:  /* mve_vqrdmlashq_m_n_sv4si */
    case 4378:  /* mve_vqrdmlashq_m_n_sv8hi */
    case 4377:  /* mve_vqrdmlashq_m_n_sv16qi */
    case 4376:  /* mve_vqrdmlahq_m_n_sv4si */
    case 4375:  /* mve_vqrdmlahq_m_n_sv8hi */
    case 4374:  /* mve_vqrdmlahq_m_n_sv16qi */
    case 4373:  /* mve_vqdmlashq_m_n_sv4si */
    case 4372:  /* mve_vqdmlashq_m_n_sv8hi */
    case 4371:  /* mve_vqdmlashq_m_n_sv16qi */
    case 4370:  /* mve_vqdmlahq_m_n_sv4si */
    case 4369:  /* mve_vqdmlahq_m_n_sv8hi */
    case 4368:  /* mve_vqdmlahq_m_n_sv16qi */
    case 4367:  /* mve_vqaddq_m_sv4si */
    case 4366:  /* mve_vqaddq_m_uv4si */
    case 4365:  /* mve_vqaddq_m_sv8hi */
    case 4364:  /* mve_vqaddq_m_uv8hi */
    case 4363:  /* mve_vqaddq_m_sv16qi */
    case 4362:  /* mve_vqaddq_m_uv16qi */
    case 4361:  /* mve_vqaddq_m_n_sv4si */
    case 4360:  /* mve_vqaddq_m_n_uv4si */
    case 4359:  /* mve_vqaddq_m_n_sv8hi */
    case 4358:  /* mve_vqaddq_m_n_uv8hi */
    case 4357:  /* mve_vqaddq_m_n_sv16qi */
    case 4356:  /* mve_vqaddq_m_n_uv16qi */
    case 4355:  /* mve_vorrq_m_uv4si */
    case 4354:  /* mve_vorrq_m_sv4si */
    case 4353:  /* mve_vorrq_m_uv8hi */
    case 4352:  /* mve_vorrq_m_sv8hi */
    case 4351:  /* mve_vorrq_m_uv16qi */
    case 4350:  /* mve_vorrq_m_sv16qi */
    case 4349:  /* mve_vornq_m_sv4si */
    case 4348:  /* mve_vornq_m_uv4si */
    case 4347:  /* mve_vornq_m_sv8hi */
    case 4346:  /* mve_vornq_m_uv8hi */
    case 4345:  /* mve_vornq_m_sv16qi */
    case 4344:  /* mve_vornq_m_uv16qi */
    case 4343:  /* mve_vmulq_m_uv4si */
    case 4342:  /* mve_vmulq_m_sv4si */
    case 4341:  /* mve_vmulq_m_uv8hi */
    case 4340:  /* mve_vmulq_m_sv8hi */
    case 4339:  /* mve_vmulq_m_uv16qi */
    case 4338:  /* mve_vmulq_m_sv16qi */
    case 4337:  /* mve_vmulq_m_n_sv4si */
    case 4336:  /* mve_vmulq_m_n_uv4si */
    case 4335:  /* mve_vmulq_m_n_sv8hi */
    case 4334:  /* mve_vmulq_m_n_uv8hi */
    case 4333:  /* mve_vmulq_m_n_sv16qi */
    case 4332:  /* mve_vmulq_m_n_uv16qi */
    case 4331:  /* mve_vmulltq_int_m_uv4si */
    case 4330:  /* mve_vmulltq_int_m_sv4si */
    case 4329:  /* mve_vmulltq_int_m_uv8hi */
    case 4328:  /* mve_vmulltq_int_m_sv8hi */
    case 4327:  /* mve_vmulltq_int_m_uv16qi */
    case 4326:  /* mve_vmulltq_int_m_sv16qi */
    case 4325:  /* mve_vmullbq_int_m_sv4si */
    case 4324:  /* mve_vmullbq_int_m_uv4si */
    case 4323:  /* mve_vmullbq_int_m_sv8hi */
    case 4322:  /* mve_vmullbq_int_m_uv8hi */
    case 4321:  /* mve_vmullbq_int_m_sv16qi */
    case 4320:  /* mve_vmullbq_int_m_uv16qi */
    case 4319:  /* mve_vmulhq_m_uv4si */
    case 4318:  /* mve_vmulhq_m_sv4si */
    case 4317:  /* mve_vmulhq_m_uv8hi */
    case 4316:  /* mve_vmulhq_m_sv8hi */
    case 4315:  /* mve_vmulhq_m_uv16qi */
    case 4314:  /* mve_vmulhq_m_sv16qi */
    case 4313:  /* mve_vmlasq_m_n_sv4si */
    case 4312:  /* mve_vmlasq_m_n_uv4si */
    case 4311:  /* mve_vmlasq_m_n_sv8hi */
    case 4310:  /* mve_vmlasq_m_n_uv8hi */
    case 4309:  /* mve_vmlasq_m_n_sv16qi */
    case 4308:  /* mve_vmlasq_m_n_uv16qi */
    case 4307:  /* mve_vmlaq_m_n_uv4si */
    case 4306:  /* mve_vmlaq_m_n_sv4si */
    case 4305:  /* mve_vmlaq_m_n_uv8hi */
    case 4304:  /* mve_vmlaq_m_n_sv8hi */
    case 4303:  /* mve_vmlaq_m_n_uv16qi */
    case 4302:  /* mve_vmlaq_m_n_sv16qi */
    case 4301:  /* mve_vmladavaq_p_sv4si */
    case 4300:  /* mve_vmladavaq_p_uv4si */
    case 4299:  /* mve_vmladavaq_p_sv8hi */
    case 4298:  /* mve_vmladavaq_p_uv8hi */
    case 4297:  /* mve_vmladavaq_p_sv16qi */
    case 4296:  /* mve_vmladavaq_p_uv16qi */
    case 4295:  /* mve_vminq_m_uv4si */
    case 4294:  /* mve_vminq_m_sv4si */
    case 4293:  /* mve_vminq_m_uv8hi */
    case 4292:  /* mve_vminq_m_sv8hi */
    case 4291:  /* mve_vminq_m_uv16qi */
    case 4290:  /* mve_vminq_m_sv16qi */
    case 4289:  /* mve_vmaxq_m_uv4si */
    case 4288:  /* mve_vmaxq_m_sv4si */
    case 4287:  /* mve_vmaxq_m_uv8hi */
    case 4286:  /* mve_vmaxq_m_sv8hi */
    case 4285:  /* mve_vmaxq_m_uv16qi */
    case 4284:  /* mve_vmaxq_m_sv16qi */
    case 4283:  /* mve_vhsubq_m_uv4si */
    case 4282:  /* mve_vhsubq_m_sv4si */
    case 4281:  /* mve_vhsubq_m_uv8hi */
    case 4280:  /* mve_vhsubq_m_sv8hi */
    case 4279:  /* mve_vhsubq_m_uv16qi */
    case 4278:  /* mve_vhsubq_m_sv16qi */
    case 4277:  /* mve_vhsubq_m_n_uv4si */
    case 4276:  /* mve_vhsubq_m_n_sv4si */
    case 4275:  /* mve_vhsubq_m_n_uv8hi */
    case 4274:  /* mve_vhsubq_m_n_sv8hi */
    case 4273:  /* mve_vhsubq_m_n_uv16qi */
    case 4272:  /* mve_vhsubq_m_n_sv16qi */
    case 4271:  /* mve_vhaddq_m_uv4si */
    case 4270:  /* mve_vhaddq_m_sv4si */
    case 4269:  /* mve_vhaddq_m_uv8hi */
    case 4268:  /* mve_vhaddq_m_sv8hi */
    case 4267:  /* mve_vhaddq_m_uv16qi */
    case 4266:  /* mve_vhaddq_m_sv16qi */
    case 4265:  /* mve_vhaddq_m_n_uv4si */
    case 4264:  /* mve_vhaddq_m_n_sv4si */
    case 4263:  /* mve_vhaddq_m_n_uv8hi */
    case 4262:  /* mve_vhaddq_m_n_sv8hi */
    case 4261:  /* mve_vhaddq_m_n_uv16qi */
    case 4260:  /* mve_vhaddq_m_n_sv16qi */
    case 4259:  /* mve_veorq_m_uv4si */
    case 4258:  /* mve_veorq_m_sv4si */
    case 4257:  /* mve_veorq_m_uv8hi */
    case 4256:  /* mve_veorq_m_sv8hi */
    case 4255:  /* mve_veorq_m_uv16qi */
    case 4254:  /* mve_veorq_m_sv16qi */
    case 4253:  /* mve_vcaddq_rot90_m_sv4si */
    case 4252:  /* mve_vcaddq_rot90_m_uv4si */
    case 4251:  /* mve_vcaddq_rot90_m_sv8hi */
    case 4250:  /* mve_vcaddq_rot90_m_uv8hi */
    case 4249:  /* mve_vcaddq_rot90_m_sv16qi */
    case 4248:  /* mve_vcaddq_rot90_m_uv16qi */
    case 4247:  /* mve_vcaddq_rot270_m_sv4si */
    case 4246:  /* mve_vcaddq_rot270_m_uv4si */
    case 4245:  /* mve_vcaddq_rot270_m_sv8hi */
    case 4244:  /* mve_vcaddq_rot270_m_uv8hi */
    case 4243:  /* mve_vcaddq_rot270_m_sv16qi */
    case 4242:  /* mve_vcaddq_rot270_m_uv16qi */
    case 4241:  /* mve_vbrsrq_m_n_sv4si */
    case 4240:  /* mve_vbrsrq_m_n_uv4si */
    case 4239:  /* mve_vbrsrq_m_n_sv8hi */
    case 4238:  /* mve_vbrsrq_m_n_uv8hi */
    case 4237:  /* mve_vbrsrq_m_n_sv16qi */
    case 4236:  /* mve_vbrsrq_m_n_uv16qi */
    case 4235:  /* mve_vbicq_m_sv4si */
    case 4234:  /* mve_vbicq_m_uv4si */
    case 4233:  /* mve_vbicq_m_sv8hi */
    case 4232:  /* mve_vbicq_m_uv8hi */
    case 4231:  /* mve_vbicq_m_sv16qi */
    case 4230:  /* mve_vbicq_m_uv16qi */
    case 4229:  /* mve_vandq_m_sv4si */
    case 4228:  /* mve_vandq_m_uv4si */
    case 4227:  /* mve_vandq_m_sv8hi */
    case 4226:  /* mve_vandq_m_uv8hi */
    case 4225:  /* mve_vandq_m_sv16qi */
    case 4224:  /* mve_vandq_m_uv16qi */
    case 4223:  /* mve_vaddq_m_sv4si */
    case 4222:  /* mve_vaddq_m_uv4si */
    case 4221:  /* mve_vaddq_m_sv8hi */
    case 4220:  /* mve_vaddq_m_uv8hi */
    case 4219:  /* mve_vaddq_m_sv16qi */
    case 4218:  /* mve_vaddq_m_uv16qi */
    case 4217:  /* mve_vaddq_m_n_uv4si */
    case 4216:  /* mve_vaddq_m_n_sv4si */
    case 4215:  /* mve_vaddq_m_n_uv8hi */
    case 4214:  /* mve_vaddq_m_n_sv8hi */
    case 4213:  /* mve_vaddq_m_n_uv16qi */
    case 4212:  /* mve_vaddq_m_n_sv16qi */
    case 4211:  /* mve_vabdq_m_uv4si */
    case 4210:  /* mve_vabdq_m_sv4si */
    case 4209:  /* mve_vabdq_m_uv8hi */
    case 4208:  /* mve_vabdq_m_sv8hi */
    case 4207:  /* mve_vabdq_m_uv16qi */
    case 4206:  /* mve_vabdq_m_sv16qi */
    case 4205:  /* mve_vcvtq_m_n_to_f_sv4sf */
    case 4204:  /* mve_vcvtq_m_n_to_f_uv4sf */
    case 4203:  /* mve_vcvtq_m_n_to_f_sv8hf */
    case 4202:  /* mve_vcvtq_m_n_to_f_uv8hf */
    case 4201:  /* mve_vsubq_m_sv4si */
    case 4200:  /* mve_vsubq_m_uv4si */
    case 4199:  /* mve_vsubq_m_sv8hi */
    case 4198:  /* mve_vsubq_m_uv8hi */
    case 4197:  /* mve_vsubq_m_sv16qi */
    case 4196:  /* mve_vsubq_m_uv16qi */
    case 4195:  /* mve_vsriq_m_n_uv4si */
    case 4194:  /* mve_vsriq_m_n_sv4si */
    case 4193:  /* mve_vsriq_m_n_uv8hi */
    case 4192:  /* mve_vsriq_m_n_sv8hi */
    case 4191:  /* mve_vsriq_m_n_uv16qi */
    case 4190:  /* mve_vsriq_m_n_sv16qi */
    case 4189:  /* mve_vshlq_m_uv4si */
    case 4188:  /* mve_vshlq_m_sv4si */
    case 4187:  /* mve_vshlq_m_uv8hi */
    case 4186:  /* mve_vshlq_m_sv8hi */
    case 4185:  /* mve_vshlq_m_uv16qi */
    case 4184:  /* mve_vshlq_m_sv16qi */
    case 4183:  /* mve_vqshluq_m_n_sv4si */
    case 4182:  /* mve_vqshluq_m_n_sv8hi */
    case 4181:  /* mve_vqshluq_m_n_sv16qi */
    case 4180:  /* mve_vabavq_p_uv4si */
    case 4179:  /* mve_vabavq_p_sv4si */
    case 4178:  /* mve_vabavq_p_uv8hi */
    case 4177:  /* mve_vabavq_p_sv8hi */
    case 4176:  /* mve_vabavq_p_uv16qi */
    case 4175:  /* mve_vabavq_p_sv16qi */
    case 4174:  /* mve_vrmlsldavhaq_sv4si */
    case 4173:  /* mve_vrmlaldavhq_p_uv4si */
    case 4172:  /* mve_vrmlaldavhq_p_sv4si */
    case 4171:  /* mve_vcvtq_m_from_f_sv4si */
    case 4170:  /* mve_vcvtq_m_from_f_uv4si */
    case 4169:  /* mve_vcvtq_m_from_f_sv8hi */
    case 4168:  /* mve_vcvtq_m_from_f_uv8hi */
    case 4167:  /* mve_vrev16q_m_uv16qi */
    case 4166:  /* mve_vrev16q_m_sv16qi */
    case 4165:  /* mve_vcvtq_m_n_from_f_uv4si */
    case 4164:  /* mve_vcvtq_m_n_from_f_sv4si */
    case 4163:  /* mve_vcvtq_m_n_from_f_uv8hi */
    case 4162:  /* mve_vcvtq_m_n_from_f_sv8hi */
    case 4161:  /* mve_vcvtnq_m_uv4si */
    case 4160:  /* mve_vcvtnq_m_sv4si */
    case 4159:  /* mve_vcvtnq_m_uv8hi */
    case 4158:  /* mve_vcvtnq_m_sv8hi */
    case 4157:  /* mve_vcvtpq_m_uv4si */
    case 4156:  /* mve_vcvtpq_m_sv4si */
    case 4155:  /* mve_vcvtpq_m_uv8hi */
    case 4154:  /* mve_vcvtpq_m_sv8hi */
    case 4153:  /* mve_vcvtmq_m_uv4si */
    case 4152:  /* mve_vcvtmq_m_sv4si */
    case 4151:  /* mve_vcvtmq_m_uv8hi */
    case 4150:  /* mve_vcvtmq_m_sv8hi */
    case 4149:  /* mve_vshrntq_n_uv4si */
    case 4148:  /* mve_vshrntq_n_sv4si */
    case 4147:  /* mve_vshrntq_n_uv8hi */
    case 4146:  /* mve_vshrntq_n_sv8hi */
    case 4145:  /* mve_vshrnbq_n_sv4si */
    case 4144:  /* mve_vshrnbq_n_uv4si */
    case 4143:  /* mve_vshrnbq_n_sv8hi */
    case 4142:  /* mve_vshrnbq_n_uv8hi */
    case 4141:  /* mve_vrshrntq_n_sv4si */
    case 4140:  /* mve_vrshrntq_n_uv4si */
    case 4139:  /* mve_vrshrntq_n_sv8hi */
    case 4138:  /* mve_vrshrntq_n_uv8hi */
    case 4137:  /* mve_vrshrnbq_n_uv4si */
    case 4136:  /* mve_vrshrnbq_n_sv4si */
    case 4135:  /* mve_vrshrnbq_n_uv8hi */
    case 4134:  /* mve_vrshrnbq_n_sv8hi */
    case 4133:  /* mve_vrndxq_m_fv4sf */
    case 4132:  /* mve_vrndxq_m_fv8hf */
    case 4131:  /* mve_vrndpq_m_fv4sf */
    case 4130:  /* mve_vrndpq_m_fv8hf */
    case 4129:  /* mve_vrndnq_m_fv4sf */
    case 4128:  /* mve_vrndnq_m_fv8hf */
    case 4127:  /* mve_vrndmq_m_fv4sf */
    case 4126:  /* mve_vrndmq_m_fv8hf */
    case 4125:  /* mve_vrndaq_m_fv4sf */
    case 4124:  /* mve_vrndaq_m_fv8hf */
    case 4123:  /* mve_vrmlsldavhxq_p_sv4si */
    case 4122:  /* mve_vrmlsldavhq_p_sv4si */
    case 4121:  /* mve_vrmlsldavhaxq_sv4si */
    case 4120:  /* mve_vrmlaldavhxq_p_sv4si */
    case 4119:  /* mve_vrmlaldavhaxq_sv4si */
    case 4118:  /* mve_vrev64q_m_fv4sf */
    case 4117:  /* mve_vrev64q_m_fv8hf */
    case 4116:  /* mve_vrev32q_m_uv8hi */
    case 4115:  /* mve_vrev32q_m_sv8hi */
    case 4114:  /* mve_vrev32q_m_uv16qi */
    case 4113:  /* mve_vrev32q_m_sv16qi */
    case 4112:  /* mve_vrev32q_m_fv8hf */
    case 4111:  /* mve_vqshruntq_n_sv4si */
    case 4110:  /* mve_vqshruntq_n_sv8hi */
    case 4109:  /* mve_vqshrunbq_n_sv4si */
    case 4108:  /* mve_vqshrunbq_n_sv8hi */
    case 4107:  /* mve_vqshrntq_n_sv4si */
    case 4106:  /* mve_vqshrntq_n_uv4si */
    case 4105:  /* mve_vqshrntq_n_sv8hi */
    case 4104:  /* mve_vqshrntq_n_uv8hi */
    case 4103:  /* mve_vqshrnbq_n_sv4si */
    case 4102:  /* mve_vqshrnbq_n_uv4si */
    case 4101:  /* mve_vqshrnbq_n_sv8hi */
    case 4100:  /* mve_vqshrnbq_n_uv8hi */
    case 4099:  /* mve_vqrshruntq_n_sv4si */
    case 4098:  /* mve_vqrshruntq_n_sv8hi */
    case 4097:  /* mve_vqrshrntq_n_sv4si */
    case 4096:  /* mve_vqrshrntq_n_uv4si */
    case 4095:  /* mve_vqrshrntq_n_sv8hi */
    case 4094:  /* mve_vqrshrntq_n_uv8hi */
    case 4093:  /* mve_vqmovuntq_m_sv4si */
    case 4092:  /* mve_vqmovuntq_m_sv8hi */
    case 4091:  /* mve_vqmovunbq_m_sv4si */
    case 4090:  /* mve_vqmovunbq_m_sv8hi */
    case 4089:  /* mve_vqmovntq_m_sv4si */
    case 4088:  /* mve_vqmovntq_m_uv4si */
    case 4087:  /* mve_vqmovntq_m_sv8hi */
    case 4086:  /* mve_vqmovntq_m_uv8hi */
    case 4085:  /* mve_vqmovnbq_m_uv4si */
    case 4084:  /* mve_vqmovnbq_m_sv4si */
    case 4083:  /* mve_vqmovnbq_m_uv8hi */
    case 4082:  /* mve_vqmovnbq_m_sv8hi */
    case 4081:  /* mve_vpselq_fv4sf */
    case 4080:  /* mve_vpselq_fv8hf */
    case 4079:  /* mve_vorrq_m_n_uv4si */
    case 4078:  /* mve_vorrq_m_n_sv4si */
    case 4077:  /* mve_vorrq_m_n_uv8hi */
    case 4076:  /* mve_vorrq_m_n_sv8hi */
    case 4075:  /* mve_vnegq_m_fv4sf */
    case 4074:  /* mve_vnegq_m_fv8hf */
    case 4073:  /* mve_vmvnq_m_n_sv4si */
    case 4072:  /* mve_vmvnq_m_n_uv4si */
    case 4071:  /* mve_vmvnq_m_n_sv8hi */
    case 4070:  /* mve_vmvnq_m_n_uv8hi */
    case 4069:  /* mve_vmovntq_m_sv4si */
    case 4068:  /* mve_vmovntq_m_uv4si */
    case 4067:  /* mve_vmovntq_m_sv8hi */
    case 4066:  /* mve_vmovntq_m_uv8hi */
    case 4065:  /* mve_vmovnbq_m_sv4si */
    case 4064:  /* mve_vmovnbq_m_uv4si */
    case 4063:  /* mve_vmovnbq_m_sv8hi */
    case 4062:  /* mve_vmovnbq_m_uv8hi */
    case 4061:  /* mve_vmovltq_m_sv8hi */
    case 4060:  /* mve_vmovltq_m_uv8hi */
    case 4059:  /* mve_vmovltq_m_sv16qi */
    case 4058:  /* mve_vmovltq_m_uv16qi */
    case 4057:  /* mve_vmovlbq_m_sv8hi */
    case 4056:  /* mve_vmovlbq_m_uv8hi */
    case 4055:  /* mve_vmovlbq_m_sv16qi */
    case 4054:  /* mve_vmovlbq_m_uv16qi */
    case 4053:  /* mve_vmlsldavxq_p_sv4si */
    case 4052:  /* mve_vmlsldavxq_p_sv8hi */
    case 4051:  /* mve_vmlsldavq_p_sv4si */
    case 4050:  /* mve_vmlsldavq_p_sv8hi */
    case 4049:  /* mve_vmlsldavaxq_sv4si */
    case 4048:  /* mve_vmlsldavaxq_sv8hi */
    case 4047:  /* mve_vmlsldavaq_sv4si */
    case 4046:  /* mve_vmlsldavaq_sv8hi */
    case 4045:  /* mve_vmlaldavxq_p_sv4si */
    case 4044:  /* mve_vmlaldavxq_p_sv8hi */
    case 4043:  /* mve_vmlaldavq_p_sv4si */
    case 4042:  /* mve_vmlaldavq_p_uv4si */
    case 4041:  /* mve_vmlaldavq_p_sv8hi */
    case 4040:  /* mve_vmlaldavq_p_uv8hi */
    case 4039:  /* mve_vmlaldavaxq_sv4si */
    case 4038:  /* mve_vmlaldavaxq_sv8hi */
    case 4037:  /* mve_vmlaldavaq_uv4si */
    case 4036:  /* mve_vmlaldavaq_sv4si */
    case 4035:  /* mve_vmlaldavaq_uv8hi */
    case 4034:  /* mve_vmlaldavaq_sv8hi */
    case 4033:  /* mve_vminnmvq_p_fv4sf */
    case 4032:  /* mve_vminnmvq_p_fv8hf */
    case 4031:  /* mve_vminnmavq_p_fv4sf */
    case 4030:  /* mve_vminnmavq_p_fv8hf */
    case 4029:  /* mve_vminnmaq_m_fv4sf */
    case 4028:  /* mve_vminnmaq_m_fv8hf */
    case 4027:  /* mve_vmaxnmvq_p_fv4sf */
    case 4026:  /* mve_vmaxnmvq_p_fv8hf */
    case 4025:  /* mve_vmaxnmavq_p_fv4sf */
    case 4024:  /* mve_vmaxnmavq_p_fv8hf */
    case 4023:  /* mve_vmaxnmaq_m_fv4sf */
    case 4022:  /* mve_vmaxnmaq_m_fv8hf */
    case 4021:  /* mve_vfmsq_fv4sf */
    case 4020:  /* mve_vfmsq_fv8hf */
    case 4019:  /* mve_vfmasq_n_fv4sf */
    case 4018:  /* mve_vfmasq_n_fv8hf */
    case 4017:  /* mve_vfmaq_n_fv4sf */
    case 4016:  /* mve_vfmaq_n_fv8hf */
    case 4015:  /* mve_vfmaq_fv4sf */
    case 4014:  /* mve_vfmaq_fv8hf */
    case 4013:  /* mve_vdupq_m_n_fv4sf */
    case 4012:  /* mve_vdupq_m_n_fv8hf */
    case 4011:  /* mve_vcvttq_m_f32_f16v4sf */
    case 4010:  /* mve_vcvttq_m_f16_f32v8hf */
    case 4009:  /* mve_vcvtbq_m_f32_f16v4sf */
    case 4008:  /* mve_vcvtbq_m_f16_f32v8hf */
    case 4007:  /* mve_vcmpneq_m_n_fv4sf */
    case 4006:  /* mve_vcmpneq_m_n_fv8hf */
    case 4005:  /* mve_vcmpneq_m_fv4sf */
    case 4004:  /* mve_vcmpneq_m_fv8hf */
    case 4003:  /* mve_vcmpltq_m_n_fv4sf */
    case 4002:  /* mve_vcmpltq_m_n_fv8hf */
    case 4001:  /* mve_vcmpltq_m_fv4sf */
    case 4000:  /* mve_vcmpltq_m_fv8hf */
    case 3999:  /* mve_vcmpleq_m_n_fv4sf */
    case 3998:  /* mve_vcmpleq_m_n_fv8hf */
    case 3997:  /* mve_vcmpleq_m_fv4sf */
    case 3996:  /* mve_vcmpleq_m_fv8hf */
    case 3995:  /* mve_vcmpgtq_m_n_fv4sf */
    case 3994:  /* mve_vcmpgtq_m_n_fv8hf */
    case 3993:  /* mve_vcmpgtq_m_fv4sf */
    case 3992:  /* mve_vcmpgtq_m_fv8hf */
    case 3991:  /* mve_vcmpgeq_m_n_fv4sf */
    case 3990:  /* mve_vcmpgeq_m_n_fv8hf */
    case 3989:  /* mve_vcmpgeq_m_fv4sf */
    case 3988:  /* mve_vcmpgeq_m_fv8hf */
    case 3987:  /* mve_vcmpeqq_m_n_fv4sf */
    case 3986:  /* mve_vcmpeqq_m_n_fv8hf */
    case 3985:  /* mve_vcmlaq_rot270v4sf */
    case 3984:  /* mve_vcmlaq_rot180v4sf */
    case 3983:  /* mve_vcmlaq_rot90v4sf */
    case 3982:  /* mve_vcmlaqv4sf */
    case 3981:  /* mve_vcmlaq_rot270v8hf */
    case 3980:  /* mve_vcmlaq_rot180v8hf */
    case 3979:  /* mve_vcmlaq_rot90v8hf */
    case 3978:  /* mve_vcmlaqv8hf */
    case 3977:  /* mve_vaddlvaq_p_sv4si */
    case 3976:  /* mve_vaddlvaq_p_uv4si */
    case 3975:  /* mve_vabsq_m_fv4sf */
    case 3974:  /* mve_vabsq_m_fv8hf */
    case 3973:  /* mve_vmladavaxq_sv4si */
    case 3972:  /* mve_vmladavaxq_sv8hi */
    case 3971:  /* mve_vmladavaxq_sv16qi */
    case 3970:  /* mve_vmlsdavaq_sv4si */
    case 3969:  /* mve_vmlsdavaq_sv8hi */
    case 3968:  /* mve_vmlsdavaq_sv16qi */
    case 3967:  /* mve_vmlsdavaxq_sv4si */
    case 3966:  /* mve_vmlsdavaxq_sv8hi */
    case 3965:  /* mve_vmlsdavaxq_sv16qi */
    case 3964:  /* mve_vqdmladhq_sv4si */
    case 3963:  /* mve_vqdmladhq_sv8hi */
    case 3962:  /* mve_vqdmladhq_sv16qi */
    case 3961:  /* mve_vqdmladhxq_sv4si */
    case 3960:  /* mve_vqdmladhxq_sv8hi */
    case 3959:  /* mve_vqdmladhxq_sv16qi */
    case 3958:  /* mve_vqdmlsdhq_sv4si */
    case 3957:  /* mve_vqdmlsdhq_sv8hi */
    case 3956:  /* mve_vqdmlsdhq_sv16qi */
    case 3955:  /* mve_vqdmlsdhxq_sv4si */
    case 3954:  /* mve_vqdmlsdhxq_sv8hi */
    case 3953:  /* mve_vqdmlsdhxq_sv16qi */
    case 3952:  /* mve_vsriq_n_uv4si */
    case 3951:  /* mve_vsriq_n_sv4si */
    case 3950:  /* mve_vsriq_n_uv8hi */
    case 3949:  /* mve_vsriq_n_sv8hi */
    case 3948:  /* mve_vsriq_n_uv16qi */
    case 3947:  /* mve_vsriq_n_sv16qi */
    case 3946:  /* mve_vsliq_n_uv4si */
    case 3945:  /* mve_vsliq_n_sv4si */
    case 3944:  /* mve_vsliq_n_uv8hi */
    case 3943:  /* mve_vsliq_n_sv8hi */
    case 3942:  /* mve_vsliq_n_uv16qi */
    case 3941:  /* mve_vsliq_n_sv16qi */
    case 3940:  /* mve_vshlq_m_r_uv4si */
    case 3939:  /* mve_vshlq_m_r_sv4si */
    case 3938:  /* mve_vshlq_m_r_uv8hi */
    case 3937:  /* mve_vshlq_m_r_sv8hi */
    case 3936:  /* mve_vshlq_m_r_uv16qi */
    case 3935:  /* mve_vshlq_m_r_sv16qi */
    case 3934:  /* mve_vrshlq_m_n_uv4si */
    case 3933:  /* mve_vrshlq_m_n_sv4si */
    case 3932:  /* mve_vrshlq_m_n_uv8hi */
    case 3931:  /* mve_vrshlq_m_n_sv8hi */
    case 3930:  /* mve_vrshlq_m_n_uv16qi */
    case 3929:  /* mve_vrshlq_m_n_sv16qi */
    case 3928:  /* mve_vrev64q_m_uv4si */
    case 3927:  /* mve_vrev64q_m_sv4si */
    case 3926:  /* mve_vrev64q_m_uv8hi */
    case 3925:  /* mve_vrev64q_m_sv8hi */
    case 3924:  /* mve_vrev64q_m_uv16qi */
    case 3923:  /* mve_vrev64q_m_sv16qi */
    case 3922:  /* mve_vqshlq_m_r_uv4si */
    case 3921:  /* mve_vqshlq_m_r_sv4si */
    case 3920:  /* mve_vqshlq_m_r_uv8hi */
    case 3919:  /* mve_vqshlq_m_r_sv8hi */
    case 3918:  /* mve_vqshlq_m_r_uv16qi */
    case 3917:  /* mve_vqshlq_m_r_sv16qi */
    case 3916:  /* mve_vqrshlq_m_n_uv4si */
    case 3915:  /* mve_vqrshlq_m_n_sv4si */
    case 3914:  /* mve_vqrshlq_m_n_uv8hi */
    case 3913:  /* mve_vqrshlq_m_n_sv8hi */
    case 3912:  /* mve_vqrshlq_m_n_uv16qi */
    case 3911:  /* mve_vqrshlq_m_n_sv16qi */
    case 3910:  /* mve_vqrdmlsdhxq_sv4si */
    case 3909:  /* mve_vqrdmlsdhxq_sv8hi */
    case 3908:  /* mve_vqrdmlsdhxq_sv16qi */
    case 3907:  /* mve_vqrdmlsdhq_sv4si */
    case 3906:  /* mve_vqrdmlsdhq_sv8hi */
    case 3905:  /* mve_vqrdmlsdhq_sv16qi */
    case 3904:  /* mve_vqrdmlashq_n_sv4si */
    case 3903:  /* mve_vqrdmlashq_n_sv8hi */
    case 3902:  /* mve_vqrdmlashq_n_sv16qi */
    case 3901:  /* mve_vqrdmlahq_n_sv4si */
    case 3900:  /* mve_vqrdmlahq_n_sv8hi */
    case 3899:  /* mve_vqrdmlahq_n_sv16qi */
    case 3898:  /* mve_vqrdmladhxq_sv4si */
    case 3897:  /* mve_vqrdmladhxq_sv8hi */
    case 3896:  /* mve_vqrdmladhxq_sv16qi */
    case 3895:  /* mve_vqrdmladhq_sv4si */
    case 3894:  /* mve_vqrdmladhq_sv8hi */
    case 3893:  /* mve_vqrdmladhq_sv16qi */
    case 3892:  /* mve_vqnegq_m_sv4si */
    case 3891:  /* mve_vqnegq_m_sv8hi */
    case 3890:  /* mve_vqnegq_m_sv16qi */
    case 3889:  /* mve_vqdmlashq_n_sv4si */
    case 3888:  /* mve_vqdmlashq_n_sv8hi */
    case 3887:  /* mve_vqdmlashq_n_sv16qi */
    case 3886:  /* mve_vqdmlahq_n_sv4si */
    case 3885:  /* mve_vqdmlahq_n_sv8hi */
    case 3884:  /* mve_vqdmlahq_n_sv16qi */
    case 3883:  /* mve_vqabsq_m_sv4si */
    case 3882:  /* mve_vqabsq_m_sv8hi */
    case 3881:  /* mve_vqabsq_m_sv16qi */
    case 3880:  /* mve_vpselq_uv2di */
    case 3879:  /* mve_vpselq_sv2di */
    case 3878:  /* mve_vpselq_uv4si */
    case 3877:  /* mve_vpselq_sv4si */
    case 3876:  /* mve_vpselq_uv8hi */
    case 3875:  /* mve_vpselq_sv8hi */
    case 3874:  /* mve_vpselq_uv16qi */
    case 3873:  /* mve_vpselq_sv16qi */
    case 3872:  /* mve_vnegq_m_sv4si */
    case 3871:  /* mve_vnegq_m_sv8hi */
    case 3870:  /* mve_vnegq_m_sv16qi */
    case 3869:  /* mve_vmvnq_m_uv4si */
    case 3868:  /* mve_vmvnq_m_sv4si */
    case 3867:  /* mve_vmvnq_m_uv8hi */
    case 3866:  /* mve_vmvnq_m_sv8hi */
    case 3865:  /* mve_vmvnq_m_uv16qi */
    case 3864:  /* mve_vmvnq_m_sv16qi */
    case 3863:  /* mve_vmlsdavxq_p_sv4si */
    case 3862:  /* mve_vmlsdavxq_p_sv8hi */
    case 3861:  /* mve_vmlsdavxq_p_sv16qi */
    case 3860:  /* mve_vmlsdavq_p_sv4si */
    case 3859:  /* mve_vmlsdavq_p_sv8hi */
    case 3858:  /* mve_vmlsdavq_p_sv16qi */
    case 3857:  /* mve_vmlasq_n_uv4si */
    case 3856:  /* mve_vmlasq_n_sv4si */
    case 3855:  /* mve_vmlasq_n_uv8hi */
    case 3854:  /* mve_vmlasq_n_sv8hi */
    case 3853:  /* mve_vmlasq_n_uv16qi */
    case 3852:  /* mve_vmlasq_n_sv16qi */
    case 3851:  /* mve_vmlaq_n_uv4si */
    case 3850:  /* mve_vmlaq_n_sv4si */
    case 3849:  /* mve_vmlaq_n_uv8hi */
    case 3848:  /* mve_vmlaq_n_sv8hi */
    case 3847:  /* mve_vmlaq_n_uv16qi */
    case 3846:  /* mve_vmlaq_n_sv16qi */
    case 3845:  /* mve_vmladavxq_p_sv4si */
    case 3844:  /* mve_vmladavxq_p_sv8hi */
    case 3843:  /* mve_vmladavxq_p_sv16qi */
    case 3842:  /* mve_vmladavq_p_uv4si */
    case 3841:  /* mve_vmladavq_p_sv4si */
    case 3840:  /* mve_vmladavq_p_uv8hi */
    case 3839:  /* mve_vmladavq_p_sv8hi */
    case 3838:  /* mve_vmladavq_p_uv16qi */
    case 3837:  /* mve_vmladavq_p_sv16qi */
    case 3836:  /* mve_vmladavaq_uv4si */
    case 3835:  /* mve_vmladavaq_sv4si */
    case 3834:  /* mve_vmladavaq_uv8hi */
    case 3833:  /* mve_vmladavaq_sv8hi */
    case 3832:  /* mve_vmladavaq_uv16qi */
    case 3831:  /* mve_vmladavaq_sv16qi */
    case 3830:  /* mve_vminvq_p_uv4si */
    case 3829:  /* mve_vminvq_p_sv4si */
    case 3828:  /* mve_vminvq_p_uv8hi */
    case 3827:  /* mve_vminvq_p_sv8hi */
    case 3826:  /* mve_vminvq_p_uv16qi */
    case 3825:  /* mve_vminvq_p_sv16qi */
    case 3824:  /* mve_vminavq_p_sv4si */
    case 3823:  /* mve_vminavq_p_sv8hi */
    case 3822:  /* mve_vminavq_p_sv16qi */
    case 3821:  /* mve_vminaq_m_sv4si */
    case 3820:  /* mve_vminaq_m_sv8hi */
    case 3819:  /* mve_vminaq_m_sv16qi */
    case 3818:  /* mve_vmaxvq_p_uv4si */
    case 3817:  /* mve_vmaxvq_p_sv4si */
    case 3816:  /* mve_vmaxvq_p_uv8hi */
    case 3815:  /* mve_vmaxvq_p_sv8hi */
    case 3814:  /* mve_vmaxvq_p_uv16qi */
    case 3813:  /* mve_vmaxvq_p_sv16qi */
    case 3812:  /* mve_vmaxavq_p_sv4si */
    case 3811:  /* mve_vmaxavq_p_sv8hi */
    case 3810:  /* mve_vmaxavq_p_sv16qi */
    case 3809:  /* mve_vmaxaq_m_sv4si */
    case 3808:  /* mve_vmaxaq_m_sv8hi */
    case 3807:  /* mve_vmaxaq_m_sv16qi */
    case 3806:  /* mve_vdupq_m_n_uv4si */
    case 3805:  /* mve_vdupq_m_n_sv4si */
    case 3804:  /* mve_vdupq_m_n_uv8hi */
    case 3803:  /* mve_vdupq_m_n_sv8hi */
    case 3802:  /* mve_vdupq_m_n_uv16qi */
    case 3801:  /* mve_vdupq_m_n_sv16qi */
    case 3800:  /* mve_vcmpneq_m_uv4si */
    case 3799:  /* mve_vcmpneq_m_sv4si */
    case 3798:  /* mve_vcmpneq_m_uv8hi */
    case 3797:  /* mve_vcmpneq_m_sv8hi */
    case 3796:  /* mve_vcmpneq_m_uv16qi */
    case 3795:  /* mve_vcmpneq_m_sv16qi */
    case 3794:  /* mve_vcmpneq_m_n_uv4si */
    case 3793:  /* mve_vcmpneq_m_n_sv4si */
    case 3792:  /* mve_vcmpneq_m_n_uv8hi */
    case 3791:  /* mve_vcmpneq_m_n_sv8hi */
    case 3790:  /* mve_vcmpneq_m_n_uv16qi */
    case 3789:  /* mve_vcmpneq_m_n_sv16qi */
    case 3788:  /* mve_vcmpltq_m_sv4si */
    case 3787:  /* mve_vcmpltq_m_sv8hi */
    case 3786:  /* mve_vcmpltq_m_sv16qi */
    case 3785:  /* mve_vcmpltq_m_n_sv4si */
    case 3784:  /* mve_vcmpltq_m_n_sv8hi */
    case 3783:  /* mve_vcmpltq_m_n_sv16qi */
    case 3782:  /* mve_vcmpleq_m_sv4si */
    case 3781:  /* mve_vcmpleq_m_sv8hi */
    case 3780:  /* mve_vcmpleq_m_sv16qi */
    case 3779:  /* mve_vcmpleq_m_n_sv4si */
    case 3778:  /* mve_vcmpleq_m_n_sv8hi */
    case 3777:  /* mve_vcmpleq_m_n_sv16qi */
    case 3776:  /* mve_vcmphiq_m_uv4si */
    case 3775:  /* mve_vcmphiq_m_uv8hi */
    case 3774:  /* mve_vcmphiq_m_uv16qi */
    case 3773:  /* mve_vcmphiq_m_n_uv4si */
    case 3772:  /* mve_vcmphiq_m_n_uv8hi */
    case 3771:  /* mve_vcmphiq_m_n_uv16qi */
    case 3770:  /* mve_vcmpgtq_m_sv4si */
    case 3769:  /* mve_vcmpgtq_m_sv8hi */
    case 3768:  /* mve_vcmpgtq_m_sv16qi */
    case 3767:  /* mve_vcmpgtq_m_n_sv4si */
    case 3766:  /* mve_vcmpgtq_m_n_sv8hi */
    case 3765:  /* mve_vcmpgtq_m_n_sv16qi */
    case 3764:  /* mve_vcmpgeq_m_sv4si */
    case 3763:  /* mve_vcmpgeq_m_sv8hi */
    case 3762:  /* mve_vcmpgeq_m_sv16qi */
    case 3761:  /* mve_vcmpgeq_m_n_sv4si */
    case 3760:  /* mve_vcmpgeq_m_n_sv8hi */
    case 3759:  /* mve_vcmpgeq_m_n_sv16qi */
    case 3758:  /* mve_vcmpeqq_m_uv4si */
    case 3757:  /* mve_vcmpeqq_m_sv4si */
    case 3756:  /* mve_vcmpeqq_m_uv8hi */
    case 3755:  /* mve_vcmpeqq_m_sv8hi */
    case 3754:  /* mve_vcmpeqq_m_uv16qi */
    case 3753:  /* mve_vcmpeqq_m_sv16qi */
    case 3752:  /* mve_vcmpeqq_m_n_uv4si */
    case 3751:  /* mve_vcmpeqq_m_n_sv4si */
    case 3750:  /* mve_vcmpeqq_m_n_uv8hi */
    case 3749:  /* mve_vcmpeqq_m_n_sv8hi */
    case 3748:  /* mve_vcmpeqq_m_n_uv16qi */
    case 3747:  /* mve_vcmpeqq_m_n_sv16qi */
    case 3746:  /* mve_vcmpcsq_m_uv4si */
    case 3745:  /* mve_vcmpcsq_m_uv8hi */
    case 3744:  /* mve_vcmpcsq_m_uv16qi */
    case 3743:  /* mve_vcmpcsq_m_n_uv4si */
    case 3742:  /* mve_vcmpcsq_m_n_uv8hi */
    case 3741:  /* mve_vcmpcsq_m_n_uv16qi */
    case 3740:  /* mve_vclzq_m_uv4si */
    case 3739:  /* mve_vclzq_m_sv4si */
    case 3738:  /* mve_vclzq_m_uv8hi */
    case 3737:  /* mve_vclzq_m_sv8hi */
    case 3736:  /* mve_vclzq_m_uv16qi */
    case 3735:  /* mve_vclzq_m_sv16qi */
    case 3734:  /* mve_vclsq_m_sv4si */
    case 3733:  /* mve_vclsq_m_sv8hi */
    case 3732:  /* mve_vclsq_m_sv16qi */
    case 3731:  /* mve_vaddvaq_p_uv4si */
    case 3730:  /* mve_vaddvaq_p_sv4si */
    case 3729:  /* mve_vaddvaq_p_uv8hi */
    case 3728:  /* mve_vaddvaq_p_sv8hi */
    case 3727:  /* mve_vaddvaq_p_uv16qi */
    case 3726:  /* mve_vaddvaq_p_sv16qi */
    case 3725:  /* mve_vabsq_m_sv4si */
    case 3724:  /* mve_vabsq_m_sv8hi */
    case 3723:  /* mve_vabsq_m_sv16qi */
    case 3716:  /* mve_vabavq_uv4si */
    case 3715:  /* mve_vabavq_sv4si */
    case 3714:  /* mve_vabavq_uv8hi */
    case 3713:  /* mve_vabavq_sv8hi */
    case 3712:  /* mve_vabavq_uv16qi */
    case 3711:  /* mve_vabavq_sv16qi */
    case 3710:  /* mve_vrmlaldavhaq_uv4si */
    case 3709:  /* mve_vrmlaldavhaq_sv4si */
    case 3708:  /* mve_vqrshrunbq_n_sv4si */
    case 3707:  /* mve_vqrshrunbq_n_sv8hi */
    case 3706:  /* mve_vqrshrnbq_n_sv4si */
    case 3705:  /* mve_vqrshrnbq_n_uv4si */
    case 3704:  /* mve_vqrshrnbq_n_sv8hi */
    case 3703:  /* mve_vqrshrnbq_n_uv8hi */
    case 3702:  /* mve_vcvtq_m_to_f_uv4sf */
    case 3701:  /* mve_vcvtq_m_to_f_sv4sf */
    case 3700:  /* mve_vcvtq_m_to_f_uv8hf */
    case 3699:  /* mve_vcvtq_m_to_f_sv8hf */
    case 3698:  /* mve_vcvtaq_m_uv4si */
    case 3697:  /* mve_vcvtaq_m_sv4si */
    case 3696:  /* mve_vcvtaq_m_uv8hi */
    case 3695:  /* mve_vcvtaq_m_sv8hi */
    case 3694:  /* mve_vcmpeqq_m_fv4sf */
    case 3693:  /* mve_vcmpeqq_m_fv8hf */
    case 3692:  /* mve_vbicq_m_n_uv4si */
    case 3691:  /* mve_vbicq_m_n_sv4si */
    case 3690:  /* mve_vbicq_m_n_uv8hi */
    case 3689:  /* mve_vbicq_m_n_sv8hi */
    case 3688:  /* mve_vrmlaldavhq_sv4si */
    case 3687:  /* mve_vrmlaldavhq_uv4si */
    case 3686:  /* mve_vmullbq_poly_pv8hi */
    case 3685:  /* mve_vmullbq_poly_pv16qi */
    case 3684:  /* mve_vmulltq_poly_pv8hi */
    case 3683:  /* mve_vmulltq_poly_pv16qi */
    case 3682:  /* mve_vsubq_fv4sf */
    case 3681:  /* mve_vsubq_fv8hf */
    case 3680:  /* mve_vshlltq_n_sv8hi */
    case 3679:  /* mve_vshlltq_n_uv8hi */
    case 3678:  /* mve_vshlltq_n_sv16qi */
    case 3677:  /* mve_vshlltq_n_uv16qi */
    case 3676:  /* mve_vshllbq_n_uv8hi */
    case 3675:  /* mve_vshllbq_n_sv8hi */
    case 3674:  /* mve_vshllbq_n_uv16qi */
    case 3673:  /* mve_vshllbq_n_sv16qi */
    case 3672:  /* mve_vrmlsldavhxq_sv4si */
    case 3671:  /* mve_vrmlsldavhq_sv4si */
    case 3670:  /* mve_vrmlaldavhxq_sv4si */
    case 3669:  /* mve_vqmovuntq_sv4si */
    case 3668:  /* mve_vqmovuntq_sv8hi */
    case 3667:  /* mve_vqmovunbq_sv4si */
    case 3666:  /* mve_vqmovunbq_sv8hi */
    case 3665:  /* mve_vqmovntq_sv4si */
    case 3664:  /* mve_vqmovntq_uv4si */
    case 3663:  /* mve_vqmovntq_sv8hi */
    case 3662:  /* mve_vqmovntq_uv8hi */
    case 3661:  /* mve_vqmovnbq_sv4si */
    case 3660:  /* mve_vqmovnbq_uv4si */
    case 3659:  /* mve_vqmovnbq_sv8hi */
    case 3658:  /* mve_vqmovnbq_uv8hi */
    case 3657:  /* mve_vqdmulltq_sv4si */
    case 3656:  /* mve_vqdmulltq_sv8hi */
    case 3655:  /* mve_vqdmulltq_n_sv4si */
    case 3654:  /* mve_vqdmulltq_n_sv8hi */
    case 3653:  /* mve_vqdmullbq_sv4si */
    case 3652:  /* mve_vqdmullbq_sv8hi */
    case 3651:  /* mve_vqdmullbq_n_sv4si */
    case 3650:  /* mve_vqdmullbq_n_sv8hi */
    case 3649:  /* mve_vorrq_n_sv4si */
    case 3648:  /* mve_vorrq_n_uv4si */
    case 3647:  /* mve_vorrq_n_sv8hi */
    case 3646:  /* mve_vorrq_n_uv8hi */
    case 3645:  /* mve_vorrq_fv4sf */
    case 3644:  /* mve_vorrq_fv8hf */
    case 3643:  /* mve_vornq_fv4sf */
    case 3642:  /* mve_vornq_fv8hf */
    case 3641:  /* mve_vmulq_n_fv4sf */
    case 3640:  /* mve_vmulq_n_fv8hf */
    case 3639:  /* mve_vmulq_fv4sf */
    case 3638:  /* mve_vmulq_fv8hf */
    case 3637:  /* mve_vmovntq_uv4si */
    case 3636:  /* mve_vmovntq_sv4si */
    case 3635:  /* mve_vmovntq_uv8hi */
    case 3634:  /* mve_vmovntq_sv8hi */
    case 3633:  /* mve_vmovnbq_sv4si */
    case 3632:  /* mve_vmovnbq_uv4si */
    case 3631:  /* mve_vmovnbq_sv8hi */
    case 3630:  /* mve_vmovnbq_uv8hi */
    case 3629:  /* mve_vmlsldavxq_sv4si */
    case 3628:  /* mve_vmlsldavxq_sv8hi */
    case 3627:  /* mve_vmlsldavq_sv4si */
    case 3626:  /* mve_vmlsldavq_sv8hi */
    case 3625:  /* mve_vmlaldavxq_sv4si */
    case 3624:  /* mve_vmlaldavxq_sv8hi */
    case 3623:  /* mve_vmlaldavq_sv4si */
    case 3622:  /* mve_vmlaldavq_uv4si */
    case 3621:  /* mve_vmlaldavq_sv8hi */
    case 3620:  /* mve_vmlaldavq_uv8hi */
    case 3619:  /* mve_vminnmvq_fv4sf */
    case 3618:  /* mve_vminnmvq_fv8hf */
    case 3617:  /* mve_vminnmq_fv4sf */
    case 3616:  /* mve_vminnmq_fv8hf */
    case 3615:  /* mve_vminnmavq_fv4sf */
    case 3614:  /* mve_vminnmavq_fv8hf */
    case 3613:  /* mve_vminnmaq_fv4sf */
    case 3612:  /* mve_vminnmaq_fv8hf */
    case 3611:  /* mve_vmaxnmvq_fv4sf */
    case 3610:  /* mve_vmaxnmvq_fv8hf */
    case 3609:  /* mve_vmaxnmq_fv4sf */
    case 3608:  /* mve_vmaxnmq_fv8hf */
    case 3607:  /* mve_vmaxnmavq_fv4sf */
    case 3606:  /* mve_vmaxnmavq_fv8hf */
    case 3605:  /* mve_vmaxnmaq_fv4sf */
    case 3604:  /* mve_vmaxnmaq_fv8hf */
    case 3603:  /* mve_veorq_fv4sf */
    case 3602:  /* mve_veorq_fv8hf */
    case 3601:  /* mve_vcvttq_f16_f32v8hf */
    case 3600:  /* mve_vcvtbq_f16_f32v8hf */
    case 3599:  /* mve_vctp64q_mv2qi */
    case 3598:  /* mve_vctp32q_mv4bi */
    case 3597:  /* mve_vctp16q_mv8bi */
    case 3596:  /* mve_vctp8q_mv16bi */
    case 3595:  /* mve_vcmulq_rot270v4sf */
    case 3594:  /* mve_vcmulq_rot180v4sf */
    case 3593:  /* mve_vcmulq_rot90v4sf */
    case 3592:  /* mve_vcmulqv4sf */
    case 3591:  /* mve_vcmulq_rot270v8hf */
    case 3590:  /* mve_vcmulq_rot180v8hf */
    case 3589:  /* mve_vcmulq_rot90v8hf */
    case 3588:  /* mve_vcmulqv8hf */
    case 3587:  /* mve_vcmpneq_n_fv4sf */
    case 3586:  /* mve_vcmpltq_n_fv4sf */
    case 3585:  /* mve_vcmpleq_n_fv4sf */
    case 3584:  /* mve_vcmpgtq_n_fv4sf */
    case 3583:  /* mve_vcmpgeq_n_fv4sf */
    case 3582:  /* mve_vcmpeqq_n_fv4sf */
    case 3581:  /* mve_vcmpneq_n_fv8hf */
    case 3580:  /* mve_vcmpltq_n_fv8hf */
    case 3579:  /* mve_vcmpleq_n_fv8hf */
    case 3578:  /* mve_vcmpgtq_n_fv8hf */
    case 3577:  /* mve_vcmpgeq_n_fv8hf */
    case 3576:  /* mve_vcmpeqq_n_fv8hf */
    case 3575:  /* mve_vcmpneq_fv4sf */
    case 3574:  /* mve_vcmpltq_fv4sf */
    case 3573:  /* mve_vcmpleq_fv4sf */
    case 3572:  /* mve_vcmpgtq_fv4sf */
    case 3571:  /* mve_vcmpgeq_fv4sf */
    case 3570:  /* mve_vcmpeqq_fv4sf */
    case 3569:  /* mve_vcmpneq_fv8hf */
    case 3568:  /* mve_vcmpltq_fv8hf */
    case 3567:  /* mve_vcmpleq_fv8hf */
    case 3566:  /* mve_vcmpgtq_fv8hf */
    case 3565:  /* mve_vcmpgeq_fv8hf */
    case 3564:  /* mve_vcmpeqq_fv8hf */
    case 3563:  /* mve_vcaddq_rot270v4sf */
    case 3562:  /* mve_vcaddq_rot90v4sf */
    case 3561:  /* mve_vcaddq_rot270v8hf */
    case 3560:  /* mve_vcaddq_rot90v8hf */
    case 3559:  /* mve_vbicq_n_uv4si */
    case 3558:  /* mve_vbicq_n_sv4si */
    case 3557:  /* mve_vbicq_n_uv8hi */
    case 3556:  /* mve_vbicq_n_sv8hi */
    case 3555:  /* mve_vbicq_fv4sf */
    case 3554:  /* mve_vbicq_fv8hf */
    case 3553:  /* mve_vandq_fv4sf */
    case 3552:  /* mve_vandq_fv8hf */
    case 3551:  /* mve_vaddq_n_fv4sf */
    case 3550:  /* mve_vaddq_n_fv8hf */
    case 3549:  /* mve_vaddlvaq_uv4si */
    case 3548:  /* mve_vaddlvaq_sv4si */
    case 3547:  /* mve_vabdq_fv4sf */
    case 3546:  /* mve_vabdq_fv8hf */
    case 3545:  /* mve_vsubqv4si */
    case 3544:  /* mve_vsubqv8hi */
    case 3543:  /* mve_vsubqv16qi */
    case 3542:  /* mve_vsubq_uv4si */
    case 3541:  /* mve_vsubq_sv4si */
    case 3540:  /* mve_vsubq_uv8hi */
    case 3539:  /* mve_vsubq_sv8hi */
    case 3538:  /* mve_vsubq_uv16qi */
    case 3537:  /* mve_vsubq_sv16qi */
    case 3536:  /* mve_vsubq_n_uv4si */
    case 3535:  /* mve_vsubq_n_sv4si */
    case 3534:  /* mve_vsubq_n_uv8hi */
    case 3533:  /* mve_vsubq_n_sv8hi */
    case 3532:  /* mve_vsubq_n_uv16qi */
    case 3531:  /* mve_vsubq_n_sv16qi */
    case 3530:  /* mve_vshlq_r_uv4si */
    case 3529:  /* mve_vshlq_r_sv4si */
    case 3528:  /* mve_vshlq_r_uv8hi */
    case 3527:  /* mve_vshlq_r_sv8hi */
    case 3526:  /* mve_vshlq_r_uv16qi */
    case 3525:  /* mve_vshlq_r_sv16qi */
    case 3524:  /* mve_vshlq_n_sv4si */
    case 3523:  /* mve_vshlq_n_uv4si */
    case 3522:  /* mve_vshlq_n_sv8hi */
    case 3521:  /* mve_vshlq_n_uv8hi */
    case 3520:  /* mve_vshlq_n_sv16qi */
    case 3519:  /* mve_vshlq_n_uv16qi */
    case 3518:  /* mve_vrshrq_n_uv4si */
    case 3517:  /* mve_vrshrq_n_sv4si */
    case 3516:  /* mve_vrshrq_n_uv8hi */
    case 3515:  /* mve_vrshrq_n_sv8hi */
    case 3514:  /* mve_vrshrq_n_uv16qi */
    case 3513:  /* mve_vrshrq_n_sv16qi */
    case 3512:  /* mve_vrshlq_uv4si */
    case 3511:  /* mve_vrshlq_sv4si */
    case 3510:  /* mve_vrshlq_uv8hi */
    case 3509:  /* mve_vrshlq_sv8hi */
    case 3508:  /* mve_vrshlq_uv16qi */
    case 3507:  /* mve_vrshlq_sv16qi */
    case 3506:  /* mve_vrshlq_n_sv4si */
    case 3505:  /* mve_vrshlq_n_uv4si */
    case 3504:  /* mve_vrshlq_n_sv8hi */
    case 3503:  /* mve_vrshlq_n_uv8hi */
    case 3502:  /* mve_vrshlq_n_sv16qi */
    case 3501:  /* mve_vrshlq_n_uv16qi */
    case 3500:  /* mve_vrmulhq_uv4si */
    case 3499:  /* mve_vrmulhq_sv4si */
    case 3498:  /* mve_vrmulhq_uv8hi */
    case 3497:  /* mve_vrmulhq_sv8hi */
    case 3496:  /* mve_vrmulhq_uv16qi */
    case 3495:  /* mve_vrmulhq_sv16qi */
    case 3494:  /* mve_vrhaddq_uv4si */
    case 3493:  /* mve_vrhaddq_sv4si */
    case 3492:  /* mve_vrhaddq_uv8hi */
    case 3491:  /* mve_vrhaddq_sv8hi */
    case 3490:  /* mve_vrhaddq_uv16qi */
    case 3489:  /* mve_vrhaddq_sv16qi */
    case 3488:  /* mve_vqsubq_sv4si */
    case 3487:  /* mve_vqsubq_uv4si */
    case 3486:  /* mve_vqsubq_sv8hi */
    case 3485:  /* mve_vqsubq_uv8hi */
    case 3484:  /* mve_vqsubq_sv16qi */
    case 3483:  /* mve_vqsubq_uv16qi */
    case 3482:  /* mve_vqsubq_n_uv4si */
    case 3481:  /* mve_vqsubq_n_sv4si */
    case 3480:  /* mve_vqsubq_n_uv8hi */
    case 3479:  /* mve_vqsubq_n_sv8hi */
    case 3478:  /* mve_vqsubq_n_uv16qi */
    case 3477:  /* mve_vqsubq_n_sv16qi */
    case 3476:  /* mve_vqshluq_n_sv4si */
    case 3475:  /* mve_vqshluq_n_sv8hi */
    case 3474:  /* mve_vqshluq_n_sv16qi */
    case 3473:  /* mve_vqshlq_uv4si */
    case 3472:  /* mve_vqshlq_sv4si */
    case 3471:  /* mve_vqshlq_uv8hi */
    case 3470:  /* mve_vqshlq_sv8hi */
    case 3469:  /* mve_vqshlq_uv16qi */
    case 3468:  /* mve_vqshlq_sv16qi */
    case 3467:  /* mve_vqshlq_r_sv4si */
    case 3466:  /* mve_vqshlq_r_uv4si */
    case 3465:  /* mve_vqshlq_r_sv8hi */
    case 3464:  /* mve_vqshlq_r_uv8hi */
    case 3463:  /* mve_vqshlq_r_sv16qi */
    case 3462:  /* mve_vqshlq_r_uv16qi */
    case 3461:  /* mve_vqshlq_n_uv4si */
    case 3460:  /* mve_vqshlq_n_sv4si */
    case 3459:  /* mve_vqshlq_n_uv8hi */
    case 3458:  /* mve_vqshlq_n_sv8hi */
    case 3457:  /* mve_vqshlq_n_uv16qi */
    case 3456:  /* mve_vqshlq_n_sv16qi */
    case 3455:  /* mve_vqrshlq_uv4si */
    case 3454:  /* mve_vqrshlq_sv4si */
    case 3453:  /* mve_vqrshlq_uv8hi */
    case 3452:  /* mve_vqrshlq_sv8hi */
    case 3451:  /* mve_vqrshlq_uv16qi */
    case 3450:  /* mve_vqrshlq_sv16qi */
    case 3449:  /* mve_vqrshlq_n_uv4si */
    case 3448:  /* mve_vqrshlq_n_sv4si */
    case 3447:  /* mve_vqrshlq_n_uv8hi */
    case 3446:  /* mve_vqrshlq_n_sv8hi */
    case 3445:  /* mve_vqrshlq_n_uv16qi */
    case 3444:  /* mve_vqrshlq_n_sv16qi */
    case 3443:  /* mve_vqrdmulhq_sv4si */
    case 3442:  /* mve_vqrdmulhq_sv8hi */
    case 3441:  /* mve_vqrdmulhq_sv16qi */
    case 3440:  /* mve_vqrdmulhq_n_sv4si */
    case 3439:  /* mve_vqrdmulhq_n_sv8hi */
    case 3438:  /* mve_vqrdmulhq_n_sv16qi */
    case 3437:  /* mve_vqdmulhq_sv4si */
    case 3436:  /* mve_vqdmulhq_sv8hi */
    case 3435:  /* mve_vqdmulhq_sv16qi */
    case 3434:  /* mve_vqdmulhq_n_sv4si */
    case 3433:  /* mve_vqdmulhq_n_sv8hi */
    case 3432:  /* mve_vqdmulhq_n_sv16qi */
    case 3431:  /* mve_vqaddq_sv4si */
    case 3430:  /* mve_vqaddq_uv4si */
    case 3429:  /* mve_vqaddq_sv8hi */
    case 3428:  /* mve_vqaddq_uv8hi */
    case 3427:  /* mve_vqaddq_sv16qi */
    case 3426:  /* mve_vqaddq_uv16qi */
    case 3425:  /* mve_vqaddq_n_uv4si */
    case 3424:  /* mve_vqaddq_n_sv4si */
    case 3423:  /* mve_vqaddq_n_uv8hi */
    case 3422:  /* mve_vqaddq_n_sv8hi */
    case 3421:  /* mve_vqaddq_n_uv16qi */
    case 3420:  /* mve_vqaddq_n_sv16qi */
    case 3419:  /* mve_vorrq_sv4si */
    case 3418:  /* mve_vorrq_sv8hi */
    case 3417:  /* mve_vorrq_sv16qi */
    case 3416:  /* mve_vornq_sv4si */
    case 3415:  /* mve_vornq_sv8hi */
    case 3414:  /* mve_vornq_sv16qi */
    case 3413:  /* mve_vmulqv4si */
    case 3412:  /* mve_vmulqv8hi */
    case 3411:  /* mve_vmulqv16qi */
    case 3410:  /* mve_vmulq_sv4si */
    case 3409:  /* mve_vmulq_uv4si */
    case 3408:  /* mve_vmulq_sv8hi */
    case 3407:  /* mve_vmulq_uv8hi */
    case 3406:  /* mve_vmulq_sv16qi */
    case 3405:  /* mve_vmulq_uv16qi */
    case 3404:  /* mve_vmulq_n_sv4si */
    case 3403:  /* mve_vmulq_n_uv4si */
    case 3402:  /* mve_vmulq_n_sv8hi */
    case 3401:  /* mve_vmulq_n_uv8hi */
    case 3400:  /* mve_vmulq_n_sv16qi */
    case 3399:  /* mve_vmulq_n_uv16qi */
    case 3398:  /* mve_vmulltq_int_sv4si */
    case 3397:  /* mve_vmulltq_int_uv4si */
    case 3396:  /* mve_vmulltq_int_sv8hi */
    case 3395:  /* mve_vmulltq_int_uv8hi */
    case 3394:  /* mve_vmulltq_int_sv16qi */
    case 3393:  /* mve_vmulltq_int_uv16qi */
    case 3392:  /* mve_vmullbq_int_sv4si */
    case 3391:  /* mve_vmullbq_int_uv4si */
    case 3390:  /* mve_vmullbq_int_sv8hi */
    case 3389:  /* mve_vmullbq_int_uv8hi */
    case 3388:  /* mve_vmullbq_int_sv16qi */
    case 3387:  /* mve_vmullbq_int_uv16qi */
    case 3386:  /* mve_vmulhq_uv4si */
    case 3385:  /* mve_vmulhq_sv4si */
    case 3384:  /* mve_vmulhq_uv8hi */
    case 3383:  /* mve_vmulhq_sv8hi */
    case 3382:  /* mve_vmulhq_uv16qi */
    case 3381:  /* mve_vmulhq_sv16qi */
    case 3380:  /* mve_vmlsdavxq_sv4si */
    case 3379:  /* mve_vmlsdavxq_sv8hi */
    case 3378:  /* mve_vmlsdavxq_sv16qi */
    case 3377:  /* mve_vmlsdavq_sv4si */
    case 3376:  /* mve_vmlsdavq_sv8hi */
    case 3375:  /* mve_vmlsdavq_sv16qi */
    case 3374:  /* mve_vmladavxq_sv4si */
    case 3373:  /* mve_vmladavxq_sv8hi */
    case 3372:  /* mve_vmladavxq_sv16qi */
    case 3371:  /* mve_vmladavq_sv4si */
    case 3370:  /* mve_vmladavq_uv4si */
    case 3369:  /* mve_vmladavq_sv8hi */
    case 3368:  /* mve_vmladavq_uv8hi */
    case 3367:  /* mve_vmladavq_sv16qi */
    case 3366:  /* mve_vmladavq_uv16qi */
    case 3365:  /* mve_vminvq_sv4si */
    case 3364:  /* mve_vminvq_uv4si */
    case 3363:  /* mve_vminvq_sv8hi */
    case 3362:  /* mve_vminvq_uv8hi */
    case 3361:  /* mve_vminvq_sv16qi */
    case 3360:  /* mve_vminvq_uv16qi */
    case 3359:  /* mve_vminq_uv4si */
    case 3358:  /* mve_vminq_uv8hi */
    case 3357:  /* mve_vminq_uv16qi */
    case 3356:  /* mve_vminq_sv4si */
    case 3355:  /* mve_vminq_sv8hi */
    case 3354:  /* mve_vminq_sv16qi */
    case 3353:  /* mve_vminavq_sv4si */
    case 3352:  /* mve_vminavq_sv8hi */
    case 3351:  /* mve_vminavq_sv16qi */
    case 3350:  /* mve_vminaq_sv4si */
    case 3349:  /* mve_vminaq_sv8hi */
    case 3348:  /* mve_vminaq_sv16qi */
    case 3347:  /* mve_vmaxvq_sv4si */
    case 3346:  /* mve_vmaxvq_uv4si */
    case 3345:  /* mve_vmaxvq_sv8hi */
    case 3344:  /* mve_vmaxvq_uv8hi */
    case 3343:  /* mve_vmaxvq_sv16qi */
    case 3342:  /* mve_vmaxvq_uv16qi */
    case 3341:  /* mve_vmaxq_uv4si */
    case 3340:  /* mve_vmaxq_uv8hi */
    case 3339:  /* mve_vmaxq_uv16qi */
    case 3338:  /* mve_vmaxq_sv4si */
    case 3337:  /* mve_vmaxq_sv8hi */
    case 3336:  /* mve_vmaxq_sv16qi */
    case 3335:  /* mve_vmaxavq_sv4si */
    case 3334:  /* mve_vmaxavq_sv8hi */
    case 3333:  /* mve_vmaxavq_sv16qi */
    case 3332:  /* mve_vmaxaq_sv4si */
    case 3331:  /* mve_vmaxaq_sv8hi */
    case 3330:  /* mve_vmaxaq_sv16qi */
    case 3329:  /* mve_vhsubq_uv4si */
    case 3328:  /* mve_vhsubq_sv4si */
    case 3327:  /* mve_vhsubq_uv8hi */
    case 3326:  /* mve_vhsubq_sv8hi */
    case 3325:  /* mve_vhsubq_uv16qi */
    case 3324:  /* mve_vhsubq_sv16qi */
    case 3323:  /* mve_vhsubq_n_sv4si */
    case 3322:  /* mve_vhsubq_n_uv4si */
    case 3321:  /* mve_vhsubq_n_sv8hi */
    case 3320:  /* mve_vhsubq_n_uv8hi */
    case 3319:  /* mve_vhsubq_n_sv16qi */
    case 3318:  /* mve_vhsubq_n_uv16qi */
    case 3317:  /* mve_vhcaddq_rot90_sv4si */
    case 3316:  /* mve_vhcaddq_rot90_sv8hi */
    case 3315:  /* mve_vhcaddq_rot90_sv16qi */
    case 3314:  /* mve_vhcaddq_rot270_sv4si */
    case 3313:  /* mve_vhcaddq_rot270_sv8hi */
    case 3312:  /* mve_vhcaddq_rot270_sv16qi */
    case 3311:  /* mve_vhaddq_uv4si */
    case 3310:  /* mve_vhaddq_sv4si */
    case 3309:  /* mve_vhaddq_uv8hi */
    case 3308:  /* mve_vhaddq_sv8hi */
    case 3307:  /* mve_vhaddq_uv16qi */
    case 3306:  /* mve_vhaddq_sv16qi */
    case 3305:  /* mve_vhaddq_n_sv4si */
    case 3304:  /* mve_vhaddq_n_uv4si */
    case 3303:  /* mve_vhaddq_n_sv8hi */
    case 3302:  /* mve_vhaddq_n_uv8hi */
    case 3301:  /* mve_vhaddq_n_sv16qi */
    case 3300:  /* mve_vhaddq_n_uv16qi */
    case 3299:  /* mve_veorq_uv4si */
    case 3298:  /* mve_veorq_uv8hi */
    case 3297:  /* mve_veorq_uv16qi */
    case 3296:  /* mve_vcaddq_rot270v4si */
    case 3295:  /* mve_vcaddq_rot90v4si */
    case 3294:  /* mve_vcaddq_rot270v8hi */
    case 3293:  /* mve_vcaddq_rot90v8hi */
    case 3292:  /* mve_vcaddq_rot270v16qi */
    case 3291:  /* mve_vcaddq_rot90v16qi */
    case 3290:  /* mve_vbrsrq_n_sv4si */
    case 3289:  /* mve_vbrsrq_n_uv4si */
    case 3288:  /* mve_vbrsrq_n_sv8hi */
    case 3287:  /* mve_vbrsrq_n_uv8hi */
    case 3286:  /* mve_vbrsrq_n_sv16qi */
    case 3285:  /* mve_vbrsrq_n_uv16qi */
    case 3284:  /* mve_vbicq_uv4si */
    case 3283:  /* mve_vbicq_uv8hi */
    case 3282:  /* mve_vbicq_uv16qi */
    case 3281:  /* mve_vandq_uv4si */
    case 3280:  /* mve_vandq_uv8hi */
    case 3279:  /* mve_vandq_uv16qi */
    case 3278:  /* mve_vaddvq_p_sv4si */
    case 3277:  /* mve_vaddvq_p_uv4si */
    case 3276:  /* mve_vaddvq_p_sv8hi */
    case 3275:  /* mve_vaddvq_p_uv8hi */
    case 3274:  /* mve_vaddvq_p_sv16qi */
    case 3273:  /* mve_vaddvq_p_uv16qi */
    case 3272:  /* mve_vaddvaq_uv4si */
    case 3271:  /* mve_vaddvaq_sv4si */
    case 3270:  /* mve_vaddvaq_uv8hi */
    case 3269:  /* mve_vaddvaq_sv8hi */
    case 3268:  /* mve_vaddvaq_uv16qi */
    case 3267:  /* mve_vaddvaq_sv16qi */
    case 3266:  /* mve_vaddq_n_uv4si */
    case 3265:  /* mve_vaddq_n_sv4si */
    case 3264:  /* mve_vaddq_n_uv8hi */
    case 3263:  /* mve_vaddq_n_sv8hi */
    case 3262:  /* mve_vaddq_n_uv16qi */
    case 3261:  /* mve_vaddq_n_sv16qi */
    case 3260:  /* mve_vabdq_uv4si */
    case 3259:  /* mve_vabdq_sv4si */
    case 3258:  /* mve_vabdq_uv8hi */
    case 3257:  /* mve_vabdq_sv8hi */
    case 3256:  /* mve_vabdq_uv16qi */
    case 3255:  /* mve_vabdq_sv16qi */
    case 3254:  /* mve_vcmpneq_n_v4si */
    case 3253:  /* mve_vcmpltq_n_v4si */
    case 3252:  /* mve_vcmpleq_n_v4si */
    case 3251:  /* mve_vcmphiq_n_v4si */
    case 3250:  /* mve_vcmpgtq_n_v4si */
    case 3249:  /* mve_vcmpcsq_n_v4si */
    case 3248:  /* mve_vcmpgeq_n_v4si */
    case 3247:  /* mve_vcmpeqq_n_v4si */
    case 3246:  /* mve_vcmpneq_n_v8hi */
    case 3245:  /* mve_vcmpltq_n_v8hi */
    case 3244:  /* mve_vcmpleq_n_v8hi */
    case 3243:  /* mve_vcmphiq_n_v8hi */
    case 3242:  /* mve_vcmpgtq_n_v8hi */
    case 3241:  /* mve_vcmpcsq_n_v8hi */
    case 3240:  /* mve_vcmpgeq_n_v8hi */
    case 3239:  /* mve_vcmpeqq_n_v8hi */
    case 3238:  /* mve_vcmpneq_n_v16qi */
    case 3237:  /* mve_vcmpltq_n_v16qi */
    case 3236:  /* mve_vcmpleq_n_v16qi */
    case 3235:  /* mve_vcmphiq_n_v16qi */
    case 3234:  /* mve_vcmpgtq_n_v16qi */
    case 3233:  /* mve_vcmpcsq_n_v16qi */
    case 3232:  /* mve_vcmpgeq_n_v16qi */
    case 3231:  /* mve_vcmpeqq_n_v16qi */
    case 3230:  /* mve_vcmpneq_v4si */
    case 3229:  /* mve_vcmpltq_v4si */
    case 3228:  /* mve_vcmpleq_v4si */
    case 3227:  /* mve_vcmphiq_v4si */
    case 3226:  /* mve_vcmpgtq_v4si */
    case 3225:  /* mve_vcmpcsq_v4si */
    case 3224:  /* mve_vcmpgeq_v4si */
    case 3223:  /* mve_vcmpeqq_v4si */
    case 3222:  /* mve_vcmpneq_v8hi */
    case 3221:  /* mve_vcmpltq_v8hi */
    case 3220:  /* mve_vcmpleq_v8hi */
    case 3219:  /* mve_vcmphiq_v8hi */
    case 3218:  /* mve_vcmpgtq_v8hi */
    case 3217:  /* mve_vcmpcsq_v8hi */
    case 3216:  /* mve_vcmpgeq_v8hi */
    case 3215:  /* mve_vcmpeqq_v8hi */
    case 3214:  /* mve_vcmpneq_v16qi */
    case 3213:  /* mve_vcmpltq_v16qi */
    case 3212:  /* mve_vcmpleq_v16qi */
    case 3211:  /* mve_vcmphiq_v16qi */
    case 3210:  /* mve_vcmpgtq_v16qi */
    case 3209:  /* mve_vcmpcsq_v16qi */
    case 3208:  /* mve_vcmpgeq_v16qi */
    case 3207:  /* mve_vcmpeqq_v16qi */
    case 3206:  /* mve_vaddlvq_p_uv4si */
    case 3205:  /* mve_vaddlvq_p_sv4si */
    case 3204:  /* mve_vcvtq_n_from_f_uv4si */
    case 3203:  /* mve_vcvtq_n_from_f_sv4si */
    case 3202:  /* mve_vcvtq_n_from_f_uv8hi */
    case 3201:  /* mve_vcvtq_n_from_f_sv8hi */
    case 3200:  /* mve_vshrq_n_uv4si_imm */
    case 3199:  /* mve_vshrq_n_uv8hi_imm */
    case 3198:  /* mve_vshrq_n_uv16qi_imm */
    case 3197:  /* mve_vshrq_n_sv4si_imm */
    case 3196:  /* mve_vshrq_n_sv8hi_imm */
    case 3195:  /* mve_vshrq_n_sv16qi_imm */
    case 3194:  /* mve_vshrq_n_uv4si */
    case 3193:  /* mve_vshrq_n_sv4si */
    case 3192:  /* mve_vshrq_n_uv8hi */
    case 3191:  /* mve_vshrq_n_sv8hi */
    case 3190:  /* mve_vshrq_n_uv16qi */
    case 3189:  /* mve_vshrq_n_sv16qi */
    case 3188:  /* mve_vcreateq_sv2di */
    case 3187:  /* mve_vcreateq_uv2di */
    case 3186:  /* mve_vcreateq_sv4si */
    case 3185:  /* mve_vcreateq_uv4si */
    case 3184:  /* mve_vcreateq_sv8hi */
    case 3183:  /* mve_vcreateq_uv8hi */
    case 3182:  /* mve_vcreateq_sv16qi */
    case 3181:  /* mve_vcreateq_uv16qi */
    case 3180:  /* mve_vcreateq_fv4sf */
    case 3179:  /* mve_vcreateq_fv8hf */
    case 3178:  /* mve_vcvtq_n_to_f_uv4sf */
    case 3177:  /* mve_vcvtq_n_to_f_sv4sf */
    case 3176:  /* mve_vcvtq_n_to_f_uv8hf */
    case 3175:  /* mve_vcvtq_n_to_f_sv8hf */
    case 3174:  /* mve_vbrsrq_n_fv4sf */
    case 3173:  /* mve_vbrsrq_n_fv8hf */
    case 3172:  /* mve_vsubq_n_fv4sf */
    case 3171:  /* mve_vsubq_n_fv8hf */
    case 3170:  /* mve_vpnotv16bi */
    case 3169:  /* mve_vctp64qv2qi */
    case 3168:  /* mve_vctp32qv4bi */
    case 3167:  /* mve_vctp16qv8bi */
    case 3166:  /* mve_vctp8qv16bi */
    case 3165:  /* mve_vaddlvq_sv4si */
    case 3164:  /* mve_vaddlvq_uv4si */
    case 3163:  /* mve_vrev16q_sv16qi */
    case 3162:  /* mve_vrev16q_uv16qi */
    case 3161:  /* mve_vmvnq_n_sv4si */
    case 3160:  /* mve_vmvnq_n_uv4si */
    case 3159:  /* mve_vmvnq_n_sv8hi */
    case 3158:  /* mve_vmvnq_n_uv8hi */
    case 3157:  /* mve_vcvtaq_sv4si */
    case 3156:  /* mve_vcvtaq_uv4si */
    case 3155:  /* mve_vcvtaq_sv8hi */
    case 3154:  /* mve_vcvtaq_uv8hi */
    case 3153:  /* mve_vcvtmq_uv4si */
    case 3152:  /* mve_vcvtmq_sv4si */
    case 3151:  /* mve_vcvtmq_uv8hi */
    case 3150:  /* mve_vcvtmq_sv8hi */
    case 3149:  /* mve_vcvtnq_uv4si */
    case 3148:  /* mve_vcvtnq_sv4si */
    case 3147:  /* mve_vcvtnq_uv8hi */
    case 3146:  /* mve_vcvtnq_sv8hi */
    case 3145:  /* mve_vcvtpq_uv4si */
    case 3144:  /* mve_vcvtpq_sv4si */
    case 3143:  /* mve_vcvtpq_uv8hi */
    case 3142:  /* mve_vcvtpq_sv8hi */
    case 3141:  /* mve_vmovlbq_uv8hi */
    case 3140:  /* mve_vmovlbq_sv8hi */
    case 3139:  /* mve_vmovlbq_uv16qi */
    case 3138:  /* mve_vmovlbq_sv16qi */
    case 3137:  /* mve_vmovltq_sv8hi */
    case 3136:  /* mve_vmovltq_uv8hi */
    case 3135:  /* mve_vmovltq_sv16qi */
    case 3134:  /* mve_vmovltq_uv16qi */
    case 3133:  /* mve_vrev32q_sv8hi */
    case 3132:  /* mve_vrev32q_uv8hi */
    case 3131:  /* mve_vrev32q_sv16qi */
    case 3130:  /* mve_vrev32q_uv16qi */
    case 3129:  /* mve_vabsq_sv4si */
    case 3128:  /* mve_vabsq_sv8hi */
    case 3127:  /* mve_vabsq_sv16qi */
    case 3126:  /* mve_vaddvq_sv4si */
    case 3125:  /* mve_vaddvq_uv4si */
    case 3124:  /* mve_vaddvq_sv8hi */
    case 3123:  /* mve_vaddvq_uv8hi */
    case 3122:  /* mve_vaddvq_sv16qi */
    case 3121:  /* mve_vaddvq_uv16qi */
    case 3120:  /* mve_vclsq_sv4si */
    case 3119:  /* mve_vclsq_sv8hi */
    case 3118:  /* mve_vclsq_sv16qi */
    case 3117:  /* mve_vclzq_sv4si */
    case 3116:  /* mve_vclzq_sv8hi */
    case 3115:  /* mve_vclzq_sv16qi */
    case 3114:  /* mve_vdupq_n_sv4si */
    case 3113:  /* mve_vdupq_n_uv4si */
    case 3112:  /* mve_vdupq_n_sv8hi */
    case 3111:  /* mve_vdupq_n_uv8hi */
    case 3110:  /* mve_vdupq_n_sv16qi */
    case 3109:  /* mve_vdupq_n_uv16qi */
    case 3108:  /* mve_vmvnq_uv4si */
    case 3107:  /* mve_vmvnq_uv8hi */
    case 3106:  /* mve_vmvnq_uv16qi */
    case 3105:  /* mve_vnegq_sv4si */
    case 3104:  /* mve_vnegq_sv8hi */
    case 3103:  /* mve_vnegq_sv16qi */
    case 3102:  /* mve_vqabsq_sv4si */
    case 3101:  /* mve_vqabsq_sv8hi */
    case 3100:  /* mve_vqabsq_sv16qi */
    case 3099:  /* mve_vqnegq_sv4si */
    case 3098:  /* mve_vqnegq_sv8hi */
    case 3097:  /* mve_vqnegq_sv16qi */
    case 3096:  /* mve_vcvtq_from_f_uv4si */
    case 3095:  /* mve_vcvtq_from_f_sv4si */
    case 3094:  /* mve_vcvtq_from_f_uv8hi */
    case 3093:  /* mve_vcvtq_from_f_sv8hi */
    case 3092:  /* mve_vrev64q_uv4si */
    case 3091:  /* mve_vrev64q_sv4si */
    case 3090:  /* mve_vrev64q_uv8hi */
    case 3089:  /* mve_vrev64q_sv8hi */
    case 3088:  /* mve_vrev64q_uv16qi */
    case 3087:  /* mve_vrev64q_sv16qi */
    case 3086:  /* mve_vcvtq_to_f_uv4sf */
    case 3085:  /* mve_vcvtq_to_f_sv4sf */
    case 3084:  /* mve_vcvtq_to_f_uv8hf */
    case 3083:  /* mve_vcvtq_to_f_sv8hf */
    case 3082:  /* mve_vcvtbq_f32_f16v4sf */
    case 3081:  /* mve_vcvttq_f32_f16v4sf */
    case 3080:  /* mve_vrev32q_fv8hf */
    case 3079:  /* mve_vabsq_fv4sf */
    case 3078:  /* mve_vabsq_fv8hf */
    case 3077:  /* mve_vdupq_n_fv4sf */
    case 3076:  /* mve_vdupq_n_fv8hf */
    case 3075:  /* mve_vnegq_fv4sf */
    case 3074:  /* mve_vnegq_fv8hf */
    case 3073:  /* mve_vrev64q_fv4sf */
    case 3072:  /* mve_vrev64q_fv8hf */
    case 3071:  /* mve_vrndaq_fv4sf */
    case 3070:  /* mve_vrndaq_fv8hf */
    case 3069:  /* mve_vrndmq_fv4sf */
    case 3068:  /* mve_vrndmq_fv8hf */
    case 3067:  /* mve_vrndnq_fv4sf */
    case 3066:  /* mve_vrndnq_fv8hf */
    case 3065:  /* mve_vrndpq_fv4sf */
    case 3064:  /* mve_vrndpq_fv8hf */
    case 3063:  /* mve_vrndq_fv4sf */
    case 3062:  /* mve_vrndq_fv8hf */
    case 3061:  /* mve_vrndxq_fv4sf */
    case 3060:  /* mve_vrndxq_fv8hf */
    case 3059:  /* mve_vrndq_m_fv4sf */
    case 3058:  /* mve_vrndq_m_fv8hf */
    case 3052:  /* *mve_vdupv2df */
    case 3051:  /* *mve_vdupv4sf */
    case 3050:  /* *mve_vdupv8hf */
    case 3049:  /* *mve_vdupv2di */
    case 3048:  /* *mve_vdupv4si */
    case 3047:  /* *mve_vdupv8hi */
    case 3046:  /* *mve_vdupv16qi */
    case 919:  /* get_fpscr */
    case 918:  /* set_fpscr */
    case 406:  /* reload_tp_hard */
    case 405:  /* load_tp_hard */
      return IS_MVE_TYPE_YES;

    default:
      return IS_MVE_TYPE_NO;

    }
}

enum attr_is_neon_type
get_attr_is_neon_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 1704:  /* neon_vcltv8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1655:  /* neon_vceqv16qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q))
        {
	  return IS_NEON_TYPE_YES;
        }
      else
        {
	  return IS_NEON_TYPE_NO;
        }

    case 1709:  /* neon_vcltv4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1650:  /* neon_vceqv8qi_insn */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_ZERO))
        {
	  return IS_NEON_TYPE_YES;
        }
      else
        {
	  return IS_NEON_TYPE_NO;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative != 7)
        {
	  return IS_NEON_TYPE_YES;
        }
      else
        {
	  return IS_NEON_TYPE_NO;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1ffULL))
        {
	  return IS_NEON_TYPE_YES;
        }
      else
        {
	  return IS_NEON_TYPE_NO;
        }

    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return IS_NEON_TYPE_YES;
        }
      else
        {
	  return IS_NEON_TYPE_NO;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return IS_NEON_TYPE_YES;
        }
      else
        {
	  return IS_NEON_TYPE_NO;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x180ULL))
        {
	  return IS_NEON_TYPE_YES;
        }
      else
        {
	  return IS_NEON_TYPE_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_ADD_Q) || (cached_type == TYPE_NEON_ADD_WIDEN) || (cached_type == TYPE_NEON_ADD_LONG) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_SUB_Q) || (cached_type == TYPE_NEON_SUB_WIDEN) || (cached_type == TYPE_NEON_SUB_LONG) || (cached_type == TYPE_NEON_QSUB) || (cached_type == TYPE_NEON_QSUB_Q) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_DOT) || (cached_type == TYPE_NEON_DOT_Q) || (cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_QNEG) || (cached_type == TYPE_NEON_QNEG_Q) || (cached_type == TYPE_NEON_QABS) || (cached_type == TYPE_NEON_QABS_Q) || (cached_type == TYPE_NEON_ABD) || (cached_type == TYPE_NEON_ABD_Q) || (cached_type == TYPE_NEON_ABD_LONG) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_MINMAX_Q) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q) || (cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_ARITH_ACC_Q) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_REDUC_ADD_LONG) || (cached_type == TYPE_NEON_REDUC_ADD_ACC) || (cached_type == TYPE_NEON_REDUC_ADD_ACC_Q) || (cached_type == TYPE_NEON_REDUC_MINMAX) || (cached_type == TYPE_NEON_REDUC_MINMAX_Q) || (cached_type == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_TST_Q) || (cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG) || (cached_type == TYPE_NEON_SHIFT_REG) || (cached_type == TYPE_NEON_SHIFT_REG_Q) || (cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SHIFT_ACC_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_REG) || (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q) || (cached_type == TYPE_NEON_INS) || (cached_type == TYPE_NEON_INS_Q) || (cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_MOVE_Q) || (cached_type == TYPE_NEON_MOVE_NARROW_Q) || (cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_PERMUTE_Q) || (cached_type == TYPE_NEON_ZIP) || (cached_type == TYPE_NEON_ZIP_Q) || (cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL1_Q) || (cached_type == TYPE_NEON_TBL2) || (cached_type == TYPE_NEON_TBL2_Q) || (cached_type == TYPE_NEON_TBL3) || (cached_type == TYPE_NEON_TBL3_Q) || (cached_type == TYPE_NEON_TBL4) || (cached_type == TYPE_NEON_TBL4_Q) || (cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_BSL_Q) || (cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CLS_Q) || (cached_type == TYPE_NEON_CNT) || (cached_type == TYPE_NEON_CNT_Q) || (cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_DUP_Q) || (cached_type == TYPE_NEON_EXT) || (cached_type == TYPE_NEON_EXT_Q) || (cached_type == TYPE_NEON_RBIT) || (cached_type == TYPE_NEON_RBIT_Q) || (cached_type == TYPE_NEON_REV) || (cached_type == TYPE_NEON_REV_Q) || (cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_MUL_S_LONG) || (cached_type == TYPE_NEON_MUL_D_LONG) || (cached_type == TYPE_NEON_MUL_H_SCALAR) || (cached_type == TYPE_NEON_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_S_SCALAR) || (cached_type == TYPE_NEON_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_B_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_LONG) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_H_Q) || (cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG) || (cached_type == TYPE_NEON_TO_GP) || (cached_type == TYPE_NEON_TO_GP_Q) || (cached_type == TYPE_NEON_FROM_GP) || (cached_type == TYPE_NEON_FROM_GP_Q) || (cached_type == TYPE_NEON_LDR) || (cached_type == TYPE_NEON_LDP) || (cached_type == TYPE_NEON_LDP_Q) || (cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_1REG_Q) || (cached_type == TYPE_NEON_LOAD1_2REG) || (cached_type == TYPE_NEON_LOAD1_2REG_Q) || (cached_type == TYPE_NEON_LOAD1_3REG) || (cached_type == TYPE_NEON_LOAD1_3REG_Q) || (cached_type == TYPE_NEON_LOAD1_4REG) || (cached_type == TYPE_NEON_LOAD1_4REG_Q) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES) || (cached_type == TYPE_NEON_LOAD1_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE) || (cached_type == TYPE_NEON_LOAD1_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD2_2REG) || (cached_type == TYPE_NEON_LOAD2_2REG_Q) || (cached_type == TYPE_NEON_LOAD2_4REG) || (cached_type == TYPE_NEON_LOAD2_4REG_Q) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES) || (cached_type == TYPE_NEON_LOAD2_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE) || (cached_type == TYPE_NEON_LOAD2_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD3_3REG) || (cached_type == TYPE_NEON_LOAD3_3REG_Q) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES) || (cached_type == TYPE_NEON_LOAD3_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE) || (cached_type == TYPE_NEON_LOAD3_ONE_LANE_Q) || (cached_type == TYPE_NEON_LOAD4_4REG) || (cached_type == TYPE_NEON_LOAD4_4REG_Q) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES) || (cached_type == TYPE_NEON_LOAD4_ALL_LANES_Q) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE) || (cached_type == TYPE_NEON_LOAD4_ONE_LANE_Q) || (cached_type == TYPE_NEON_STR) || (cached_type == TYPE_NEON_STP) || (cached_type == TYPE_NEON_STP_Q) || (cached_type == TYPE_NEON_STORE1_1REG) || (cached_type == TYPE_NEON_STORE1_1REG_Q) || (cached_type == TYPE_NEON_STORE1_2REG) || (cached_type == TYPE_NEON_STORE1_2REG_Q) || (cached_type == TYPE_NEON_STORE1_3REG) || (cached_type == TYPE_NEON_STORE1_3REG_Q) || (cached_type == TYPE_NEON_STORE1_4REG) || (cached_type == TYPE_NEON_STORE1_4REG_Q) || (cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE2_2REG) || (cached_type == TYPE_NEON_STORE2_2REG_Q) || (cached_type == TYPE_NEON_STORE2_4REG) || (cached_type == TYPE_NEON_STORE2_4REG_Q) || (cached_type == TYPE_NEON_STORE2_ONE_LANE) || (cached_type == TYPE_NEON_STORE2_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE3_3REG) || (cached_type == TYPE_NEON_STORE3_3REG_Q) || (cached_type == TYPE_NEON_STORE3_ONE_LANE) || (cached_type == TYPE_NEON_STORE3_ONE_LANE_Q) || (cached_type == TYPE_NEON_STORE4_4REG) || (cached_type == TYPE_NEON_STORE4_4REG_Q) || (cached_type == TYPE_NEON_STORE4_ONE_LANE) || (cached_type == TYPE_NEON_STORE4_ONE_LANE_Q) || (cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_ABD_D) || (cached_type == TYPE_NEON_FP_ABD_D_Q) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_ABS_S_Q) || (cached_type == TYPE_NEON_FP_ABS_D) || (cached_type == TYPE_NEON_FP_ABS_D_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_D) || (cached_type == TYPE_NEON_FP_ADDSUB_D_Q) || (cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_D) || (cached_type == TYPE_NEON_FP_COMPARE_D_Q) || (cached_type == TYPE_NEON_FP_MINMAX_S) || (cached_type == TYPE_NEON_FP_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_MINMAX_D) || (cached_type == TYPE_NEON_FP_MINMAX_D_Q) || (cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_NEG_D) || (cached_type == TYPE_NEON_FP_NEG_D_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_D) || (cached_type == TYPE_NEON_FP_REDUC_MINMAX_D_Q) || (cached_type == TYPE_NEON_FP_CVT_NARROW_S_Q) || (cached_type == TYPE_NEON_FP_CVT_NARROW_D_Q) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_H) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_S) || (cached_type == TYPE_NEON_FP_TO_INT_S) || (cached_type == TYPE_NEON_FP_TO_INT_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_S) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q) || (cached_type == TYPE_NEON_FP_TO_INT_D) || (cached_type == TYPE_NEON_FP_TO_INT_D_Q) || (cached_type == TYPE_NEON_INT_TO_FP_D) || (cached_type == TYPE_NEON_INT_TO_FP_D_Q) || (cached_type == TYPE_NEON_FP_ROUND_S) || (cached_type == TYPE_NEON_FP_ROUND_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_D) || (cached_type == TYPE_NEON_FP_RECPE_D_Q) || (cached_type == TYPE_NEON_FP_RECPS_S) || (cached_type == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RECPS_D) || (cached_type == TYPE_NEON_FP_RECPS_D_Q) || (cached_type == TYPE_NEON_FP_RECPX_S) || (cached_type == TYPE_NEON_FP_RECPX_S_Q) || (cached_type == TYPE_NEON_FP_RECPX_D) || (cached_type == TYPE_NEON_FP_RECPX_D_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_S) || (cached_type == TYPE_NEON_FP_RSQRTE_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTE_D) || (cached_type == TYPE_NEON_FP_RSQRTE_D_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_S) || (cached_type == TYPE_NEON_FP_RSQRTS_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_D) || (cached_type == TYPE_NEON_FP_RSQRTS_D_Q) || (cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MUL_D) || (cached_type == TYPE_NEON_FP_MUL_D_Q) || (cached_type == TYPE_NEON_FP_MUL_D_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MLA_S) || (cached_type == TYPE_NEON_FP_MLA_S_Q) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MLA_D) || (cached_type == TYPE_NEON_FP_MLA_D_Q) || (cached_type == TYPE_NEON_FP_MLA_D_SCALAR_Q) || (cached_type == TYPE_NEON_FP_SQRT_S) || (cached_type == TYPE_NEON_FP_SQRT_S_Q) || (cached_type == TYPE_NEON_FP_SQRT_D) || (cached_type == TYPE_NEON_FP_SQRT_D_Q) || (cached_type == TYPE_NEON_FP_DIV_S) || (cached_type == TYPE_NEON_FP_DIV_S_Q) || (cached_type == TYPE_NEON_FP_DIV_D) || (cached_type == TYPE_NEON_FP_DIV_D_Q) || (cached_type == TYPE_CRYPTO_AESE) || (cached_type == TYPE_NEON_FCADD) || (cached_type == TYPE_NEON_FCMLA) || (cached_type == TYPE_CRYPTO_AESMC) || (cached_type == TYPE_CRYPTO_SHA1_XOR) || (cached_type == TYPE_CRYPTO_SHA1_FAST) || (cached_type == TYPE_CRYPTO_SHA1_SLOW) || (cached_type == TYPE_CRYPTO_SHA256_FAST) || (cached_type == TYPE_CRYPTO_SHA256_SLOW))
        {
	  return IS_NEON_TYPE_YES;
        }
      else
        {
	  return IS_NEON_TYPE_NO;
        }

    case 2871:  /* crypto_sha1p_lb */
    case 2870:  /* crypto_sha1m_lb */
    case 2869:  /* crypto_sha1c_lb */
    case 2867:  /* crypto_sha1h_lb */
    case 2866:  /* crypto_sha256su1 */
    case 2865:  /* crypto_sha256h2 */
    case 2864:  /* crypto_sha256h */
    case 2863:  /* crypto_sha1su0 */
    case 2862:  /* crypto_sha256su0 */
    case 2861:  /* crypto_sha1su1 */
    case 2860:  /* *aarch32_crypto_aesd_fused_protected */
    case 2859:  /* *aarch32_crypto_aesd_fused */
    case 2858:  /* *aarch32_crypto_aese_fused_protected */
    case 2857:  /* *aarch32_crypto_aese_fused */
    case 2856:  /* *crypto_aesimc_protected */
    case 2855:  /* *crypto_aesmc_protected */
    case 2854:  /* aes_op_protect_neon_vld1v16qi */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2852:  /* aes_op_protect */
    case 2851:  /* *crypto_aese_insn */
    case 2850:  /* *crypto_aesd_insn */
    case 2849:  /* crypto_aesimc */
    case 2848:  /* crypto_aesmc */
    case 2847:  /* neon_vfmat_lanev8bf */
    case 2846:  /* neon_vfmab_lanev8bf */
    case 2845:  /* neon_vfmatv8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2843:  /* neon_vmmlav8bf */
    case 2840:  /* neon_vbfcvt_highv8bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2836:  /* neon_vbfcvtv4sf_highv8bf */
    case 2835:  /* neon_vbfcvtv4sfv8bf */
    case 2834:  /* neon_vbfcvtv4sfv4bf */
    case 2833:  /* neon_vbfdot_lanev8bfv4sf */
    case 2832:  /* neon_vbfdot_lanev8bfv2sf */
    case 2831:  /* neon_vbfdot_lanev4bfv4sf */
    case 2830:  /* neon_vbfdot_lanev4bfv2sf */
    case 2829:  /* neon_vbfdotv4sf */
    case 2828:  /* neon_vbfdotv2sf */
    case 2827:  /* neon_usmmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2825:  /* neon_smmlav16qi */
    case 2824:  /* neon_vabdv4sf_3 */
    case 2823:  /* neon_vabdv2sf_3 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2818:  /* neon_vabdv8hf_2 */
    case 2817:  /* neon_vabdv4hf_2 */
    case 2816:  /* neon_vec_pack_trunc_v2di */
    case 2815:  /* neon_vec_pack_trunc_v4si */
    case 2814:  /* neon_vec_pack_trunc_v8hi */
    case 2810:  /* neon_vec_umult_v2si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2808:  /* neon_vec_umult_v4hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2806:  /* neon_vec_umult_v8qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2804:  /* neon_unpacku_v2si */
    case 2803:  /* neon_unpacks_v2si */
    case 2802:  /* neon_unpacku_v4hi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2799:  /* neon_unpacks_v8qi */
    case 2798:  /* neon_vec_ushiftl_v2si */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2768:  /* neon_vst4_lanev8bf */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2763:  /* neon_vst4_lanev2sf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2758:  /* neon_vst4_lanev8qi */
    case 2757:  /* neon_vst4qbv4sf */
    case 2756:  /* neon_vst4qbv4si */
    case 2755:  /* neon_vst4qbv8bf */
    case 2754:  /* neon_vst4qbv8hf */
    case 2753:  /* neon_vst4qbv8hi */
    case 2752:  /* neon_vst4qbv16qi */
    case 2751:  /* neon_vst4qav4sf */
    case 2750:  /* neon_vst4qav4si */
    case 2749:  /* neon_vst4qav8bf */
    case 2748:  /* neon_vst4qav8hf */
    case 2747:  /* neon_vst4qav8hi */
    case 2746:  /* neon_vst4qav16qi */
    case 2745:  /* neon_vst4di */
    case 2744:  /* neon_vst4v2sf */
    case 2743:  /* neon_vst4v2si */
    case 2742:  /* neon_vst4v4bf */
    case 2741:  /* neon_vst4v4hf */
    case 2740:  /* neon_vst4v4hi */
    case 2739:  /* neon_vst4v8qi */
    case 2738:  /* neon_vld4_dupv8bf */
    case 2737:  /* neon_vld4_dupdi */
    case 2736:  /* neon_vld4_dupv2sf */
    case 2735:  /* neon_vld4_dupv2si */
    case 2734:  /* neon_vld4_dupv4bf */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2732:  /* neon_vld4_dupv4hi */
    case 2731:  /* neon_vld4_dupv8qi */
    case 2730:  /* neon_vld4_lanev8bf */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2726:  /* neon_vld4_lanev8hi */
    case 2725:  /* neon_vld4_lanev2sf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2720:  /* neon_vld4_lanev8qi */
    case 2719:  /* neon_vld4qbv4sf */
    case 2718:  /* neon_vld4qbv4si */
    case 2717:  /* neon_vld4qbv8bf */
    case 2716:  /* neon_vld4qbv8hf */
    case 2715:  /* neon_vld4qbv8hi */
    case 2714:  /* neon_vld4qbv16qi */
    case 2713:  /* neon_vld4qav4sf */
    case 2712:  /* neon_vld4qav4si */
    case 2711:  /* neon_vld4qav8bf */
    case 2710:  /* neon_vld4qav8hf */
    case 2709:  /* neon_vld4qav8hi */
    case 2708:  /* neon_vld4qav16qi */
    case 2707:  /* neon_vld4di */
    case 2706:  /* neon_vld4v2sf */
    case 2705:  /* neon_vld4v2si */
    case 2704:  /* neon_vld4v4bf */
    case 2703:  /* neon_vld4v4hf */
    case 2702:  /* neon_vld4v4hi */
    case 2701:  /* neon_vld4v8qi */
    case 2700:  /* neon_vst3_lanev8bf */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2696:  /* neon_vst3_lanev8hi */
    case 2695:  /* neon_vst3_lanev2sf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2690:  /* neon_vst3_lanev8qi */
    case 2689:  /* neon_vst3qbv4sf */
    case 2688:  /* neon_vst3qbv4si */
    case 2687:  /* neon_vst3qbv8bf */
    case 2686:  /* neon_vst3qbv8hf */
    case 2685:  /* neon_vst3qbv8hi */
    case 2684:  /* neon_vst3qbv16qi */
    case 2683:  /* neon_vst3qav4sf */
    case 2682:  /* neon_vst3qav4si */
    case 2681:  /* neon_vst3qav8bf */
    case 2680:  /* neon_vst3qav8hf */
    case 2679:  /* neon_vst3qav8hi */
    case 2678:  /* neon_vst3qav16qi */
    case 2677:  /* neon_vst3di */
    case 2676:  /* neon_vst3v2sf */
    case 2675:  /* neon_vst3v2si */
    case 2674:  /* neon_vst3v4bf */
    case 2673:  /* neon_vst3v4hf */
    case 2672:  /* neon_vst3v4hi */
    case 2671:  /* neon_vst3v8qi */
    case 2670:  /* neon_vld3_dupv8bf */
    case 2669:  /* neon_vld3_dupdi */
    case 2668:  /* neon_vld3_dupv2sf */
    case 2667:  /* neon_vld3_dupv2si */
    case 2666:  /* neon_vld3_dupv4bf */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2664:  /* neon_vld3_dupv4hi */
    case 2663:  /* neon_vld3_dupv8qi */
    case 2662:  /* neon_vld3_lanev8bf */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2658:  /* neon_vld3_lanev8hi */
    case 2657:  /* neon_vld3_lanev2sf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2652:  /* neon_vld3_lanev8qi */
    case 2651:  /* neon_vld3qbv4sf */
    case 2650:  /* neon_vld3qbv4si */
    case 2649:  /* neon_vld3qbv8bf */
    case 2648:  /* neon_vld3qbv8hf */
    case 2647:  /* neon_vld3qbv8hi */
    case 2646:  /* neon_vld3qbv16qi */
    case 2645:  /* neon_vld3qav4sf */
    case 2644:  /* neon_vld3qav4si */
    case 2643:  /* neon_vld3qav8bf */
    case 2642:  /* neon_vld3qav8hf */
    case 2641:  /* neon_vld3qav8hi */
    case 2640:  /* neon_vld3qav16qi */
    case 2639:  /* neon_vld3di */
    case 2638:  /* neon_vld3v2sf */
    case 2637:  /* neon_vld3v2si */
    case 2636:  /* neon_vld3v4bf */
    case 2635:  /* neon_vld3v4hf */
    case 2634:  /* neon_vld3v4hi */
    case 2633:  /* neon_vld3v8qi */
    case 2632:  /* neon_vst2_lanev8bf */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2628:  /* neon_vst2_lanev8hi */
    case 2627:  /* neon_vst2_lanev2sf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2622:  /* neon_vst2_lanev8qi */
    case 2621:  /* neon_vst2v4sf */
    case 2620:  /* neon_vst2v4si */
    case 2619:  /* neon_vst2v8bf */
    case 2618:  /* neon_vst2v8hf */
    case 2617:  /* neon_vst2v8hi */
    case 2616:  /* neon_vst2v16qi */
    case 2615:  /* neon_vst2di */
    case 2614:  /* neon_vst2v2sf */
    case 2613:  /* neon_vst2v2si */
    case 2612:  /* neon_vst2v4bf */
    case 2611:  /* neon_vst2v4hf */
    case 2610:  /* neon_vst2v4hi */
    case 2609:  /* neon_vst2v8qi */
    case 2608:  /* neon_vld2_dupv8bf */
    case 2607:  /* neon_vld2_dupdi */
    case 2606:  /* neon_vld2_dupv2sf */
    case 2605:  /* neon_vld2_dupv2si */
    case 2604:  /* neon_vld2_dupv4bf */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2602:  /* neon_vld2_dupv4hi */
    case 2601:  /* neon_vld2_dupv8qi */
    case 2600:  /* neon_vld2_lanev8bf */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2596:  /* neon_vld2_lanev8hi */
    case 2595:  /* neon_vld2_lanev2sf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2590:  /* neon_vld2_lanev8qi */
    case 2589:  /* neon_vld2v4sf */
    case 2588:  /* neon_vld2v4si */
    case 2587:  /* neon_vld2v8bf */
    case 2586:  /* neon_vld2v8hf */
    case 2585:  /* neon_vld2v8hi */
    case 2584:  /* neon_vld2v16qi */
    case 2583:  /* neon_vld2di */
    case 2582:  /* neon_vld2v2sf */
    case 2581:  /* neon_vld2v2si */
    case 2580:  /* neon_vld2v4bf */
    case 2579:  /* neon_vld2v4hf */
    case 2578:  /* neon_vld2v4hi */
    case 2577:  /* neon_vld2v8qi */
    case 2576:  /* neon_vst1_lanev2di */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2570:  /* neon_vst1_lanev16qi */
    case 2569:  /* neon_vst1_lanedi */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2563:  /* neon_vst1_lanev8qi */
    case 2562:  /* neon_vst1v2di */
    case 2561:  /* neon_vst1di */
    case 2560:  /* neon_vst1v4sf */
    case 2559:  /* neon_vst1v2sf */
    case 2558:  /* neon_vst1v8bf */
    case 2557:  /* neon_vst1v4bf */
    case 2556:  /* neon_vst1v8hf */
    case 2555:  /* neon_vst1v4hf */
    case 2554:  /* neon_vst1v4si */
    case 2553:  /* neon_vst1v2si */
    case 2552:  /* neon_vst1v8hi */
    case 2551:  /* neon_vst1v4hi */
    case 2550:  /* neon_vst1v16qi */
    case 2549:  /* neon_vst1v8qi */
    case 2548:  /* neon_vld1_dupv2di */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2543:  /* neon_vld1_dupv16qi */
    case 2542:  /* neon_vld1_dupv2sf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2537:  /* neon_vld1_dupv8qi */
    case 2536:  /* neon_vld1_lanev2di */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2530:  /* neon_vld1_lanev16qi */
    case 2529:  /* neon_vld1_lanedi */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2523:  /* neon_vld1_lanev8qi */
    case 2522:  /* neon_vld1v2di */
    case 2521:  /* neon_vld1di */
    case 2520:  /* neon_vld1v4sf */
    case 2519:  /* neon_vld1v2sf */
    case 2518:  /* neon_vld1v8bf */
    case 2517:  /* neon_vld1v4bf */
    case 2516:  /* neon_vld1v8hf */
    case 2515:  /* neon_vld1v4hf */
    case 2514:  /* neon_vld1v4si */
    case 2513:  /* neon_vld1v2si */
    case 2512:  /* neon_vld1v8hi */
    case 2511:  /* neon_vld1v4hi */
    case 2510:  /* neon_vld1v16qi */
    case 2509:  /* neon_vld1v8qi */
    case 2508:  /* *neon_vuzpv4hf_insn */
    case 2507:  /* *neon_vuzpv8hf_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2490:  /* *neon_vzipv16qi_insn */
    case 2489:  /* *neon_vzipv8qi_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
    case 2487:  /* *neon_vtrnv8hf_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2478:  /* neon_vtbx4v8qi */
    case 2477:  /* neon_vtbx3v8qi */
    case 2476:  /* neon_vtbx2v8qi */
    case 2475:  /* neon_vtbx1v8qi */
    case 2471:  /* neon_vtbl4v8qi */
    case 2470:  /* neon_vtbl3v8qi */
    case 2469:  /* neon_vtbl2v8qi */
    case 2468:  /* neon_vtbl1v8qi */
    case 2467:  /* neon_vsli_nv2di */
    case 2466:  /* neon_vsli_ndi */
    case 2465:  /* neon_vsli_nv4si */
    case 2464:  /* neon_vsli_nv2si */
    case 2463:  /* neon_vsli_nv8hi */
    case 2462:  /* neon_vsli_nv4hi */
    case 2461:  /* neon_vsli_nv16qi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2459:  /* neon_vsri_nv2di */
    case 2458:  /* neon_vsri_ndi */
    case 2457:  /* neon_vsri_nv4si */
    case 2456:  /* neon_vsri_nv2si */
    case 2455:  /* neon_vsri_nv8hi */
    case 2454:  /* neon_vsri_nv4hi */
    case 2453:  /* neon_vsri_nv16qi */
    case 2452:  /* neon_vsri_nv8qi */
    case 2451:  /* neon_vrsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2448:  /* neon_vsras_nv2di */
    case 2447:  /* neon_vrsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2444:  /* neon_vsras_ndi */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2440:  /* neon_vsras_nv4si */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2436:  /* neon_vsras_nv2si */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2424:  /* neon_vsras_nv16qi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2420:  /* neon_vsras_nv8qi */
    case 2419:  /* neon_vshllu_nv2si */
    case 2418:  /* neon_vshlls_nv2si */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2413:  /* neon_vqshlu_nv2di */
    case 2412:  /* neon_vqshlu_ndi */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2389:  /* neon_vshl_nv2di */
    case 2388:  /* neon_vshl_ndi */
    case 2387:  /* neon_vshl_nv4si */
    case 2386:  /* neon_vshl_nv2si */
    case 2385:  /* neon_vshl_nv8hi */
    case 2384:  /* neon_vshl_nv4hi */
    case 2383:  /* neon_vshl_nv16qi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2381:  /* neon_vqrshrun_nv2di */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2363:  /* neon_vrshrn_nv2di */
    case 2362:  /* neon_vshrn_nv2di */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2360:  /* neon_vshrn_nv4si */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2357:  /* neon_vrshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2354:  /* neon_vshrs_nv2di */
    case 2353:  /* neon_vrshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2350:  /* neon_vshrs_ndi */
    case 2349:  /* neon_vrshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2346:  /* neon_vshrs_nv4si */
    case 2345:  /* neon_vrshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2342:  /* neon_vshrs_nv2si */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2325:  /* neon_vqrshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2322:  /* neon_vqshlsv2di */
    case 2321:  /* neon_vqrshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2318:  /* neon_vqshlsdi */
    case 2317:  /* neon_vqrshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2314:  /* neon_vqshlsv4si */
    case 2313:  /* neon_vqrshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2310:  /* neon_vqshlsv2si */
    case 2309:  /* neon_vqrshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2305:  /* neon_vqrshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2298:  /* neon_vqshlsv16qi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2294:  /* neon_vqshlsv8qi */
    case 2293:  /* neon_vrshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2290:  /* neon_vshlsv2di */
    case 2289:  /* neon_vrshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2287:  /* neon_vshludi */
    case 2286:  /* neon_vshlsdi */
    case 2285:  /* neon_vrshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2282:  /* neon_vshlsv4si */
    case 2281:  /* neon_vrshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2278:  /* neon_vshlsv2si */
    case 2277:  /* neon_vrshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2274:  /* neon_vshlsv8hi */
    case 2273:  /* neon_vrshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2270:  /* neon_vshlsv4hi */
    case 2269:  /* neon_vrshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2266:  /* neon_vshlsv16qi */
    case 2265:  /* neon_vrshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2262:  /* neon_vshlsv8qi */
    case 2261:  /* neon_vbslv2di_internal */
    case 2260:  /* neon_vbsldi_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2249:  /* neon_vbslv16qi_internal */
    case 2248:  /* neon_vbslv8qi_internal */
    case 2247:  /* neon_vrev16v16qi */
    case 2246:  /* neon_vrev16v8qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2244:  /* neon_vrev32v16qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2242:  /* neon_vrev32v8qi */
    case 2241:  /* neon_vrev64v2di */
    case 2240:  /* neon_vrev64v4sf */
    case 2239:  /* neon_vrev64v2sf */
    case 2238:  /* neon_vrev64v8hf */
    case 2237:  /* neon_vrev64v4hf */
    case 2236:  /* neon_vrev64v4si */
    case 2235:  /* neon_vrev64v2si */
    case 2234:  /* neon_vrev64v8hi */
    case 2233:  /* neon_vrev64v4hi */
    case 2232:  /* neon_vrev64v16qi */
    case 2231:  /* neon_vrev64v8qi */
    case 2230:  /* neon_vextv2di */
    case 2229:  /* neon_vextdi */
    case 2228:  /* neon_vextv4sf */
    case 2227:  /* neon_vextv2sf */
    case 2226:  /* neon_vextv8bf */
    case 2225:  /* neon_vextv4bf */
    case 2224:  /* neon_vextv8hf */
    case 2223:  /* neon_vextv4hf */
    case 2222:  /* neon_vextv4si */
    case 2221:  /* neon_vextv2si */
    case 2220:  /* neon_vextv8hi */
    case 2219:  /* neon_vextv4hi */
    case 2218:  /* neon_vextv16qi */
    case 2217:  /* neon_vextv8qi */
    case 2216:  /* neon_vqdmlsl_lanev2si */
    case 2215:  /* neon_vqdmlsl_lanev4hi */
    case 2214:  /* neon_vmlslu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2212:  /* neon_vmlslu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2210:  /* neon_vmls_lanev4sf */
    case 2209:  /* neon_vmls_lanev4si */
    case 2208:  /* neon_vmls_lanev8hi */
    case 2207:  /* neon_vmls_lanev2sf */
    case 2206:  /* neon_vmls_lanev2si */
    case 2205:  /* neon_vmls_lanev4hi */
    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2201:  /* neon_vmlals_lanev2si */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2199:  /* neon_vmlals_lanev4hi */
    case 2198:  /* neon_vmla_lanev4sf */
    case 2197:  /* neon_vmla_lanev4si */
    case 2196:  /* neon_vmla_lanev8hi */
    case 2195:  /* neon_vmla_lanev2sf */
    case 2194:  /* neon_vmla_lanev2si */
    case 2193:  /* neon_vmla_lanev4hi */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
    case 2189:  /* neon_vqrdmlah_lanev4hi */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
    case 2187:  /* neon_vqrdmlah_lanev4si */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
    case 2185:  /* neon_vqrdmlah_lanev8hi */
    case 2184:  /* neon_vqrdmulh_lanev2si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 2176:  /* neon_vqdmull_lanev2si */
    case 2175:  /* neon_vqdmull_lanev4hi */
    case 2174:  /* neon_vmullu_lanev2si */
    case 2173:  /* neon_vmulls_lanev2si */
    case 2172:  /* neon_vmullu_lanev4hi */
    case 2171:  /* neon_vmulls_lanev4hi */
    case 2170:  /* neon_vmul_lanev4hf */
    case 2169:  /* neon_vmul_lanev8hf */
    case 2168:  /* neon_vmul_lanev4sf */
    case 2167:  /* neon_vmul_lanev4si */
    case 2166:  /* neon_vmul_lanev8hi */
    case 2165:  /* neon_vmul_lanev2sf */
    case 2164:  /* neon_vmul_lanev2si */
    case 2163:  /* neon_vmul_lanev4hi */
    case 2162:  /* neon_vmovluv2si */
    case 2161:  /* neon_vmovlsv2si */
    case 2160:  /* neon_vmovluv4hi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2158:  /* neon_vmovluv8qi */
    case 2157:  /* neon_vmovlsv8qi */
    case 2156:  /* neon_vqmovunv2di */
    case 2155:  /* neon_vqmovunv4si */
    case 2154:  /* neon_vqmovunv8hi */
    case 2153:  /* neon_vqmovnuv2di */
    case 2152:  /* neon_vqmovnsv2di */
    case 2151:  /* neon_vqmovnuv4si */
    case 2150:  /* neon_vqmovnsv4si */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2148:  /* neon_vqmovnsv8hi */
    case 2147:  /* neon_vmovnv2di */
    case 2146:  /* neon_vmovnv4si */
    case 2145:  /* neon_vmovnv8hi */
    case 2144:  /* neon_vcvtpuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2136:  /* neon_vcvtpuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2128:  /* neon_vcvtu_nv8hi */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2126:  /* neon_vcvtu_nv4hi */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2123:  /* neon_vcvts_nv4si */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2121:  /* neon_vcvts_nv2si */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2108:  /* neon_vcvtuv8hi */
    case 2107:  /* neon_vcvtsv8hi */
    case 2106:  /* neon_vcvtuv4hi */
    case 2105:  /* neon_vcvtsv4hi */
    case 2104:  /* neon_vcvtv4hfv4sf */
    case 2103:  /* neon_vcvtv4sfv4hf */
    case 2102:  /* neon_vcvtuv4si */
    case 2101:  /* neon_vcvtsv4si */
    case 2100:  /* neon_vcvtuv2si */
    case 2099:  /* neon_vcvtsv2si */
    case 2098:  /* neon_vcvtuv4sf */
    case 2097:  /* neon_vcvtsv4sf */
    case 2096:  /* neon_vcvtuv2sf */
    case 2095:  /* neon_vcvtsv2sf */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2088:  /* floatv4siv4sf2 */
    case 2087:  /* floatv2siv2sf2 */
    case 2079:  /* *neon_vswpv2di */
    case 2078:  /* *neon_vswpdi */
    case 2077:  /* *neon_vswpv4sf */
    case 2076:  /* *neon_vswpv2sf */
    case 2075:  /* *neon_vswpv8bf */
    case 2074:  /* *neon_vswpv4bf */
    case 2073:  /* *neon_vswpv8hf */
    case 2072:  /* *neon_vswpv4hf */
    case 2071:  /* *neon_vswpv4si */
    case 2070:  /* *neon_vswpv2si */
    case 2069:  /* *neon_vswpv8hi */
    case 2068:  /* *neon_vswpv4hi */
    case 2067:  /* *neon_vswpv16qi */
    case 2066:  /* *neon_vswpv8qi */
    case 2065:  /* neon_vdup_lanev8bf_internal */
    case 2064:  /* neon_vdup_lanev4bf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 2052:  /* neon_vdup_nv4sf */
    case 2051:  /* neon_vdup_nv4si */
    case 2050:  /* neon_vdup_nv2sf */
    case 2049:  /* neon_vdup_nv2si */
    case 2048:  /* neon_vdup_nv8bf */
    case 2047:  /* neon_vdup_nv4bf */
    case 2046:  /* neon_vdup_nv8hf */
    case 2045:  /* neon_vdup_nv4hf */
    case 2044:  /* neon_vdup_nv8hi */
    case 2043:  /* neon_vdup_nv16qi */
    case 2042:  /* neon_vdup_nv4hi */
    case 2041:  /* neon_vdup_nv8qi */
    case 2040:  /* neon_vget_lanev4sf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2031:  /* neon_vget_lanev16qi_sext_internal */
    case 2030:  /* neon_vget_lanev2sf_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2023:  /* neon_vget_lanev8qi_sext_internal */
    case 2022:  /* neon_vrsqrtev4sf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2020:  /* neon_vrsqrtev2sf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2018:  /* neon_vrecpev4sf */
    case 2017:  /* neon_vrecpev4si */
    case 2016:  /* neon_vrecpev2sf */
    case 2015:  /* neon_vrecpev2si */
    case 2014:  /* neon_vrecpev4hf */
    case 2013:  /* neon_vrecpev8hf */
    case 2012:  /* popcountv16qi2 */
    case 2011:  /* popcountv8qi2 */
    case 2010:  /* neon_vclzv4si */
    case 2009:  /* neon_vclzv2si */
    case 2008:  /* neon_vclzv8hi */
    case 2007:  /* neon_vclzv4hi */
    case 2006:  /* neon_vclzv16qi */
    case 2005:  /* neon_vclzv8qi */
    case 2004:  /* neon_vclsv4si */
    case 2003:  /* neon_vclsv2si */
    case 2002:  /* neon_vclsv8hi */
    case 2001:  /* neon_vclsv4hi */
    case 2000:  /* neon_vclsv16qi */
    case 1999:  /* neon_vclsv8qi */
    case 1998:  /* neon_vqnegv4si */
    case 1997:  /* neon_vqnegv2si */
    case 1996:  /* neon_vqnegv8hi */
    case 1995:  /* neon_vqnegv4hi */
    case 1994:  /* neon_vqnegv16qi */
    case 1993:  /* neon_vqnegv8qi */
    case 1992:  /* neon_sudot_laneqv16qi */
    case 1991:  /* neon_usdot_laneqv16qi */
    case 1990:  /* neon_sudot_laneqv8qi */
    case 1989:  /* neon_usdot_laneqv8qi */
    case 1988:  /* neon_sudot_lanev16qi */
    case 1987:  /* neon_usdot_lanev16qi */
    case 1986:  /* neon_sudot_lanev8qi */
    case 1985:  /* neon_usdot_lanev8qi */
    case 1984:  /* neon_udot_laneqv16qi */
    case 1983:  /* neon_sdot_laneqv16qi */
    case 1982:  /* neon_udot_laneqv8qi */
    case 1981:  /* neon_sdot_laneqv8qi */
    case 1980:  /* neon_udot_lanev16qi */
    case 1979:  /* neon_sdot_lanev16qi */
    case 1978:  /* neon_udot_lanev8qi */
    case 1977:  /* neon_sdot_lanev8qi */
    case 1976:  /* neon_usdotv16qi */
    case 1975:  /* neon_usdotv8qi */
    case 1974:  /* udot_prodv16qi */
    case 1973:  /* sdot_prodv16qi */
    case 1972:  /* udot_prodv8qi */
    case 1971:  /* sdot_prodv8qi */
    case 1970:  /* neon_vcmlaq_lane270v4sf */
    case 1969:  /* neon_vcmlaq_lane180v4sf */
    case 1968:  /* neon_vcmlaq_lane90v4sf */
    case 1967:  /* neon_vcmlaq_lane0v4sf */
    case 1966:  /* neon_vcmlaq_lane270v8hf */
    case 1965:  /* neon_vcmlaq_lane180v8hf */
    case 1964:  /* neon_vcmlaq_lane90v8hf */
    case 1963:  /* neon_vcmlaq_lane0v8hf */
    case 1962:  /* neon_vcmla_laneq270v4hf */
    case 1961:  /* neon_vcmla_laneq180v4hf */
    case 1960:  /* neon_vcmla_laneq90v4hf */
    case 1959:  /* neon_vcmla_laneq0v4hf */
    case 1958:  /* neon_vcmla_laneq270v2sf */
    case 1957:  /* neon_vcmla_laneq180v2sf */
    case 1956:  /* neon_vcmla_laneq90v2sf */
    case 1955:  /* neon_vcmla_laneq0v2sf */
    case 1954:  /* neon_vcmla_lane270v4sf */
    case 1953:  /* neon_vcmla_lane180v4sf */
    case 1952:  /* neon_vcmla_lane90v4sf */
    case 1951:  /* neon_vcmla_lane0v4sf */
    case 1950:  /* neon_vcmla_lane270v2sf */
    case 1949:  /* neon_vcmla_lane180v2sf */
    case 1948:  /* neon_vcmla_lane90v2sf */
    case 1947:  /* neon_vcmla_lane0v2sf */
    case 1946:  /* neon_vcmla_lane270v8hf */
    case 1945:  /* neon_vcmla_lane180v8hf */
    case 1944:  /* neon_vcmla_lane90v8hf */
    case 1943:  /* neon_vcmla_lane0v8hf */
    case 1942:  /* neon_vcmla_lane270v4hf */
    case 1941:  /* neon_vcmla_lane180v4hf */
    case 1940:  /* neon_vcmla_lane90v4hf */
    case 1939:  /* neon_vcmla_lane0v4hf */
    case 1938:  /* neon_vcmla270v4sf */
    case 1937:  /* neon_vcmla180v4sf */
    case 1936:  /* neon_vcmla90v4sf */
    case 1935:  /* neon_vcmla0v4sf */
    case 1934:  /* neon_vcmla270v2sf */
    case 1933:  /* neon_vcmla180v2sf */
    case 1932:  /* neon_vcmla90v2sf */
    case 1931:  /* neon_vcmla0v2sf */
    case 1930:  /* neon_vcmla270v8hf */
    case 1929:  /* neon_vcmla180v8hf */
    case 1928:  /* neon_vcmla90v8hf */
    case 1927:  /* neon_vcmla0v8hf */
    case 1926:  /* neon_vcmla270v4hf */
    case 1925:  /* neon_vcmla180v4hf */
    case 1924:  /* neon_vcmla90v4hf */
    case 1923:  /* neon_vcmla0v4hf */
    case 1922:  /* neon_vcadd270v4sf */
    case 1921:  /* neon_vcadd90v4sf */
    case 1920:  /* neon_vcadd270v2sf */
    case 1919:  /* neon_vcadd90v2sf */
    case 1918:  /* neon_vcadd270v8hf */
    case 1917:  /* neon_vcadd90v8hf */
    case 1916:  /* neon_vcadd270v4hf */
    case 1915:  /* neon_vcadd90v4hf */
    case 1914:  /* neon_bswapv2di */
    case 1913:  /* neon_bswapv4si */
    case 1912:  /* neon_bswapv2si */
    case 1911:  /* neon_bswapv8hi */
    case 1910:  /* neon_bswapv4hi */
    case 1909:  /* neon_vqabsv4si */
    case 1908:  /* neon_vqabsv2si */
    case 1907:  /* neon_vqabsv8hi */
    case 1906:  /* neon_vqabsv4hi */
    case 1905:  /* neon_vqabsv16qi */
    case 1904:  /* neon_vqabsv8qi */
    case 1903:  /* neon_vrsqrtsv4hf */
    case 1902:  /* neon_vrsqrtsv8hf */
    case 1901:  /* neon_vrsqrtsv4sf */
    case 1900:  /* neon_vrsqrtsv2sf */
    case 1899:  /* neon_vrecpsv4hf */
    case 1898:  /* neon_vrecpsv8hf */
    case 1897:  /* neon_vrecpsv4sf */
    case 1896:  /* neon_vrecpsv2sf */
    case 1895:  /* neon_vpminfv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1893:  /* neon_vpminfv2sf */
    case 1892:  /* neon_vpmaxfv2sf */
    case 1891:  /* neon_vpminuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1888:  /* neon_vpmaxsv2si */
    case 1887:  /* neon_vpminuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1883:  /* neon_vpminuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1879:  /* neon_vpadaluv4si */
    case 1878:  /* neon_vpadalsv4si */
    case 1877:  /* neon_vpadaluv2si */
    case 1876:  /* neon_vpadalsv2si */
    case 1875:  /* neon_vpadaluv8hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1868:  /* neon_vpadalsv8qi */
    case 1867:  /* neon_vpaddluv4si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1865:  /* neon_vpaddluv2si */
    case 1864:  /* neon_vpaddlsv2si */
    case 1863:  /* neon_vpaddluv8hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1856:  /* neon_vpaddlsv8qi */
    case 1855:  /* fminv4sf3 */
    case 1854:  /* fmaxv4sf3 */
    case 1853:  /* fminv2sf3 */
    case 1852:  /* fmaxv2sf3 */
    case 1851:  /* neon_vminnmv4sf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1849:  /* neon_vminnmv2sf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1847:  /* neon_vminnmv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1845:  /* neon_vminnmv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1843:  /* neon_vpminfv4hf */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1841:  /* neon_vminfv4hf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1839:  /* neon_vminfv8hf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1837:  /* neon_vminfv4sf */
    case 1836:  /* neon_vmaxfv4sf */
    case 1835:  /* neon_vminfv2sf */
    case 1834:  /* neon_vmaxfv2sf */
    case 1833:  /* neon_vminuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1830:  /* neon_vmaxsv4si */
    case 1829:  /* neon_vminuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1826:  /* neon_vmaxsv2si */
    case 1825:  /* neon_vminuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1821:  /* neon_vminuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1817:  /* neon_vminuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1814:  /* neon_vmaxsv16qi */
    case 1813:  /* neon_vminuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1810:  /* neon_vmaxsv8qi */
    case 1809:  /* neon_vabaluv2si */
    case 1808:  /* neon_vabalsv2si */
    case 1807:  /* neon_vabaluv4hi */
    case 1806:  /* neon_vabalsv4hi */
    case 1805:  /* neon_vabaluv8qi */
    case 1804:  /* neon_vabalsv8qi */
    case 1803:  /* neon_vabauv4si */
    case 1802:  /* neon_vabasv4si */
    case 1801:  /* neon_vabauv2si */
    case 1800:  /* neon_vabasv2si */
    case 1799:  /* neon_vabauv8hi */
    case 1798:  /* neon_vabasv8hi */
    case 1797:  /* neon_vabauv4hi */
    case 1796:  /* neon_vabasv4hi */
    case 1795:  /* neon_vabauv16qi */
    case 1794:  /* neon_vabasv16qi */
    case 1793:  /* neon_vabauv8qi */
    case 1792:  /* neon_vabasv8qi */
    case 1791:  /* neon_vabdluv2si */
    case 1790:  /* neon_vabdlsv2si */
    case 1789:  /* neon_vabdluv4hi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1787:  /* neon_vabdluv8qi */
    case 1786:  /* neon_vabdlsv8qi */
    case 1785:  /* neon_vabdfv4sf */
    case 1784:  /* neon_vabdfv2sf */
    case 1783:  /* neon_vabdv4hf */
    case 1782:  /* neon_vabdv8hf */
    case 1781:  /* neon_vabduv4si */
    case 1780:  /* neon_vabdsv4si */
    case 1779:  /* neon_vabduv2si */
    case 1778:  /* neon_vabdsv2si */
    case 1777:  /* neon_vabduv8hi */
    case 1776:  /* neon_vabdsv8hi */
    case 1775:  /* neon_vabduv4hi */
    case 1774:  /* neon_vabdsv4hi */
    case 1773:  /* neon_vabduv16qi */
    case 1772:  /* neon_vabdsv16qi */
    case 1771:  /* neon_vabduv8qi */
    case 1770:  /* neon_vabdsv8qi */
    case 1769:  /* neon_vtst_combinev4si */
    case 1768:  /* neon_vtst_combinev2si */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1765:  /* neon_vtst_combinev16qi */
    case 1764:  /* neon_vtst_combinev8qi */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1731:  /* neon_vcgeuv4si */
    case 1730:  /* neon_vcgtuv4si */
    case 1729:  /* neon_vcgeuv2si */
    case 1728:  /* neon_vcgtuv2si */
    case 1727:  /* neon_vcgeuv8hi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1725:  /* neon_vcgeuv4hi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1722:  /* neon_vcgtuv16qi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1720:  /* neon_vcgtuv8qi */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1690:  /* neon_vceqv2sf_insn_unspec */
    case 1649:  /* neon_vrsubhnv2di */
    case 1648:  /* neon_vsubhnv2di */
    case 1647:  /* neon_vrsubhnv4si */
    case 1646:  /* neon_vsubhnv4si */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1644:  /* neon_vsubhnv8hi */
    case 1643:  /* neon_vhsubuv4si */
    case 1642:  /* neon_vhsubsv4si */
    case 1641:  /* neon_vhsubuv2si */
    case 1640:  /* neon_vhsubsv2si */
    case 1639:  /* neon_vhsubuv8hi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1637:  /* neon_vhsubuv4hi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1634:  /* neon_vhsubsv16qi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1632:  /* neon_vhsubsv8qi */
    case 1631:  /* neon_vqsubuv2di */
    case 1630:  /* neon_vqsubsv2di */
    case 1629:  /* neon_vqsubudi */
    case 1628:  /* neon_vqsubsdi */
    case 1627:  /* neon_vqsubuv4si */
    case 1626:  /* neon_vqsubsv4si */
    case 1625:  /* neon_vqsubuv2si */
    case 1624:  /* neon_vqsubsv2si */
    case 1623:  /* neon_vqsubuv8hi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1621:  /* neon_vqsubuv4hi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1618:  /* neon_vqsubsv16qi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1616:  /* neon_vqsubsv8qi */
    case 1615:  /* neon_vsubwuv2si */
    case 1614:  /* neon_vsubwsv2si */
    case 1613:  /* neon_vsubwuv4hi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1610:  /* neon_vsubwsv8qi */
    case 1609:  /* neon_vsubluv2si */
    case 1608:  /* neon_vsublsv2si */
    case 1607:  /* neon_vsubluv4hi */
    case 1606:  /* neon_vsublsv4hi */
    case 1605:  /* neon_vsubluv8qi */
    case 1604:  /* neon_vsublsv8qi */
    case 1603:  /* neon_vsubv4sf_unspec */
    case 1602:  /* neon_vsubv2sf_unspec */
    case 1601:  /* neon_vqdmullv2si */
    case 1600:  /* neon_vqdmullv4hi */
    case 1599:  /* neon_vmullpv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1597:  /* neon_vmullsv2si */
    case 1596:  /* neon_vmullpv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1594:  /* neon_vmullsv4hi */
    case 1593:  /* neon_vmullpv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1591:  /* neon_vmullsv8qi */
    case 1590:  /* neon_vqdmlslv2si */
    case 1589:  /* neon_vqdmlslv4hi */
    case 1588:  /* neon_vqdmlalv2si */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1581:  /* neon_vqrdmlahv2si */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1579:  /* neon_vqrdmlahv4hi */
    case 1578:  /* neon_vqrdmulhv4si */
    case 1577:  /* neon_vqdmulhv4si */
    case 1576:  /* neon_vqrdmulhv8hi */
    case 1575:  /* neon_vqdmulhv8hi */
    case 1574:  /* neon_vqrdmulhv2si */
    case 1573:  /* neon_vqdmulhv2si */
    case 1572:  /* neon_vqrdmulhv4hi */
    case 1571:  /* neon_vqdmulhv4hi */
    case 1570:  /* neon_vmlsluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1568:  /* neon_vmlsluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1566:  /* neon_vmlsluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1564:  /* neon_vmlsv4sf_unspec */
    case 1563:  /* neon_vmlsv2sf_unspec */
    case 1562:  /* neon_vmlsv4si_unspec */
    case 1561:  /* neon_vmlsv2si_unspec */
    case 1560:  /* neon_vmlsv8hi_unspec */
    case 1559:  /* neon_vmlsv4hi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
    case 1556:  /* neon_vmlaluv2si */
    case 1555:  /* neon_vmlalsv2si */
    case 1554:  /* neon_vmlaluv4hi */
    case 1553:  /* neon_vmlalsv4hi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1551:  /* neon_vmlalsv8qi */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1518:  /* neon_vmulfv4hf */
    case 1517:  /* neon_vmulfv8hf */
    case 1516:  /* neon_vmulfv4sf */
    case 1515:  /* neon_vmulfv2sf */
    case 1514:  /* neon_vmulpv16qi */
    case 1513:  /* neon_vmulpv8qi */
    case 1512:  /* neon_vraddhnv2di */
    case 1511:  /* neon_vaddhnv2di */
    case 1510:  /* neon_vraddhnv4si */
    case 1509:  /* neon_vaddhnv4si */
    case 1508:  /* neon_vraddhnv8hi */
    case 1507:  /* neon_vaddhnv8hi */
    case 1506:  /* neon_vqadduv2di */
    case 1505:  /* neon_vqaddsv2di */
    case 1504:  /* neon_vqaddudi */
    case 1503:  /* neon_vqaddsdi */
    case 1502:  /* neon_vqadduv4si */
    case 1501:  /* neon_vqaddsv4si */
    case 1500:  /* neon_vqadduv2si */
    case 1499:  /* neon_vqaddsv2si */
    case 1498:  /* neon_vqadduv8hi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1496:  /* neon_vqadduv4hi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1494:  /* neon_vqadduv16qi */
    case 1493:  /* neon_vqaddsv16qi */
    case 1492:  /* neon_vqadduv8qi */
    case 1491:  /* neon_vqaddsv8qi */
    case 1490:  /* neon_vhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1486:  /* neon_vhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1483:  /* neon_vrhaddsv2si */
    case 1482:  /* neon_vhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1474:  /* neon_vhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1467:  /* neon_vrhaddsv8qi */
    case 1466:  /* neon_vaddwuv2si */
    case 1465:  /* neon_vaddwsv2si */
    case 1464:  /* neon_vaddwuv4hi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1461:  /* neon_vaddwsv8qi */
    case 1460:  /* neon_vaddluv2si */
    case 1459:  /* neon_vaddlsv2si */
    case 1458:  /* neon_vaddluv4hi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1456:  /* neon_vaddluv8qi */
    case 1455:  /* neon_vaddlsv8qi */
    case 1454:  /* neon_vaddv4sf_unspec */
    case 1453:  /* neon_vaddv2sf_unspec */
    case 1452:  /* *us_subv2sf_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1445:  /* *ss_subv8qi_neon */
    case 1444:  /* *us_addv2sf_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1437:  /* *ss_addv8qi_neon */
    case 1436:  /* neon_vpumaxv2si */
    case 1435:  /* neon_vpumaxv4hi */
    case 1434:  /* neon_vpumaxv8qi */
    case 1433:  /* neon_vpuminv2si */
    case 1432:  /* neon_vpuminv4hi */
    case 1431:  /* neon_vpuminv8qi */
    case 1430:  /* neon_vpsmaxv2sf */
    case 1429:  /* neon_vpsmaxv2si */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1426:  /* neon_vpsminv2sf */
    case 1425:  /* neon_vpsminv2si */
    case 1424:  /* neon_vpsminv4hi */
    case 1423:  /* neon_vpsminv8qi */
    case 1422:  /* neon_vpaddv4hf */
    case 1421:  /* neon_vpadd_internalv2sf */
    case 1420:  /* neon_vpadd_internalv2si */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1418:  /* neon_vpadd_internalv8qi */
    case 1417:  /* arm_reduc_plus_internal_v2di */
    case 1416:  /* quad_halves_umaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1412:  /* quad_halves_plusv16qi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1408:  /* quad_halves_sminv8hi */
    case 1407:  /* quad_halves_plusv8hi */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1405:  /* quad_halves_sminv4sf */
    case 1404:  /* quad_halves_plusv4sf */
    case 1403:  /* quad_halves_umaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1400:  /* quad_halves_sminv4si */
    case 1399:  /* quad_halves_plusv4si */
    case 1398:  /* widen_usumv2si3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
    case 1380:  /* neon_load_count */
    case 1379:  /* ashlv2di3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1377:  /* ashlv2si3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1372:  /* ashlv2di3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1370:  /* ashlv2si3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1367:  /* ashlv16qi3_signed */
    case 1366:  /* ashlv8qi3_signed */
    case 1365:  /* vlshrv4si3_imm */
    case 1364:  /* vlshrv2si3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1355:  /* vashrv16qi3_imm */
    case 1354:  /* vashrv8qi3_imm */
    case 1353:  /* *smaxv4sf3_neon */
    case 1352:  /* *smaxv2sf3_neon */
    case 1351:  /* *smaxv4si3_neon */
    case 1350:  /* *smaxv2si3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1345:  /* *sminv4sf3_neon */
    case 1344:  /* *sminv2sf3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1339:  /* *sminv16qi3_neon */
    case 1338:  /* *sminv8qi3_neon */
    case 1337:  /* *umaxv4si3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1327:  /* *uminv16qi3_neon */
    case 1326:  /* *uminv8qi3_neon */
    case 1325:  /* neon_vrsqrtev4hf */
    case 1324:  /* neon_vrsqrtev8hf */
    case 1323:  /* neon_vrndxv4hf */
    case 1322:  /* neon_vrndpv4hf */
    case 1321:  /* neon_vrndnv4hf */
    case 1320:  /* neon_vrndmv4hf */
    case 1319:  /* neon_vrndav4hf */
    case 1318:  /* neon_vrndv4hf */
    case 1317:  /* neon_vrndxv8hf */
    case 1316:  /* neon_vrndpv8hf */
    case 1315:  /* neon_vrndnv8hf */
    case 1314:  /* neon_vrndmv8hf */
    case 1313:  /* neon_vrndav8hf */
    case 1312:  /* neon_vrndv8hf */
    case 1311:  /* neon_negv4hf2 */
    case 1310:  /* neon_absv4hf2 */
    case 1309:  /* neon_negv8hf2 */
    case 1308:  /* neon_absv8hf2 */
    case 1307:  /* neon_negv4sf2 */
    case 1306:  /* neon_negv2sf2 */
    case 1305:  /* neon_negv4si2 */
    case 1304:  /* neon_negv2si2 */
    case 1303:  /* neon_negv8hi2 */
    case 1302:  /* neon_negv4hi2 */
    case 1301:  /* neon_negv16qi2 */
    case 1300:  /* neon_negv8qi2 */
    case 1299:  /* neon_absv4sf2 */
    case 1298:  /* neon_absv2sf2 */
    case 1297:  /* neon_absv4si2 */
    case 1296:  /* neon_absv2si2 */
    case 1295:  /* neon_absv8hi2 */
    case 1294:  /* neon_absv4hi2 */
    case 1293:  /* neon_absv16qi2 */
    case 1292:  /* neon_absv8qi2 */
    case 1291:  /* one_cmplv2di2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1289:  /* one_cmplv2sf2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1282:  /* one_cmplv16qi2_neon */
    case 1281:  /* one_cmplv8qi2_neon */
    case 1280:  /* xorv2di3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1278:  /* xorv2sf3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1247:  /* andv2di3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1242:  /* andv4si3_neon */
    case 1241:  /* andv2si3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1227:  /* iorv16qi3_neon */
    case 1226:  /* iorv8qi3_neon */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1220:  /* neon_vcvtpv4sfv4si */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1214:  /* neon_vcvtpv2sfv2si */
    case 1213:  /* neon_vrintnv4sf */
    case 1212:  /* neon_vrintav4sf */
    case 1211:  /* neon_vrintxv4sf */
    case 1210:  /* neon_vrintmv4sf */
    case 1209:  /* neon_vrintzv4sf */
    case 1208:  /* neon_vrintpv4sf */
    case 1207:  /* neon_vrintnv2sf */
    case 1206:  /* neon_vrintav2sf */
    case 1205:  /* neon_vrintxv2sf */
    case 1204:  /* neon_vrintmv2sf */
    case 1203:  /* neon_vrintzv2sf */
    case 1202:  /* neon_vrintpv2sf */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1197:  /* *fmsubv4sf4 */
    case 1196:  /* *fmsubv2sf4 */
    case 1195:  /* fmav4hf4 */
    case 1194:  /* fmav8hf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1191:  /* fmav4sf4 */
    case 1190:  /* fmav2sf4 */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1181:  /* mulv4hf3addv4hf_neon */
    case 1180:  /* mulv8hf3addv8hf_neon */
    case 1179:  /* mulv4sf3addv4sf_neon */
    case 1178:  /* mulv2sf3addv2sf_neon */
    case 1177:  /* mulv4si3addv4si_neon */
    case 1176:  /* mulv2si3addv2si_neon */
    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1173:  /* mulv16qi3addv16qi_neon */
    case 1172:  /* mulv8qi3addv8qi_neon */
    case 1171:  /* *mulv4sf3_neon */
    case 1170:  /* *mulv2sf3_neon */
    case 1169:  /* *mulv4si3_neon */
    case 1168:  /* *mulv2si3_neon */
    case 1167:  /* *mulv8hi3_neon */
    case 1166:  /* *mulv4hi3_neon */
    case 1165:  /* *mulv16qi3_neon */
    case 1164:  /* *mulv8qi3_neon */
    case 1163:  /* *subv2di3_neon */
    case 1162:  /* *subv4sf3_neon */
    case 1161:  /* *subv2sf3_neon */
    case 1160:  /* *subv8hf3_neon */
    case 1159:  /* *subv4hf3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1157:  /* *subv2si3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1154:  /* *subv16qi3_neon */
    case 1153:  /* *subv8qi3_neon */
    case 1152:  /* *addv2di3_neon */
    case 1151:  /* *addv4sf3_neon */
    case 1150:  /* *addv2sf3_neon */
    case 1149:  /* *addv8hf3_neon */
    case 1148:  /* *addv4hf3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1146:  /* *addv2si3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1143:  /* *addv16qi3_neon */
    case 1142:  /* *addv8qi3_neon */
    case 1141:  /* neon_vec_extractv2didi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1136:  /* neon_vec_extractv16qiqi */
    case 1135:  /* vec_extractv2sfsf */
    case 1134:  /* vec_extractv2sisi */
    case 1133:  /* vec_extractv4bfbf */
    case 1132:  /* vec_extractv4hfhf */
    case 1131:  /* vec_extractv4hihi */
    case 1130:  /* vec_extractv8qiqi */
    case 1129:  /* vec_setv2di_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1124:  /* vec_setv16qi_internal */
    case 1123:  /* vec_setv2sf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1118:  /* vec_setv8qi_internal */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1111:  /* *movmisalignv16qi_neon_load */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1104:  /* *movmisalignv16qi_neon_store */
    case 1103:  /* *movmisaligndi_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1097:  /* *movmisalignv8qi_neon_load */
    case 1096:  /* *movmisaligndi_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1089:  /* *neon_movxi */
    case 1088:  /* *neon_movci */
    case 1087:  /* *neon_movoi */
    case 1086:  /* *neon_movei */
    case 1070:  /* unaligned_storev8qi */
    case 787:  /* neon_vrndihf */
    case 786:  /* neon_vrndxhf */
    case 785:  /* neon_vrndphf */
    case 784:  /* neon_vrndnhf */
    case 783:  /* neon_vrndmhf */
    case 782:  /* neon_vrndahf */
    case 781:  /* neon_vrndhf */
    case 522:  /* mve_vshlq_uv4si */
    case 521:  /* mve_vshlq_sv4si */
    case 520:  /* mve_vshlq_uv2si */
    case 519:  /* mve_vshlq_sv2si */
    case 518:  /* mve_vshlq_uv8hi */
    case 517:  /* mve_vshlq_sv8hi */
    case 516:  /* mve_vshlq_uv4hi */
    case 515:  /* mve_vshlq_sv4hi */
    case 514:  /* mve_vshlq_uv16qi */
    case 513:  /* mve_vshlq_sv16qi */
    case 512:  /* mve_vshlq_uv8qi */
    case 511:  /* mve_vshlq_sv8qi */
      return IS_NEON_TYPE_YES;

    default:
      return IS_NEON_TYPE_NO;

    }
}

enum attr_mul32
get_attr_mul32 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMLAWX) || (cached_type == TYPE_MUL) || (cached_type == TYPE_MULS) || (cached_type == TYPE_MLA) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUADX) || (cached_type == TYPE_SMLAD) || (cached_type == TYPE_SMLADX) || (cached_type == TYPE_SMUSD) || (cached_type == TYPE_SMUSDX) || (cached_type == TYPE_SMLSD) || (cached_type == TYPE_SMLSDX) || (cached_type == TYPE_SMMUL) || (cached_type == TYPE_SMMULR) || (cached_type == TYPE_SMMLA) || (cached_type == TYPE_SMLALD) || (cached_type == TYPE_SMLSLD))
        {
	  return MUL32_YES;
        }
      else
        {
	  return MUL32_NO;
        }

    case 6938:  /* *p *thumb2_mulsi_short */
    case 6490:  /* *p arm_smlsldx */
    case 6489:  /* *p arm_smlsld */
    case 6488:  /* *p arm_smlaldx */
    case 6487:  /* *p arm_smlald */
    case 6396:  /* *p arm_smlawt_setq_insn */
    case 6395:  /* *p arm_smlawt_insn */
    case 6394:  /* *p arm_smlawb_setq_insn */
    case 6393:  /* *p arm_smlawb_insn */
    case 6389:  /* *p arm_smlatt_setq */
    case 6388:  /* *p maddhisi4tt */
    case 6387:  /* *p arm_smlatb_setq */
    case 6386:  /* *p maddhisi4tb */
    case 6385:  /* *p arm_smlabb_setq */
    case 6384:  /* *p *arm_maddhisi4 */
    case 6383:  /* *p *mulhisi3tt */
    case 6382:  /* *p *mulhisi3bt */
    case 6381:  /* *p *mulhisi3tb */
    case 6380:  /* *p mulhisi3 */
    case 6373:  /* *p *mls */
    case 6372:  /* *p *mla */
    case 6371:  /* *p *mul */
    case 1056:  /* *thumb2_mulsi_short_compare0_scratch */
    case 1055:  /* *thumb2_mulsi_short_compare0 */
    case 1054:  /* *thumb2_mulsi_short */
    case 939:  /* *thumb_mulsi3_v6 */
    case 938:  /* *thumb_mulsi3 */
    case 225:  /* arm_smlsldx */
    case 224:  /* arm_smlsld */
    case 223:  /* arm_smlaldx */
    case 222:  /* arm_smlald */
    case 89:  /* arm_smlawt_setq_insn */
    case 88:  /* arm_smlawt_insn */
    case 87:  /* arm_smlawb_setq_insn */
    case 86:  /* arm_smlawb_insn */
    case 82:  /* arm_smlatt_setq */
    case 81:  /* maddhisi4tt */
    case 80:  /* arm_smlatb_setq */
    case 79:  /* maddhisi4tb */
    case 78:  /* arm_smlabb_setq */
    case 77:  /* *arm_maddhisi4 */
    case 76:  /* *mulhisi3tt */
    case 75:  /* *mulhisi3bt */
    case 74:  /* *mulhisi3tb */
    case 73:  /* mulhisi3 */
    case 66:  /* *mulsi3addsi_compare0_scratch_v6 */
    case 65:  /* *mulsi3addsi_compare0_scratch */
    case 64:  /* *mulsi3addsi_compare0_v6 */
    case 63:  /* *mulsi3addsi_compare0 */
    case 62:  /* *mulsi_compare0_scratch_v6 */
    case 61:  /* *mulsi_compare0_scratch */
    case 60:  /* *mulsi3_compare0_v6 */
    case 59:  /* *mulsi3_compare0 */
    case 58:  /* *mls */
    case 57:  /* *mla */
    case 56:  /* *mul */
      return MUL32_YES;

    default:
      return MUL32_NO;

    }
}

int
get_attr_neg_pool_range (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 3045:  /* *mve_movv2df */
    case 3044:  /* *mve_movv4sf */
    case 3043:  /* *mve_movv8hf */
    case 3042:  /* *mve_movti */
    case 3041:  /* *mve_movv2di */
    case 3040:  /* *mve_movv4si */
    case 3039:  /* *mve_movv8hi */
    case 3038:  /* *mve_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 996 /* 0x3e4 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  return 996 /* 0x3e4 */;
        }

    case 6927:  /* *p *thumb2_movhi_insn */
    case 1009:  /* *thumb2_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  return 250 /* 0xfa */;
        }

    case 6926:  /* *p *thumb2_movsi_insn */
    case 1007:  /* *thumb2_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 0;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 250 /* 0xfa */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 244 /* 0xf4 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 532:  /* *cond_iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  return 4084 /* 0xff4 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 6524:  /* *p *movhi_insn_arch4 */
    case 265:  /* *movhi_insn_arch4 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  return 244 /* 0xf4 */;
        }

    case 258:  /* pic_load_addr_unified */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4084 /* 0xff4 */;
        }
      else
        {
	  return 0;
        }

    case 6521:  /* *p *arm_movsi_insn */
    case 257:  /* *arm_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 4084 /* 0xff4 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 259:  /* pic_load_addr_32bit */
      if ((! (
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB))))
        {
	  return 4084 /* 0xff4 */;
        }
      else
        {
	  return 0;
        }

    case 531:  /* *iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 4084 /* 0xff4 */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 9)
        {
	  return 1012 /* 0x3f4 */;
        }
      else if (which_alternative == 10)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 11)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 12)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 13)
        {
	  return 1008 /* 0x3f0 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 770:  /* *thumb2_movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 1008 /* 0x3f0 */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  return 0;
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 1071:  /* *neon_movv8qi */
    case 1072:  /* *neon_movv4hi */
    case 1073:  /* *neon_movv4hf */
    case 1074:  /* *neon_movv4bf */
    case 1075:  /* *neon_movv2si */
    case 1076:  /* *neon_movv2sf */
    case 1077:  /* *neon_movdi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 1004 /* 0x3ec */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  return 1004 /* 0x3ec */;
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 1078:  /* *neon_movv16qi */
    case 1079:  /* *neon_movv8hi */
    case 1080:  /* *neon_movv8hf */
    case 1081:  /* *neon_movv8bf */
    case 1082:  /* *neon_movv4si */
    case 1083:  /* *neon_movv4sf */
    case 1084:  /* *neon_movv2di */
    case 1085:  /* *neon_movti */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 996 /* 0x3e4 */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  return 996 /* 0x3e4 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 316:  /* *load_indirect_jump */
    case 6537:  /* *p *load_indirect_jump */
      return 4084 /* 0xff4 */;

    case 533:  /* movv2si_internal */
    case 534:  /* movv4hi_internal */
    case 535:  /* movv8qi_internal */
    case 6623:  /* *p movv2si_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6625:  /* *p movv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  return 244 /* 0xf4 */;
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  return 244 /* 0xf4 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 758:  /* *arm_movsi_vfp */
    case 6848:  /* *p *arm_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 4084 /* 0xff4 */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 9)
        {
	  return 1008 /* 0x3f0 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 759:  /* *thumb2_movsi_vfp */
    case 6849:  /* *p *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 0;
        }
      else if (which_alternative == 6)
        {
	  return 0;
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 9)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 10)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 11)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 12)
        {
	  return 1008 /* 0x3f0 */;
        }
      else if (which_alternative == 13)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 14)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 15)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 16)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 760:  /* *movdi_vfp */
    case 6850:  /* *p *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 1004 /* 0x3ec */;
        }
      else if (which_alternative == 5)
        {
	  return 0;
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 9)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 10)
        {
	  return 1004 /* 0x3ec */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 767:  /* *movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  return 1008 /* 0x3f0 */;
        }
      else if (which_alternative == 4)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 4080 /* 0xff0 */;
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 768:  /* *thumb2_movsf_vfp */
    case 6854:  /* *p *thumb2_movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  return 1008 /* 0x3f0 */;
        }
      else if (which_alternative == 4)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 0;
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 769:  /* *movdf_vfp */
    case 6855:  /* *p *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 1004 /* 0x3ec */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  return 1004 /* 0x3ec */;
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }

    case 1037:  /* *thumb2_extendqisi_v6 */
    case 1038:  /* *thumb2_zero_extendhisi2_v6 */
    case 1039:  /* thumb2_zero_extendqisi2_v6 */
    case 6928:  /* *p *thumb2_extendqisi_v6 */
    case 6929:  /* *p *thumb2_zero_extendhisi2_v6 */
    case 6930:  /* *p thumb2_zero_extendqisi2_v6 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_neg_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_neg_pool_range (insn);
	    }
        }
      else
        {
	  return 250 /* 0xfa */;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return get_attr_thumb2_neg_pool_range (insn);
        }
      else
        {
	  return get_attr_arm_neg_pool_range (insn);
        }

    }
}

enum attr_nonce_enabled
get_attr_nonce_enabled (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return NONCE_ENABLED_YES;

    }
}

enum attr_opt_enabled
get_attr_opt_enabled (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_opt cached_opt ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if ((cached_opt = get_attr_opt (insn)) == OPT_ANY)
        {
	  return OPT_ENABLED_YES;
        }
      else if ((cached_opt == OPT_SPEED) && (
#line 215 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(optimize_function_for_speed_p (cfun))))
        {
	  return OPT_ENABLED_YES;
        }
      else if ((cached_opt == OPT_SIZE) && (
#line 219 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(optimize_function_for_size_p (cfun))))
        {
	  return OPT_ENABLED_YES;
        }
      else
        {
	  return OPT_ENABLED_NO;
        }

    default:
      return OPT_ENABLED_YES;

    }
}

enum attr_opt
get_attr_opt (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return OPT_ANY;

    }
}

enum attr_predicable
get_attr_predicable (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 1005:  /* *thumb2_neg_abssi2 */
    case 1004:  /* *thumb2_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return PREDICABLE_YES;
        }
      else
        {
	  return PREDICABLE_NO;
        }

    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return PREDICABLE_YES;
        }
      else if (which_alternative == 3)
        {
	  return PREDICABLE_NO;
        }
      else
        {
	  return PREDICABLE_YES;
        }

    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return PREDICABLE_YES;
        }
      else if (which_alternative == 2)
        {
	  return PREDICABLE_NO;
        }
      else if (which_alternative == 3)
        {
	  return PREDICABLE_YES;
        }
      else
        {
	  return PREDICABLE_NO;
        }

    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3fULL))
        {
	  return PREDICABLE_YES;
        }
      else if (((1ULL << which_alternative) & 0xc0ULL))
        {
	  return PREDICABLE_NO;
        }
      else
        {
	  return PREDICABLE_YES;
        }

    case 752:  /* *arm_movhi_fp16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  return PREDICABLE_YES;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return PREDICABLE_NO;
        }
      else
        {
	  return PREDICABLE_YES;
        }

    case 411:  /* *arm_rev */
    case 163:  /* unaligned_storehi */
    case 162:  /* unaligned_storesi */
    case 160:  /* unaligned_loadhiu */
    case 158:  /* unaligned_loadsi */
    case 171:  /* *arm_abssi2 */
    case 172:  /* *arm_neg_abssi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return PREDICABLE_NO;
        }
      else
        {
	  return PREDICABLE_YES;
        }

    case 7:  /* *arm_addsi3 */
    case 14:  /* *addsi3_compare0_scratch */
    case 15:  /* *compare_negsi_si */
    case 19:  /* *compare_addsi2_op0 */
    case 20:  /* *compare_addsi2_op1 */
    case 21:  /* addsi3_carryin */
    case 22:  /* add0si3_carryin */
    case 23:  /* *addsi3_carryin_alt2 */
    case 24:  /* *addsi3_carryin_shift */
    case 29:  /* subsi3_carryin */
    case 30:  /* rsbsi_carryin_reg */
    case 31:  /* *add_not_cin */
    case 32:  /* add_not_shift_cin */
    case 41:  /* *subsi3_carryin_shift */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 43:  /* *rsbsi3_carryin_shift */
    case 44:  /* *rsbsi3_carryin_shift_alt */
    case 45:  /* *arm_subsi3_insn */
    case 56:  /* *mul */
    case 57:  /* *mla */
    case 58:  /* *mls */
    case 67:  /* smull */
    case 68:  /* umull */
    case 69:  /* smlal */
    case 70:  /* umlal */
    case 71:  /* *smull_high */
    case 72:  /* *umull_high */
    case 73:  /* mulhisi3 */
    case 74:  /* *mulhisi3tb */
    case 75:  /* *mulhisi3bt */
    case 76:  /* *mulhisi3tt */
    case 77:  /* *arm_maddhisi4 */
    case 78:  /* arm_smlabb_setq */
    case 79:  /* maddhisi4tb */
    case 80:  /* arm_smlatb_setq */
    case 81:  /* maddhisi4tt */
    case 82:  /* arm_smlatt_setq */
    case 83:  /* maddhidi4 */
    case 84:  /* *maddhidi4tb */
    case 85:  /* *maddhidi4tt */
    case 86:  /* arm_smlawb_insn */
    case 87:  /* arm_smlawb_setq_insn */
    case 88:  /* arm_smlawt_insn */
    case 89:  /* arm_smlawt_setq_insn */
    case 90:  /* *arm_andsi3_insn */
    case 93:  /* *zeroextractsi_compare0_scratch */
    case 98:  /* insv_zero */
    case 99:  /* insv_t2 */
    case 100:  /* *bfi */
    case 101:  /* *bfi_alt1 */
    case 102:  /* *bfi_alt2 */
    case 103:  /* *bfi_alt3 */
    case 104:  /* andsi_notsi_si */
    case 105:  /* andsi_not_shiftsi_si */
    case 106:  /* andsi_not_shiftsi_si_scc_no_reuse */
    case 107:  /* andsi_not_shiftsi_si_scc */
    case 110:  /* *iorsi3_insn */
    case 113:  /* *arm_xorsi3 */
    case 116:  /* *andsi_iorsi3_notsi */
    case 117:  /* *smax_0 */
    case 118:  /* *smax_m1 */
    case 120:  /* *smin_0 */
    case 127:  /* arm_qadd_insn */
    case 128:  /* arm_qadd_setq_insn */
    case 129:  /* arm_qsub_insn */
    case 130:  /* arm_qsub_setq_insn */
    case 131:  /* arm_get_apsr */
    case 132:  /* arm_set_apsr */
    case 133:  /* satsi_smin */
    case 134:  /* satsi_smin_setq */
    case 135:  /* satsi_smax */
    case 136:  /* satsi_smax_setq */
    case 137:  /* *satsi_smin_shift */
    case 138:  /* *satsi_smax_shift */
    case 151:  /* *arm_shiftsi3 */
    case 154:  /* *not_shiftsi */
    case 159:  /* unaligned_loadhis */
    case 164:  /* *extv_reg */
    case 165:  /* extzv_t2 */
    case 166:  /* divsi3 */
    case 167:  /* udivsi3 */
    case 168:  /* *arm_negsi2 */
    case 173:  /* *arm_one_cmplsi2 */
    case 176:  /* *arm_zero_extendhisi2 */
    case 177:  /* *arm_zero_extendhisi2_v6 */
    case 178:  /* *arm_zero_extendhisi2addsi */
    case 179:  /* *arm_zero_extendqisi2 */
    case 180:  /* *arm_zero_extendqisi2_v6 */
    case 181:  /* *arm_zero_extendqisi2addsi */
    case 182:  /* *compareqi_eq0 */
    case 183:  /* *arm_extendhisi2 */
    case 184:  /* *arm_extendhisi2_v6 */
    case 186:  /* *arm_extendqihi_insn */
    case 187:  /* *arm_extendqisi */
    case 188:  /* *arm_extendqisi_v6 */
    case 189:  /* *arm_extendqisi2addsi */
    case 190:  /* arm_sxtb16 */
    case 191:  /* arm_uxtb16 */
    case 192:  /* arm_qadd8 */
    case 193:  /* arm_qsub8 */
    case 194:  /* arm_shadd8 */
    case 195:  /* arm_shsub8 */
    case 196:  /* arm_uhadd8 */
    case 197:  /* arm_uhsub8 */
    case 198:  /* arm_uqadd8 */
    case 199:  /* arm_uqsub8 */
    case 200:  /* arm_qadd16 */
    case 201:  /* arm_qasx */
    case 202:  /* arm_qsax */
    case 203:  /* arm_qsub16 */
    case 204:  /* arm_shadd16 */
    case 205:  /* arm_shasx */
    case 206:  /* arm_shsax */
    case 207:  /* arm_shsub16 */
    case 208:  /* arm_uhadd16 */
    case 209:  /* arm_uhasx */
    case 210:  /* arm_uhsax */
    case 211:  /* arm_uhsub16 */
    case 212:  /* arm_uqadd16 */
    case 213:  /* arm_uqasx */
    case 214:  /* arm_uqsax */
    case 215:  /* arm_uqsub16 */
    case 216:  /* arm_smusd */
    case 217:  /* arm_smusdx */
    case 218:  /* arm_sxtab16 */
    case 219:  /* arm_uxtab16 */
    case 220:  /* arm_usad8 */
    case 221:  /* arm_usada8 */
    case 222:  /* arm_smlald */
    case 223:  /* arm_smlaldx */
    case 224:  /* arm_smlsld */
    case 225:  /* arm_smlsldx */
    case 226:  /* arm_sadd8 */
    case 227:  /* arm_ssub8 */
    case 228:  /* arm_uadd8 */
    case 229:  /* arm_usub8 */
    case 230:  /* arm_sadd16 */
    case 231:  /* arm_sasx */
    case 232:  /* arm_ssax */
    case 233:  /* arm_ssub16 */
    case 234:  /* arm_uadd16 */
    case 235:  /* arm_uasx */
    case 236:  /* arm_usax */
    case 237:  /* arm_usub16 */
    case 238:  /* arm_smlad_insn */
    case 239:  /* arm_smlad_setq_insn */
    case 240:  /* arm_smladx_insn */
    case 241:  /* arm_smladx_setq_insn */
    case 242:  /* arm_smlsd_insn */
    case 243:  /* arm_smlsd_setq_insn */
    case 244:  /* arm_smlsdx_insn */
    case 245:  /* arm_smlsdx_setq_insn */
    case 246:  /* arm_smuad_insn */
    case 247:  /* arm_smuad_setq_insn */
    case 248:  /* arm_smuadx_insn */
    case 249:  /* arm_smuadx_setq_insn */
    case 250:  /* arm_ssat16_insn */
    case 251:  /* arm_ssat16_setq_insn */
    case 252:  /* arm_usat16_insn */
    case 253:  /* arm_usat16_setq_insn */
    case 254:  /* arm_sel */
    case 256:  /* *arm_movt */
    case 257:  /* *arm_movsi_insn */
    case 262:  /* pic_add_dot_plus_eight */
    case 263:  /* tls_load_dot_plus_eight */
    case 265:  /* *movhi_insn_arch4 */
    case 266:  /* *movhi_bytes */
    case 267:  /* *arm_movqi_insn */
    case 268:  /* *arm32_movhf */
    case 269:  /* *arm32_movbf */
    case 270:  /* *arm_movsf_soft_insn */
    case 272:  /* *arm_cmpsi_insn */
    case 275:  /* *arm_cmpsi_negshiftsi_si */
    case 288:  /* *arm_jump */
    case 298:  /* *arm_return */
    case 303:  /* *arm_simple_return */
    case 306:  /* probe_stack */
    case 315:  /* *arm_indirect_jump */
    case 316:  /* *load_indirect_jump */
    case 319:  /* *add_multsi */
    case 320:  /* *rsb_multsi */
    case 321:  /* *orr_multsi */
    case 322:  /* *eor_multsi */
    case 323:  /* *and_multsi */
    case 324:  /* *add_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 328:  /* *and_shiftsi */
    case 331:  /* *sub_shiftsi */
    case 380:  /* *arith_adjacentmem */
    case 386:  /* *load_multiple_with_writeback */
    case 387:  /* *pop_multiple_with_writeback_and_return */
    case 388:  /* *pop_multiple_with_return */
    case 389:  /* *ldr_with_return */
    case 399:  /* clzsi2 */
    case 400:  /* rbitsi2 */
    case 405:  /* load_tp_hard */
    case 410:  /* *arm_movtas_ze */
    case 416:  /* *thumb2_ldrd */
    case 417:  /* *thumb2_ldrd_base */
    case 418:  /* *thumb2_ldrd_base_neg */
    case 419:  /* *thumb2_strd */
    case 420:  /* *thumb2_strd_base */
    case 421:  /* *thumb2_strd_base_neg */
    case 428:  /* *arm_ldrd */
    case 429:  /* *arm_strd */
    case 430:  /* *ldm4_ */
    case 432:  /* *ldm4_ia_update */
    case 434:  /* *stm4_ */
    case 435:  /* *stm4_ia_update */
    case 437:  /* *ldm4_ib */
    case 438:  /* *ldm4_ib_update */
    case 439:  /* *stm4_ib */
    case 440:  /* *stm4_ib_update */
    case 441:  /* *ldm4_da */
    case 442:  /* *ldm4_da_update */
    case 443:  /* *stm4_da */
    case 444:  /* *stm4_da_update */
    case 445:  /* *ldm4_db */
    case 446:  /* *ldm4_db_update */
    case 447:  /* *stm4_db */
    case 448:  /* *stm4_db_update */
    case 449:  /* *ldm3_ */
    case 451:  /* *ldm3_ia_update */
    case 453:  /* *stm3_ */
    case 454:  /* *stm3_ia_update */
    case 456:  /* *ldm3_ib */
    case 457:  /* *ldm3_ib_update */
    case 458:  /* *stm3_ib */
    case 459:  /* *stm3_ib_update */
    case 460:  /* *ldm3_da */
    case 461:  /* *ldm3_da_update */
    case 462:  /* *stm3_da */
    case 463:  /* *stm3_da_update */
    case 464:  /* *ldm3_db */
    case 465:  /* *ldm3_db_update */
    case 466:  /* *stm3_db */
    case 467:  /* *stm3_db_update */
    case 468:  /* *ldm2_ */
    case 470:  /* *ldm2_ia_update */
    case 472:  /* *stm2_ */
    case 473:  /* *stm2_ia_update */
    case 475:  /* *ldm2_ib */
    case 476:  /* *ldm2_ib_update */
    case 477:  /* *stm2_ib */
    case 478:  /* *stm2_ib_update */
    case 479:  /* *ldm2_da */
    case 480:  /* *ldm2_da_update */
    case 481:  /* *stm2_da */
    case 482:  /* *stm2_da_update */
    case 483:  /* *ldm2_db */
    case 484:  /* *ldm2_db_update */
    case 485:  /* *stm2_db */
    case 486:  /* *stm2_db_update */
    case 487:  /* *load_multiple */
    case 523:  /* tbcstv8qi */
    case 524:  /* tbcstv4hi */
    case 525:  /* tbcstv2si */
    case 526:  /* iwmmxt_iordi3 */
    case 527:  /* iwmmxt_xordi3 */
    case 528:  /* iwmmxt_anddi3 */
    case 529:  /* iwmmxt_nanddi3 */
    case 533:  /* movv2si_internal */
    case 534:  /* movv4hi_internal */
    case 535:  /* movv8qi_internal */
    case 536:  /* *andv2si3_iwmmxt */
    case 537:  /* *andv4hi3_iwmmxt */
    case 538:  /* *andv8qi3_iwmmxt */
    case 539:  /* *iorv2si3_iwmmxt */
    case 540:  /* *iorv4hi3_iwmmxt */
    case 541:  /* *iorv8qi3_iwmmxt */
    case 542:  /* *xorv2si3_iwmmxt */
    case 543:  /* *xorv4hi3_iwmmxt */
    case 544:  /* *xorv8qi3_iwmmxt */
    case 545:  /* *addv2si3_iwmmxt */
    case 546:  /* *addv4hi3_iwmmxt */
    case 547:  /* *addv8qi3_iwmmxt */
    case 548:  /* ssaddv8qi3 */
    case 549:  /* ssaddv4hi3 */
    case 550:  /* ssaddv2si3 */
    case 551:  /* usaddv8qi3 */
    case 552:  /* usaddv4hi3 */
    case 553:  /* usaddv2si3 */
    case 554:  /* *subv2si3_iwmmxt */
    case 555:  /* *subv4hi3_iwmmxt */
    case 556:  /* *subv8qi3_iwmmxt */
    case 557:  /* sssubv8qi3 */
    case 558:  /* sssubv4hi3 */
    case 559:  /* sssubv2si3 */
    case 560:  /* ussubv8qi3 */
    case 561:  /* ussubv4hi3 */
    case 562:  /* ussubv2si3 */
    case 563:  /* *mulv4hi3_iwmmxt */
    case 564:  /* smulv4hi3_highpart */
    case 565:  /* umulv4hi3_highpart */
    case 566:  /* iwmmxt_wmacs */
    case 567:  /* iwmmxt_wmacsz */
    case 568:  /* iwmmxt_wmacu */
    case 569:  /* iwmmxt_wmacuz */
    case 570:  /* iwmmxt_clrdi */
    case 571:  /* iwmmxt_clrv8qi */
    case 572:  /* iwmmxt_clrv4hi */
    case 573:  /* iwmmxt_clrv2si */
    case 574:  /* iwmmxt_uavgrndv8qi3 */
    case 575:  /* iwmmxt_uavgrndv4hi3 */
    case 576:  /* iwmmxt_uavgv8qi3 */
    case 577:  /* iwmmxt_uavgv4hi3 */
    case 578:  /* iwmmxt_tinsrb */
    case 579:  /* iwmmxt_tinsrh */
    case 580:  /* iwmmxt_tinsrw */
    case 581:  /* iwmmxt_textrmub */
    case 582:  /* iwmmxt_textrmsb */
    case 583:  /* iwmmxt_textrmuh */
    case 584:  /* iwmmxt_textrmsh */
    case 585:  /* iwmmxt_textrmw */
    case 586:  /* iwmmxt_wshufh */
    case 587:  /* eqv8qi3 */
    case 588:  /* eqv4hi3 */
    case 589:  /* eqv2si3 */
    case 590:  /* gtuv8qi3 */
    case 591:  /* gtuv4hi3 */
    case 592:  /* gtuv2si3 */
    case 593:  /* gtv8qi3 */
    case 594:  /* gtv4hi3 */
    case 595:  /* gtv2si3 */
    case 596:  /* *smaxv2si3_iwmmxt */
    case 597:  /* *smaxv4hi3_iwmmxt */
    case 598:  /* *smaxv8qi3_iwmmxt */
    case 599:  /* *umaxv2si3_iwmmxt */
    case 600:  /* *umaxv4hi3_iwmmxt */
    case 601:  /* *umaxv8qi3_iwmmxt */
    case 602:  /* *sminv2si3_iwmmxt */
    case 603:  /* *sminv4hi3_iwmmxt */
    case 604:  /* *sminv8qi3_iwmmxt */
    case 605:  /* *uminv2si3_iwmmxt */
    case 606:  /* *uminv4hi3_iwmmxt */
    case 607:  /* *uminv8qi3_iwmmxt */
    case 608:  /* iwmmxt_wpackhss */
    case 609:  /* iwmmxt_wpackwss */
    case 610:  /* iwmmxt_wpackdss */
    case 611:  /* iwmmxt_wpackhus */
    case 612:  /* iwmmxt_wpackwus */
    case 613:  /* iwmmxt_wpackdus */
    case 614:  /* iwmmxt_wunpckihb */
    case 615:  /* iwmmxt_wunpckihh */
    case 616:  /* iwmmxt_wunpckihw */
    case 617:  /* iwmmxt_wunpckilb */
    case 618:  /* iwmmxt_wunpckilh */
    case 619:  /* iwmmxt_wunpckilw */
    case 620:  /* iwmmxt_wunpckehub */
    case 621:  /* iwmmxt_wunpckehuh */
    case 622:  /* iwmmxt_wunpckehuw */
    case 623:  /* iwmmxt_wunpckehsb */
    case 624:  /* iwmmxt_wunpckehsh */
    case 625:  /* iwmmxt_wunpckehsw */
    case 626:  /* iwmmxt_wunpckelub */
    case 627:  /* iwmmxt_wunpckeluh */
    case 628:  /* iwmmxt_wunpckeluw */
    case 629:  /* iwmmxt_wunpckelsb */
    case 630:  /* iwmmxt_wunpckelsh */
    case 631:  /* iwmmxt_wunpckelsw */
    case 632:  /* rorv4hi3 */
    case 633:  /* rorv2si3 */
    case 634:  /* rordi3 */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 643:  /* ashldi3_iwmmxt */
    case 644:  /* rorv4hi3_di */
    case 645:  /* rorv2si3_di */
    case 646:  /* rordi3_di */
    case 647:  /* ashrv4hi3_di */
    case 648:  /* ashrv2si3_di */
    case 649:  /* ashrdi3_di */
    case 650:  /* lshrv4hi3_di */
    case 651:  /* lshrv2si3_di */
    case 652:  /* lshrdi3_di */
    case 653:  /* ashlv4hi3_di */
    case 654:  /* ashlv2si3_di */
    case 655:  /* ashldi3_di */
    case 656:  /* iwmmxt_wmadds */
    case 657:  /* iwmmxt_wmaddu */
    case 658:  /* iwmmxt_tmia */
    case 659:  /* iwmmxt_tmiaph */
    case 660:  /* iwmmxt_tmiabb */
    case 661:  /* iwmmxt_tmiatb */
    case 662:  /* iwmmxt_tmiabt */
    case 663:  /* iwmmxt_tmiatt */
    case 664:  /* iwmmxt_tmovmskb */
    case 665:  /* iwmmxt_tmovmskh */
    case 666:  /* iwmmxt_tmovmskw */
    case 667:  /* iwmmxt_waccb */
    case 668:  /* iwmmxt_wacch */
    case 669:  /* iwmmxt_waccw */
    case 670:  /* iwmmxt_waligni */
    case 671:  /* iwmmxt_walignr */
    case 672:  /* iwmmxt_walignr0 */
    case 673:  /* iwmmxt_walignr1 */
    case 674:  /* iwmmxt_walignr2 */
    case 675:  /* iwmmxt_walignr3 */
    case 676:  /* iwmmxt_wsadb */
    case 677:  /* iwmmxt_wsadh */
    case 678:  /* iwmmxt_wsadbz */
    case 679:  /* iwmmxt_wsadhz */
    case 680:  /* iwmmxt_wabsv2si3 */
    case 681:  /* iwmmxt_wabsv4hi3 */
    case 682:  /* iwmmxt_wabsv8qi3 */
    case 683:  /* iwmmxt_wabsdiffb */
    case 684:  /* iwmmxt_wabsdiffh */
    case 685:  /* iwmmxt_wabsdiffw */
    case 686:  /* iwmmxt_waddsubhx */
    case 687:  /* iwmmxt_wsubaddhx */
    case 688:  /* addcv4hi3 */
    case 689:  /* addcv2si3 */
    case 690:  /* iwmmxt_avg4 */
    case 691:  /* iwmmxt_avg4r */
    case 692:  /* iwmmxt_wmaddsx */
    case 693:  /* iwmmxt_wmaddux */
    case 694:  /* iwmmxt_wmaddsn */
    case 695:  /* iwmmxt_wmaddun */
    case 696:  /* iwmmxt_wmulwsm */
    case 697:  /* iwmmxt_wmulwum */
    case 698:  /* iwmmxt_wmulsmr */
    case 699:  /* iwmmxt_wmulumr */
    case 700:  /* iwmmxt_wmulwsmr */
    case 701:  /* iwmmxt_wmulwumr */
    case 702:  /* iwmmxt_wmulwl */
    case 703:  /* iwmmxt_wqmulm */
    case 704:  /* iwmmxt_wqmulwm */
    case 705:  /* iwmmxt_wqmulmr */
    case 706:  /* iwmmxt_wqmulwmr */
    case 707:  /* iwmmxt_waddbhusm */
    case 708:  /* iwmmxt_waddbhusl */
    case 709:  /* iwmmxt_wqmiabb */
    case 710:  /* iwmmxt_wqmiabt */
    case 711:  /* iwmmxt_wqmiatb */
    case 712:  /* iwmmxt_wqmiatt */
    case 713:  /* iwmmxt_wqmiabbn */
    case 714:  /* iwmmxt_wqmiabtn */
    case 715:  /* iwmmxt_wqmiatbn */
    case 716:  /* iwmmxt_wqmiattn */
    case 717:  /* iwmmxt_wmiabb */
    case 718:  /* iwmmxt_wmiabt */
    case 719:  /* iwmmxt_wmiatb */
    case 720:  /* iwmmxt_wmiatt */
    case 721:  /* iwmmxt_wmiabbn */
    case 722:  /* iwmmxt_wmiabtn */
    case 723:  /* iwmmxt_wmiatbn */
    case 724:  /* iwmmxt_wmiattn */
    case 725:  /* iwmmxt_wmiawbb */
    case 726:  /* iwmmxt_wmiawbt */
    case 727:  /* iwmmxt_wmiawtb */
    case 728:  /* iwmmxt_wmiawtt */
    case 729:  /* iwmmxt_wmiawbbn */
    case 730:  /* iwmmxt_wmiawbtn */
    case 731:  /* iwmmxt_wmiawtbn */
    case 732:  /* iwmmxt_wmiawttn */
    case 733:  /* iwmmxt_wmerge */
    case 734:  /* iwmmxt_tandcv2si3 */
    case 735:  /* iwmmxt_tandcv4hi3 */
    case 736:  /* iwmmxt_tandcv8qi3 */
    case 737:  /* iwmmxt_torcv2si3 */
    case 738:  /* iwmmxt_torcv4hi3 */
    case 739:  /* iwmmxt_torcv8qi3 */
    case 740:  /* iwmmxt_torvscv2si3 */
    case 741:  /* iwmmxt_torvscv4hi3 */
    case 742:  /* iwmmxt_torvscv8qi3 */
    case 743:  /* iwmmxt_textrcv2si3 */
    case 744:  /* iwmmxt_textrcv4hi3 */
    case 745:  /* iwmmxt_textrcv8qi3 */
    case 746:  /* *arm_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 751:  /* *thumb2_movhi_vfp */
    case 758:  /* *arm_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
    case 760:  /* *movdi_vfp */
    case 767:  /* *movsf_vfp */
    case 768:  /* *thumb2_movsf_vfp */
    case 775:  /* *abssf2_vfp */
    case 776:  /* *absdf2_vfp */
    case 777:  /* *negsf2_vfp */
    case 778:  /* *negdf2_vfp */
    case 789:  /* *addsf3_vfp */
    case 790:  /* *adddf3_vfp */
    case 792:  /* *subsf3_vfp */
    case 793:  /* *subdf3_vfp */
    case 795:  /* *divsf3_vfp */
    case 796:  /* *divdf3_vfp */
    case 798:  /* *mulsf3_vfp */
    case 799:  /* *muldf3_vfp */
    case 802:  /* *mulsf3negsf_vfp */
    case 803:  /* *negmulsf3_vfp */
    case 804:  /* *muldf3negdf_vfp */
    case 805:  /* *negmuldf3_vfp */
    case 807:  /* *mulsf3addsf_vfp */
    case 808:  /* *muldf3adddf_vfp */
    case 810:  /* *mulsf3subsf_vfp */
    case 811:  /* *muldf3subdf_vfp */
    case 813:  /* *mulsf3negsfaddsf_vfp */
    case 814:  /* *fmuldf3negdfadddf_vfp */
    case 816:  /* *mulsf3negsfsubsf_vfp */
    case 817:  /* *muldf3negdfsubdf_vfp */
    case 819:  /* fmasf4 */
    case 820:  /* fmadf4 */
    case 822:  /* *fmsubsf4 */
    case 823:  /* *fmsubdf4 */
    case 825:  /* *fnmsubsf4 */
    case 826:  /* *fnmsubdf4 */
    case 828:  /* *fnmaddsf4 */
    case 829:  /* *fnmadddf4 */
    case 830:  /* *extendsfdf2_vfp */
    case 831:  /* *truncdfsf2_vfp */
    case 832:  /* extendhfsf2 */
    case 833:  /* *truncdfhf2 */
    case 834:  /* *extendhfdf2 */
    case 835:  /* truncsfhf2 */
    case 836:  /* *truncsisf2_vfp */
    case 837:  /* *truncsidf2_vfp */
    case 838:  /* fixuns_truncsfsi2 */
    case 839:  /* fixuns_truncdfsi2 */
    case 840:  /* *floatsisf2_vfp */
    case 841:  /* *floatsidf2_vfp */
    case 842:  /* floatunssisf2 */
    case 843:  /* floatunssidf2 */
    case 846:  /* *sqrtsf2_vfp */
    case 847:  /* *sqrtdf2_vfp */
    case 849:  /* push_fpsysreg_insn */
    case 850:  /* pop_fpsysreg_insn */
    case 851:  /* *clear_vfp_multiple */
    case 852:  /* lazy_store_multiple_insn */
    case 858:  /* *cmpsf_vfp */
    case 859:  /* *cmpsf_trap_vfp */
    case 860:  /* *cmpdf_vfp */
    case 861:  /* *cmpdf_trap_vfp */
    case 862:  /* *combine_vcvt_f32_u32 */
    case 863:  /* *combine_vcvt_f32_s32 */
    case 864:  /* *combine_vcvt_f64_u32 */
    case 865:  /* *combine_vcvt_f64_s32 */
    case 866:  /* *combine_vcvtf2i */
    case 884:  /* btruncsf2 */
    case 887:  /* nearbyintsf2 */
    case 888:  /* rintsf2 */
    case 890:  /* btruncdf2 */
    case 893:  /* nearbyintdf2 */
    case 894:  /* rintdf2 */
    case 1006:  /* *thumb2_pop_single */
    case 1007:  /* *thumb2_movsi_insn */
    case 1009:  /* *thumb2_movhi_insn */
    case 1037:  /* *thumb2_extendqisi_v6 */
    case 1038:  /* *thumb2_zero_extendhisi2_v6 */
    case 1039:  /* thumb2_zero_extendqisi2_v6 */
    case 1045:  /* *thumb2_alusi3_short */
    case 1046:  /* *thumb2_shiftsi3_short */
    case 1047:  /* *thumb2_movqi_shortim */
    case 1048:  /* *thumb2_movhi_shortim */
    case 1049:  /* *thumb2_movsi_shortim */
    case 1050:  /* *thumb2_addsi_short */
    case 1051:  /* *thumb2_subsi_short */
    case 1054:  /* *thumb2_mulsi_short */
    case 1059:  /* *thumb2_one_cmplsi2_short */
    case 1060:  /* *thumb2_negsi2_short */
    case 1061:  /* *orsi_notsi_si */
    case 1062:  /* *orsi_not_shiftsi_si */
    case 1063:  /* *clear_apsr */
    case 1064:  /* *clear_multiple */
    case 1065:  /* thumb2_asrl */
    case 1066:  /* thumb2_lsll */
    case 1067:  /* thumb2_lsrl */
    case 2873:  /* atomic_loadqi */
    case 2874:  /* atomic_loadhi */
    case 2875:  /* atomic_loadsi */
    case 2876:  /* atomic_storeqi */
    case 2877:  /* atomic_storehi */
    case 2878:  /* atomic_storesi */
    case 2879:  /* arm_atomic_loaddi2_ldrd */
    case 2964:  /* arm_load_exclusiveqi */
    case 2965:  /* arm_load_exclusivehi */
    case 2966:  /* arm_load_acquire_exclusiveqi */
    case 2967:  /* arm_load_acquire_exclusivehi */
    case 2968:  /* arm_load_exclusivesi */
    case 2969:  /* arm_load_acquire_exclusivesi */
    case 2970:  /* arm_load_exclusivedi */
    case 2971:  /* arm_load_acquire_exclusivedi */
    case 2972:  /* arm_store_exclusiveqi */
    case 2973:  /* arm_store_exclusivehi */
    case 2974:  /* arm_store_exclusivesi */
    case 2975:  /* arm_store_exclusivedi */
    case 2976:  /* arm_store_release_exclusivedi */
    case 2977:  /* arm_store_release_exclusiveqi */
    case 2978:  /* arm_store_release_exclusivehi */
    case 2979:  /* arm_store_release_exclusivesi */
    case 2980:  /* addqq3 */
    case 2981:  /* addhq3 */
    case 2982:  /* addsq3 */
    case 2983:  /* adduqq3 */
    case 2984:  /* adduhq3 */
    case 2985:  /* addusq3 */
    case 2986:  /* addha3 */
    case 2987:  /* addsa3 */
    case 2988:  /* adduha3 */
    case 2989:  /* addusa3 */
    case 2990:  /* *arm_addv4qq3 */
    case 2991:  /* *arm_addv2hq3 */
    case 2992:  /* *arm_addv2ha3 */
    case 2993:  /* usaddv4uqq3 */
    case 2994:  /* usaddv2uhq3 */
    case 2995:  /* usadduqq3 */
    case 2996:  /* usadduhq3 */
    case 2997:  /* usaddv2uha3 */
    case 2998:  /* usadduha3 */
    case 2999:  /* *arm_ssaddv4qq3 */
    case 3000:  /* *arm_ssaddv2hq3 */
    case 3001:  /* *arm_ssaddqq3 */
    case 3002:  /* *arm_ssaddhq3 */
    case 3003:  /* *arm_ssaddv2ha3 */
    case 3004:  /* *arm_ssaddha3 */
    case 3005:  /* *arm_ssaddsq3 */
    case 3006:  /* *arm_ssaddsa3 */
    case 3007:  /* subqq3 */
    case 3008:  /* subhq3 */
    case 3009:  /* subsq3 */
    case 3010:  /* subuqq3 */
    case 3011:  /* subuhq3 */
    case 3012:  /* subusq3 */
    case 3013:  /* subha3 */
    case 3014:  /* subsa3 */
    case 3015:  /* subuha3 */
    case 3016:  /* subusa3 */
    case 3017:  /* *arm_subv4qq3 */
    case 3018:  /* *arm_subv2hq3 */
    case 3019:  /* *arm_subv2ha3 */
    case 3020:  /* ussubv4uqq3 */
    case 3021:  /* ussubv2uhq3 */
    case 3022:  /* ussubuqq3 */
    case 3023:  /* ussubuhq3 */
    case 3024:  /* ussubv2uha3 */
    case 3025:  /* ussubuha3 */
    case 3026:  /* *arm_sssubv4qq3 */
    case 3027:  /* *arm_sssubv2hq3 */
    case 3028:  /* *arm_sssubqq3 */
    case 3029:  /* *arm_sssubhq3 */
    case 3030:  /* *arm_sssubv2ha3 */
    case 3031:  /* *arm_sssubha3 */
    case 3032:  /* *arm_sssubsq3 */
    case 3033:  /* *arm_sssubsa3 */
    case 3036:  /* arm_ssatsihi_shift */
    case 3037:  /* arm_usatsihi */
    case 4922:  /* mve_uqrshll_sat64_di */
    case 4923:  /* mve_uqrshll_sat48_di */
    case 4924:  /* mve_sqrshrl_sat64_di */
    case 4925:  /* mve_sqrshrl_sat48_di */
    case 4926:  /* mve_uqrshl_si */
    case 4927:  /* mve_sqrshr_si */
    case 4928:  /* mve_uqshll_di */
    case 4929:  /* mve_urshrl_di */
    case 4930:  /* mve_uqshl_si */
    case 4931:  /* mve_urshr_si */
    case 4932:  /* mve_sqshl_si */
    case 4933:  /* mve_srshr_si */
    case 4934:  /* mve_srshrl_di */
    case 4935:  /* mve_sqshll_di */
      return PREDICABLE_YES;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return PREDICABLE_NO;

    }
}

int
get_attr_pool_range (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 6927:  /* *p *thumb2_movhi_insn */
    case 1009:  /* *thumb2_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  return 4094 /* 0xffe */;
        }

    case 6926:  /* *p *thumb2_movsi_insn */
    case 1007:  /* *thumb2_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 964:  /* *thumb_movdf_insn */
    case 963:  /* *thumb1_movsf_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 962:  /* *thumb1_movhf */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 961:  /* *thumb1_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  return 32 /* 0x20 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xffULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 958:  /* *thumb1_movdi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3fULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x1fULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 4094 /* 0xffe */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 256 /* 0x100 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 532:  /* *cond_iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  return 4096 /* 0x1000 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 6524:  /* *p *movhi_insn_arch4 */
    case 265:  /* *movhi_insn_arch4 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  return 256 /* 0x100 */;
        }

    case 6521:  /* *p *arm_movsi_insn */
    case 257:  /* *arm_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 4096 /* 0x1000 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 258:  /* pic_load_addr_unified */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 4096 /* 0x1000 */;
        }
      else if (which_alternative == 1)
        {
	  return 4094 /* 0xffe */;
        }
      else
        {
	  return 1022 /* 0x3fe */;
        }

    case 259:  /* pic_load_addr_32bit */
      if ((! (
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB))))
        {
	  return 4096 /* 0x1000 */;
        }
      else
        {
	  return 4094 /* 0xffe */;
        }

    case 260:  /* pic_load_addr_thumb1 */
      return 1018 /* 0x3fa */;

    case 531:  /* *iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 4096 /* 0x1000 */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  return 1024 /* 0x400 */;
        }
      else if (which_alternative == 9)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 10)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 11)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 12)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 13)
        {
	  return 1020 /* 0x3fc */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 770:  /* *thumb2_movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 1018 /* 0x3fa */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  return 4094 /* 0xffe */;
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 954:  /* *thumb1_zero_extendqisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  return 32 /* 0x20 */;
        }

    case 956:  /* thumb1_extendhisi2 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  return 1018 /* 0x3fa */;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      return 250 /* 0xfa */;

    case 316:  /* *load_indirect_jump */
    case 6537:  /* *p *load_indirect_jump */
      return 4096 /* 0x1000 */;

    case 533:  /* movv2si_internal */
    case 534:  /* movv4hi_internal */
    case 535:  /* movv8qi_internal */
    case 6623:  /* *p movv2si_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6625:  /* *p movv8qi_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  return 256 /* 0x100 */;
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  return 256 /* 0x100 */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 758:  /* *arm_movsi_vfp */
    case 6848:  /* *p *arm_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 4096 /* 0x1000 */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 9)
        {
	  return 1020 /* 0x3fc */;
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 759:  /* *thumb2_movsi_vfp */
    case 6849:  /* *p *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 1018 /* 0x3fa */;
        }
      else if (which_alternative == 6)
        {
	  return 4094 /* 0xffe */;
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 9)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 10)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 11)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 12)
        {
	  return 1018 /* 0x3fa */;
        }
      else if (which_alternative == 13)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 14)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 15)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 16)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 767:  /* *movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  return 1020 /* 0x3fc */;
        }
      else if (which_alternative == 4)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 4096 /* 0x1000 */;
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 768:  /* *thumb2_movsf_vfp */
    case 6854:  /* *p *thumb2_movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  return 1018 /* 0x3fa */;
        }
      else if (which_alternative == 4)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 5)
        {
	  return 4090 /* 0xffa */;
        }
      else if (which_alternative == 6)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 769:  /* *movdf_vfp */
    case 6855:  /* *p *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 1)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 2)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 3)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 4)
        {
	  return 1020 /* 0x3fc */;
        }
      else if (which_alternative == 5)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 6)
        {
	  return 1020 /* 0x3fc */;
        }
      else if (which_alternative == 7)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else if (which_alternative == 8)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }

    case 1037:  /* *thumb2_extendqisi_v6 */
    case 1038:  /* *thumb2_zero_extendhisi2_v6 */
    case 1039:  /* thumb2_zero_extendqisi2_v6 */
    case 6928:  /* *p *thumb2_extendqisi_v6 */
    case 6929:  /* *p *thumb2_zero_extendhisi2_v6 */
    case 6930:  /* *p thumb2_zero_extendqisi2_v6 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
	    {
	      return get_attr_thumb2_pool_range (insn);
	    }
	  else
	    {
	      return get_attr_arm_pool_range (insn);
	    }
        }
      else
        {
	  return 4094 /* 0xffe */;
        }

    default:
      if ((
#line 79 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(TARGET_THUMB)))
        {
	  return get_attr_thumb2_pool_range (insn);
        }
      else
        {
	  return get_attr_arm_pool_range (insn);
        }

    }
}

enum attr_predicated
get_attr_predicated (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 6353:  /* *p *arm_addsi3 */
    case 6354:  /* *p *addsi3_compare0_scratch */
    case 6355:  /* *p *compare_negsi_si */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6358:  /* *p addsi3_carryin */
    case 6359:  /* *p add0si3_carryin */
    case 6360:  /* *p *addsi3_carryin_alt2 */
    case 6361:  /* *p *addsi3_carryin_shift */
    case 6362:  /* *p subsi3_carryin */
    case 6363:  /* *p rsbsi_carryin_reg */
    case 6364:  /* *p *add_not_cin */
    case 6365:  /* *p add_not_shift_cin */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6368:  /* *p *rsbsi3_carryin_shift */
    case 6369:  /* *p *rsbsi3_carryin_shift_alt */
    case 6370:  /* *p *arm_subsi3_insn */
    case 6371:  /* *p *mul */
    case 6372:  /* *p *mla */
    case 6373:  /* *p *mls */
    case 6374:  /* *p smull */
    case 6375:  /* *p umull */
    case 6376:  /* *p smlal */
    case 6377:  /* *p umlal */
    case 6378:  /* *p *smull_high */
    case 6379:  /* *p *umull_high */
    case 6380:  /* *p mulhisi3 */
    case 6381:  /* *p *mulhisi3tb */
    case 6382:  /* *p *mulhisi3bt */
    case 6383:  /* *p *mulhisi3tt */
    case 6384:  /* *p *arm_maddhisi4 */
    case 6385:  /* *p arm_smlabb_setq */
    case 6386:  /* *p maddhisi4tb */
    case 6387:  /* *p arm_smlatb_setq */
    case 6388:  /* *p maddhisi4tt */
    case 6389:  /* *p arm_smlatt_setq */
    case 6390:  /* *p maddhidi4 */
    case 6391:  /* *p *maddhidi4tb */
    case 6392:  /* *p *maddhidi4tt */
    case 6393:  /* *p arm_smlawb_insn */
    case 6394:  /* *p arm_smlawb_setq_insn */
    case 6395:  /* *p arm_smlawt_insn */
    case 6396:  /* *p arm_smlawt_setq_insn */
    case 6397:  /* *p *arm_andsi3_insn */
    case 6398:  /* *p *zeroextractsi_compare0_scratch */
    case 6399:  /* *p insv_zero */
    case 6400:  /* *p insv_t2 */
    case 6401:  /* *p *bfi */
    case 6402:  /* *p *bfi_alt1 */
    case 6403:  /* *p *bfi_alt2 */
    case 6404:  /* *p *bfi_alt3 */
    case 6405:  /* *p andsi_notsi_si */
    case 6406:  /* *p andsi_not_shiftsi_si */
    case 6407:  /* *p andsi_not_shiftsi_si_scc_no_reuse */
    case 6408:  /* *p andsi_not_shiftsi_si_scc */
    case 6409:  /* *p *iorsi3_insn */
    case 6410:  /* *p *arm_xorsi3 */
    case 6411:  /* *p *andsi_iorsi3_notsi */
    case 6412:  /* *p *smax_0 */
    case 6413:  /* *p *smax_m1 */
    case 6414:  /* *p *smin_0 */
    case 6415:  /* *p arm_qadd_insn */
    case 6416:  /* *p arm_qadd_setq_insn */
    case 6417:  /* *p arm_qsub_insn */
    case 6418:  /* *p arm_qsub_setq_insn */
    case 6419:  /* *p arm_get_apsr */
    case 6420:  /* *p arm_set_apsr */
    case 6421:  /* *p satsi_smin */
    case 6422:  /* *p satsi_smin_setq */
    case 6423:  /* *p satsi_smax */
    case 6424:  /* *p satsi_smax_setq */
    case 6425:  /* *p *satsi_smin_shift */
    case 6426:  /* *p *satsi_smax_shift */
    case 6427:  /* *p *arm_shiftsi3 */
    case 6428:  /* *p *not_shiftsi */
    case 6429:  /* *p unaligned_loadsi */
    case 6430:  /* *p unaligned_loadhis */
    case 6431:  /* *p unaligned_loadhiu */
    case 6432:  /* *p unaligned_storesi */
    case 6433:  /* *p unaligned_storehi */
    case 6434:  /* *p *extv_reg */
    case 6435:  /* *p extzv_t2 */
    case 6436:  /* *p divsi3 */
    case 6437:  /* *p udivsi3 */
    case 6438:  /* *p *arm_negsi2 */
    case 6439:  /* *p *arm_abssi2 */
    case 6440:  /* *p *arm_neg_abssi2 */
    case 6441:  /* *p *arm_one_cmplsi2 */
    case 6442:  /* *p *arm_zero_extendhisi2 */
    case 6443:  /* *p *arm_zero_extendhisi2_v6 */
    case 6444:  /* *p *arm_zero_extendhisi2addsi */
    case 6445:  /* *p *arm_zero_extendqisi2 */
    case 6446:  /* *p *arm_zero_extendqisi2_v6 */
    case 6447:  /* *p *arm_zero_extendqisi2addsi */
    case 6448:  /* *p *compareqi_eq0 */
    case 6449:  /* *p *arm_extendhisi2 */
    case 6450:  /* *p *arm_extendhisi2_v6 */
    case 6451:  /* *p *arm_extendqihi_insn */
    case 6452:  /* *p *arm_extendqisi */
    case 6453:  /* *p *arm_extendqisi_v6 */
    case 6454:  /* *p *arm_extendqisi2addsi */
    case 6455:  /* *p arm_sxtb16 */
    case 6456:  /* *p arm_uxtb16 */
    case 6457:  /* *p arm_qadd8 */
    case 6458:  /* *p arm_qsub8 */
    case 6459:  /* *p arm_shadd8 */
    case 6460:  /* *p arm_shsub8 */
    case 6461:  /* *p arm_uhadd8 */
    case 6462:  /* *p arm_uhsub8 */
    case 6463:  /* *p arm_uqadd8 */
    case 6464:  /* *p arm_uqsub8 */
    case 6465:  /* *p arm_qadd16 */
    case 6466:  /* *p arm_qasx */
    case 6467:  /* *p arm_qsax */
    case 6468:  /* *p arm_qsub16 */
    case 6469:  /* *p arm_shadd16 */
    case 6470:  /* *p arm_shasx */
    case 6471:  /* *p arm_shsax */
    case 6472:  /* *p arm_shsub16 */
    case 6473:  /* *p arm_uhadd16 */
    case 6474:  /* *p arm_uhasx */
    case 6475:  /* *p arm_uhsax */
    case 6476:  /* *p arm_uhsub16 */
    case 6477:  /* *p arm_uqadd16 */
    case 6478:  /* *p arm_uqasx */
    case 6479:  /* *p arm_uqsax */
    case 6480:  /* *p arm_uqsub16 */
    case 6481:  /* *p arm_smusd */
    case 6482:  /* *p arm_smusdx */
    case 6483:  /* *p arm_sxtab16 */
    case 6484:  /* *p arm_uxtab16 */
    case 6485:  /* *p arm_usad8 */
    case 6486:  /* *p arm_usada8 */
    case 6487:  /* *p arm_smlald */
    case 6488:  /* *p arm_smlaldx */
    case 6489:  /* *p arm_smlsld */
    case 6490:  /* *p arm_smlsldx */
    case 6491:  /* *p arm_sadd8 */
    case 6492:  /* *p arm_ssub8 */
    case 6493:  /* *p arm_uadd8 */
    case 6494:  /* *p arm_usub8 */
    case 6495:  /* *p arm_sadd16 */
    case 6496:  /* *p arm_sasx */
    case 6497:  /* *p arm_ssax */
    case 6498:  /* *p arm_ssub16 */
    case 6499:  /* *p arm_uadd16 */
    case 6500:  /* *p arm_uasx */
    case 6501:  /* *p arm_usax */
    case 6502:  /* *p arm_usub16 */
    case 6503:  /* *p arm_smlad_insn */
    case 6504:  /* *p arm_smlad_setq_insn */
    case 6505:  /* *p arm_smladx_insn */
    case 6506:  /* *p arm_smladx_setq_insn */
    case 6507:  /* *p arm_smlsd_insn */
    case 6508:  /* *p arm_smlsd_setq_insn */
    case 6509:  /* *p arm_smlsdx_insn */
    case 6510:  /* *p arm_smlsdx_setq_insn */
    case 6511:  /* *p arm_smuad_insn */
    case 6512:  /* *p arm_smuad_setq_insn */
    case 6513:  /* *p arm_smuadx_insn */
    case 6514:  /* *p arm_smuadx_setq_insn */
    case 6515:  /* *p arm_ssat16_insn */
    case 6516:  /* *p arm_ssat16_setq_insn */
    case 6517:  /* *p arm_usat16_insn */
    case 6518:  /* *p arm_usat16_setq_insn */
    case 6519:  /* *p arm_sel */
    case 6520:  /* *p *arm_movt */
    case 6521:  /* *p *arm_movsi_insn */
    case 6522:  /* *p pic_add_dot_plus_eight */
    case 6523:  /* *p tls_load_dot_plus_eight */
    case 6524:  /* *p *movhi_insn_arch4 */
    case 6525:  /* *p *movhi_bytes */
    case 6526:  /* *p *arm_movqi_insn */
    case 6527:  /* *p *arm32_movhf */
    case 6528:  /* *p *arm32_movbf */
    case 6529:  /* *p *arm_movsf_soft_insn */
    case 6530:  /* *p *arm_cmpsi_insn */
    case 6531:  /* *p *arm_cmpsi_negshiftsi_si */
    case 6532:  /* *p *arm_jump */
    case 6533:  /* *p *arm_return */
    case 6534:  /* *p *arm_simple_return */
    case 6535:  /* *p probe_stack */
    case 6536:  /* *p *arm_indirect_jump */
    case 6537:  /* *p *load_indirect_jump */
    case 6538:  /* *p *add_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6542:  /* *p *and_multsi */
    case 6543:  /* *p *add_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6547:  /* *p *and_shiftsi */
    case 6548:  /* *p *sub_shiftsi */
    case 6549:  /* *p *arith_adjacentmem */
    case 6550:  /* *p *load_multiple_with_writeback */
    case 6551:  /* *p *pop_multiple_with_writeback_and_return */
    case 6552:  /* *p *pop_multiple_with_return */
    case 6553:  /* *p *ldr_with_return */
    case 6554:  /* *p clzsi2 */
    case 6555:  /* *p rbitsi2 */
    case 6556:  /* *p load_tp_hard */
    case 6557:  /* *p *arm_movtas_ze */
    case 6558:  /* *p *arm_rev */
    case 6559:  /* *p *thumb2_ldrd */
    case 6560:  /* *p *thumb2_ldrd_base */
    case 6561:  /* *p *thumb2_ldrd_base_neg */
    case 6562:  /* *p *thumb2_strd */
    case 6563:  /* *p *thumb2_strd_base */
    case 6564:  /* *p *thumb2_strd_base_neg */
    case 6565:  /* *p *arm_ldrd */
    case 6566:  /* *p *arm_strd */
    case 6567:  /* *p *ldm4_ */
    case 6568:  /* *p *ldm4_ia_update */
    case 6569:  /* *p *stm4_ */
    case 6570:  /* *p *stm4_ia_update */
    case 6571:  /* *p *ldm4_ib */
    case 6572:  /* *p *ldm4_ib_update */
    case 6573:  /* *p *stm4_ib */
    case 6574:  /* *p *stm4_ib_update */
    case 6575:  /* *p *ldm4_da */
    case 6576:  /* *p *ldm4_da_update */
    case 6577:  /* *p *stm4_da */
    case 6578:  /* *p *stm4_da_update */
    case 6579:  /* *p *ldm4_db */
    case 6580:  /* *p *ldm4_db_update */
    case 6581:  /* *p *stm4_db */
    case 6582:  /* *p *stm4_db_update */
    case 6583:  /* *p *ldm3_ */
    case 6584:  /* *p *ldm3_ia_update */
    case 6585:  /* *p *stm3_ */
    case 6586:  /* *p *stm3_ia_update */
    case 6587:  /* *p *ldm3_ib */
    case 6588:  /* *p *ldm3_ib_update */
    case 6589:  /* *p *stm3_ib */
    case 6590:  /* *p *stm3_ib_update */
    case 6591:  /* *p *ldm3_da */
    case 6592:  /* *p *ldm3_da_update */
    case 6593:  /* *p *stm3_da */
    case 6594:  /* *p *stm3_da_update */
    case 6595:  /* *p *ldm3_db */
    case 6596:  /* *p *ldm3_db_update */
    case 6597:  /* *p *stm3_db */
    case 6598:  /* *p *stm3_db_update */
    case 6599:  /* *p *ldm2_ */
    case 6600:  /* *p *ldm2_ia_update */
    case 6601:  /* *p *stm2_ */
    case 6602:  /* *p *stm2_ia_update */
    case 6603:  /* *p *ldm2_ib */
    case 6604:  /* *p *ldm2_ib_update */
    case 6605:  /* *p *stm2_ib */
    case 6606:  /* *p *stm2_ib_update */
    case 6607:  /* *p *ldm2_da */
    case 6608:  /* *p *ldm2_da_update */
    case 6609:  /* *p *stm2_da */
    case 6610:  /* *p *stm2_da_update */
    case 6611:  /* *p *ldm2_db */
    case 6612:  /* *p *ldm2_db_update */
    case 6613:  /* *p *stm2_db */
    case 6614:  /* *p *stm2_db_update */
    case 6615:  /* *p *load_multiple */
    case 6616:  /* *p tbcstv8qi */
    case 6617:  /* *p tbcstv4hi */
    case 6618:  /* *p tbcstv2si */
    case 6619:  /* *p iwmmxt_iordi3 */
    case 6620:  /* *p iwmmxt_xordi3 */
    case 6621:  /* *p iwmmxt_anddi3 */
    case 6622:  /* *p iwmmxt_nanddi3 */
    case 6623:  /* *p movv2si_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6625:  /* *p movv8qi_internal */
    case 6626:  /* *p *andv2si3_iwmmxt */
    case 6627:  /* *p *andv4hi3_iwmmxt */
    case 6628:  /* *p *andv8qi3_iwmmxt */
    case 6629:  /* *p *iorv2si3_iwmmxt */
    case 6630:  /* *p *iorv4hi3_iwmmxt */
    case 6631:  /* *p *iorv8qi3_iwmmxt */
    case 6632:  /* *p *xorv2si3_iwmmxt */
    case 6633:  /* *p *xorv4hi3_iwmmxt */
    case 6634:  /* *p *xorv8qi3_iwmmxt */
    case 6635:  /* *p *addv2si3_iwmmxt */
    case 6636:  /* *p *addv4hi3_iwmmxt */
    case 6637:  /* *p *addv8qi3_iwmmxt */
    case 6638:  /* *p ssaddv8qi3 */
    case 6639:  /* *p ssaddv4hi3 */
    case 6640:  /* *p ssaddv2si3 */
    case 6641:  /* *p usaddv8qi3 */
    case 6642:  /* *p usaddv4hi3 */
    case 6643:  /* *p usaddv2si3 */
    case 6644:  /* *p *subv2si3_iwmmxt */
    case 6645:  /* *p *subv4hi3_iwmmxt */
    case 6646:  /* *p *subv8qi3_iwmmxt */
    case 6647:  /* *p sssubv8qi3 */
    case 6648:  /* *p sssubv4hi3 */
    case 6649:  /* *p sssubv2si3 */
    case 6650:  /* *p ussubv8qi3 */
    case 6651:  /* *p ussubv4hi3 */
    case 6652:  /* *p ussubv2si3 */
    case 6653:  /* *p *mulv4hi3_iwmmxt */
    case 6654:  /* *p smulv4hi3_highpart */
    case 6655:  /* *p umulv4hi3_highpart */
    case 6656:  /* *p iwmmxt_wmacs */
    case 6657:  /* *p iwmmxt_wmacsz */
    case 6658:  /* *p iwmmxt_wmacu */
    case 6659:  /* *p iwmmxt_wmacuz */
    case 6660:  /* *p iwmmxt_clrdi */
    case 6661:  /* *p iwmmxt_clrv8qi */
    case 6662:  /* *p iwmmxt_clrv4hi */
    case 6663:  /* *p iwmmxt_clrv2si */
    case 6664:  /* *p iwmmxt_uavgrndv8qi3 */
    case 6665:  /* *p iwmmxt_uavgrndv4hi3 */
    case 6666:  /* *p iwmmxt_uavgv8qi3 */
    case 6667:  /* *p iwmmxt_uavgv4hi3 */
    case 6668:  /* *p iwmmxt_tinsrb */
    case 6669:  /* *p iwmmxt_tinsrh */
    case 6670:  /* *p iwmmxt_tinsrw */
    case 6671:  /* *p iwmmxt_textrmub */
    case 6672:  /* *p iwmmxt_textrmsb */
    case 6673:  /* *p iwmmxt_textrmuh */
    case 6674:  /* *p iwmmxt_textrmsh */
    case 6675:  /* *p iwmmxt_textrmw */
    case 6676:  /* *p iwmmxt_wshufh */
    case 6677:  /* *p eqv8qi3 */
    case 6678:  /* *p eqv4hi3 */
    case 6679:  /* *p eqv2si3 */
    case 6680:  /* *p gtuv8qi3 */
    case 6681:  /* *p gtuv4hi3 */
    case 6682:  /* *p gtuv2si3 */
    case 6683:  /* *p gtv8qi3 */
    case 6684:  /* *p gtv4hi3 */
    case 6685:  /* *p gtv2si3 */
    case 6686:  /* *p *smaxv2si3_iwmmxt */
    case 6687:  /* *p *smaxv4hi3_iwmmxt */
    case 6688:  /* *p *smaxv8qi3_iwmmxt */
    case 6689:  /* *p *umaxv2si3_iwmmxt */
    case 6690:  /* *p *umaxv4hi3_iwmmxt */
    case 6691:  /* *p *umaxv8qi3_iwmmxt */
    case 6692:  /* *p *sminv2si3_iwmmxt */
    case 6693:  /* *p *sminv4hi3_iwmmxt */
    case 6694:  /* *p *sminv8qi3_iwmmxt */
    case 6695:  /* *p *uminv2si3_iwmmxt */
    case 6696:  /* *p *uminv4hi3_iwmmxt */
    case 6697:  /* *p *uminv8qi3_iwmmxt */
    case 6698:  /* *p iwmmxt_wpackhss */
    case 6699:  /* *p iwmmxt_wpackwss */
    case 6700:  /* *p iwmmxt_wpackdss */
    case 6701:  /* *p iwmmxt_wpackhus */
    case 6702:  /* *p iwmmxt_wpackwus */
    case 6703:  /* *p iwmmxt_wpackdus */
    case 6704:  /* *p iwmmxt_wunpckihb */
    case 6705:  /* *p iwmmxt_wunpckihh */
    case 6706:  /* *p iwmmxt_wunpckihw */
    case 6707:  /* *p iwmmxt_wunpckilb */
    case 6708:  /* *p iwmmxt_wunpckilh */
    case 6709:  /* *p iwmmxt_wunpckilw */
    case 6710:  /* *p iwmmxt_wunpckehub */
    case 6711:  /* *p iwmmxt_wunpckehuh */
    case 6712:  /* *p iwmmxt_wunpckehuw */
    case 6713:  /* *p iwmmxt_wunpckehsb */
    case 6714:  /* *p iwmmxt_wunpckehsh */
    case 6715:  /* *p iwmmxt_wunpckehsw */
    case 6716:  /* *p iwmmxt_wunpckelub */
    case 6717:  /* *p iwmmxt_wunpckeluh */
    case 6718:  /* *p iwmmxt_wunpckeluw */
    case 6719:  /* *p iwmmxt_wunpckelsb */
    case 6720:  /* *p iwmmxt_wunpckelsh */
    case 6721:  /* *p iwmmxt_wunpckelsw */
    case 6722:  /* *p rorv4hi3 */
    case 6723:  /* *p rorv2si3 */
    case 6724:  /* *p rordi3 */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6734:  /* *p rorv4hi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6736:  /* *p rordi3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6745:  /* *p ashldi3_di */
    case 6746:  /* *p iwmmxt_wmadds */
    case 6747:  /* *p iwmmxt_wmaddu */
    case 6748:  /* *p iwmmxt_tmia */
    case 6749:  /* *p iwmmxt_tmiaph */
    case 6750:  /* *p iwmmxt_tmiabb */
    case 6751:  /* *p iwmmxt_tmiatb */
    case 6752:  /* *p iwmmxt_tmiabt */
    case 6753:  /* *p iwmmxt_tmiatt */
    case 6754:  /* *p iwmmxt_tmovmskb */
    case 6755:  /* *p iwmmxt_tmovmskh */
    case 6756:  /* *p iwmmxt_tmovmskw */
    case 6757:  /* *p iwmmxt_waccb */
    case 6758:  /* *p iwmmxt_wacch */
    case 6759:  /* *p iwmmxt_waccw */
    case 6760:  /* *p iwmmxt_waligni */
    case 6761:  /* *p iwmmxt_walignr */
    case 6762:  /* *p iwmmxt_walignr0 */
    case 6763:  /* *p iwmmxt_walignr1 */
    case 6764:  /* *p iwmmxt_walignr2 */
    case 6765:  /* *p iwmmxt_walignr3 */
    case 6766:  /* *p iwmmxt_wsadb */
    case 6767:  /* *p iwmmxt_wsadh */
    case 6768:  /* *p iwmmxt_wsadbz */
    case 6769:  /* *p iwmmxt_wsadhz */
    case 6770:  /* *p iwmmxt_wabsv2si3 */
    case 6771:  /* *p iwmmxt_wabsv4hi3 */
    case 6772:  /* *p iwmmxt_wabsv8qi3 */
    case 6773:  /* *p iwmmxt_wabsdiffb */
    case 6774:  /* *p iwmmxt_wabsdiffh */
    case 6775:  /* *p iwmmxt_wabsdiffw */
    case 6776:  /* *p iwmmxt_waddsubhx */
    case 6777:  /* *p iwmmxt_wsubaddhx */
    case 6778:  /* *p addcv4hi3 */
    case 6779:  /* *p addcv2si3 */
    case 6780:  /* *p iwmmxt_avg4 */
    case 6781:  /* *p iwmmxt_avg4r */
    case 6782:  /* *p iwmmxt_wmaddsx */
    case 6783:  /* *p iwmmxt_wmaddux */
    case 6784:  /* *p iwmmxt_wmaddsn */
    case 6785:  /* *p iwmmxt_wmaddun */
    case 6786:  /* *p iwmmxt_wmulwsm */
    case 6787:  /* *p iwmmxt_wmulwum */
    case 6788:  /* *p iwmmxt_wmulsmr */
    case 6789:  /* *p iwmmxt_wmulumr */
    case 6790:  /* *p iwmmxt_wmulwsmr */
    case 6791:  /* *p iwmmxt_wmulwumr */
    case 6792:  /* *p iwmmxt_wmulwl */
    case 6793:  /* *p iwmmxt_wqmulm */
    case 6794:  /* *p iwmmxt_wqmulwm */
    case 6795:  /* *p iwmmxt_wqmulmr */
    case 6796:  /* *p iwmmxt_wqmulwmr */
    case 6797:  /* *p iwmmxt_waddbhusm */
    case 6798:  /* *p iwmmxt_waddbhusl */
    case 6799:  /* *p iwmmxt_wqmiabb */
    case 6800:  /* *p iwmmxt_wqmiabt */
    case 6801:  /* *p iwmmxt_wqmiatb */
    case 6802:  /* *p iwmmxt_wqmiatt */
    case 6803:  /* *p iwmmxt_wqmiabbn */
    case 6804:  /* *p iwmmxt_wqmiabtn */
    case 6805:  /* *p iwmmxt_wqmiatbn */
    case 6806:  /* *p iwmmxt_wqmiattn */
    case 6807:  /* *p iwmmxt_wmiabb */
    case 6808:  /* *p iwmmxt_wmiabt */
    case 6809:  /* *p iwmmxt_wmiatb */
    case 6810:  /* *p iwmmxt_wmiatt */
    case 6811:  /* *p iwmmxt_wmiabbn */
    case 6812:  /* *p iwmmxt_wmiabtn */
    case 6813:  /* *p iwmmxt_wmiatbn */
    case 6814:  /* *p iwmmxt_wmiattn */
    case 6815:  /* *p iwmmxt_wmiawbb */
    case 6816:  /* *p iwmmxt_wmiawbt */
    case 6817:  /* *p iwmmxt_wmiawtb */
    case 6818:  /* *p iwmmxt_wmiawtt */
    case 6819:  /* *p iwmmxt_wmiawbbn */
    case 6820:  /* *p iwmmxt_wmiawbtn */
    case 6821:  /* *p iwmmxt_wmiawtbn */
    case 6822:  /* *p iwmmxt_wmiawttn */
    case 6823:  /* *p iwmmxt_wmerge */
    case 6824:  /* *p iwmmxt_tandcv2si3 */
    case 6825:  /* *p iwmmxt_tandcv4hi3 */
    case 6826:  /* *p iwmmxt_tandcv8qi3 */
    case 6827:  /* *p iwmmxt_torcv2si3 */
    case 6828:  /* *p iwmmxt_torcv4hi3 */
    case 6829:  /* *p iwmmxt_torcv8qi3 */
    case 6830:  /* *p iwmmxt_torvscv2si3 */
    case 6831:  /* *p iwmmxt_torvscv4hi3 */
    case 6832:  /* *p iwmmxt_torvscv8qi3 */
    case 6833:  /* *p iwmmxt_textrcv2si3 */
    case 6834:  /* *p iwmmxt_textrcv4hi3 */
    case 6835:  /* *p iwmmxt_textrcv8qi3 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6842:  /* *p *arm_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6848:  /* *p *arm_movsi_vfp */
    case 6849:  /* *p *thumb2_movsi_vfp */
    case 6850:  /* *p *movdi_vfp */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6853:  /* *p *movsf_vfp */
    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6855:  /* *p *movdf_vfp */
    case 6856:  /* *p *abssf2_vfp */
    case 6857:  /* *p *absdf2_vfp */
    case 6858:  /* *p *negsf2_vfp */
    case 6859:  /* *p *negdf2_vfp */
    case 6860:  /* *p *addsf3_vfp */
    case 6861:  /* *p *adddf3_vfp */
    case 6862:  /* *p *subsf3_vfp */
    case 6863:  /* *p *subdf3_vfp */
    case 6864:  /* *p *divsf3_vfp */
    case 6865:  /* *p *divdf3_vfp */
    case 6866:  /* *p *mulsf3_vfp */
    case 6867:  /* *p *muldf3_vfp */
    case 6868:  /* *p *mulsf3negsf_vfp */
    case 6869:  /* *p *negmulsf3_vfp */
    case 6870:  /* *p *muldf3negdf_vfp */
    case 6871:  /* *p *negmuldf3_vfp */
    case 6872:  /* *p *mulsf3addsf_vfp */
    case 6873:  /* *p *muldf3adddf_vfp */
    case 6874:  /* *p *mulsf3subsf_vfp */
    case 6875:  /* *p *muldf3subdf_vfp */
    case 6876:  /* *p *mulsf3negsfaddsf_vfp */
    case 6877:  /* *p *fmuldf3negdfadddf_vfp */
    case 6878:  /* *p *mulsf3negsfsubsf_vfp */
    case 6879:  /* *p *muldf3negdfsubdf_vfp */
    case 6880:  /* *p fmasf4 */
    case 6881:  /* *p fmadf4 */
    case 6882:  /* *p *fmsubsf4 */
    case 6883:  /* *p *fmsubdf4 */
    case 6884:  /* *p *fnmsubsf4 */
    case 6885:  /* *p *fnmsubdf4 */
    case 6886:  /* *p *fnmaddsf4 */
    case 6887:  /* *p *fnmadddf4 */
    case 6888:  /* *p *extendsfdf2_vfp */
    case 6889:  /* *p *truncdfsf2_vfp */
    case 6890:  /* *p extendhfsf2 */
    case 6891:  /* *p *truncdfhf2 */
    case 6892:  /* *p *extendhfdf2 */
    case 6893:  /* *p truncsfhf2 */
    case 6894:  /* *p *truncsisf2_vfp */
    case 6895:  /* *p *truncsidf2_vfp */
    case 6896:  /* *p fixuns_truncsfsi2 */
    case 6897:  /* *p fixuns_truncdfsi2 */
    case 6898:  /* *p *floatsisf2_vfp */
    case 6899:  /* *p *floatsidf2_vfp */
    case 6900:  /* *p floatunssisf2 */
    case 6901:  /* *p floatunssidf2 */
    case 6902:  /* *p *sqrtsf2_vfp */
    case 6903:  /* *p *sqrtdf2_vfp */
    case 6904:  /* *p push_fpsysreg_insn */
    case 6905:  /* *p pop_fpsysreg_insn */
    case 6906:  /* *p *clear_vfp_multiple */
    case 6907:  /* *p lazy_store_multiple_insn */
    case 6908:  /* *p *cmpsf_vfp */
    case 6909:  /* *p *cmpsf_trap_vfp */
    case 6910:  /* *p *cmpdf_vfp */
    case 6911:  /* *p *cmpdf_trap_vfp */
    case 6912:  /* *p *combine_vcvt_f32_u32 */
    case 6913:  /* *p *combine_vcvt_f32_s32 */
    case 6914:  /* *p *combine_vcvt_f64_u32 */
    case 6915:  /* *p *combine_vcvt_f64_s32 */
    case 6916:  /* *p *combine_vcvtf2i */
    case 6917:  /* *p btruncsf2 */
    case 6918:  /* *p nearbyintsf2 */
    case 6919:  /* *p rintsf2 */
    case 6920:  /* *p btruncdf2 */
    case 6921:  /* *p nearbyintdf2 */
    case 6922:  /* *p rintdf2 */
    case 6923:  /* *p *thumb2_abssi2 */
    case 6924:  /* *p *thumb2_neg_abssi2 */
    case 6925:  /* *p *thumb2_pop_single */
    case 6926:  /* *p *thumb2_movsi_insn */
    case 6927:  /* *p *thumb2_movhi_insn */
    case 6928:  /* *p *thumb2_extendqisi_v6 */
    case 6929:  /* *p *thumb2_zero_extendhisi2_v6 */
    case 6930:  /* *p thumb2_zero_extendqisi2_v6 */
    case 6931:  /* *p *thumb2_alusi3_short */
    case 6932:  /* *p *thumb2_shiftsi3_short */
    case 6933:  /* *p *thumb2_movqi_shortim */
    case 6934:  /* *p *thumb2_movhi_shortim */
    case 6935:  /* *p *thumb2_movsi_shortim */
    case 6936:  /* *p *thumb2_addsi_short */
    case 6937:  /* *p *thumb2_subsi_short */
    case 6938:  /* *p *thumb2_mulsi_short */
    case 6939:  /* *p *thumb2_one_cmplsi2_short */
    case 6940:  /* *p *thumb2_negsi2_short */
    case 6941:  /* *p *orsi_notsi_si */
    case 6942:  /* *p *orsi_not_shiftsi_si */
    case 6943:  /* *p *clear_apsr */
    case 6944:  /* *p *clear_multiple */
    case 6945:  /* *p thumb2_asrl */
    case 6946:  /* *p thumb2_lsll */
    case 6947:  /* *p thumb2_lsrl */
    case 6948:  /* *p atomic_loadqi */
    case 6949:  /* *p atomic_loadhi */
    case 6950:  /* *p atomic_loadsi */
    case 6951:  /* *p atomic_storeqi */
    case 6952:  /* *p atomic_storehi */
    case 6953:  /* *p atomic_storesi */
    case 6954:  /* *p arm_atomic_loaddi2_ldrd */
    case 6955:  /* *p arm_load_exclusiveqi */
    case 6956:  /* *p arm_load_exclusivehi */
    case 6957:  /* *p arm_load_acquire_exclusiveqi */
    case 6958:  /* *p arm_load_acquire_exclusivehi */
    case 6959:  /* *p arm_load_exclusivesi */
    case 6960:  /* *p arm_load_acquire_exclusivesi */
    case 6961:  /* *p arm_load_exclusivedi */
    case 6962:  /* *p arm_load_acquire_exclusivedi */
    case 6963:  /* *p arm_store_exclusiveqi */
    case 6964:  /* *p arm_store_exclusivehi */
    case 6965:  /* *p arm_store_exclusivesi */
    case 6966:  /* *p arm_store_exclusivedi */
    case 6967:  /* *p arm_store_release_exclusivedi */
    case 6968:  /* *p arm_store_release_exclusiveqi */
    case 6969:  /* *p arm_store_release_exclusivehi */
    case 6970:  /* *p arm_store_release_exclusivesi */
    case 6971:  /* *p addqq3 */
    case 6972:  /* *p addhq3 */
    case 6973:  /* *p addsq3 */
    case 6974:  /* *p adduqq3 */
    case 6975:  /* *p adduhq3 */
    case 6976:  /* *p addusq3 */
    case 6977:  /* *p addha3 */
    case 6978:  /* *p addsa3 */
    case 6979:  /* *p adduha3 */
    case 6980:  /* *p addusa3 */
    case 6981:  /* *p *arm_addv4qq3 */
    case 6982:  /* *p *arm_addv2hq3 */
    case 6983:  /* *p *arm_addv2ha3 */
    case 6984:  /* *p usaddv4uqq3 */
    case 6985:  /* *p usaddv2uhq3 */
    case 6986:  /* *p usadduqq3 */
    case 6987:  /* *p usadduhq3 */
    case 6988:  /* *p usaddv2uha3 */
    case 6989:  /* *p usadduha3 */
    case 6990:  /* *p *arm_ssaddv4qq3 */
    case 6991:  /* *p *arm_ssaddv2hq3 */
    case 6992:  /* *p *arm_ssaddqq3 */
    case 6993:  /* *p *arm_ssaddhq3 */
    case 6994:  /* *p *arm_ssaddv2ha3 */
    case 6995:  /* *p *arm_ssaddha3 */
    case 6996:  /* *p *arm_ssaddsq3 */
    case 6997:  /* *p *arm_ssaddsa3 */
    case 6998:  /* *p subqq3 */
    case 6999:  /* *p subhq3 */
    case 7000:  /* *p subsq3 */
    case 7001:  /* *p subuqq3 */
    case 7002:  /* *p subuhq3 */
    case 7003:  /* *p subusq3 */
    case 7004:  /* *p subha3 */
    case 7005:  /* *p subsa3 */
    case 7006:  /* *p subuha3 */
    case 7007:  /* *p subusa3 */
    case 7008:  /* *p *arm_subv4qq3 */
    case 7009:  /* *p *arm_subv2hq3 */
    case 7010:  /* *p *arm_subv2ha3 */
    case 7011:  /* *p ussubv4uqq3 */
    case 7012:  /* *p ussubv2uhq3 */
    case 7013:  /* *p ussubuqq3 */
    case 7014:  /* *p ussubuhq3 */
    case 7015:  /* *p ussubv2uha3 */
    case 7016:  /* *p ussubuha3 */
    case 7017:  /* *p *arm_sssubv4qq3 */
    case 7018:  /* *p *arm_sssubv2hq3 */
    case 7019:  /* *p *arm_sssubqq3 */
    case 7020:  /* *p *arm_sssubhq3 */
    case 7021:  /* *p *arm_sssubv2ha3 */
    case 7022:  /* *p *arm_sssubha3 */
    case 7023:  /* *p *arm_sssubsq3 */
    case 7024:  /* *p *arm_sssubsa3 */
    case 7025:  /* *p arm_ssatsihi_shift */
    case 7026:  /* *p arm_usatsihi */
    case 7027:  /* *p mve_uqrshll_sat64_di */
    case 7028:  /* *p mve_uqrshll_sat48_di */
    case 7029:  /* *p mve_sqrshrl_sat64_di */
    case 7030:  /* *p mve_sqrshrl_sat48_di */
    case 7031:  /* *p mve_uqrshl_si */
    case 7032:  /* *p mve_sqrshr_si */
    case 7033:  /* *p mve_uqshll_di */
    case 7034:  /* *p mve_urshrl_di */
    case 7035:  /* *p mve_uqshl_si */
    case 7036:  /* *p mve_urshr_si */
    case 7037:  /* *p mve_sqshl_si */
    case 7038:  /* *p mve_srshr_si */
    case 7039:  /* *p mve_srshrl_di */
    case 7040:  /* *p mve_sqshll_di */
      return PREDICATED_YES;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return PREDICATED_NO;

    }
}

enum attr_predicable_short_it
get_attr_predicable_short_it (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return PREDICABLE_SHORT_IT_NO;
        }
      else if (which_alternative == 3)
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else
        {
	  return PREDICABLE_SHORT_IT_NO;
        }

    case 6927:  /* *p *thumb2_movhi_insn */
    case 6926:  /* *p *thumb2_movsi_insn */
    case 6849:  /* *p *thumb2_movsi_vfp */
    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 1009:  /* *thumb2_movhi_insn */
    case 1007:  /* *thumb2_movsi_insn */
    case 759:  /* *thumb2_movsi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else if (which_alternative == 1)
        {
	  return PREDICABLE_SHORT_IT_NO;
        }
      else if (which_alternative == 2)
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else
        {
	  return PREDICABLE_SHORT_IT_NO;
        }

    case 6530:  /* *p *arm_cmpsi_insn */
    case 272:  /* *arm_cmpsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else
        {
	  return PREDICABLE_SHORT_IT_NO;
        }

    case 6526:  /* *p *arm_movqi_insn */
    case 267:  /* *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else if (which_alternative == 2)
        {
	  return PREDICABLE_SHORT_IT_NO;
        }
      else if (which_alternative == 3)
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else
        {
	  return PREDICABLE_SHORT_IT_NO;
        }

    case 6427:  /* *p *arm_shiftsi3 */
    case 6357:  /* *p *compare_addsi2_op1 */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 151:  /* *arm_shiftsi3 */
    case 20:  /* *compare_addsi2_op1 */
    case 19:  /* *compare_addsi2_op0 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else
        {
	  return PREDICABLE_SHORT_IT_NO;
        }

    case 6370:  /* *p *arm_subsi3_insn */
    case 6353:  /* *p *arm_addsi3 */
    case 45:  /* *arm_subsi3_insn */
    case 7:  /* *arm_addsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else
        {
	  return PREDICABLE_SHORT_IT_NO;
        }

    case 6410:  /* *p *arm_xorsi3 */
    case 6409:  /* *p *iorsi3_insn */
    case 6397:  /* *p *arm_andsi3_insn */
    case 113:  /* *arm_xorsi3 */
    case 110:  /* *iorsi3_insn */
    case 90:  /* *arm_andsi3_insn */
    case 158:  /* unaligned_loadsi */
    case 160:  /* unaligned_loadhiu */
    case 162:  /* unaligned_storesi */
    case 163:  /* unaligned_storehi */
    case 6429:  /* *p unaligned_loadsi */
    case 6431:  /* *p unaligned_loadhiu */
    case 6432:  /* *p unaligned_storesi */
    case 6433:  /* *p unaligned_storehi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return PREDICABLE_SHORT_IT_NO;
        }
      else if (which_alternative == 1)
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else
        {
	  return PREDICABLE_SHORT_IT_NO;
        }

    case 6371:  /* *p *mul */
    case 6360:  /* *p *addsi3_carryin_alt2 */
    case 6358:  /* *p addsi3_carryin */
    case 56:  /* *mul */
    case 23:  /* *addsi3_carryin_alt2 */
    case 21:  /* addsi3_carryin */
    case 15:  /* *compare_negsi_si */
    case 168:  /* *arm_negsi2 */
    case 173:  /* *arm_one_cmplsi2 */
    case 2980:  /* addqq3 */
    case 2981:  /* addhq3 */
    case 2982:  /* addsq3 */
    case 2983:  /* adduqq3 */
    case 2984:  /* adduhq3 */
    case 2985:  /* addusq3 */
    case 2986:  /* addha3 */
    case 2987:  /* addsa3 */
    case 2988:  /* adduha3 */
    case 2989:  /* addusa3 */
    case 3007:  /* subqq3 */
    case 3008:  /* subhq3 */
    case 3009:  /* subsq3 */
    case 3010:  /* subuqq3 */
    case 3011:  /* subuhq3 */
    case 3012:  /* subusq3 */
    case 3013:  /* subha3 */
    case 3014:  /* subsa3 */
    case 3015:  /* subuha3 */
    case 3016:  /* subusa3 */
    case 6355:  /* *p *compare_negsi_si */
    case 6438:  /* *p *arm_negsi2 */
    case 6441:  /* *p *arm_one_cmplsi2 */
    case 6971:  /* *p addqq3 */
    case 6972:  /* *p addhq3 */
    case 6973:  /* *p addsq3 */
    case 6974:  /* *p adduqq3 */
    case 6975:  /* *p adduhq3 */
    case 6976:  /* *p addusq3 */
    case 6977:  /* *p addha3 */
    case 6978:  /* *p addsa3 */
    case 6979:  /* *p adduha3 */
    case 6980:  /* *p addusa3 */
    case 6998:  /* *p subqq3 */
    case 6999:  /* *p subhq3 */
    case 7000:  /* *p subsq3 */
    case 7001:  /* *p subuqq3 */
    case 7002:  /* *p subuhq3 */
    case 7003:  /* *p subusq3 */
    case 7004:  /* *p subha3 */
    case 7005:  /* *p subsa3 */
    case 7006:  /* *p subuha3 */
    case 7007:  /* *p subusa3 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return PREDICABLE_SHORT_IT_YES;
        }
      else
        {
	  return PREDICABLE_SHORT_IT_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return PREDICABLE_SHORT_IT_NO;

    }
}

enum attr_required_for_purecode
get_attr_required_for_purecode (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7fULL))
        {
	  return REQUIRED_FOR_PURECODE_NO;
        }
      else if (which_alternative == 7)
        {
	  return REQUIRED_FOR_PURECODE_YES;
        }
      else
        {
	  return REQUIRED_FOR_PURECODE_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return REQUIRED_FOR_PURECODE_NO;

    }
}

int
get_attr_shift (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 329:  /* *arith_shiftsi_compare0 */
    case 330:  /* *arith_shiftsi_compare0_scratch */
      return 4;

    case 24:  /* *addsi3_carryin_shift */
    case 41:  /* *subsi3_carryin_shift */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 137:  /* *satsi_smin_shift */
    case 138:  /* *satsi_smax_shift */
    case 324:  /* *add_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 328:  /* *and_shiftsi */
    case 331:  /* *sub_shiftsi */
    case 332:  /* *sub_shiftsi_compare0 */
    case 333:  /* *sub_shiftsi_compare0_scratch */
    case 6361:  /* *p *addsi3_carryin_shift */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6425:  /* *p *satsi_smin_shift */
    case 6426:  /* *p *satsi_smax_shift */
    case 6543:  /* *p *add_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6547:  /* *p *and_shiftsi */
    case 6548:  /* *p *sub_shiftsi */
      return 3;

    case 105:  /* andsi_not_shiftsi_si */
    case 275:  /* *arm_cmpsi_negshiftsi_si */
    case 319:  /* *add_multsi */
    case 320:  /* *rsb_multsi */
    case 321:  /* *orr_multsi */
    case 322:  /* *eor_multsi */
    case 323:  /* *and_multsi */
    case 367:  /* *if_shift_move */
    case 369:  /* *if_move_shift */
    case 1062:  /* *orsi_not_shiftsi_si */
    case 6406:  /* *p andsi_not_shiftsi_si */
    case 6531:  /* *p *arm_cmpsi_negshiftsi_si */
    case 6538:  /* *p *add_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6542:  /* *p *and_multsi */
    case 6942:  /* *p *orsi_not_shiftsi_si */
      return 2;

    case 106:  /* andsi_not_shiftsi_si_scc_no_reuse */
    case 107:  /* andsi_not_shiftsi_si_scc */
    case 151:  /* *arm_shiftsi3 */
    case 152:  /* *shiftsi3_compare0 */
    case 153:  /* *shiftsi3_compare0_scratch */
    case 154:  /* *not_shiftsi */
    case 155:  /* *not_shiftsi_compare0 */
    case 156:  /* *not_shiftsi_compare0_scratch */
    case 171:  /* *arm_abssi2 */
    case 172:  /* *arm_neg_abssi2 */
    case 273:  /* *cmpsi_shiftsi */
    case 274:  /* *cmpsi_shiftsi_swp */
    case 371:  /* *if_shift_shift */
    case 1004:  /* *thumb2_abssi2 */
    case 1005:  /* *thumb2_neg_abssi2 */
    case 1046:  /* *thumb2_shiftsi3_short */
    case 3036:  /* arm_ssatsihi_shift */
    case 6407:  /* *p andsi_not_shiftsi_si_scc_no_reuse */
    case 6408:  /* *p andsi_not_shiftsi_si_scc */
    case 6427:  /* *p *arm_shiftsi3 */
    case 6428:  /* *p *not_shiftsi */
    case 6439:  /* *p *arm_abssi2 */
    case 6440:  /* *p *arm_neg_abssi2 */
    case 6923:  /* *p *thumb2_abssi2 */
    case 6924:  /* *p *thumb2_neg_abssi2 */
    case 6932:  /* *p *thumb2_shiftsi3_short */
    case 7025:  /* *p arm_ssatsihi_shift */
      return 1;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

int
get_attr_thumb2_neg_pool_range (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

int
get_attr_thumb2_pool_range (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 3045:  /* *mve_movv2df */
    case 3044:  /* *mve_movv4sf */
    case 3043:  /* *mve_movv8hf */
    case 3042:  /* *mve_movti */
    case 3041:  /* *mve_movv2di */
    case 3040:  /* *mve_movv4si */
    case 3039:  /* *mve_movv8hi */
    case 3038:  /* *mve_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 0;
        }
      else if (which_alternative == 4)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  return 0;
        }

    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return 0;
        }
      else
        {
	  return 1018 /* 0x3fa */;
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 0;
        }
      else if (which_alternative == 4)
        {
	  return 1018 /* 0x3fa */;
        }
      else if (((1ULL << which_alternative) & 0xe0ULL))
        {
	  return 0;
        }
      else if (which_alternative == 8)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  return 0;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 0;
        }
      else if (which_alternative == 4)
        {
	  return 1018 /* 0x3fa */;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return 0;
        }
      else if (which_alternative == 7)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  return 0;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return 0;
        }
      else if (which_alternative == 4)
        {
	  return 1018 /* 0x3fa */;
        }
      else if (which_alternative == 5)
        {
	  return 4094 /* 0xffe */;
        }
      else if (((1ULL << which_alternative) & 0x3c0ULL))
        {
	  return 0;
        }
      else if (which_alternative == 10)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  return 0;
        }

    case 271:  /* *movdf_soft_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 0;
        }
      else if (which_alternative == 3)
        {
	  return 1018 /* 0x3fa */;
        }
      else
        {
	  return 0;
        }

    case 255:  /* *arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return 0;
        }
      else if (which_alternative == 3)
        {
	  return 4094 /* 0xffe */;
        }
      else
        {
	  return 0;
        }

    case 270:  /* *arm_movsf_soft_insn */
    case 6529:  /* *p *arm_movsf_soft_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return 0;
        }
      else if (which_alternative == 1)
        {
	  return 4094 /* 0xffe */;
        }
      else
        {
	  return 0;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return 0;

    }
}

enum attr_type
get_attr_type (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_autodetect_type cached_autodetect_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 3045:  /* *mve_movv2df */
    case 3044:  /* *mve_movv4sf */
    case 3043:  /* *mve_movv8hf */
    case 3042:  /* *mve_movti */
    case 3041:  /* *mve_movv2di */
    case 3040:  /* *mve_movv4si */
    case 3039:  /* *mve_movv8hi */
    case 3038:  /* *mve_movv16qi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return TYPE_MVE_MOVE;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_MVE_LOAD;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_MVE_STORE;
        }
      else
        {
	  return TYPE_MVE_LOAD;
        }

    case 7025:  /* *p arm_ssatsihi_shift */
    case 3036:  /* arm_ssatsihi_shift */
      extract_insn_cached (insn);
      if (alu_shift_reg_p (operands[1], VOIDmode))
        {
	  return TYPE_ALU_SHIFT_REG;
        }
      else
        {
	  if (alu_shift_operator_lsl_1_to_4 (operands[1], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	    }
	  else
	    {
	      return TYPE_ALU_SHIFT_IMM_OTHER;
	    }
        }

    case 1085:  /* *neon_movti */
    case 1084:  /* *neon_movv2di */
    case 1083:  /* *neon_movv4sf */
    case 1082:  /* *neon_movv4si */
    case 1081:  /* *neon_movv8bf */
    case 1080:  /* *neon_movv8hf */
    case 1079:  /* *neon_movv8hi */
    case 1078:  /* *neon_movv16qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_MOVE_Q;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_NEON_STORE2_2REG_Q;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return TYPE_NEON_MOVE_Q;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_NEON_LOAD2_2REG_Q;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_NEON_TO_GP_Q;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_NEON_FROM_GP_Q;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_NEON_LOAD1_4REG;
        }
      else
        {
	  return TYPE_NEON_STORE1_4REG;
        }

    case 1077:  /* *neon_movdi */
    case 1076:  /* *neon_movv2sf */
    case 1075:  /* *neon_movv2si */
    case 1074:  /* *neon_movv4bf */
    case 1073:  /* *neon_movv4hf */
    case 1072:  /* *neon_movv4hi */
    case 1071:  /* *neon_movv8qi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_MOVE;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_NEON_STORE1_1REG;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return TYPE_NEON_MOVE;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_NEON_LOAD1_1REG;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_NEON_TO_GP;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_NEON_FROM_GP;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_NEON_LOAD1_2REG;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_NEON_STORE1_2REG;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 6942:  /* *p *orsi_not_shiftsi_si */
    case 1062:  /* *orsi_not_shiftsi_si */
      extract_insn_cached (insn);
      if (alu_shift_reg_p (operands[4], VOIDmode))
        {
	  return TYPE_ALU_SHIFT_REG;
        }
      else
        {
	  if (alu_shift_operator_lsl_1_to_4 (operands[4], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	    }
	  else
	    {
	      return TYPE_ALU_SHIFT_IMM_OTHER;
	    }
        }

    case 6927:  /* *p *thumb2_movhi_insn */
    case 1009:  /* *thumb2_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MOV_REG;
        }
      else if (((1ULL << which_alternative) & 0xeULL))
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_STORE_4;
        }
      else
        {
	  return TYPE_LOAD_4;
        }

    case 6926:  /* *p *thumb2_movsi_insn */
    case 1007:  /* *thumb2_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MOV_REG;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_LOAD_4;
        }
      else
        {
	  return TYPE_STORE_4;
        }

    case 963:  /* *thumb1_movsf_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ALUS_IMM;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_STORE_4;
        }
      else
        {
	  return TYPE_MOV_REG;
        }

    case 962:  /* *thumb1_movhf */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_STORE_4;
        }
      else
        {
	  return TYPE_MOV_REG;
        }

    case 961:  /* *thumb1_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ALU_IMM;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MOV_REG;
        }
      else
        {
	  return TYPE_MOV_IMM;
        }

    case 960:  /* *thumb1_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ALUS_IMM;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_STORE_4;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return TYPE_MOV_REG;
        }
      else
        {
	  return TYPE_MOV_IMM;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MOV_REG;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return TYPE_MOV_IMM;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_ALU_SREG;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 9)
        {
	  return TYPE_STORE_4;
        }
      else
        {
	  return TYPE_MOV_REG;
        }

    case 958:  /* *thumb1_movdi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_LOAD_8;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_STORE_8;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_LOAD_8;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_STORE_8;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 935:  /* *thumb1_addsi3 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_ALUS_IMM;
        }
      else if (((1ULL << which_alternative) & 0x7cULL))
        {
	  return TYPE_ALUS_SREG;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 774:  /* *thumb2_movdfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return TYPE_FFARITHD;
        }
      else if (((1ULL << which_alternative) & 0x18ULL))
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_F_MCRR;
        }
      else
        {
	  return TYPE_F_MRRC;
        }

    case 773:  /* *movdfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return TYPE_FFARITHD;
        }
      else if (((1ULL << which_alternative) & 0x38ULL))
        {
	  return TYPE_F_MCR;
        }
      else
        {
	  return TYPE_F_MRRC;
        }

    case 772:  /* *thumb2_movsfcc_vfp */
    case 771:  /* *movsfcc_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return TYPE_FMOV;
        }
      else if (((1ULL << which_alternative) & 0x38ULL))
        {
	  return TYPE_F_MCR;
        }
      else
        {
	  return TYPE_F_MRC;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return TYPE_MULTIPLE;
        }
      else if (((1ULL << which_alternative) & 0x30ULL))
        {
	  return TYPE_LOAD_8;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_STORE_8;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_F_MCRR;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_F_MRRC;
        }
      else if (which_alternative == 9)
        {
	  return TYPE_FFARITHD;
        }
      else if (which_alternative == 10)
        {
	  return TYPE_F_LOADD;
        }
      else
        {
	  return TYPE_F_STORED;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MVN_REG;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_MOV_IMM;
        }
      else if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return TYPE_LOAD_4;
        }
      else if (((1ULL << which_alternative) & 0x180ULL))
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 9)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 10)
        {
	  return TYPE_F_MRC;
        }
      else if (which_alternative == 11)
        {
	  return TYPE_FMOV;
        }
      else if (which_alternative == 12)
        {
	  return TYPE_F_LOADS;
        }
      else if (which_alternative == 13)
        {
	  return TYPE_F_STORES;
        }
      else if (((1ULL << which_alternative) & 0xc000ULL))
        {
	  return TYPE_MVE_MOVE;
        }
      else
        {
	  return TYPE_MRS;
        }

    case 6848:  /* *p *arm_movsi_vfp */
    case 758:  /* *arm_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_F_MRC;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_FMOV;
        }
      else if (which_alternative == 9)
        {
	  return TYPE_F_LOADS;
        }
      else
        {
	  return TYPE_F_STORES;
        }

    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MOV_REG;
        }
      else if (((1ULL << which_alternative) & 0xeULL))
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_F_MRC;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_FMOV;
        }
      else
        {
	  return TYPE_MVE_MOVE;
        }

    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_WMMX_WMOV;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_WMMX_WSTR;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_WMMX_WLDR;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_WMMX_TMRRC;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_WMMX_TMCRR;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_UNTYPED;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_LOAD_4;
        }
      else
        {
	  return TYPE_STORE_4;
        }

    case 532:  /* *cond_iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_UNTYPED;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_STORE_4;
        }
      else
        {
	  return TYPE_UNTYPED;
        }

    case 531:  /* *iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return TYPE_UNTYPED;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_STORE_4;
        }
      else if (((1ULL << which_alternative) & 0x3c0ULL))
        {
	  return TYPE_UNTYPED;
        }
      else if (which_alternative == 10)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 11)
        {
	  return TYPE_F_MRC;
        }
      else if (which_alternative == 12)
        {
	  return TYPE_FMOV;
        }
      else if (which_alternative == 13)
        {
	  return TYPE_F_LOADS;
        }
      else
        {
	  return TYPE_F_STORES;
        }

    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return TYPE_UNTYPED;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_LOAD_8;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_STORE_8;
        }
      else if (((1ULL << which_alternative) & 0x3e0ULL))
        {
	  return TYPE_UNTYPED;
        }
      else if (which_alternative == 10)
        {
	  return TYPE_F_MCRR;
        }
      else if (which_alternative == 11)
        {
	  return TYPE_F_MRRC;
        }
      else if (which_alternative == 12)
        {
	  return TYPE_FFARITHD;
        }
      else if (which_alternative == 13)
        {
	  return TYPE_F_LOADD;
        }
      else
        {
	  return TYPE_F_STORED;
        }

    case 369:  /* *if_move_shift */
    case 367:  /* *if_shift_move */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[3], VOIDmode))
	    {
	      return TYPE_MOV_SHIFT;
	    }
	  else
	    {
	      return TYPE_MOV_SHIFT_REG;
	    }
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 355:  /* *if_move_plus */
    case 353:  /* *if_plus_move */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[3], VOIDmode))
	    {
	      return TYPE_ALU_IMM;
	    }
	  else
	    {
	      return TYPE_ALU_SREG;
	    }
        }
      else if (which_alternative == 1)
        {
	  return TYPE_ALU_IMM;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 6542:  /* *p *and_multsi */
    case 6541:  /* *p *eor_multsi */
    case 6540:  /* *p *orr_multsi */
    case 6539:  /* *p *rsb_multsi */
    case 6538:  /* *p *add_multsi */
    case 323:  /* *and_multsi */
    case 322:  /* *eor_multsi */
    case 321:  /* *orr_multsi */
    case 320:  /* *rsb_multsi */
    case 319:  /* *add_multsi */
      extract_insn_cached (insn);
      if (const_2_4_8_16_operand (operands[3], VOIDmode))
        {
	  return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
        }
      else
        {
	  return TYPE_ALU_SHIFT_IMM_OTHER;
        }

    case 6530:  /* *p *arm_cmpsi_insn */
    case 272:  /* *arm_cmpsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ALUS_IMM;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return TYPE_ALUS_SREG;
        }
      else
        {
	  return TYPE_ALUS_IMM;
        }

    case 6526:  /* *p *arm_movqi_insn */
    case 267:  /* *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_MOV_REG;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_LOAD_4;
        }
      else
        {
	  return TYPE_STORE_4;
        }

    case 271:  /* *movdf_soft_insn */
    case 255:  /* *arm_movdi */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x7ULL))
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_LOAD_8;
        }
      else
        {
	  return TYPE_STORE_8;
        }

    case 6410:  /* *p *arm_xorsi3 */
    case 113:  /* *arm_xorsi3 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_LOGIC_IMM;
        }
      else if (((1ULL << which_alternative) & 0x6ULL))
        {
	  return TYPE_LOGIC_REG;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 6409:  /* *p *iorsi3_insn */
    case 110:  /* *iorsi3_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_LOGIC_IMM;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_LOGIC_REG;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_LOGIC_IMM;
        }
      else
        {
	  return TYPE_LOGIC_REG;
        }

    case 92:  /* *andsi3_compare0_scratch */
    case 91:  /* *andsi3_compare0 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_LOGICS_IMM;
        }
      else
        {
	  return TYPE_LOGICS_REG;
        }

    case 6397:  /* *p *arm_andsi3_insn */
    case 90:  /* *arm_andsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_LOGIC_IMM;
        }
      else if (((1ULL << which_alternative) & 0xcULL))
        {
	  return TYPE_LOGIC_REG;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_BFM;
        }
      else
        {
	  return TYPE_LOGIC_IMM;
        }

    case 46:  /* subsi3_compare0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ALUS_IMM;
        }
      else
        {
	  return TYPE_ALUS_SREG;
        }

    case 6370:  /* *p *arm_subsi3_insn */
    case 45:  /* *arm_subsi3_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xfULL))
        {
	  return TYPE_ALU_SREG;
        }
      else if (((1ULL << which_alternative) & 0x30ULL))
        {
	  return TYPE_ALU_IMM;
        }
      else if (((1ULL << which_alternative) & 0xc0ULL))
        {
	  return TYPE_ALU_SREG;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 6427:  /* *p *arm_shiftsi3 */
    case 6365:  /* *p add_not_shift_cin */
    case 151:  /* *arm_shiftsi3 */
    case 32:  /* add_not_shift_cin */
      extract_insn_cached (insn);
      if (alu_shift_reg_p (operands[3], VOIDmode))
        {
	  return TYPE_ALU_SHIFT_REG;
        }
      else
        {
	  if (alu_shift_operator_lsl_1_to_4 (operands[3], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	    }
	  else
	    {
	      return TYPE_ALU_SHIFT_IMM_OTHER;
	    }
        }

    case 6547:  /* *p *and_shiftsi */
    case 6546:  /* *p *eor_shiftsi */
    case 6545:  /* *p *orr_shiftsi */
    case 6544:  /* *p *rsb_shiftsi */
    case 6543:  /* *p *add_shiftsi */
    case 6369:  /* *p *rsbsi3_carryin_shift_alt */
    case 6368:  /* *p *rsbsi3_carryin_shift */
    case 6367:  /* *p *subsi3_carryin_shift_alt */
    case 6366:  /* *p *subsi3_carryin_shift */
    case 6361:  /* *p *addsi3_carryin_shift */
    case 328:  /* *and_shiftsi */
    case 327:  /* *eor_shiftsi */
    case 326:  /* *orr_shiftsi */
    case 325:  /* *rsb_shiftsi */
    case 324:  /* *add_shiftsi */
    case 44:  /* *rsbsi3_carryin_shift_alt */
    case 43:  /* *rsbsi3_carryin_shift */
    case 42:  /* *subsi3_carryin_shift_alt */
    case 41:  /* *subsi3_carryin_shift */
    case 24:  /* *addsi3_carryin_shift */
      extract_insn_cached (insn);
      if (alu_shift_reg_p (operands[2], VOIDmode))
        {
	  return TYPE_ALU_SHIFT_REG;
        }
      else
        {
	  if (alu_shift_operator_lsl_1_to_4 (operands[2], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	    }
	  else
	    {
	      return TYPE_ALU_SHIFT_IMM_OTHER;
	    }
        }

    case 6360:  /* *p *addsi3_carryin_alt2 */
    case 6358:  /* *p addsi3_carryin */
    case 23:  /* *addsi3_carryin_alt2 */
    case 21:  /* addsi3_carryin */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_ADC_REG;
        }
      else
        {
	  return TYPE_ADC_IMM;
        }

    case 6354:  /* *p *addsi3_compare0_scratch */
    case 14:  /* *addsi3_compare0_scratch */
    case 13:  /* addsi3_compare0 */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x3ULL))
        {
	  return TYPE_ALUS_IMM;
        }
      else
        {
	  return TYPE_ALUS_SREG;
        }

    case 47:  /* subsi3_compare */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ALUS_IMM;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_ALUS_SREG;
        }
      else
        {
	  return TYPE_ALUS_IMM;
        }

    case 112:  /* *iorsi3_compare0_scratch */
    case 111:  /* *iorsi3_compare0 */
    case 114:  /* *xorsi3_compare0 */
    case 115:  /* *xorsi3_compare0_scratch */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_LOGICS_IMM;
        }
      else
        {
	  return TYPE_LOGICS_REG;
        }

    case 170:  /* negsi2_carryin */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ADC_IMM;
        }
      else
        {
	  return TYPE_ADC_REG;
        }

    case 286:  /* *movsicc_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[2], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 1)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 2)
        {
	  if (const_int_operand (operands[1], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_MULTIPLE;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 335:  /* *ior_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_LOGIC_IMM;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 337:  /* *cond_move */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[2], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 1)
        {
	  if (const_int_operand (operands[1], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 359:  /* *if_arith_move */
    case 361:  /* *if_move_arith */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[3], VOIDmode))
	    {
	      if (alu_shift_operator_lsl_1_to_4 (operands[5], VOIDmode))
	        {
		  return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	        }
	      else
	        {
		  return TYPE_ALU_SHIFT_IMM_OTHER;
	        }
	    }
	  else
	    {
	      return TYPE_ALU_SHIFT_REG;
	    }
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 371:  /* *if_shift_shift */
      extract_insn_cached (insn);
      if ((const_int_operand (operands[2], VOIDmode)) && (const_int_operand (operands[4], VOIDmode)))
        {
	  return TYPE_MOV_SHIFT;
        }
      else
        {
	  return TYPE_MOV_SHIFT_REG;
        }

    case 365:  /* *if_not_move */
    case 363:  /* *if_move_not */
    case 381:  /* *cond_move_not */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MVN_REG;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 511:  /* mve_vshlq_sv8qi */
    case 512:  /* mve_vshlq_uv8qi */
    case 515:  /* mve_vshlq_sv4hi */
    case 516:  /* mve_vshlq_uv4hi */
    case 519:  /* mve_vshlq_sv2si */
    case 520:  /* mve_vshlq_uv2si */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_SHIFT_REG;
        }
      else
        {
	  return TYPE_NEON_SHIFT_IMM;
        }

    case 513:  /* mve_vshlq_sv16qi */
    case 514:  /* mve_vshlq_uv16qi */
    case 517:  /* mve_vshlq_sv8hi */
    case 518:  /* mve_vshlq_uv8hi */
    case 521:  /* mve_vshlq_sv4si */
    case 522:  /* mve_vshlq_uv4si */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_SHIFT_REG_Q;
        }
      else
        {
	  return TYPE_NEON_SHIFT_IMM_Q;
        }

    case 763:  /* *movhf_vfp_neon */
    case 764:  /* *movbf_vfp_neon */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_LOAD1_1REG;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_NEON_STORE1_1REG;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_FMOV;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_F_MRC;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 765:  /* *movhf_vfp */
    case 766:  /* *movbf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_FMOV;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_F_MRC;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 153:  /* *shiftsi3_compare0_scratch */
    case 944:  /* *thumb1_ashlsi3 */
    case 945:  /* *thumb1_ashrsi3 */
    case 946:  /* *thumb1_lshrsi3 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_SHIFT_IMM;
        }
      else
        {
	  return TYPE_SHIFT_REG;
        }

    case 964:  /* *thumb_movdf_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_LOAD_8;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_STORE_8;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_LOAD_8;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_STORE_8;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 967:  /* thumb1_cbz */
      if (get_attr_length (insn) == 2)
        {
	  return TYPE_BRANCH;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 1016:  /* *thumb2_movsicc_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[2], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 1)
        {
	  if (const_int_operand (operands[1], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 2)
        {
	  if (const_int_operand (operands[2], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 4)
        {
	  if (const_int_operand (operands[1], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 5)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 9)
        {
	  return TYPE_MULTIPLE;
        }
      else if (which_alternative == 10)
        {
	  return TYPE_MULTIPLE;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 1052:  /* thumb2_addsi3_compare0 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[2], VOIDmode))
	    {
	      return TYPE_ALUS_IMM;
	    }
	  else
	    {
	      return TYPE_ALUS_SREG;
	    }
        }
      else if (which_alternative == 1)
        {
	  return TYPE_ALUS_IMM;
        }
      else
        {
	  if (const_int_operand (operands[2], VOIDmode))
	    {
	      return TYPE_ALUS_IMM;
	    }
	  else
	    {
	      return TYPE_ALUS_SREG;
	    }
        }

    case 1053:  /* *thumb2_addsi3_compare0_scratch */
      extract_insn_cached (insn);
      if (const_int_operand (operands[1], VOIDmode))
        {
	  return TYPE_ALUS_IMM;
        }
      else
        {
	  return TYPE_ALUS_SREG;
        }

    case 1057:  /* *thumb2_cbz */
    case 1058:  /* *thumb2_cbnz */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_BRANCH;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 1086:  /* *neon_movei */
    case 1087:  /* *neon_movoi */
    case 1088:  /* *neon_movci */
    case 1089:  /* *neon_movxi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_MOVE_Q;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_NEON_STORE2_2REG_Q;
        }
      else
        {
	  return TYPE_NEON_LOAD2_2REG_Q;
        }

    case 1118:  /* vec_setv8qi_internal */
    case 1119:  /* vec_setv4hi_internal */
    case 1120:  /* vec_setv4hf_internal */
    case 1121:  /* vec_setv4bf_internal */
    case 1122:  /* vec_setv2si_internal */
    case 1123:  /* vec_setv2sf_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_LOAD1_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_FROM_GP;
        }

    case 1124:  /* vec_setv16qi_internal */
    case 1125:  /* vec_setv8hi_internal */
    case 1126:  /* vec_setv8hf_internal */
    case 1127:  /* vec_setv4si_internal */
    case 1128:  /* vec_setv4sf_internal */
    case 1129:  /* vec_setv2di_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_LOAD1_ALL_LANES_Q;
        }
      else
        {
	  return TYPE_NEON_FROM_GP_Q;
        }

    case 1130:  /* vec_extractv8qiqi */
    case 1131:  /* vec_extractv4hihi */
    case 1132:  /* vec_extractv4hfhf */
    case 1133:  /* vec_extractv4bfbf */
    case 1134:  /* vec_extractv2sisi */
    case 1135:  /* vec_extractv2sfsf */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_STORE1_ONE_LANE;
        }
      else
        {
	  return TYPE_NEON_TO_GP;
        }

    case 1136:  /* neon_vec_extractv16qiqi */
    case 1137:  /* neon_vec_extractv8hihi */
    case 1138:  /* neon_vec_extractv8hfhf */
    case 1139:  /* neon_vec_extractv4sisi */
    case 1140:  /* neon_vec_extractv4sfsf */
    case 1141:  /* neon_vec_extractv2didi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_STORE1_ONE_LANE_Q;
        }
      else
        {
	  return TYPE_NEON_TO_GP_Q;
        }

    case 1142:  /* *addv8qi3_neon */
    case 1144:  /* *addv4hi3_neon */
    case 1146:  /* *addv2si3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_ADDSUB_S;
        }
      else
        {
	  return TYPE_NEON_ADD;
        }

    case 1143:  /* *addv16qi3_neon */
    case 1145:  /* *addv8hi3_neon */
    case 1147:  /* *addv4si3_neon */
    case 1152:  /* *addv2di3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_ADDSUB_S_Q;
        }
      else
        {
	  return TYPE_NEON_ADD_Q;
        }

    case 1153:  /* *subv8qi3_neon */
    case 1155:  /* *subv4hi3_neon */
    case 1157:  /* *subv2si3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_ADDSUB_S;
        }
      else
        {
	  return TYPE_NEON_SUB;
        }

    case 1154:  /* *subv16qi3_neon */
    case 1156:  /* *subv8hi3_neon */
    case 1158:  /* *subv4si3_neon */
    case 1163:  /* *subv2di3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_ADDSUB_S_Q;
        }
      else
        {
	  return TYPE_NEON_SUB_Q;
        }

    case 1166:  /* *mulv4hi3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S;
        }
      else
        {
	  return TYPE_NEON_MUL_H;
        }

    case 1167:  /* *mulv8hi3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S_Q;
        }
      else
        {
	  return TYPE_NEON_MUL_H_Q;
        }

    case 1168:  /* *mulv2si3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S;
        }
      else
        {
	  return TYPE_NEON_MUL_S;
        }

    case 1169:  /* *mulv4si3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S_Q;
        }
      else
        {
	  return TYPE_NEON_MUL_S_Q;
        }

    case 1292:  /* neon_absv8qi2 */
    case 1294:  /* neon_absv4hi2 */
    case 1296:  /* neon_absv2si2 */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_ABS_S;
        }
      else
        {
	  return TYPE_NEON_ABS;
        }

    case 1293:  /* neon_absv16qi2 */
    case 1295:  /* neon_absv8hi2 */
    case 1297:  /* neon_absv4si2 */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_ABS_S_Q;
        }
      else
        {
	  return TYPE_NEON_ABS_Q;
        }

    case 1298:  /* neon_absv2sf2 */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_ABS_S;
        }
      else
        {
	  return TYPE_NEON_ABS;
        }

    case 1299:  /* neon_absv4sf2 */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_ABS_S_Q;
        }
      else
        {
	  return TYPE_NEON_ABS_Q;
        }

    case 1300:  /* neon_negv8qi2 */
    case 1302:  /* neon_negv4hi2 */
    case 1304:  /* neon_negv2si2 */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_NEG_S;
        }
      else
        {
	  return TYPE_NEON_NEG;
        }

    case 1301:  /* neon_negv16qi2 */
    case 1303:  /* neon_negv8hi2 */
    case 1305:  /* neon_negv4si2 */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_NEG_S_Q;
        }
      else
        {
	  return TYPE_NEON_NEG_Q;
        }

    case 1306:  /* neon_negv2sf2 */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_NEG_S;
        }
      else
        {
	  return TYPE_NEON_NEG;
        }

    case 1307:  /* neon_negv4sf2 */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_NEG_S_Q;
        }
      else
        {
	  return TYPE_NEON_NEG_Q;
        }

    case 1338:  /* *sminv8qi3_neon */
    case 1340:  /* *sminv4hi3_neon */
    case 1342:  /* *sminv2si3_neon */
    case 1346:  /* *smaxv8qi3_neon */
    case 1348:  /* *smaxv4hi3_neon */
    case 1350:  /* *smaxv2si3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MINMAX_S;
        }
      else
        {
	  return TYPE_NEON_MINMAX;
        }

    case 1339:  /* *sminv16qi3_neon */
    case 1341:  /* *sminv8hi3_neon */
    case 1343:  /* *sminv4si3_neon */
    case 1347:  /* *smaxv16qi3_neon */
    case 1349:  /* *smaxv8hi3_neon */
    case 1351:  /* *smaxv4si3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MINMAX_S_Q;
        }
      else
        {
	  return TYPE_NEON_MINMAX_Q;
        }

    case 1344:  /* *sminv2sf3_neon */
    case 1352:  /* *smaxv2sf3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MINMAX_S;
        }
      else
        {
	  return TYPE_NEON_MINMAX;
        }

    case 1345:  /* *sminv4sf3_neon */
    case 1353:  /* *smaxv4sf3_neon */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MINMAX_S_Q;
        }
      else
        {
	  return TYPE_NEON_MINMAX_Q;
        }

    case 1380:  /* neon_load_count */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_LOAD1_1REG;
        }
      else
        {
	  return TYPE_NEON_FROM_GP;
        }

    case 1418:  /* neon_vpadd_internalv8qi */
    case 1419:  /* neon_vpadd_internalv4hi */
    case 1420:  /* neon_vpadd_internalv2si */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_REDUC_ADD_S;
        }
      else
        {
	  return TYPE_NEON_REDUC_ADD;
        }

    case 1421:  /* neon_vpadd_internalv2sf */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_REDUC_ADD_S;
        }
      else
        {
	  return TYPE_NEON_REDUC_ADD;
        }

    case 1423:  /* neon_vpsminv8qi */
    case 1424:  /* neon_vpsminv4hi */
    case 1425:  /* neon_vpsminv2si */
    case 1427:  /* neon_vpsmaxv8qi */
    case 1428:  /* neon_vpsmaxv4hi */
    case 1429:  /* neon_vpsmaxv2si */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_REDUC_MINMAX_S;
        }
      else
        {
	  return TYPE_NEON_REDUC_MINMAX;
        }

    case 1426:  /* neon_vpsminv2sf */
    case 1430:  /* neon_vpsmaxv2sf */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_REDUC_MINMAX_S;
        }
      else
        {
	  return TYPE_NEON_REDUC_MINMAX;
        }

    case 1148:  /* *addv4hf3_neon */
    case 1150:  /* *addv2sf3_neon */
    case 1453:  /* neon_vaddv2sf_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_ADDSUB_S;
        }
      else
        {
	  return TYPE_NEON_ADD;
        }

    case 1149:  /* *addv8hf3_neon */
    case 1151:  /* *addv4sf3_neon */
    case 1454:  /* neon_vaddv4sf_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_ADDSUB_S_Q;
        }
      else
        {
	  return TYPE_NEON_ADD_Q;
        }

    case 1164:  /* *mulv8qi3_neon */
    case 1513:  /* neon_vmulpv8qi */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S;
        }
      else
        {
	  return TYPE_NEON_MUL_B;
        }

    case 1165:  /* *mulv16qi3_neon */
    case 1514:  /* neon_vmulpv16qi */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S_Q;
        }
      else
        {
	  return TYPE_NEON_MUL_B_Q;
        }

    case 1170:  /* *mulv2sf3_neon */
    case 1515:  /* neon_vmulfv2sf */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MUL_S;
        }
      else
        {
	  return TYPE_NEON_MUL_S;
        }

    case 1171:  /* *mulv4sf3_neon */
    case 1516:  /* neon_vmulfv4sf */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MUL_S_Q;
        }
      else
        {
	  return TYPE_NEON_MUL_S_Q;
        }

    case 1172:  /* mulv8qi3addv8qi_neon */
    case 1182:  /* mulv8qi3negv8qiaddv8qi_neon */
    case 1543:  /* neon_vmlav8qi_unspec */
    case 1557:  /* neon_vmlsv8qi_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S;
        }
      else
        {
	  return TYPE_NEON_MLA_B;
        }

    case 1173:  /* mulv16qi3addv16qi_neon */
    case 1183:  /* mulv16qi3negv16qiaddv16qi_neon */
    case 1544:  /* neon_vmlav16qi_unspec */
    case 1558:  /* neon_vmlsv16qi_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S_Q;
        }
      else
        {
	  return TYPE_NEON_MLA_B_Q;
        }

    case 1174:  /* mulv4hi3addv4hi_neon */
    case 1184:  /* mulv4hi3negv4hiaddv4hi_neon */
    case 1545:  /* neon_vmlav4hi_unspec */
    case 1559:  /* neon_vmlsv4hi_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S;
        }
      else
        {
	  return TYPE_NEON_MLA_H;
        }

    case 1175:  /* mulv8hi3addv8hi_neon */
    case 1185:  /* mulv8hi3negv8hiaddv8hi_neon */
    case 1546:  /* neon_vmlav8hi_unspec */
    case 1560:  /* neon_vmlsv8hi_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S_Q;
        }
      else
        {
	  return TYPE_NEON_MLA_H_Q;
        }

    case 1176:  /* mulv2si3addv2si_neon */
    case 1186:  /* mulv2si3negv2siaddv2si_neon */
    case 1547:  /* neon_vmlav2si_unspec */
    case 1561:  /* neon_vmlsv2si_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S;
        }
      else
        {
	  return TYPE_NEON_MLA_S;
        }

    case 1177:  /* mulv4si3addv4si_neon */
    case 1187:  /* mulv4si3negv4siaddv4si_neon */
    case 1548:  /* neon_vmlav4si_unspec */
    case 1562:  /* neon_vmlsv4si_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S_Q;
        }
      else
        {
	  return TYPE_NEON_MLA_S_Q;
        }

    case 1178:  /* mulv2sf3addv2sf_neon */
    case 1188:  /* mulv2sf3negv2sfaddv2sf_neon */
    case 1549:  /* neon_vmlav2sf_unspec */
    case 1563:  /* neon_vmlsv2sf_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MLA_S;
        }
      else
        {
	  return TYPE_NEON_MLA_S;
        }

    case 1179:  /* mulv4sf3addv4sf_neon */
    case 1189:  /* mulv4sf3negv4sfaddv4sf_neon */
    case 1550:  /* neon_vmlav4sf_unspec */
    case 1564:  /* neon_vmlsv4sf_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MLA_S_Q;
        }
      else
        {
	  return TYPE_NEON_MLA_S_Q;
        }

    case 1159:  /* *subv4hf3_neon */
    case 1161:  /* *subv2sf3_neon */
    case 1602:  /* neon_vsubv2sf_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_ADDSUB_S;
        }
      else
        {
	  return TYPE_NEON_SUB;
        }

    case 1160:  /* *subv8hf3_neon */
    case 1162:  /* *subv4sf3_neon */
    case 1603:  /* neon_vsubv4sf_unspec */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_ADDSUB_S_Q;
        }
      else
        {
	  return TYPE_NEON_SUB_Q;
        }

    case 1655:  /* neon_vceqv16qi_insn */
    case 1656:  /* neon_vcgtv16qi_insn */
    case 1657:  /* neon_vcgev16qi_insn */
    case 1658:  /* neon_vclev16qi_insn */
    case 1659:  /* neon_vcltv16qi_insn */
    case 1665:  /* neon_vceqv8hi_insn */
    case 1666:  /* neon_vcgtv8hi_insn */
    case 1667:  /* neon_vcgev8hi_insn */
    case 1668:  /* neon_vclev8hi_insn */
    case 1669:  /* neon_vcltv8hi_insn */
    case 1675:  /* neon_vceqv4si_insn */
    case 1676:  /* neon_vcgtv4si_insn */
    case 1677:  /* neon_vcgev4si_insn */
    case 1678:  /* neon_vclev4si_insn */
    case 1679:  /* neon_vcltv4si_insn */
    case 1685:  /* neon_vceqv4sf_insn */
    case 1686:  /* neon_vcgtv4sf_insn */
    case 1687:  /* neon_vcgev4sf_insn */
    case 1688:  /* neon_vclev4sf_insn */
    case 1689:  /* neon_vcltv4sf_insn */
    case 1700:  /* neon_vceqv8hf_fp16insn */
    case 1701:  /* neon_vcgtv8hf_fp16insn */
    case 1702:  /* neon_vcgev8hf_fp16insn */
    case 1703:  /* neon_vclev8hf_fp16insn */
    case 1704:  /* neon_vcltv8hf_fp16insn */
      extract_insn_cached (insn);
      if (zero_operand (operands[2], VOIDmode))
        {
	  return TYPE_NEON_COMPARE_ZERO_Q;
        }
      else
        {
	  return TYPE_NEON_COMPARE_Q;
        }

    case 1650:  /* neon_vceqv8qi_insn */
    case 1651:  /* neon_vcgtv8qi_insn */
    case 1652:  /* neon_vcgev8qi_insn */
    case 1653:  /* neon_vclev8qi_insn */
    case 1654:  /* neon_vcltv8qi_insn */
    case 1660:  /* neon_vceqv4hi_insn */
    case 1661:  /* neon_vcgtv4hi_insn */
    case 1662:  /* neon_vcgev4hi_insn */
    case 1663:  /* neon_vclev4hi_insn */
    case 1664:  /* neon_vcltv4hi_insn */
    case 1670:  /* neon_vceqv2si_insn */
    case 1671:  /* neon_vcgtv2si_insn */
    case 1672:  /* neon_vcgev2si_insn */
    case 1673:  /* neon_vclev2si_insn */
    case 1674:  /* neon_vcltv2si_insn */
    case 1680:  /* neon_vceqv2sf_insn */
    case 1681:  /* neon_vcgtv2sf_insn */
    case 1682:  /* neon_vcgev2sf_insn */
    case 1683:  /* neon_vclev2sf_insn */
    case 1684:  /* neon_vcltv2sf_insn */
    case 1705:  /* neon_vceqv4hf_fp16insn */
    case 1706:  /* neon_vcgtv4hf_fp16insn */
    case 1707:  /* neon_vcgev4hf_fp16insn */
    case 1708:  /* neon_vclev4hf_fp16insn */
    case 1709:  /* neon_vcltv4hf_fp16insn */
      extract_insn_cached (insn);
      if (zero_operand (operands[2], VOIDmode))
        {
	  return TYPE_NEON_COMPARE_ZERO;
        }
      else
        {
	  return TYPE_NEON_COMPARE;
        }

    case 2049:  /* neon_vdup_nv2si */
    case 2050:  /* neon_vdup_nv2sf */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_FROM_GP;
        }
      else
        {
	  return TYPE_NEON_DUP;
        }

    case 2051:  /* neon_vdup_nv4si */
    case 2052:  /* neon_vdup_nv4sf */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_FROM_GP_Q;
        }
      else
        {
	  return TYPE_NEON_DUP_Q;
        }

    case 2163:  /* neon_vmul_lanev4hi */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S_SCALAR;
        }
      else
        {
	  return TYPE_NEON_MUL_H_SCALAR;
        }

    case 2164:  /* neon_vmul_lanev2si */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S_SCALAR;
        }
      else
        {
	  return TYPE_NEON_MUL_S_SCALAR;
        }

    case 2165:  /* neon_vmul_lanev2sf */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MUL_S_SCALAR;
        }
      else
        {
	  return TYPE_NEON_MUL_S_SCALAR;
        }

    case 2166:  /* neon_vmul_lanev8hi */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S_SCALAR_Q;
        }
      else
        {
	  return TYPE_NEON_MUL_H_SCALAR_Q;
        }

    case 2167:  /* neon_vmul_lanev4si */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MUL_S_SCALAR_Q;
        }
      else
        {
	  return TYPE_NEON_MUL_S_SCALAR_Q;
        }

    case 2168:  /* neon_vmul_lanev4sf */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MUL_S_SCALAR_Q;
        }
      else
        {
	  return TYPE_NEON_MUL_S_SCALAR_Q;
        }

    case 2193:  /* neon_vmla_lanev4hi */
    case 2205:  /* neon_vmls_lanev4hi */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S_SCALAR;
        }
      else
        {
	  return TYPE_NEON_MLA_H_SCALAR;
        }

    case 2194:  /* neon_vmla_lanev2si */
    case 2206:  /* neon_vmls_lanev2si */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S_SCALAR;
        }
      else
        {
	  return TYPE_NEON_MLA_S_SCALAR;
        }

    case 2195:  /* neon_vmla_lanev2sf */
    case 2207:  /* neon_vmls_lanev2sf */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MLA_S_SCALAR;
        }
      else
        {
	  return TYPE_NEON_MLA_S_SCALAR;
        }

    case 2196:  /* neon_vmla_lanev8hi */
    case 2208:  /* neon_vmls_lanev8hi */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S_SCALAR_Q;
        }
      else
        {
	  return TYPE_NEON_MLA_H_SCALAR_Q;
        }

    case 2197:  /* neon_vmla_lanev4si */
    case 2209:  /* neon_vmls_lanev4si */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(false))
        {
	  return TYPE_NEON_FP_MLA_S_SCALAR_Q;
        }
      else
        {
	  return TYPE_NEON_MLA_S_SCALAR_Q;
        }

    case 2198:  /* neon_vmla_lanev4sf */
    case 2210:  /* neon_vmls_lanev4sf */
      extract_constrain_insn_cached (insn);
      if (
#line 4067 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/neon.md"
(true))
        {
	  return TYPE_NEON_FP_MLA_S_SCALAR_Q;
        }
      else
        {
	  return TYPE_NEON_MLA_S_SCALAR_Q;
        }

    case 2577:  /* neon_vld2v8qi */
      if ((8) == (64))
        {
	  return TYPE_NEON_LOAD1_2REG;
        }
      else
        {
	  return TYPE_NEON_LOAD2_2REG;
        }

    case 2578:  /* neon_vld2v4hi */
    case 2579:  /* neon_vld2v4hf */
    case 2580:  /* neon_vld2v4bf */
      if ((16) == (64))
        {
	  return TYPE_NEON_LOAD1_2REG;
        }
      else
        {
	  return TYPE_NEON_LOAD2_2REG;
        }

    case 2581:  /* neon_vld2v2si */
    case 2582:  /* neon_vld2v2sf */
      if ((32) == (64))
        {
	  return TYPE_NEON_LOAD1_2REG;
        }
      else
        {
	  return TYPE_NEON_LOAD2_2REG;
        }

    case 2583:  /* neon_vld2di */
      if ((64) == (64))
        {
	  return TYPE_NEON_LOAD1_2REG;
        }
      else
        {
	  return TYPE_NEON_LOAD2_2REG;
        }

    case 2601:  /* neon_vld2_dupv8qi */
      if ((8) > (1))
        {
	  return TYPE_NEON_LOAD2_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2602:  /* neon_vld2_dupv4hi */
    case 2603:  /* neon_vld2_dupv4hf */
    case 2604:  /* neon_vld2_dupv4bf */
      if ((4) > (1))
        {
	  return TYPE_NEON_LOAD2_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2605:  /* neon_vld2_dupv2si */
    case 2606:  /* neon_vld2_dupv2sf */
      if ((2) > (1))
        {
	  return TYPE_NEON_LOAD2_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2607:  /* neon_vld2_dupdi */
      if ((1) > (1))
        {
	  return TYPE_NEON_LOAD2_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2609:  /* neon_vst2v8qi */
      if ((8) == (64))
        {
	  return TYPE_NEON_STORE1_2REG;
        }
      else
        {
	  return TYPE_NEON_STORE2_ONE_LANE;
        }

    case 2610:  /* neon_vst2v4hi */
    case 2611:  /* neon_vst2v4hf */
    case 2612:  /* neon_vst2v4bf */
      if ((16) == (64))
        {
	  return TYPE_NEON_STORE1_2REG;
        }
      else
        {
	  return TYPE_NEON_STORE2_ONE_LANE;
        }

    case 2613:  /* neon_vst2v2si */
    case 2614:  /* neon_vst2v2sf */
      if ((32) == (64))
        {
	  return TYPE_NEON_STORE1_2REG;
        }
      else
        {
	  return TYPE_NEON_STORE2_ONE_LANE;
        }

    case 2615:  /* neon_vst2di */
      if ((64) == (64))
        {
	  return TYPE_NEON_STORE1_2REG;
        }
      else
        {
	  return TYPE_NEON_STORE2_ONE_LANE;
        }

    case 2633:  /* neon_vld3v8qi */
      if ((8) == (64))
        {
	  return TYPE_NEON_LOAD1_3REG;
        }
      else
        {
	  return TYPE_NEON_LOAD3_3REG;
        }

    case 2634:  /* neon_vld3v4hi */
    case 2635:  /* neon_vld3v4hf */
    case 2636:  /* neon_vld3v4bf */
      if ((16) == (64))
        {
	  return TYPE_NEON_LOAD1_3REG;
        }
      else
        {
	  return TYPE_NEON_LOAD3_3REG;
        }

    case 2637:  /* neon_vld3v2si */
    case 2638:  /* neon_vld3v2sf */
      if ((32) == (64))
        {
	  return TYPE_NEON_LOAD1_3REG;
        }
      else
        {
	  return TYPE_NEON_LOAD3_3REG;
        }

    case 2639:  /* neon_vld3di */
      if ((64) == (64))
        {
	  return TYPE_NEON_LOAD1_3REG;
        }
      else
        {
	  return TYPE_NEON_LOAD3_3REG;
        }

    case 2663:  /* neon_vld3_dupv8qi */
      if ((8) > (1))
        {
	  return TYPE_NEON_LOAD3_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2664:  /* neon_vld3_dupv4hi */
    case 2665:  /* neon_vld3_dupv4hf */
    case 2666:  /* neon_vld3_dupv4bf */
      if ((4) > (1))
        {
	  return TYPE_NEON_LOAD3_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2667:  /* neon_vld3_dupv2si */
    case 2668:  /* neon_vld3_dupv2sf */
      if ((2) > (1))
        {
	  return TYPE_NEON_LOAD3_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2669:  /* neon_vld3_dupdi */
      if ((1) > (1))
        {
	  return TYPE_NEON_LOAD3_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2671:  /* neon_vst3v8qi */
      if ((8) == (64))
        {
	  return TYPE_NEON_STORE1_3REG;
        }
      else
        {
	  return TYPE_NEON_STORE3_ONE_LANE;
        }

    case 2672:  /* neon_vst3v4hi */
    case 2673:  /* neon_vst3v4hf */
    case 2674:  /* neon_vst3v4bf */
      if ((16) == (64))
        {
	  return TYPE_NEON_STORE1_3REG;
        }
      else
        {
	  return TYPE_NEON_STORE3_ONE_LANE;
        }

    case 2675:  /* neon_vst3v2si */
    case 2676:  /* neon_vst3v2sf */
      if ((32) == (64))
        {
	  return TYPE_NEON_STORE1_3REG;
        }
      else
        {
	  return TYPE_NEON_STORE3_ONE_LANE;
        }

    case 2677:  /* neon_vst3di */
      if ((64) == (64))
        {
	  return TYPE_NEON_STORE1_3REG;
        }
      else
        {
	  return TYPE_NEON_STORE3_ONE_LANE;
        }

    case 2701:  /* neon_vld4v8qi */
      if ((8) == (64))
        {
	  return TYPE_NEON_LOAD1_4REG;
        }
      else
        {
	  return TYPE_NEON_LOAD4_4REG;
        }

    case 2702:  /* neon_vld4v4hi */
    case 2703:  /* neon_vld4v4hf */
    case 2704:  /* neon_vld4v4bf */
      if ((16) == (64))
        {
	  return TYPE_NEON_LOAD1_4REG;
        }
      else
        {
	  return TYPE_NEON_LOAD4_4REG;
        }

    case 2705:  /* neon_vld4v2si */
    case 2706:  /* neon_vld4v2sf */
      if ((32) == (64))
        {
	  return TYPE_NEON_LOAD1_4REG;
        }
      else
        {
	  return TYPE_NEON_LOAD4_4REG;
        }

    case 2707:  /* neon_vld4di */
      if ((64) == (64))
        {
	  return TYPE_NEON_LOAD1_4REG;
        }
      else
        {
	  return TYPE_NEON_LOAD4_4REG;
        }

    case 2731:  /* neon_vld4_dupv8qi */
      if ((8) > (1))
        {
	  return TYPE_NEON_LOAD4_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2732:  /* neon_vld4_dupv4hi */
    case 2733:  /* neon_vld4_dupv4hf */
    case 2734:  /* neon_vld4_dupv4bf */
      if ((4) > (1))
        {
	  return TYPE_NEON_LOAD4_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2735:  /* neon_vld4_dupv2si */
    case 2736:  /* neon_vld4_dupv2sf */
      if ((2) > (1))
        {
	  return TYPE_NEON_LOAD4_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2737:  /* neon_vld4_dupdi */
      if ((1) > (1))
        {
	  return TYPE_NEON_LOAD4_ALL_LANES;
        }
      else
        {
	  return TYPE_NEON_LOAD1_1REG;
        }

    case 2739:  /* neon_vst4v8qi */
      if ((8) == (64))
        {
	  return TYPE_NEON_STORE1_4REG;
        }
      else
        {
	  return TYPE_NEON_STORE4_4REG;
        }

    case 2740:  /* neon_vst4v4hi */
    case 2741:  /* neon_vst4v4hf */
    case 2742:  /* neon_vst4v4bf */
      if ((16) == (64))
        {
	  return TYPE_NEON_STORE1_4REG;
        }
      else
        {
	  return TYPE_NEON_STORE4_4REG;
        }

    case 2743:  /* neon_vst4v2si */
    case 2744:  /* neon_vst4v2sf */
      if ((32) == (64))
        {
	  return TYPE_NEON_STORE1_4REG;
        }
      else
        {
	  return TYPE_NEON_STORE4_4REG;
        }

    case 2745:  /* neon_vst4di */
      if ((64) == (64))
        {
	  return TYPE_NEON_STORE1_4REG;
        }
      else
        {
	  return TYPE_NEON_STORE4_4REG;
        }

    case 2852:  /* aes_op_protect */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_NEON_MOVE_Q;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_NEON_FROM_GP_Q;
        }
      else
        {
	  return TYPE_NEON_LOAD1_4REG;
        }

    case 7:  /* *arm_addsi3 */
    case 17:  /* addsi3_compare_op1 */
    case 18:  /* *addsi3_compare_op2 */
    case 6353:  /* *p *arm_addsi3 */
      extract_insn_cached (insn);
      if (const_int_operand (operands[2], VOIDmode))
        {
	  return TYPE_ALU_IMM;
        }
      else
        {
	  return TYPE_ALU_SREG;
        }

    case 19:  /* *compare_addsi2_op0 */
    case 20:  /* *compare_addsi2_op1 */
    case 6356:  /* *p *compare_addsi2_op0 */
    case 6357:  /* *p *compare_addsi2_op1 */
      extract_insn_cached (insn);
      if (const_int_operand (operands[1], VOIDmode))
        {
	  return TYPE_ALU_IMM;
        }
      else
        {
	  return TYPE_ALU_SREG;
        }

    case 29:  /* subsi3_carryin */
    case 6362:  /* *p subsi3_carryin */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ADC_REG;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_ADC_IMM;
        }
      else
        {
	  return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
        }

    case 31:  /* *add_not_cin */
    case 6364:  /* *p *add_not_cin */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ADC_REG;
        }
      else
        {
	  return TYPE_ADC_IMM;
        }

    case 105:  /* andsi_not_shiftsi_si */
    case 106:  /* andsi_not_shiftsi_si_scc_no_reuse */
    case 107:  /* andsi_not_shiftsi_si_scc */
    case 6406:  /* *p andsi_not_shiftsi_si */
    case 6407:  /* *p andsi_not_shiftsi_si_scc_no_reuse */
    case 6408:  /* *p andsi_not_shiftsi_si_scc */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_LOGIC_SHIFT_IMM;
        }
      else
        {
	  return TYPE_LOGIC_SHIFT_REG;
        }

    case 154:  /* *not_shiftsi */
    case 155:  /* *not_shiftsi_compare0 */
    case 156:  /* *not_shiftsi_compare0_scratch */
    case 6428:  /* *p *not_shiftsi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MVN_SHIFT;
        }
      else
        {
	  return TYPE_MVN_SHIFT_REG;
        }

    case 176:  /* *arm_zero_extendhisi2 */
    case 179:  /* *arm_zero_extendqisi2 */
    case 183:  /* *arm_extendhisi2 */
    case 187:  /* *arm_extendqisi */
    case 954:  /* *thumb1_zero_extendqisi2 */
    case 6442:  /* *p *arm_zero_extendhisi2 */
    case 6445:  /* *p *arm_zero_extendqisi2 */
    case 6449:  /* *p *arm_extendhisi2 */
    case 6452:  /* *p *arm_extendqisi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ALU_SHIFT_REG;
        }
      else
        {
	  return TYPE_LOAD_BYTE;
        }

    case 257:  /* *arm_movsi_insn */
    case 6521:  /* *p *arm_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_LOAD_4;
        }
      else
        {
	  return TYPE_STORE_4;
        }

    case 265:  /* *movhi_insn_arch4 */
    case 6524:  /* *p *movhi_insn_arch4 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[1], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 1)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_STORE_4;
        }
      else
        {
	  return TYPE_LOAD_4;
        }

    case 266:  /* *movhi_bytes */
    case 6525:  /* *p *movhi_bytes */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_MOV_REG;
        }
      else
        {
	  return TYPE_MVN_IMM;
        }

    case 268:  /* *arm32_movhf */
    case 269:  /* *arm32_movbf */
    case 6527:  /* *p *arm32_movhf */
    case 6528:  /* *p *arm32_movbf */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_MOV_REG;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 270:  /* *arm_movsf_soft_insn */
    case 6529:  /* *p *arm_movsf_soft_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_LOAD_4;
        }
      else
        {
	  return TYPE_STORE_4;
        }

    case 152:  /* *shiftsi3_compare0 */
    case 273:  /* *cmpsi_shiftsi */
    case 274:  /* *cmpsi_shiftsi_swp */
    case 275:  /* *arm_cmpsi_negshiftsi_si */
    case 329:  /* *arith_shiftsi_compare0 */
    case 330:  /* *arith_shiftsi_compare0_scratch */
    case 331:  /* *sub_shiftsi */
    case 332:  /* *sub_shiftsi_compare0 */
    case 333:  /* *sub_shiftsi_compare0_scratch */
    case 6531:  /* *p *arm_cmpsi_negshiftsi_si */
    case 6548:  /* *p *sub_shiftsi */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_ALUS_SHIFT_IMM;
        }
      else
        {
	  return TYPE_ALUS_SHIFT_REG;
        }

    case 746:  /* *arm_movhi_vfp */
    case 752:  /* *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 6842:  /* *p *arm_movhi_fp16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[1], VOIDmode))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MOV_REG;
	    }
        }
      else if (which_alternative == 1)
        {
	  return TYPE_MVN_IMM;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_MOV_IMM;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_F_MRC;
        }
      else
        {
	  return TYPE_FMOV;
        }

    case 761:  /* *movhf_vfp_hf16 */
    case 762:  /* *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 6852:  /* *p *movbf_vfp_bf16 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_FMOV;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_MOV_REG;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_F_MRC;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_FCONSTS;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_NEON_LOAD1_1REG;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_NEON_STORE1_1REG;
        }
      else
        {
	  if (
#line 471 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/vfp.md"
(arm_arch_thumb2))
	    {
	      return TYPE_MOV_IMM;
	    }
	  else
	    {
	      return TYPE_MULTIPLE;
	    }
        }

    case 767:  /* *movsf_vfp */
    case 768:  /* *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 6854:  /* *p *thumb2_movsf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_F_MCR;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_F_MRC;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_FCONSTS;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_F_LOADS;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_F_STORES;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_LOAD_4;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_STORE_4;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_FMOV;
        }
      else
        {
	  return TYPE_MOV_REG;
        }

    case 769:  /* *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 6855:  /* *p *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_F_MCRR;
        }
      else if (which_alternative == 1)
        {
	  return TYPE_F_MRRC;
        }
      else if (which_alternative == 2)
        {
	  return TYPE_FCONSTD;
        }
      else if (which_alternative == 3)
        {
	  return TYPE_NEON_MOVE;
        }
      else if (which_alternative == 4)
        {
	  return TYPE_F_LOADD;
        }
      else if (which_alternative == 5)
        {
	  return TYPE_F_STORED;
        }
      else if (which_alternative == 6)
        {
	  return TYPE_LOAD_8;
        }
      else if (which_alternative == 7)
        {
	  return TYPE_STORE_8;
        }
      else if (which_alternative == 8)
        {
	  return TYPE_FFARITHD;
        }
      else
        {
	  return TYPE_MULTIPLE;
        }

    case 957:  /* thumb1_extendqisi2 */
    case 177:  /* *arm_zero_extendhisi2_v6 */
    case 180:  /* *arm_zero_extendqisi2_v6 */
    case 184:  /* *arm_extendhisi2_v6 */
    case 188:  /* *arm_extendqisi_v6 */
    case 953:  /* *thumb1_zero_extendhisi2 */
    case 955:  /* *thumb1_zero_extendqisi2_v6 */
    case 956:  /* thumb1_extendhisi2 */
    case 1037:  /* *thumb2_extendqisi_v6 */
    case 1038:  /* *thumb2_zero_extendhisi2_v6 */
    case 1039:  /* thumb2_zero_extendqisi2_v6 */
    case 6443:  /* *p *arm_zero_extendhisi2_v6 */
    case 6446:  /* *p *arm_zero_extendqisi2_v6 */
    case 6450:  /* *p *arm_extendhisi2_v6 */
    case 6453:  /* *p *arm_extendqisi_v6 */
    case 6928:  /* *p *thumb2_extendqisi_v6 */
    case 6929:  /* *p *thumb2_zero_extendhisi2_v6 */
    case 6930:  /* *p thumb2_zero_extendqisi2_v6 */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return TYPE_EXTEND;
        }
      else
        {
	  return TYPE_LOAD_BYTE;
        }

    case 1046:  /* *thumb2_shiftsi3_short */
    case 6932:  /* *p *thumb2_shiftsi3_short */
      extract_insn_cached (insn);
      if (const_int_operand (operands[2], VOIDmode))
        {
	  if (alu_shift_operator_lsl_1_to_4 (operands[3], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	    }
	  else
	    {
	      return TYPE_ALU_SHIFT_IMM_OTHER;
	    }
        }
      else
        {
	  return TYPE_ALU_SHIFT_REG;
        }

    case 1050:  /* *thumb2_addsi_short */
    case 6936:  /* *p *thumb2_addsi_short */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  if (const_int_operand (operands[2], VOIDmode))
	    {
	      return TYPE_ALU_IMM;
	    }
	  else
	    {
	      return TYPE_ALU_SREG;
	    }
        }
      else
        {
	  return TYPE_ALU_IMM;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_insn_cached (insn);
      if (((cached_autodetect_type = get_attr_autodetect_type (insn)) == AUTODETECT_TYPE_ALU_SHIFT_LSR_OP2) || (cached_autodetect_type == AUTODETECT_TYPE_ALU_SHIFT_ASR_OP2))
        {
	  return TYPE_ALU_SHIFT_IMM_OTHER;
        }
      else if (cached_autodetect_type == AUTODETECT_TYPE_ALU_SHIFT_LSL_OP2)
        {
	  if (const_1_to_4_operand (operands[2], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	    }
	  else
	    {
	      return TYPE_ALU_SHIFT_IMM_OTHER;
	    }
        }
      else if (cached_autodetect_type == AUTODETECT_TYPE_ALU_SHIFT_MUL_OP3)
        {
	  if (const_2_4_8_16_operand (operands[3], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	    }
	  else
	    {
	      return TYPE_ALU_SHIFT_IMM_OTHER;
	    }
        }
      else if (cached_autodetect_type == AUTODETECT_TYPE_ALU_SHIFT_OPERATOR1)
        {
	  if (alu_shift_reg_p (operands[1], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_REG;
	    }
	  else
	    {
	      if (alu_shift_operator_lsl_1_to_4 (operands[1], VOIDmode))
	        {
		  return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	        }
	      else
	        {
		  return TYPE_ALU_SHIFT_IMM_OTHER;
	        }
	    }
        }
      else if (cached_autodetect_type == AUTODETECT_TYPE_ALU_SHIFT_OPERATOR2)
        {
	  if (alu_shift_reg_p (operands[2], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_REG;
	    }
	  else
	    {
	      if (alu_shift_operator_lsl_1_to_4 (operands[2], VOIDmode))
	        {
		  return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	        }
	      else
	        {
		  return TYPE_ALU_SHIFT_IMM_OTHER;
	        }
	    }
        }
      else if (cached_autodetect_type == AUTODETECT_TYPE_ALU_SHIFT_OPERATOR3)
        {
	  if (alu_shift_reg_p (operands[3], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_REG;
	    }
	  else
	    {
	      if (alu_shift_operator_lsl_1_to_4 (operands[3], VOIDmode))
	        {
		  return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	        }
	      else
	        {
		  return TYPE_ALU_SHIFT_IMM_OTHER;
	        }
	    }
        }
      else if (cached_autodetect_type == AUTODETECT_TYPE_ALU_SHIFT_OPERATOR4)
        {
	  if (alu_shift_reg_p (operands[4], VOIDmode))
	    {
	      return TYPE_ALU_SHIFT_REG;
	    }
	  else
	    {
	      if (alu_shift_operator_lsl_1_to_4 (operands[4], VOIDmode))
	        {
		  return TYPE_ALU_SHIFT_IMM_LSL_1TO4;
	        }
	      else
	        {
		  return TYPE_ALU_SHIFT_IMM_OTHER;
	        }
	    }
        }
      else
        {
	  return TYPE_UNTYPED;
        }

    case 4959:  /* *movmisalignv16qi_mve_load */
    case 4960:  /* *movmisalignv8hi_mve_load */
    case 4961:  /* *movmisalignv4si_mve_load */
    case 4962:  /* *movmisalignv8hf_mve_load */
    case 4963:  /* *movmisalignv4sf_mve_load */
      return TYPE_MVE_LOAD;

    case 4954:  /* *movmisalignv16qi_mve_store */
    case 4955:  /* *movmisalignv8hi_mve_store */
    case 4956:  /* *movmisalignv4si_mve_store */
    case 4957:  /* *movmisalignv8hf_mve_store */
    case 4958:  /* *movmisalignv4sf_mve_store */
      return TYPE_MVE_STORE;

    case 139:  /* arm_cx1si */
    case 140:  /* arm_cx1di */
    case 141:  /* arm_cx1asi */
    case 142:  /* arm_cx1adi */
    case 143:  /* arm_cx2si */
    case 144:  /* arm_cx2di */
    case 145:  /* arm_cx2asi */
    case 146:  /* arm_cx2adi */
    case 147:  /* arm_cx3si */
    case 148:  /* arm_cx3di */
    case 149:  /* arm_cx3asi */
    case 150:  /* arm_cx3adi */
    case 488:  /* arm_cdp */
    case 489:  /* arm_cdp2 */
    case 490:  /* *ldc */
    case 491:  /* *ldc */
    case 492:  /* *ldc */
    case 493:  /* *ldc */
    case 494:  /* *stc */
    case 495:  /* *stc */
    case 496:  /* *stc */
    case 497:  /* *stc */
    case 498:  /* arm_mcr */
    case 499:  /* arm_mcr2 */
    case 500:  /* arm_mrc */
    case 501:  /* arm_mrc2 */
    case 502:  /* arm_mcrr */
    case 503:  /* arm_mcrr2 */
    case 504:  /* arm_mrrc */
    case 505:  /* arm_mrrc2 */
    case 922:  /* arm_vcx1si */
    case 923:  /* arm_vcx1di */
    case 924:  /* arm_vcx1asi */
    case 925:  /* arm_vcx1adi */
    case 926:  /* arm_vcx2si */
    case 927:  /* arm_vcx2di */
    case 928:  /* arm_vcx2asi */
    case 929:  /* arm_vcx2adi */
    case 930:  /* arm_vcx3si */
    case 931:  /* arm_vcx3di */
    case 932:  /* arm_vcx3asi */
    case 933:  /* arm_vcx3adi */
    case 4942:  /* arm_vcx1qv16qi */
    case 4943:  /* arm_vcx1qav16qi */
    case 4944:  /* arm_vcx2qv16qi */
    case 4945:  /* arm_vcx2qav16qi */
    case 4946:  /* arm_vcx3qv16qi */
    case 4947:  /* arm_vcx3qav16qi */
    case 4948:  /* arm_vcx1q_p_v16qi */
    case 4949:  /* arm_vcx1qa_p_v16qi */
    case 4950:  /* arm_vcx2q_p_v16qi */
    case 4951:  /* arm_vcx2qa_p_v16qi */
    case 4952:  /* arm_vcx3q_p_v16qi */
    case 4953:  /* arm_vcx3qa_p_v16qi */
      return TYPE_COPROC;

    case 2868:  /* crypto_vmullp64 */
      return TYPE_CRYPTO_PMULL;

    case 2864:  /* crypto_sha256h */
    case 2865:  /* crypto_sha256h2 */
    case 2866:  /* crypto_sha256su1 */
      return TYPE_CRYPTO_SHA256_SLOW;

    case 2862:  /* crypto_sha256su0 */
      return TYPE_CRYPTO_SHA256_FAST;

    case 2869:  /* crypto_sha1c_lb */
    case 2870:  /* crypto_sha1m_lb */
    case 2871:  /* crypto_sha1p_lb */
      return TYPE_CRYPTO_SHA1_SLOW;

    case 2861:  /* crypto_sha1su1 */
    case 2867:  /* crypto_sha1h_lb */
      return TYPE_CRYPTO_SHA1_FAST;

    case 2863:  /* crypto_sha1su0 */
      return TYPE_CRYPTO_SHA1_XOR;

    case 2848:  /* crypto_aesmc */
    case 2849:  /* crypto_aesimc */
    case 2855:  /* *crypto_aesmc_protected */
    case 2856:  /* *crypto_aesimc_protected */
      return TYPE_CRYPTO_AESMC;

    case 2850:  /* *crypto_aesd_insn */
    case 2851:  /* *crypto_aese_insn */
    case 2857:  /* *aarch32_crypto_aese_fused */
    case 2858:  /* *aarch32_crypto_aese_fused_protected */
    case 2859:  /* *aarch32_crypto_aesd_fused */
    case 2860:  /* *aarch32_crypto_aesd_fused_protected */
      return TYPE_CRYPTO_AESE;

    case 2846:  /* neon_vfmab_lanev8bf */
    case 2847:  /* neon_vfmat_lanev8bf */
      return TYPE_NEON_FP_MLA_S_SCALAR_Q;

    case 1180:  /* mulv8hf3addv8hf_neon */
    case 1191:  /* fmav4sf4 */
    case 1193:  /* fmav4sf4_intrinsic */
    case 1194:  /* fmav8hf4 */
    case 1197:  /* *fmsubv4sf4 */
    case 1199:  /* fmsubv4sf4_intrinsic */
    case 1200:  /* fmsubv8hf4_intrinsic */
    case 1520:  /* vfmal_lowv4sf_intrinsic */
    case 1522:  /* vfmsl_highv4sf_intrinsic */
    case 1524:  /* vfmal_highv4sf_intrinsic */
    case 1526:  /* vfmsl_lowv4sf_intrinsic */
    case 1528:  /* vfmal_lane_lowv4sf_intrinsic */
    case 1530:  /* vfmal_lane_lowv4hfv4sf_intrinsic */
    case 1532:  /* vfmal_lane_highv4hfv4sf_intrinsic */
    case 1534:  /* vfmal_lane_highv4sf_intrinsic */
    case 1536:  /* vfmsl_lane_lowv4sf_intrinsic */
    case 1538:  /* vfmsl_lane_lowv4hfv4sf_intrinsic */
    case 1540:  /* vfmsl_lane_highv4hfv4sf_intrinsic */
    case 1542:  /* vfmsl_lane_highv4sf_intrinsic */
    case 2843:  /* neon_vmmlav8bf */
    case 2844:  /* neon_vfmabv8bf */
    case 2845:  /* neon_vfmatv8bf */
      return TYPE_NEON_FP_MLA_S_Q;

    case 1181:  /* mulv4hf3addv4hf_neon */
    case 1190:  /* fmav2sf4 */
    case 1192:  /* fmav2sf4_intrinsic */
    case 1195:  /* fmav4hf4 */
    case 1196:  /* *fmsubv2sf4 */
    case 1198:  /* fmsubv2sf4_intrinsic */
    case 1201:  /* fmsubv4hf4_intrinsic */
    case 1519:  /* vfmal_lowv2sf_intrinsic */
    case 1521:  /* vfmsl_highv2sf_intrinsic */
    case 1523:  /* vfmal_highv2sf_intrinsic */
    case 1525:  /* vfmsl_lowv2sf_intrinsic */
    case 1527:  /* vfmal_lane_lowv2sf_intrinsic */
    case 1529:  /* vfmal_lane_lowv8hfv2sf_intrinsic */
    case 1531:  /* vfmal_lane_highv8hfv2sf_intrinsic */
    case 1533:  /* vfmal_lane_highv2sf_intrinsic */
    case 1535:  /* vfmsl_lane_lowv2sf_intrinsic */
    case 1537:  /* vfmsl_lane_lowv8hfv2sf_intrinsic */
    case 1539:  /* vfmsl_lane_highv8hfv2sf_intrinsic */
    case 1541:  /* vfmsl_lane_highv2sf_intrinsic */
      return TYPE_NEON_FP_MLA_S;

    case 2169:  /* neon_vmul_lanev8hf */
      return TYPE_NEON_FP_MUL_S_SCALAR_Q;

    case 2170:  /* neon_vmul_lanev4hf */
      return TYPE_NEON_FP_MUL_S_SCALAR;

    case 1901:  /* neon_vrsqrtsv4sf */
    case 1902:  /* neon_vrsqrtsv8hf */
      return TYPE_NEON_FP_RSQRTS_S_Q;

    case 1900:  /* neon_vrsqrtsv2sf */
    case 1903:  /* neon_vrsqrtsv4hf */
      return TYPE_NEON_FP_RSQRTS_S;

    case 1324:  /* neon_vrsqrtev8hf */
    case 2021:  /* neon_vrsqrtev4si */
    case 2022:  /* neon_vrsqrtev4sf */
      return TYPE_NEON_FP_RSQRTE_S_Q;

    case 1325:  /* neon_vrsqrtev4hf */
    case 2019:  /* neon_vrsqrtev2si */
    case 2020:  /* neon_vrsqrtev2sf */
      return TYPE_NEON_FP_RSQRTE_S;

    case 1897:  /* neon_vrecpsv4sf */
    case 1898:  /* neon_vrecpsv8hf */
      return TYPE_NEON_FP_RECPS_S_Q;

    case 1896:  /* neon_vrecpsv2sf */
    case 1899:  /* neon_vrecpsv4hf */
      return TYPE_NEON_FP_RECPS_S;

    case 2013:  /* neon_vrecpev8hf */
    case 2017:  /* neon_vrecpev4si */
    case 2018:  /* neon_vrecpev4sf */
      return TYPE_NEON_FP_RECPE_S_Q;

    case 2014:  /* neon_vrecpev4hf */
    case 2015:  /* neon_vrecpev2si */
    case 2016:  /* neon_vrecpev2sf */
      return TYPE_NEON_FP_RECPE_S;

    case 1208:  /* neon_vrintpv4sf */
    case 1209:  /* neon_vrintzv4sf */
    case 1210:  /* neon_vrintmv4sf */
    case 1211:  /* neon_vrintxv4sf */
    case 1212:  /* neon_vrintav4sf */
    case 1213:  /* neon_vrintnv4sf */
    case 1312:  /* neon_vrndv8hf */
    case 1313:  /* neon_vrndav8hf */
    case 1314:  /* neon_vrndmv8hf */
    case 1315:  /* neon_vrndnv8hf */
    case 1316:  /* neon_vrndpv8hf */
    case 1317:  /* neon_vrndxv8hf */
      return TYPE_NEON_FP_ROUND_S_Q;

    case 781:  /* neon_vrndhf */
    case 782:  /* neon_vrndahf */
    case 783:  /* neon_vrndmhf */
    case 784:  /* neon_vrndnhf */
    case 785:  /* neon_vrndphf */
    case 786:  /* neon_vrndxhf */
    case 787:  /* neon_vrndihf */
    case 1202:  /* neon_vrintpv2sf */
    case 1203:  /* neon_vrintzv2sf */
    case 1204:  /* neon_vrintmv2sf */
    case 1205:  /* neon_vrintxv2sf */
    case 1206:  /* neon_vrintav2sf */
    case 1207:  /* neon_vrintnv2sf */
    case 1318:  /* neon_vrndv4hf */
    case 1319:  /* neon_vrndav4hf */
    case 1320:  /* neon_vrndmv4hf */
    case 1321:  /* neon_vrndnv4hf */
    case 1322:  /* neon_vrndpv4hf */
    case 1323:  /* neon_vrndxv4hf */
      return TYPE_NEON_FP_ROUND_S;

    case 2088:  /* floatv4siv4sf2 */
    case 2090:  /* floatunsv4siv4sf2 */
    case 2101:  /* neon_vcvtsv4si */
    case 2102:  /* neon_vcvtuv4si */
    case 2107:  /* neon_vcvtsv8hi */
    case 2108:  /* neon_vcvtuv8hi */
    case 2123:  /* neon_vcvts_nv4si */
    case 2124:  /* neon_vcvtu_nv4si */
    case 2127:  /* neon_vcvts_nv8hi */
    case 2128:  /* neon_vcvtu_nv8hi */
      return TYPE_NEON_INT_TO_FP_S_Q;

    case 2087:  /* floatv2siv2sf2 */
    case 2089:  /* floatunsv2siv2sf2 */
    case 2099:  /* neon_vcvtsv2si */
    case 2100:  /* neon_vcvtuv2si */
    case 2105:  /* neon_vcvtsv4hi */
    case 2106:  /* neon_vcvtuv4hi */
    case 2121:  /* neon_vcvts_nv2si */
    case 2122:  /* neon_vcvtu_nv2si */
    case 2125:  /* neon_vcvts_nv4hi */
    case 2126:  /* neon_vcvtu_nv4hi */
      return TYPE_NEON_INT_TO_FP_S;

    case 1220:  /* neon_vcvtpv4sfv4si */
    case 1221:  /* neon_vcvtmv4sfv4si */
    case 1222:  /* neon_vcvtav4sfv4si */
    case 1223:  /* neon_vcvtpuv4sfv4si */
    case 1224:  /* neon_vcvtmuv4sfv4si */
    case 1225:  /* neon_vcvtauv4sfv4si */
    case 2092:  /* fix_truncv4sfv4si2 */
    case 2094:  /* fixuns_truncv4sfv4si2 */
    case 2097:  /* neon_vcvtsv4sf */
    case 2098:  /* neon_vcvtuv4sf */
    case 2109:  /* neon_vcvtsv8hf */
    case 2110:  /* neon_vcvtuv8hf */
    case 2115:  /* neon_vcvts_nv4sf */
    case 2116:  /* neon_vcvtu_nv4sf */
    case 2117:  /* neon_vcvts_nv8hf */
    case 2118:  /* neon_vcvtu_nv8hf */
    case 2129:  /* neon_vcvtasv8hf */
    case 2130:  /* neon_vcvtauv8hf */
    case 2131:  /* neon_vcvtmsv8hf */
    case 2132:  /* neon_vcvtmuv8hf */
    case 2133:  /* neon_vcvtnsv8hf */
    case 2134:  /* neon_vcvtnuv8hf */
    case 2135:  /* neon_vcvtpsv8hf */
    case 2136:  /* neon_vcvtpuv8hf */
      return TYPE_NEON_FP_TO_INT_S_Q;

    case 1214:  /* neon_vcvtpv2sfv2si */
    case 1215:  /* neon_vcvtmv2sfv2si */
    case 1216:  /* neon_vcvtav2sfv2si */
    case 1217:  /* neon_vcvtpuv2sfv2si */
    case 1218:  /* neon_vcvtmuv2sfv2si */
    case 1219:  /* neon_vcvtauv2sfv2si */
    case 2091:  /* fix_truncv2sfv2si2 */
    case 2093:  /* fixuns_truncv2sfv2si2 */
    case 2095:  /* neon_vcvtsv2sf */
    case 2096:  /* neon_vcvtuv2sf */
    case 2111:  /* neon_vcvtsv4hf */
    case 2112:  /* neon_vcvtuv4hf */
    case 2113:  /* neon_vcvts_nv2sf */
    case 2114:  /* neon_vcvtu_nv2sf */
    case 2119:  /* neon_vcvts_nv4hf */
    case 2120:  /* neon_vcvtu_nv4hf */
    case 2137:  /* neon_vcvtasv4hf */
    case 2138:  /* neon_vcvtauv4hf */
    case 2139:  /* neon_vcvtmsv4hf */
    case 2140:  /* neon_vcvtmuv4hf */
    case 2141:  /* neon_vcvtnsv4hf */
    case 2142:  /* neon_vcvtnuv4hf */
    case 2143:  /* neon_vcvtpsv4hf */
    case 2144:  /* neon_vcvtpuv4hf */
      return TYPE_NEON_FP_TO_INT_S;

    case 2103:  /* neon_vcvtv4sfv4hf */
      return TYPE_NEON_FP_CVT_WIDEN_H;

    case 2104:  /* neon_vcvtv4hfv4sf */
    case 2834:  /* neon_vbfcvtv4sfv4bf */
    case 2835:  /* neon_vbfcvtv4sfv8bf */
    case 2836:  /* neon_vbfcvtv4sf_highv8bf */
      return TYPE_NEON_FP_CVT_NARROW_S_Q;

    case 1405:  /* quad_halves_sminv4sf */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1894:  /* neon_vpmaxfv4sf */
    case 1895:  /* neon_vpminfv4sf */
      return TYPE_NEON_FP_REDUC_MINMAX_S_Q;

    case 1892:  /* neon_vpmaxfv2sf */
    case 1893:  /* neon_vpminfv2sf */
      return TYPE_NEON_FP_REDUC_MINMAX_S;

    case 1404:  /* quad_halves_plusv4sf */
      return TYPE_NEON_FP_REDUC_ADD_S_Q;

    case 1836:  /* neon_vmaxfv4sf */
    case 1837:  /* neon_vminfv4sf */
    case 1838:  /* neon_vmaxfv8hf */
    case 1839:  /* neon_vminfv8hf */
    case 1844:  /* neon_vmaxnmv8hf */
    case 1845:  /* neon_vminnmv8hf */
    case 1850:  /* neon_vmaxnmv4sf */
    case 1851:  /* neon_vminnmv4sf */
    case 1854:  /* fmaxv4sf3 */
    case 1855:  /* fminv4sf3 */
      return TYPE_NEON_FP_MINMAX_S_Q;

    case 1834:  /* neon_vmaxfv2sf */
    case 1835:  /* neon_vminfv2sf */
    case 1840:  /* neon_vmaxfv4hf */
    case 1841:  /* neon_vminfv4hf */
    case 1846:  /* neon_vmaxnmv4hf */
    case 1847:  /* neon_vminnmv4hf */
    case 1848:  /* neon_vmaxnmv2sf */
    case 1849:  /* neon_vminnmv2sf */
    case 1852:  /* fmaxv2sf3 */
    case 1853:  /* fminv2sf3 */
      return TYPE_NEON_FP_MINMAX_S;

    case 1695:  /* neon_vceqv4sf_insn_unspec */
    case 1696:  /* neon_vcgtv4sf_insn_unspec */
    case 1697:  /* neon_vcgev4sf_insn_unspec */
    case 1698:  /* neon_vcltv4sf_insn_unspec */
    case 1699:  /* neon_vclev4sf_insn_unspec */
    case 1710:  /* neon_vceqv8hf_fp16insn_unspec */
    case 1711:  /* neon_vcgtv8hf_fp16insn_unspec */
    case 1712:  /* neon_vcgev8hf_fp16insn_unspec */
    case 1713:  /* neon_vcltv8hf_fp16insn_unspec */
    case 1714:  /* neon_vclev8hf_fp16insn_unspec */
    case 1736:  /* neon_vcagtv4sf_insn */
    case 1737:  /* neon_vcagev4sf_insn */
    case 1738:  /* neon_vcaltv4sf_insn */
    case 1739:  /* neon_vcalev4sf_insn */
    case 1744:  /* neon_vcagev4sf_insn_unspec */
    case 1745:  /* neon_vcagtv4sf_insn_unspec */
    case 1746:  /* neon_vcalev4sf_insn_unspec */
    case 1747:  /* neon_vcaltv4sf_insn_unspec */
    case 1748:  /* neon_vcagtv8hf_fp16insn */
    case 1749:  /* neon_vcagev8hf_fp16insn */
    case 1750:  /* neon_vcaltv8hf_fp16insn */
    case 1751:  /* neon_vcalev8hf_fp16insn */
    case 1756:  /* neon_vcagev8hf_fp16insn_unspec */
    case 1757:  /* neon_vcagtv8hf_fp16insn_unspec */
    case 1758:  /* neon_vcalev8hf_fp16insn_unspec */
    case 1759:  /* neon_vcaltv8hf_fp16insn_unspec */
      return TYPE_NEON_FP_COMPARE_S_Q;

    case 1690:  /* neon_vceqv2sf_insn_unspec */
    case 1691:  /* neon_vcgtv2sf_insn_unspec */
    case 1692:  /* neon_vcgev2sf_insn_unspec */
    case 1693:  /* neon_vcltv2sf_insn_unspec */
    case 1694:  /* neon_vclev2sf_insn_unspec */
    case 1715:  /* neon_vceqv4hf_fp16insn_unspec */
    case 1716:  /* neon_vcgtv4hf_fp16insn_unspec */
    case 1717:  /* neon_vcgev4hf_fp16insn_unspec */
    case 1718:  /* neon_vcltv4hf_fp16insn_unspec */
    case 1719:  /* neon_vclev4hf_fp16insn_unspec */
    case 1732:  /* neon_vcagtv2sf_insn */
    case 1733:  /* neon_vcagev2sf_insn */
    case 1734:  /* neon_vcaltv2sf_insn */
    case 1735:  /* neon_vcalev2sf_insn */
    case 1740:  /* neon_vcagev2sf_insn_unspec */
    case 1741:  /* neon_vcagtv2sf_insn_unspec */
    case 1742:  /* neon_vcalev2sf_insn_unspec */
    case 1743:  /* neon_vcaltv2sf_insn_unspec */
    case 1752:  /* neon_vcagtv4hf_fp16insn */
    case 1753:  /* neon_vcagev4hf_fp16insn */
    case 1754:  /* neon_vcaltv4hf_fp16insn */
    case 1755:  /* neon_vcalev4hf_fp16insn */
    case 1760:  /* neon_vcagev4hf_fp16insn_unspec */
    case 1761:  /* neon_vcagtv4hf_fp16insn_unspec */
    case 1762:  /* neon_vcalev4hf_fp16insn_unspec */
    case 1763:  /* neon_vcaltv4hf_fp16insn_unspec */
      return TYPE_NEON_FP_COMPARE_S;

    case 1785:  /* neon_vabdfv4sf */
    case 2818:  /* neon_vabdv8hf_2 */
    case 2820:  /* neon_vabdv4sf_2 */
    case 2822:  /* neon_vabdv8hf_3 */
    case 2824:  /* neon_vabdv4sf_3 */
      return TYPE_NEON_FP_ABD_S_Q;

    case 1784:  /* neon_vabdfv2sf */
    case 2817:  /* neon_vabdv4hf_2 */
    case 2819:  /* neon_vabdv2sf_2 */
    case 2821:  /* neon_vabdv4hf_3 */
    case 2823:  /* neon_vabdv2sf_3 */
      return TYPE_NEON_FP_ABD_S;

    case 2758:  /* neon_vst4_lanev8qi */
    case 2759:  /* neon_vst4_lanev4hi */
    case 2760:  /* neon_vst4_lanev4hf */
    case 2761:  /* neon_vst4_lanev4bf */
    case 2762:  /* neon_vst4_lanev2si */
    case 2763:  /* neon_vst4_lanev2sf */
      return TYPE_NEON_STORE4_ONE_LANE;

    case 2746:  /* neon_vst4qav16qi */
    case 2747:  /* neon_vst4qav8hi */
    case 2748:  /* neon_vst4qav8hf */
    case 2749:  /* neon_vst4qav8bf */
    case 2750:  /* neon_vst4qav4si */
    case 2751:  /* neon_vst4qav4sf */
    case 2752:  /* neon_vst4qbv16qi */
    case 2753:  /* neon_vst4qbv8hi */
    case 2754:  /* neon_vst4qbv8hf */
    case 2755:  /* neon_vst4qbv8bf */
    case 2756:  /* neon_vst4qbv4si */
    case 2757:  /* neon_vst4qbv4sf */
    case 2764:  /* neon_vst4_lanev8hi */
    case 2765:  /* neon_vst4_lanev8hf */
    case 2766:  /* neon_vst4_lanev4si */
    case 2767:  /* neon_vst4_lanev4sf */
    case 2768:  /* neon_vst4_lanev8bf */
      return TYPE_NEON_STORE4_4REG_Q;

    case 2696:  /* neon_vst3_lanev8hi */
    case 2697:  /* neon_vst3_lanev8hf */
    case 2698:  /* neon_vst3_lanev4si */
    case 2699:  /* neon_vst3_lanev4sf */
    case 2700:  /* neon_vst3_lanev8bf */
      return TYPE_NEON_STORE3_ONE_LANE_Q;

    case 2690:  /* neon_vst3_lanev8qi */
    case 2691:  /* neon_vst3_lanev4hi */
    case 2692:  /* neon_vst3_lanev4hf */
    case 2693:  /* neon_vst3_lanev4bf */
    case 2694:  /* neon_vst3_lanev2si */
    case 2695:  /* neon_vst3_lanev2sf */
      return TYPE_NEON_STORE3_ONE_LANE;

    case 2678:  /* neon_vst3qav16qi */
    case 2679:  /* neon_vst3qav8hi */
    case 2680:  /* neon_vst3qav8hf */
    case 2681:  /* neon_vst3qav8bf */
    case 2682:  /* neon_vst3qav4si */
    case 2683:  /* neon_vst3qav4sf */
    case 2684:  /* neon_vst3qbv16qi */
    case 2685:  /* neon_vst3qbv8hi */
    case 2686:  /* neon_vst3qbv8hf */
    case 2687:  /* neon_vst3qbv8bf */
    case 2688:  /* neon_vst3qbv4si */
    case 2689:  /* neon_vst3qbv4sf */
      return TYPE_NEON_STORE3_3REG_Q;

    case 2628:  /* neon_vst2_lanev8hi */
    case 2629:  /* neon_vst2_lanev8hf */
    case 2630:  /* neon_vst2_lanev4si */
    case 2631:  /* neon_vst2_lanev4sf */
    case 2632:  /* neon_vst2_lanev8bf */
      return TYPE_NEON_STORE2_ONE_LANE_Q;

    case 2622:  /* neon_vst2_lanev8qi */
    case 2623:  /* neon_vst2_lanev4hi */
    case 2624:  /* neon_vst2_lanev4hf */
    case 2625:  /* neon_vst2_lanev4bf */
    case 2626:  /* neon_vst2_lanev2si */
    case 2627:  /* neon_vst2_lanev2sf */
      return TYPE_NEON_STORE2_ONE_LANE;

    case 2616:  /* neon_vst2v16qi */
    case 2617:  /* neon_vst2v8hi */
    case 2618:  /* neon_vst2v8hf */
    case 2619:  /* neon_vst2v8bf */
    case 2620:  /* neon_vst2v4si */
    case 2621:  /* neon_vst2v4sf */
      return TYPE_NEON_STORE2_4REG_Q;

    case 2570:  /* neon_vst1_lanev16qi */
    case 2571:  /* neon_vst1_lanev8hi */
    case 2572:  /* neon_vst1_lanev8hf */
    case 2573:  /* neon_vst1_lanev8bf */
    case 2574:  /* neon_vst1_lanev4si */
    case 2575:  /* neon_vst1_lanev4sf */
    case 2576:  /* neon_vst1_lanev2di */
      return TYPE_NEON_STORE1_ONE_LANE_Q;

    case 2563:  /* neon_vst1_lanev8qi */
    case 2564:  /* neon_vst1_lanev4hi */
    case 2565:  /* neon_vst1_lanev4hf */
    case 2566:  /* neon_vst1_lanev4bf */
    case 2567:  /* neon_vst1_lanev2si */
    case 2568:  /* neon_vst1_lanev2sf */
    case 2569:  /* neon_vst1_lanedi */
      return TYPE_NEON_STORE1_ONE_LANE;

    case 1104:  /* *movmisalignv16qi_neon_store */
    case 1105:  /* *movmisalignv8hi_neon_store */
    case 1106:  /* *movmisalignv8hf_neon_store */
    case 1107:  /* *movmisalignv8bf_neon_store */
    case 1108:  /* *movmisalignv4si_neon_store */
    case 1109:  /* *movmisalignv4sf_neon_store */
    case 1110:  /* *movmisalignv2di_neon_store */
    case 2550:  /* neon_vst1v16qi */
    case 2552:  /* neon_vst1v8hi */
    case 2554:  /* neon_vst1v4si */
    case 2556:  /* neon_vst1v8hf */
    case 2558:  /* neon_vst1v8bf */
    case 2560:  /* neon_vst1v4sf */
    case 2562:  /* neon_vst1v2di */
      return TYPE_NEON_STORE1_1REG_Q;

    case 1070:  /* unaligned_storev8qi */
    case 1090:  /* *movmisalignv8qi_neon_store */
    case 1091:  /* *movmisalignv4hi_neon_store */
    case 1092:  /* *movmisalignv4hf_neon_store */
    case 1093:  /* *movmisalignv4bf_neon_store */
    case 1094:  /* *movmisalignv2si_neon_store */
    case 1095:  /* *movmisalignv2sf_neon_store */
    case 1096:  /* *movmisaligndi_neon_store */
    case 2549:  /* neon_vst1v8qi */
    case 2551:  /* neon_vst1v4hi */
    case 2553:  /* neon_vst1v2si */
    case 2555:  /* neon_vst1v4hf */
    case 2557:  /* neon_vst1v4bf */
    case 2559:  /* neon_vst1v2sf */
    case 2561:  /* neon_vst1di */
      return TYPE_NEON_STORE1_1REG;

    case 2726:  /* neon_vld4_lanev8hi */
    case 2727:  /* neon_vld4_lanev8hf */
    case 2728:  /* neon_vld4_lanev4si */
    case 2729:  /* neon_vld4_lanev4sf */
    case 2730:  /* neon_vld4_lanev8bf */
      return TYPE_NEON_LOAD4_ONE_LANE_Q;

    case 2720:  /* neon_vld4_lanev8qi */
    case 2721:  /* neon_vld4_lanev4hi */
    case 2722:  /* neon_vld4_lanev4hf */
    case 2723:  /* neon_vld4_lanev4bf */
    case 2724:  /* neon_vld4_lanev2si */
    case 2725:  /* neon_vld4_lanev2sf */
      return TYPE_NEON_LOAD4_ONE_LANE;

    case 2738:  /* neon_vld4_dupv8bf */
      return TYPE_NEON_LOAD4_ALL_LANES_Q;

    case 2708:  /* neon_vld4qav16qi */
    case 2709:  /* neon_vld4qav8hi */
    case 2710:  /* neon_vld4qav8hf */
    case 2711:  /* neon_vld4qav8bf */
    case 2712:  /* neon_vld4qav4si */
    case 2713:  /* neon_vld4qav4sf */
    case 2714:  /* neon_vld4qbv16qi */
    case 2715:  /* neon_vld4qbv8hi */
    case 2716:  /* neon_vld4qbv8hf */
    case 2717:  /* neon_vld4qbv8bf */
    case 2718:  /* neon_vld4qbv4si */
    case 2719:  /* neon_vld4qbv4sf */
      return TYPE_NEON_LOAD4_4REG_Q;

    case 2658:  /* neon_vld3_lanev8hi */
    case 2659:  /* neon_vld3_lanev8hf */
    case 2660:  /* neon_vld3_lanev4si */
    case 2661:  /* neon_vld3_lanev4sf */
    case 2662:  /* neon_vld3_lanev8bf */
      return TYPE_NEON_LOAD3_ONE_LANE_Q;

    case 2652:  /* neon_vld3_lanev8qi */
    case 2653:  /* neon_vld3_lanev4hi */
    case 2654:  /* neon_vld3_lanev4hf */
    case 2655:  /* neon_vld3_lanev4bf */
    case 2656:  /* neon_vld3_lanev2si */
    case 2657:  /* neon_vld3_lanev2sf */
      return TYPE_NEON_LOAD3_ONE_LANE;

    case 2670:  /* neon_vld3_dupv8bf */
      return TYPE_NEON_LOAD3_ALL_LANES_Q;

    case 2640:  /* neon_vld3qav16qi */
    case 2641:  /* neon_vld3qav8hi */
    case 2642:  /* neon_vld3qav8hf */
    case 2643:  /* neon_vld3qav8bf */
    case 2644:  /* neon_vld3qav4si */
    case 2645:  /* neon_vld3qav4sf */
    case 2646:  /* neon_vld3qbv16qi */
    case 2647:  /* neon_vld3qbv8hi */
    case 2648:  /* neon_vld3qbv8hf */
    case 2649:  /* neon_vld3qbv8bf */
    case 2650:  /* neon_vld3qbv4si */
    case 2651:  /* neon_vld3qbv4sf */
      return TYPE_NEON_LOAD3_3REG_Q;

    case 2596:  /* neon_vld2_lanev8hi */
    case 2597:  /* neon_vld2_lanev8hf */
    case 2598:  /* neon_vld2_lanev4si */
    case 2599:  /* neon_vld2_lanev4sf */
    case 2600:  /* neon_vld2_lanev8bf */
      return TYPE_NEON_LOAD2_ONE_LANE_Q;

    case 2590:  /* neon_vld2_lanev8qi */
    case 2591:  /* neon_vld2_lanev4hi */
    case 2592:  /* neon_vld2_lanev4hf */
    case 2593:  /* neon_vld2_lanev4bf */
    case 2594:  /* neon_vld2_lanev2si */
    case 2595:  /* neon_vld2_lanev2sf */
      return TYPE_NEON_LOAD2_ONE_LANE;

    case 2608:  /* neon_vld2_dupv8bf */
      return TYPE_NEON_LOAD2_ALL_LANES_Q;

    case 2584:  /* neon_vld2v16qi */
    case 2585:  /* neon_vld2v8hi */
    case 2586:  /* neon_vld2v8hf */
    case 2587:  /* neon_vld2v8bf */
    case 2588:  /* neon_vld2v4si */
    case 2589:  /* neon_vld2v4sf */
      return TYPE_NEON_LOAD2_2REG_Q;

    case 2530:  /* neon_vld1_lanev16qi */
    case 2531:  /* neon_vld1_lanev8hi */
    case 2532:  /* neon_vld1_lanev8hf */
    case 2533:  /* neon_vld1_lanev8bf */
    case 2534:  /* neon_vld1_lanev4si */
    case 2535:  /* neon_vld1_lanev4sf */
    case 2536:  /* neon_vld1_lanev2di */
      return TYPE_NEON_LOAD1_ONE_LANE_Q;

    case 2523:  /* neon_vld1_lanev8qi */
    case 2524:  /* neon_vld1_lanev4hi */
    case 2525:  /* neon_vld1_lanev4hf */
    case 2526:  /* neon_vld1_lanev4bf */
    case 2527:  /* neon_vld1_lanev2si */
    case 2528:  /* neon_vld1_lanev2sf */
    case 2529:  /* neon_vld1_lanedi */
      return TYPE_NEON_LOAD1_ONE_LANE;

    case 2543:  /* neon_vld1_dupv16qi */
    case 2544:  /* neon_vld1_dupv8hi */
    case 2545:  /* neon_vld1_dupv8hf */
    case 2546:  /* neon_vld1_dupv4si */
    case 2547:  /* neon_vld1_dupv4sf */
    case 2548:  /* neon_vld1_dupv2di */
      return TYPE_NEON_LOAD1_ALL_LANES_Q;

    case 2537:  /* neon_vld1_dupv8qi */
    case 2538:  /* neon_vld1_dupv4hi */
    case 2539:  /* neon_vld1_dupv4hf */
    case 2540:  /* neon_vld1_dupv4bf */
    case 2541:  /* neon_vld1_dupv2si */
    case 2542:  /* neon_vld1_dupv2sf */
      return TYPE_NEON_LOAD1_ALL_LANES;

    case 1111:  /* *movmisalignv16qi_neon_load */
    case 1112:  /* *movmisalignv8hi_neon_load */
    case 1113:  /* *movmisalignv8hf_neon_load */
    case 1114:  /* *movmisalignv8bf_neon_load */
    case 1115:  /* *movmisalignv4si_neon_load */
    case 1116:  /* *movmisalignv4sf_neon_load */
    case 1117:  /* *movmisalignv2di_neon_load */
    case 2510:  /* neon_vld1v16qi */
    case 2512:  /* neon_vld1v8hi */
    case 2514:  /* neon_vld1v4si */
    case 2516:  /* neon_vld1v8hf */
    case 2518:  /* neon_vld1v8bf */
    case 2520:  /* neon_vld1v4sf */
    case 2522:  /* neon_vld1v2di */
    case 2853:  /* *aes_op_protect_misalign_load */
    case 2854:  /* aes_op_protect_neon_vld1v16qi */
      return TYPE_NEON_LOAD1_1REG_Q;

    case 1097:  /* *movmisalignv8qi_neon_load */
    case 1098:  /* *movmisalignv4hi_neon_load */
    case 1099:  /* *movmisalignv4hf_neon_load */
    case 1100:  /* *movmisalignv4bf_neon_load */
    case 1101:  /* *movmisalignv2si_neon_load */
    case 1102:  /* *movmisalignv2sf_neon_load */
    case 1103:  /* *movmisaligndi_neon_load */
    case 2509:  /* neon_vld1v8qi */
    case 2511:  /* neon_vld1v4hi */
    case 2513:  /* neon_vld1v2si */
    case 2515:  /* neon_vld1v4hf */
    case 2517:  /* neon_vld1v4bf */
    case 2519:  /* neon_vld1v2sf */
    case 2521:  /* neon_vld1di */
      return TYPE_NEON_LOAD1_1REG;

    case 2043:  /* neon_vdup_nv16qi */
    case 2044:  /* neon_vdup_nv8hi */
    case 2046:  /* neon_vdup_nv8hf */
    case 2048:  /* neon_vdup_nv8bf */
      return TYPE_NEON_FROM_GP_Q;

    case 2041:  /* neon_vdup_nv8qi */
    case 2042:  /* neon_vdup_nv4hi */
    case 2045:  /* neon_vdup_nv4hf */
    case 2047:  /* neon_vdup_nv4bf */
      return TYPE_NEON_FROM_GP;

    case 2031:  /* neon_vget_lanev16qi_sext_internal */
    case 2032:  /* neon_vget_lanev8hi_sext_internal */
    case 2033:  /* neon_vget_lanev8hf_sext_internal */
    case 2034:  /* neon_vget_lanev4si_sext_internal */
    case 2035:  /* neon_vget_lanev4sf_sext_internal */
    case 2036:  /* neon_vget_lanev16qi_zext_internal */
    case 2037:  /* neon_vget_lanev8hi_zext_internal */
    case 2038:  /* neon_vget_lanev8hf_zext_internal */
    case 2039:  /* neon_vget_lanev4si_zext_internal */
    case 2040:  /* neon_vget_lanev4sf_zext_internal */
      return TYPE_NEON_TO_GP_Q;

    case 2023:  /* neon_vget_lanev8qi_sext_internal */
    case 2024:  /* neon_vget_lanev4hi_sext_internal */
    case 2025:  /* neon_vget_lanev2si_sext_internal */
    case 2026:  /* neon_vget_lanev2sf_sext_internal */
    case 2027:  /* neon_vget_lanev8qi_zext_internal */
    case 2028:  /* neon_vget_lanev4hi_zext_internal */
    case 2029:  /* neon_vget_lanev2si_zext_internal */
    case 2030:  /* neon_vget_lanev2sf_zext_internal */
      return TYPE_NEON_TO_GP;

    case 2204:  /* neon_vqdmlal_lanev2si */
    case 2216:  /* neon_vqdmlsl_lanev2si */
      return TYPE_NEON_SAT_MLA_S_SCALAR_LONG;

    case 2203:  /* neon_vqdmlal_lanev4hi */
    case 2215:  /* neon_vqdmlsl_lanev4hi */
      return TYPE_NEON_SAT_MLA_H_SCALAR_LONG;

    case 1581:  /* neon_vqrdmlahv2si */
    case 1582:  /* neon_vqrdmlshv2si */
    case 1585:  /* neon_vqrdmlahv4si */
    case 1586:  /* neon_vqrdmlshv4si */
    case 1588:  /* neon_vqdmlalv2si */
    case 1590:  /* neon_vqdmlslv2si */
      return TYPE_NEON_SAT_MLA_S_LONG;

    case 1579:  /* neon_vqrdmlahv4hi */
    case 1580:  /* neon_vqrdmlshv4hi */
    case 1583:  /* neon_vqrdmlahv8hi */
    case 1584:  /* neon_vqrdmlshv8hi */
    case 1587:  /* neon_vqdmlalv4hi */
    case 1589:  /* neon_vqdmlslv4hi */
      return TYPE_NEON_SAT_MLA_H_LONG;

    case 2201:  /* neon_vmlals_lanev2si */
    case 2202:  /* neon_vmlalu_lanev2si */
    case 2213:  /* neon_vmlsls_lanev2si */
    case 2214:  /* neon_vmlslu_lanev2si */
      return TYPE_NEON_MLA_S_SCALAR_LONG;

    case 2199:  /* neon_vmlals_lanev4hi */
    case 2200:  /* neon_vmlalu_lanev4hi */
    case 2211:  /* neon_vmlsls_lanev4hi */
    case 2212:  /* neon_vmlslu_lanev4hi */
      return TYPE_NEON_MLA_H_SCALAR_LONG;

    case 2187:  /* neon_vqrdmlah_lanev4si */
    case 2188:  /* neon_vqrdmlsh_lanev4si */
      return TYPE_NEON_MLA_S_SCALAR_Q;

    case 2191:  /* neon_vqrdmlah_lanev2si */
    case 2192:  /* neon_vqrdmlsh_lanev2si */
      return TYPE_NEON_MLA_S_SCALAR;

    case 2185:  /* neon_vqrdmlah_lanev8hi */
    case 2186:  /* neon_vqrdmlsh_lanev8hi */
      return TYPE_NEON_MLA_H_SCALAR_Q;

    case 2189:  /* neon_vqrdmlah_lanev4hi */
    case 2190:  /* neon_vqrdmlsh_lanev4hi */
      return TYPE_NEON_MLA_H_SCALAR;

    case 1555:  /* neon_vmlalsv2si */
    case 1556:  /* neon_vmlaluv2si */
    case 1569:  /* neon_vmlslsv2si */
    case 1570:  /* neon_vmlsluv2si */
      return TYPE_NEON_MLA_S_LONG;

    case 1553:  /* neon_vmlalsv4hi */
    case 1554:  /* neon_vmlaluv4hi */
    case 1567:  /* neon_vmlslsv4hi */
    case 1568:  /* neon_vmlsluv4hi */
      return TYPE_NEON_MLA_H_LONG;

    case 1551:  /* neon_vmlalsv8qi */
    case 1552:  /* neon_vmlaluv8qi */
    case 1565:  /* neon_vmlslsv8qi */
    case 1566:  /* neon_vmlsluv8qi */
      return TYPE_NEON_MLA_B_LONG;

    case 2825:  /* neon_smmlav16qi */
    case 2826:  /* neon_ummlav16qi */
    case 2827:  /* neon_usmmlav16qi */
      return TYPE_NEON_MLA_S_Q;

    case 2176:  /* neon_vqdmull_lanev2si */
      return TYPE_NEON_SAT_MUL_S_SCALAR_LONG;

    case 2175:  /* neon_vqdmull_lanev4hi */
      return TYPE_NEON_SAT_MUL_H_SCALAR_LONG;

    case 2179:  /* neon_vqdmulh_lanev4si */
    case 2180:  /* neon_vqrdmulh_lanev4si */
    case 2183:  /* neon_vqdmulh_lanev2si */
    case 2184:  /* neon_vqrdmulh_lanev2si */
      return TYPE_NEON_SAT_MUL_S_SCALAR_Q;

    case 2177:  /* neon_vqdmulh_lanev8hi */
    case 2178:  /* neon_vqrdmulh_lanev8hi */
    case 2181:  /* neon_vqdmulh_lanev4hi */
    case 2182:  /* neon_vqrdmulh_lanev4hi */
      return TYPE_NEON_SAT_MUL_H_SCALAR_Q;

    case 1601:  /* neon_vqdmullv2si */
      return TYPE_NEON_SAT_MUL_S_LONG;

    case 1600:  /* neon_vqdmullv4hi */
      return TYPE_NEON_SAT_MUL_H_LONG;

    case 1577:  /* neon_vqdmulhv4si */
    case 1578:  /* neon_vqrdmulhv4si */
      return TYPE_NEON_SAT_MUL_S_Q;

    case 1573:  /* neon_vqdmulhv2si */
    case 1574:  /* neon_vqrdmulhv2si */
      return TYPE_NEON_SAT_MUL_S;

    case 1575:  /* neon_vqdmulhv8hi */
    case 1576:  /* neon_vqrdmulhv8hi */
      return TYPE_NEON_SAT_MUL_H_Q;

    case 1571:  /* neon_vqdmulhv4hi */
    case 1572:  /* neon_vqrdmulhv4hi */
      return TYPE_NEON_SAT_MUL_H;

    case 2173:  /* neon_vmulls_lanev2si */
    case 2174:  /* neon_vmullu_lanev2si */
      return TYPE_NEON_MUL_S_SCALAR_LONG;

    case 2171:  /* neon_vmulls_lanev4hi */
    case 2172:  /* neon_vmullu_lanev4hi */
      return TYPE_NEON_MUL_H_SCALAR_LONG;

    case 1597:  /* neon_vmullsv2si */
    case 1598:  /* neon_vmulluv2si */
    case 1599:  /* neon_vmullpv2si */
    case 2785:  /* neon_vec_smult_lo_v4si */
    case 2786:  /* neon_vec_umult_lo_v4si */
    case 2791:  /* neon_vec_smult_hi_v4si */
    case 2792:  /* neon_vec_umult_hi_v4si */
    case 2809:  /* neon_vec_smult_v2si */
    case 2810:  /* neon_vec_umult_v2si */
      return TYPE_NEON_MUL_S_LONG;

    case 1594:  /* neon_vmullsv4hi */
    case 1595:  /* neon_vmulluv4hi */
    case 1596:  /* neon_vmullpv4hi */
    case 2783:  /* neon_vec_smult_lo_v8hi */
    case 2784:  /* neon_vec_umult_lo_v8hi */
    case 2789:  /* neon_vec_smult_hi_v8hi */
    case 2790:  /* neon_vec_umult_hi_v8hi */
    case 2807:  /* neon_vec_smult_v4hi */
    case 2808:  /* neon_vec_umult_v4hi */
      return TYPE_NEON_MUL_H_LONG;

    case 1591:  /* neon_vmullsv8qi */
    case 1592:  /* neon_vmulluv8qi */
    case 1593:  /* neon_vmullpv8qi */
    case 2781:  /* neon_vec_smult_lo_v16qi */
    case 2782:  /* neon_vec_umult_lo_v16qi */
    case 2787:  /* neon_vec_smult_hi_v16qi */
    case 2788:  /* neon_vec_umult_hi_v16qi */
    case 2805:  /* neon_vec_smult_v8qi */
    case 2806:  /* neon_vec_umult_v8qi */
      return TYPE_NEON_MUL_B_LONG;

    case 1517:  /* neon_vmulfv8hf */
      return TYPE_NEON_MUL_S_Q;

    case 1518:  /* neon_vmulfv4hf */
      return TYPE_NEON_MUL_S;

    case 1911:  /* neon_bswapv8hi */
    case 1913:  /* neon_bswapv4si */
    case 1914:  /* neon_bswapv2di */
    case 2232:  /* neon_vrev64v16qi */
    case 2234:  /* neon_vrev64v8hi */
    case 2236:  /* neon_vrev64v4si */
    case 2238:  /* neon_vrev64v8hf */
    case 2240:  /* neon_vrev64v4sf */
    case 2241:  /* neon_vrev64v2di */
    case 2244:  /* neon_vrev32v16qi */
    case 2245:  /* neon_vrev32v8hi */
    case 2247:  /* neon_vrev16v16qi */
      return TYPE_NEON_REV_Q;

    case 1910:  /* neon_bswapv4hi */
    case 1912:  /* neon_bswapv2si */
    case 2231:  /* neon_vrev64v8qi */
    case 2233:  /* neon_vrev64v4hi */
    case 2235:  /* neon_vrev64v2si */
    case 2237:  /* neon_vrev64v4hf */
    case 2239:  /* neon_vrev64v2sf */
    case 2242:  /* neon_vrev32v8qi */
    case 2243:  /* neon_vrev32v4hi */
    case 2246:  /* neon_vrev16v8qi */
      return TYPE_NEON_REV;

    case 2218:  /* neon_vextv16qi */
    case 2220:  /* neon_vextv8hi */
    case 2222:  /* neon_vextv4si */
    case 2224:  /* neon_vextv8hf */
    case 2226:  /* neon_vextv8bf */
    case 2228:  /* neon_vextv4sf */
    case 2230:  /* neon_vextv2di */
      return TYPE_NEON_EXT_Q;

    case 2217:  /* neon_vextv8qi */
    case 2219:  /* neon_vextv4hi */
    case 2221:  /* neon_vextv2si */
    case 2223:  /* neon_vextv4hf */
    case 2225:  /* neon_vextv4bf */
    case 2227:  /* neon_vextv2sf */
    case 2229:  /* neon_vextdi */
      return TYPE_NEON_EXT;

    case 2055:  /* neon_vdup_lanev16qi_internal */
    case 2057:  /* neon_vdup_lanev8hi_internal */
    case 2059:  /* neon_vdup_lanev4si_internal */
    case 2061:  /* neon_vdup_lanev4sf_internal */
    case 2062:  /* neon_vdup_lanev8hf_internal */
    case 2065:  /* neon_vdup_lanev8bf_internal */
      return TYPE_NEON_DUP_Q;

    case 2054:  /* neon_vdup_lanev8qi_internal */
    case 2056:  /* neon_vdup_lanev4hi_internal */
    case 2058:  /* neon_vdup_lanev2si_internal */
    case 2060:  /* neon_vdup_lanev2sf_internal */
    case 2063:  /* neon_vdup_lanev4hf_internal */
    case 2064:  /* neon_vdup_lanev4bf_internal */
      return TYPE_NEON_DUP;

    case 2006:  /* neon_vclzv16qi */
    case 2008:  /* neon_vclzv8hi */
    case 2010:  /* neon_vclzv4si */
    case 2012:  /* popcountv16qi2 */
      return TYPE_NEON_CNT_Q;

    case 2005:  /* neon_vclzv8qi */
    case 2007:  /* neon_vclzv4hi */
    case 2009:  /* neon_vclzv2si */
    case 2011:  /* popcountv8qi2 */
      return TYPE_NEON_CNT;

    case 2000:  /* neon_vclsv16qi */
    case 2002:  /* neon_vclsv8hi */
    case 2004:  /* neon_vclsv4si */
      return TYPE_NEON_CLS_Q;

    case 1999:  /* neon_vclsv8qi */
    case 2001:  /* neon_vclsv4hi */
    case 2003:  /* neon_vclsv2si */
      return TYPE_NEON_CLS;

    case 2249:  /* neon_vbslv16qi_internal */
    case 2251:  /* neon_vbslv8hi_internal */
    case 2253:  /* neon_vbslv4si_internal */
    case 2255:  /* neon_vbslv8hf_internal */
    case 2257:  /* neon_vbslv8bf_internal */
    case 2259:  /* neon_vbslv4sf_internal */
    case 2261:  /* neon_vbslv2di_internal */
      return TYPE_NEON_BSL_Q;

    case 2248:  /* neon_vbslv8qi_internal */
    case 2250:  /* neon_vbslv4hi_internal */
    case 2252:  /* neon_vbslv2si_internal */
    case 2254:  /* neon_vbslv4hf_internal */
    case 2256:  /* neon_vbslv4bf_internal */
    case 2258:  /* neon_vbslv2sf_internal */
    case 2260:  /* neon_vbsldi_internal */
      return TYPE_NEON_BSL;

    case 2471:  /* neon_vtbl4v8qi */
    case 2478:  /* neon_vtbx4v8qi */
      return TYPE_NEON_TBL4;

    case 2470:  /* neon_vtbl3v8qi */
    case 2477:  /* neon_vtbx3v8qi */
      return TYPE_NEON_TBL3;

    case 2469:  /* neon_vtbl2v8qi */
    case 2476:  /* neon_vtbx2v8qi */
      return TYPE_NEON_TBL2;

    case 2468:  /* neon_vtbl1v8qi */
    case 2475:  /* neon_vtbx1v8qi */
      return TYPE_NEON_TBL1;

    case 2490:  /* *neon_vzipv16qi_insn */
    case 2492:  /* *neon_vzipv8hi_insn */
    case 2494:  /* *neon_vzipv4si_insn */
    case 2496:  /* *neon_vzipv4sf_insn */
    case 2497:  /* *neon_vzipv8hf_insn */
    case 2500:  /* *neon_vuzpv16qi_insn */
    case 2502:  /* *neon_vuzpv8hi_insn */
    case 2504:  /* *neon_vuzpv4si_insn */
    case 2506:  /* *neon_vuzpv4sf_insn */
    case 2507:  /* *neon_vuzpv8hf_insn */
      return TYPE_NEON_ZIP_Q;

    case 2489:  /* *neon_vzipv8qi_insn */
    case 2491:  /* *neon_vzipv4hi_insn */
    case 2493:  /* *neon_vzipv2si_insn */
    case 2495:  /* *neon_vzipv2sf_insn */
    case 2498:  /* *neon_vzipv4hf_insn */
    case 2499:  /* *neon_vuzpv8qi_insn */
    case 2501:  /* *neon_vuzpv4hi_insn */
    case 2503:  /* *neon_vuzpv2si_insn */
    case 2505:  /* *neon_vuzpv2sf_insn */
    case 2508:  /* *neon_vuzpv4hf_insn */
      return TYPE_NEON_ZIP;

    case 2067:  /* *neon_vswpv16qi */
    case 2069:  /* *neon_vswpv8hi */
    case 2071:  /* *neon_vswpv4si */
    case 2073:  /* *neon_vswpv8hf */
    case 2075:  /* *neon_vswpv8bf */
    case 2077:  /* *neon_vswpv4sf */
    case 2079:  /* *neon_vswpv2di */
    case 2480:  /* *neon_vtrnv16qi_insn */
    case 2482:  /* *neon_vtrnv8hi_insn */
    case 2484:  /* *neon_vtrnv4si_insn */
    case 2486:  /* *neon_vtrnv4sf_insn */
    case 2487:  /* *neon_vtrnv8hf_insn */
      return TYPE_NEON_PERMUTE_Q;

    case 2066:  /* *neon_vswpv8qi */
    case 2068:  /* *neon_vswpv4hi */
    case 2070:  /* *neon_vswpv2si */
    case 2072:  /* *neon_vswpv4hf */
    case 2074:  /* *neon_vswpv4bf */
    case 2076:  /* *neon_vswpv2sf */
    case 2078:  /* *neon_vswpdi */
    case 2479:  /* *neon_vtrnv8qi_insn */
    case 2481:  /* *neon_vtrnv4hi_insn */
    case 2483:  /* *neon_vtrnv2si_insn */
    case 2485:  /* *neon_vtrnv2sf_insn */
    case 2488:  /* *neon_vtrnv4hf_insn */
      return TYPE_NEON_PERMUTE;

    case 2814:  /* neon_vec_pack_trunc_v8hi */
    case 2815:  /* neon_vec_pack_trunc_v4si */
    case 2816:  /* neon_vec_pack_trunc_v2di */
      return TYPE_NEON_MOVE_NARROW_Q;

    case 1282:  /* one_cmplv16qi2_neon */
    case 1284:  /* one_cmplv8hi2_neon */
    case 1286:  /* one_cmplv4si2_neon */
    case 1288:  /* one_cmplv8hf2_neon */
    case 1290:  /* one_cmplv4sf2_neon */
    case 1291:  /* one_cmplv2di2_neon */
      return TYPE_NEON_MOVE_Q;

    case 1281:  /* one_cmplv8qi2_neon */
    case 1283:  /* one_cmplv4hi2_neon */
    case 1285:  /* one_cmplv2si2_neon */
    case 1287:  /* one_cmplv4hf2_neon */
    case 1289:  /* one_cmplv2sf2_neon */
    case 2799:  /* neon_unpacks_v8qi */
    case 2800:  /* neon_unpacku_v8qi */
    case 2801:  /* neon_unpacks_v4hi */
    case 2802:  /* neon_unpacku_v4hi */
    case 2803:  /* neon_unpacks_v2si */
    case 2804:  /* neon_unpacku_v2si */
      return TYPE_NEON_MOVE;

    case 2148:  /* neon_vqmovnsv8hi */
    case 2149:  /* neon_vqmovnuv8hi */
    case 2150:  /* neon_vqmovnsv4si */
    case 2151:  /* neon_vqmovnuv4si */
    case 2152:  /* neon_vqmovnsv2di */
    case 2153:  /* neon_vqmovnuv2di */
    case 2154:  /* neon_vqmovunv8hi */
    case 2155:  /* neon_vqmovunv4si */
    case 2156:  /* neon_vqmovunv2di */
    case 2364:  /* neon_vqshrns_nv8hi */
    case 2365:  /* neon_vqshrnu_nv8hi */
    case 2366:  /* neon_vqrshrns_nv8hi */
    case 2367:  /* neon_vqrshrnu_nv8hi */
    case 2368:  /* neon_vqshrns_nv4si */
    case 2369:  /* neon_vqshrnu_nv4si */
    case 2370:  /* neon_vqrshrns_nv4si */
    case 2371:  /* neon_vqrshrnu_nv4si */
    case 2372:  /* neon_vqshrns_nv2di */
    case 2373:  /* neon_vqshrnu_nv2di */
    case 2374:  /* neon_vqrshrns_nv2di */
    case 2375:  /* neon_vqrshrnu_nv2di */
    case 2376:  /* neon_vqshrun_nv8hi */
    case 2377:  /* neon_vqrshrun_nv8hi */
    case 2378:  /* neon_vqshrun_nv4si */
    case 2379:  /* neon_vqrshrun_nv4si */
    case 2380:  /* neon_vqshrun_nv2di */
    case 2381:  /* neon_vqrshrun_nv2di */
      return TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q;

    case 2298:  /* neon_vqshlsv16qi */
    case 2299:  /* neon_vqshluv16qi */
    case 2300:  /* neon_vqrshlsv16qi */
    case 2301:  /* neon_vqrshluv16qi */
    case 2306:  /* neon_vqshlsv8hi */
    case 2307:  /* neon_vqshluv8hi */
    case 2308:  /* neon_vqrshlsv8hi */
    case 2309:  /* neon_vqrshluv8hi */
    case 2314:  /* neon_vqshlsv4si */
    case 2315:  /* neon_vqshluv4si */
    case 2316:  /* neon_vqrshlsv4si */
    case 2317:  /* neon_vqrshluv4si */
    case 2322:  /* neon_vqshlsv2di */
    case 2323:  /* neon_vqshluv2di */
    case 2324:  /* neon_vqrshlsv2di */
    case 2325:  /* neon_vqrshluv2di */
    case 2392:  /* neon_vqshl_s_nv16qi */
    case 2393:  /* neon_vqshl_u_nv16qi */
    case 2396:  /* neon_vqshl_s_nv8hi */
    case 2397:  /* neon_vqshl_u_nv8hi */
    case 2400:  /* neon_vqshl_s_nv4si */
    case 2401:  /* neon_vqshl_u_nv4si */
    case 2404:  /* neon_vqshl_s_nv2di */
    case 2405:  /* neon_vqshl_u_nv2di */
    case 2407:  /* neon_vqshlu_nv16qi */
    case 2409:  /* neon_vqshlu_nv8hi */
    case 2411:  /* neon_vqshlu_nv4si */
    case 2413:  /* neon_vqshlu_nv2di */
      return TYPE_NEON_SAT_SHIFT_IMM_Q;

    case 2294:  /* neon_vqshlsv8qi */
    case 2295:  /* neon_vqshluv8qi */
    case 2296:  /* neon_vqrshlsv8qi */
    case 2297:  /* neon_vqrshluv8qi */
    case 2302:  /* neon_vqshlsv4hi */
    case 2303:  /* neon_vqshluv4hi */
    case 2304:  /* neon_vqrshlsv4hi */
    case 2305:  /* neon_vqrshluv4hi */
    case 2310:  /* neon_vqshlsv2si */
    case 2311:  /* neon_vqshluv2si */
    case 2312:  /* neon_vqrshlsv2si */
    case 2313:  /* neon_vqrshluv2si */
    case 2318:  /* neon_vqshlsdi */
    case 2319:  /* neon_vqshludi */
    case 2320:  /* neon_vqrshlsdi */
    case 2321:  /* neon_vqrshludi */
    case 2390:  /* neon_vqshl_s_nv8qi */
    case 2391:  /* neon_vqshl_u_nv8qi */
    case 2394:  /* neon_vqshl_s_nv4hi */
    case 2395:  /* neon_vqshl_u_nv4hi */
    case 2398:  /* neon_vqshl_s_nv2si */
    case 2399:  /* neon_vqshl_u_nv2si */
    case 2402:  /* neon_vqshl_s_ndi */
    case 2403:  /* neon_vqshl_u_ndi */
    case 2406:  /* neon_vqshlu_nv8qi */
    case 2408:  /* neon_vqshlu_nv4hi */
    case 2410:  /* neon_vqshlu_nv2si */
    case 2412:  /* neon_vqshlu_ndi */
      return TYPE_NEON_SAT_SHIFT_IMM;

    case 2424:  /* neon_vsras_nv16qi */
    case 2425:  /* neon_vsrau_nv16qi */
    case 2426:  /* neon_vrsras_nv16qi */
    case 2427:  /* neon_vrsrau_nv16qi */
    case 2432:  /* neon_vsras_nv8hi */
    case 2433:  /* neon_vsrau_nv8hi */
    case 2434:  /* neon_vrsras_nv8hi */
    case 2435:  /* neon_vrsrau_nv8hi */
    case 2440:  /* neon_vsras_nv4si */
    case 2441:  /* neon_vsrau_nv4si */
    case 2442:  /* neon_vrsras_nv4si */
    case 2443:  /* neon_vrsrau_nv4si */
    case 2448:  /* neon_vsras_nv2di */
    case 2449:  /* neon_vsrau_nv2di */
    case 2450:  /* neon_vrsras_nv2di */
    case 2451:  /* neon_vrsrau_nv2di */
      return TYPE_NEON_SHIFT_ACC_Q;

    case 2420:  /* neon_vsras_nv8qi */
    case 2421:  /* neon_vsrau_nv8qi */
    case 2422:  /* neon_vrsras_nv8qi */
    case 2423:  /* neon_vrsrau_nv8qi */
    case 2428:  /* neon_vsras_nv4hi */
    case 2429:  /* neon_vsrau_nv4hi */
    case 2430:  /* neon_vrsras_nv4hi */
    case 2431:  /* neon_vrsrau_nv4hi */
    case 2436:  /* neon_vsras_nv2si */
    case 2437:  /* neon_vsrau_nv2si */
    case 2438:  /* neon_vrsras_nv2si */
    case 2439:  /* neon_vrsrau_nv2si */
    case 2444:  /* neon_vsras_ndi */
    case 2445:  /* neon_vsrau_ndi */
    case 2446:  /* neon_vrsras_ndi */
    case 2447:  /* neon_vrsrau_ndi */
      return TYPE_NEON_SHIFT_ACC;

    case 1367:  /* ashlv16qi3_signed */
    case 1369:  /* ashlv8hi3_signed */
    case 1371:  /* ashlv4si3_signed */
    case 1372:  /* ashlv2di3_signed */
    case 1374:  /* ashlv16qi3_unsigned */
    case 1376:  /* ashlv8hi3_unsigned */
    case 1378:  /* ashlv4si3_unsigned */
    case 1379:  /* ashlv2di3_unsigned */
    case 2453:  /* neon_vsri_nv16qi */
    case 2455:  /* neon_vsri_nv8hi */
    case 2457:  /* neon_vsri_nv4si */
    case 2459:  /* neon_vsri_nv2di */
    case 2461:  /* neon_vsli_nv16qi */
    case 2463:  /* neon_vsli_nv8hi */
    case 2465:  /* neon_vsli_nv4si */
    case 2467:  /* neon_vsli_nv2di */
      return TYPE_NEON_SHIFT_REG_Q;

    case 1366:  /* ashlv8qi3_signed */
    case 1368:  /* ashlv4hi3_signed */
    case 1370:  /* ashlv2si3_signed */
    case 1373:  /* ashlv8qi3_unsigned */
    case 1375:  /* ashlv4hi3_unsigned */
    case 1377:  /* ashlv2si3_unsigned */
    case 2452:  /* neon_vsri_nv8qi */
    case 2454:  /* neon_vsri_nv4hi */
    case 2456:  /* neon_vsri_nv2si */
    case 2458:  /* neon_vsri_ndi */
    case 2460:  /* neon_vsli_nv8qi */
    case 2462:  /* neon_vsli_nv4hi */
    case 2464:  /* neon_vsli_nv2si */
    case 2466:  /* neon_vsli_ndi */
      return TYPE_NEON_SHIFT_REG;

    case 2157:  /* neon_vmovlsv8qi */
    case 2158:  /* neon_vmovluv8qi */
    case 2159:  /* neon_vmovlsv4hi */
    case 2160:  /* neon_vmovluv4hi */
    case 2161:  /* neon_vmovlsv2si */
    case 2162:  /* neon_vmovluv2si */
    case 2414:  /* neon_vshlls_nv8qi */
    case 2415:  /* neon_vshllu_nv8qi */
    case 2416:  /* neon_vshlls_nv4hi */
    case 2417:  /* neon_vshllu_nv4hi */
    case 2418:  /* neon_vshlls_nv2si */
    case 2419:  /* neon_vshllu_nv2si */
    case 2769:  /* neon_vec_unpacks_lo_v16qi */
    case 2770:  /* neon_vec_unpacku_lo_v16qi */
    case 2771:  /* neon_vec_unpacks_lo_v8hi */
    case 2772:  /* neon_vec_unpacku_lo_v8hi */
    case 2773:  /* neon_vec_unpacks_lo_v4si */
    case 2774:  /* neon_vec_unpacku_lo_v4si */
    case 2775:  /* neon_vec_unpacks_hi_v16qi */
    case 2776:  /* neon_vec_unpacku_hi_v16qi */
    case 2777:  /* neon_vec_unpacks_hi_v8hi */
    case 2778:  /* neon_vec_unpacku_hi_v8hi */
    case 2779:  /* neon_vec_unpacks_hi_v4si */
    case 2780:  /* neon_vec_unpacku_hi_v4si */
    case 2793:  /* neon_vec_sshiftl_v8qi */
    case 2794:  /* neon_vec_ushiftl_v8qi */
    case 2795:  /* neon_vec_sshiftl_v4hi */
    case 2796:  /* neon_vec_ushiftl_v4hi */
    case 2797:  /* neon_vec_sshiftl_v2si */
    case 2798:  /* neon_vec_ushiftl_v2si */
      return TYPE_NEON_SHIFT_IMM_LONG;

    case 2145:  /* neon_vmovnv8hi */
    case 2146:  /* neon_vmovnv4si */
    case 2147:  /* neon_vmovnv2di */
    case 2358:  /* neon_vshrn_nv8hi */
    case 2359:  /* neon_vrshrn_nv8hi */
    case 2360:  /* neon_vshrn_nv4si */
    case 2361:  /* neon_vrshrn_nv4si */
    case 2362:  /* neon_vshrn_nv2di */
    case 2363:  /* neon_vrshrn_nv2di */
      return TYPE_NEON_SHIFT_IMM_NARROW_Q;

    case 1355:  /* vashrv16qi3_imm */
    case 1357:  /* vashrv8hi3_imm */
    case 1359:  /* vashrv4si3_imm */
    case 1361:  /* vlshrv16qi3_imm */
    case 1363:  /* vlshrv8hi3_imm */
    case 1365:  /* vlshrv4si3_imm */
    case 2266:  /* neon_vshlsv16qi */
    case 2267:  /* neon_vshluv16qi */
    case 2268:  /* neon_vrshlsv16qi */
    case 2269:  /* neon_vrshluv16qi */
    case 2274:  /* neon_vshlsv8hi */
    case 2275:  /* neon_vshluv8hi */
    case 2276:  /* neon_vrshlsv8hi */
    case 2277:  /* neon_vrshluv8hi */
    case 2282:  /* neon_vshlsv4si */
    case 2283:  /* neon_vshluv4si */
    case 2284:  /* neon_vrshlsv4si */
    case 2285:  /* neon_vrshluv4si */
    case 2290:  /* neon_vshlsv2di */
    case 2291:  /* neon_vshluv2di */
    case 2292:  /* neon_vrshlsv2di */
    case 2293:  /* neon_vrshluv2di */
    case 2330:  /* neon_vshrs_nv16qi */
    case 2331:  /* neon_vshru_nv16qi */
    case 2332:  /* neon_vrshrs_nv16qi */
    case 2333:  /* neon_vrshru_nv16qi */
    case 2338:  /* neon_vshrs_nv8hi */
    case 2339:  /* neon_vshru_nv8hi */
    case 2340:  /* neon_vrshrs_nv8hi */
    case 2341:  /* neon_vrshru_nv8hi */
    case 2346:  /* neon_vshrs_nv4si */
    case 2347:  /* neon_vshru_nv4si */
    case 2348:  /* neon_vrshrs_nv4si */
    case 2349:  /* neon_vrshru_nv4si */
    case 2354:  /* neon_vshrs_nv2di */
    case 2355:  /* neon_vshru_nv2di */
    case 2356:  /* neon_vrshrs_nv2di */
    case 2357:  /* neon_vrshru_nv2di */
    case 2383:  /* neon_vshl_nv16qi */
    case 2385:  /* neon_vshl_nv8hi */
    case 2387:  /* neon_vshl_nv4si */
    case 2389:  /* neon_vshl_nv2di */
    case 2838:  /* neon_vbfcvtv4bf */
    case 2839:  /* neon_vbfcvtv8bf */
    case 2840:  /* neon_vbfcvt_highv8bf */
      return TYPE_NEON_SHIFT_IMM_Q;

    case 1354:  /* vashrv8qi3_imm */
    case 1356:  /* vashrv4hi3_imm */
    case 1358:  /* vashrv2si3_imm */
    case 1360:  /* vlshrv8qi3_imm */
    case 1362:  /* vlshrv4hi3_imm */
    case 1364:  /* vlshrv2si3_imm */
    case 2262:  /* neon_vshlsv8qi */
    case 2263:  /* neon_vshluv8qi */
    case 2264:  /* neon_vrshlsv8qi */
    case 2265:  /* neon_vrshluv8qi */
    case 2270:  /* neon_vshlsv4hi */
    case 2271:  /* neon_vshluv4hi */
    case 2272:  /* neon_vrshlsv4hi */
    case 2273:  /* neon_vrshluv4hi */
    case 2278:  /* neon_vshlsv2si */
    case 2279:  /* neon_vshluv2si */
    case 2280:  /* neon_vrshlsv2si */
    case 2281:  /* neon_vrshluv2si */
    case 2286:  /* neon_vshlsdi */
    case 2287:  /* neon_vshludi */
    case 2288:  /* neon_vrshlsdi */
    case 2289:  /* neon_vrshludi */
    case 2326:  /* neon_vshrs_nv8qi */
    case 2327:  /* neon_vshru_nv8qi */
    case 2328:  /* neon_vrshrs_nv8qi */
    case 2329:  /* neon_vrshru_nv8qi */
    case 2334:  /* neon_vshrs_nv4hi */
    case 2335:  /* neon_vshru_nv4hi */
    case 2336:  /* neon_vrshrs_nv4hi */
    case 2337:  /* neon_vrshru_nv4hi */
    case 2342:  /* neon_vshrs_nv2si */
    case 2343:  /* neon_vshru_nv2si */
    case 2344:  /* neon_vrshrs_nv2si */
    case 2345:  /* neon_vrshru_nv2si */
    case 2350:  /* neon_vshrs_ndi */
    case 2351:  /* neon_vshru_ndi */
    case 2352:  /* neon_vrshrs_ndi */
    case 2353:  /* neon_vrshru_ndi */
    case 2382:  /* neon_vshl_nv8qi */
    case 2384:  /* neon_vshl_nv4hi */
    case 2386:  /* neon_vshl_nv2si */
    case 2388:  /* neon_vshl_ndi */
      return TYPE_NEON_SHIFT_IMM;

    case 1765:  /* neon_vtst_combinev16qi */
    case 1767:  /* neon_vtst_combinev8hi */
    case 1769:  /* neon_vtst_combinev4si */
      return TYPE_NEON_TST_Q;

    case 1764:  /* neon_vtst_combinev8qi */
    case 1766:  /* neon_vtst_combinev4hi */
    case 1768:  /* neon_vtst_combinev2si */
      return TYPE_NEON_TST;

    case 1227:  /* iorv16qi3_neon */
    case 1229:  /* iorv8hi3_neon */
    case 1231:  /* iorv4si3_neon */
    case 1233:  /* iorv8hf3_neon */
    case 1235:  /* iorv4sf3_neon */
    case 1236:  /* iorv2di3_neon */
    case 1238:  /* andv16qi3_neon */
    case 1240:  /* andv8hi3_neon */
    case 1242:  /* andv4si3_neon */
    case 1244:  /* andv8hf3_neon */
    case 1246:  /* andv4sf3_neon */
    case 1247:  /* andv2di3_neon */
    case 1249:  /* ornv16qi3_neon */
    case 1251:  /* ornv8hi3_neon */
    case 1253:  /* ornv4si3_neon */
    case 1255:  /* ornv8hf3_neon */
    case 1257:  /* ornv4sf3_neon */
    case 1258:  /* ornv2di3_neon */
    case 1260:  /* bicv16qi3_neon */
    case 1262:  /* bicv8hi3_neon */
    case 1264:  /* bicv4si3_neon */
    case 1266:  /* bicv8hf3_neon */
    case 1268:  /* bicv4sf3_neon */
    case 1269:  /* bicv2di3_neon */
    case 1271:  /* xorv16qi3_neon */
    case 1273:  /* xorv8hi3_neon */
    case 1275:  /* xorv4si3_neon */
    case 1277:  /* xorv8hf3_neon */
    case 1279:  /* xorv4sf3_neon */
    case 1280:  /* xorv2di3_neon */
      return TYPE_NEON_LOGIC_Q;

    case 1226:  /* iorv8qi3_neon */
    case 1228:  /* iorv4hi3_neon */
    case 1230:  /* iorv2si3_neon */
    case 1232:  /* iorv4hf3_neon */
    case 1234:  /* iorv2sf3_neon */
    case 1237:  /* andv8qi3_neon */
    case 1239:  /* andv4hi3_neon */
    case 1241:  /* andv2si3_neon */
    case 1243:  /* andv4hf3_neon */
    case 1245:  /* andv2sf3_neon */
    case 1248:  /* ornv8qi3_neon */
    case 1250:  /* ornv4hi3_neon */
    case 1252:  /* ornv2si3_neon */
    case 1254:  /* ornv4hf3_neon */
    case 1256:  /* ornv2sf3_neon */
    case 1259:  /* bicv8qi3_neon */
    case 1261:  /* bicv4hi3_neon */
    case 1263:  /* bicv2si3_neon */
    case 1265:  /* bicv4hf3_neon */
    case 1267:  /* bicv2sf3_neon */
    case 1270:  /* xorv8qi3_neon */
    case 1272:  /* xorv4hi3_neon */
    case 1274:  /* xorv2si3_neon */
    case 1276:  /* xorv4hf3_neon */
    case 1278:  /* xorv2sf3_neon */
      return TYPE_NEON_LOGIC;

    case 1400:  /* quad_halves_sminv4si */
    case 1401:  /* quad_halves_smaxv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1403:  /* quad_halves_umaxv4si */
    case 1408:  /* quad_halves_sminv8hi */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1415:  /* quad_halves_uminv16qi */
    case 1416:  /* quad_halves_umaxv16qi */
      return TYPE_NEON_REDUC_MINMAX_Q;

    case 1431:  /* neon_vpuminv8qi */
    case 1432:  /* neon_vpuminv4hi */
    case 1433:  /* neon_vpuminv2si */
    case 1434:  /* neon_vpumaxv8qi */
    case 1435:  /* neon_vpumaxv4hi */
    case 1436:  /* neon_vpumaxv2si */
    case 1842:  /* neon_vpmaxfv4hf */
    case 1843:  /* neon_vpminfv4hf */
    case 1880:  /* neon_vpmaxsv8qi */
    case 1881:  /* neon_vpmaxuv8qi */
    case 1882:  /* neon_vpminsv8qi */
    case 1883:  /* neon_vpminuv8qi */
    case 1884:  /* neon_vpmaxsv4hi */
    case 1885:  /* neon_vpmaxuv4hi */
    case 1886:  /* neon_vpminsv4hi */
    case 1887:  /* neon_vpminuv4hi */
    case 1888:  /* neon_vpmaxsv2si */
    case 1889:  /* neon_vpmaxuv2si */
    case 1890:  /* neon_vpminsv2si */
    case 1891:  /* neon_vpminuv2si */
      return TYPE_NEON_REDUC_MINMAX;

    case 1868:  /* neon_vpadalsv8qi */
    case 1869:  /* neon_vpadaluv8qi */
    case 1870:  /* neon_vpadalsv16qi */
    case 1871:  /* neon_vpadaluv16qi */
    case 1872:  /* neon_vpadalsv4hi */
    case 1873:  /* neon_vpadaluv4hi */
    case 1874:  /* neon_vpadalsv8hi */
    case 1875:  /* neon_vpadaluv8hi */
    case 1876:  /* neon_vpadalsv2si */
    case 1877:  /* neon_vpadaluv2si */
    case 1878:  /* neon_vpadalsv4si */
    case 1879:  /* neon_vpadaluv4si */
      return TYPE_NEON_REDUC_ADD_ACC;

    case 1856:  /* neon_vpaddlsv8qi */
    case 1857:  /* neon_vpaddluv8qi */
    case 1858:  /* neon_vpaddlsv16qi */
    case 1859:  /* neon_vpaddluv16qi */
    case 1860:  /* neon_vpaddlsv4hi */
    case 1861:  /* neon_vpaddluv4hi */
    case 1862:  /* neon_vpaddlsv8hi */
    case 1863:  /* neon_vpaddluv8hi */
    case 1864:  /* neon_vpaddlsv2si */
    case 1865:  /* neon_vpaddluv2si */
    case 1866:  /* neon_vpaddlsv4si */
    case 1867:  /* neon_vpaddluv4si */
      return TYPE_NEON_REDUC_ADD_LONG;

    case 1399:  /* quad_halves_plusv4si */
    case 1407:  /* quad_halves_plusv8hi */
    case 1412:  /* quad_halves_plusv16qi */
      return TYPE_NEON_REDUC_ADD_Q;

    case 1422:  /* neon_vpaddv4hf */
      return TYPE_NEON_REDUC_ADD;

    case 1794:  /* neon_vabasv16qi */
    case 1795:  /* neon_vabauv16qi */
    case 1798:  /* neon_vabasv8hi */
    case 1799:  /* neon_vabauv8hi */
    case 1802:  /* neon_vabasv4si */
    case 1803:  /* neon_vabauv4si */
      return TYPE_NEON_ARITH_ACC_Q;

    case 1792:  /* neon_vabasv8qi */
    case 1793:  /* neon_vabauv8qi */
    case 1796:  /* neon_vabasv4hi */
    case 1797:  /* neon_vabauv4hi */
    case 1800:  /* neon_vabasv2si */
    case 1801:  /* neon_vabauv2si */
    case 1804:  /* neon_vabalsv8qi */
    case 1805:  /* neon_vabaluv8qi */
    case 1806:  /* neon_vabalsv4hi */
    case 1807:  /* neon_vabaluv4hi */
    case 1808:  /* neon_vabalsv2si */
    case 1809:  /* neon_vabaluv2si */
      return TYPE_NEON_ARITH_ACC;

    case 1722:  /* neon_vcgtuv16qi */
    case 1723:  /* neon_vcgeuv16qi */
    case 1726:  /* neon_vcgtuv8hi */
    case 1727:  /* neon_vcgeuv8hi */
    case 1730:  /* neon_vcgtuv4si */
    case 1731:  /* neon_vcgeuv4si */
      return TYPE_NEON_COMPARE_Q;

    case 1720:  /* neon_vcgtuv8qi */
    case 1721:  /* neon_vcgeuv8qi */
    case 1724:  /* neon_vcgtuv4hi */
    case 1725:  /* neon_vcgeuv4hi */
    case 1728:  /* neon_vcgtuv2si */
    case 1729:  /* neon_vcgeuv2si */
      return TYPE_NEON_COMPARE;

    case 1327:  /* *uminv16qi3_neon */
    case 1329:  /* *uminv8hi3_neon */
    case 1331:  /* *uminv4si3_neon */
    case 1333:  /* *umaxv16qi3_neon */
    case 1335:  /* *umaxv8hi3_neon */
    case 1337:  /* *umaxv4si3_neon */
    case 1814:  /* neon_vmaxsv16qi */
    case 1815:  /* neon_vmaxuv16qi */
    case 1816:  /* neon_vminsv16qi */
    case 1817:  /* neon_vminuv16qi */
    case 1822:  /* neon_vmaxsv8hi */
    case 1823:  /* neon_vmaxuv8hi */
    case 1824:  /* neon_vminsv8hi */
    case 1825:  /* neon_vminuv8hi */
    case 1830:  /* neon_vmaxsv4si */
    case 1831:  /* neon_vmaxuv4si */
    case 1832:  /* neon_vminsv4si */
    case 1833:  /* neon_vminuv4si */
      return TYPE_NEON_MINMAX_Q;

    case 1326:  /* *uminv8qi3_neon */
    case 1328:  /* *uminv4hi3_neon */
    case 1330:  /* *uminv2si3_neon */
    case 1332:  /* *umaxv8qi3_neon */
    case 1334:  /* *umaxv4hi3_neon */
    case 1336:  /* *umaxv2si3_neon */
    case 1810:  /* neon_vmaxsv8qi */
    case 1811:  /* neon_vmaxuv8qi */
    case 1812:  /* neon_vminsv8qi */
    case 1813:  /* neon_vminuv8qi */
    case 1818:  /* neon_vmaxsv4hi */
    case 1819:  /* neon_vmaxuv4hi */
    case 1820:  /* neon_vminsv4hi */
    case 1821:  /* neon_vminuv4hi */
    case 1826:  /* neon_vmaxsv2si */
    case 1827:  /* neon_vmaxuv2si */
    case 1828:  /* neon_vminsv2si */
    case 1829:  /* neon_vminuv2si */
      return TYPE_NEON_MINMAX;

    case 1786:  /* neon_vabdlsv8qi */
    case 1787:  /* neon_vabdluv8qi */
    case 1788:  /* neon_vabdlsv4hi */
    case 1789:  /* neon_vabdluv4hi */
    case 1790:  /* neon_vabdlsv2si */
    case 1791:  /* neon_vabdluv2si */
      return TYPE_NEON_ABD_LONG;

    case 1772:  /* neon_vabdsv16qi */
    case 1773:  /* neon_vabduv16qi */
    case 1776:  /* neon_vabdsv8hi */
    case 1777:  /* neon_vabduv8hi */
    case 1780:  /* neon_vabdsv4si */
    case 1781:  /* neon_vabduv4si */
    case 1782:  /* neon_vabdv8hf */
      return TYPE_NEON_ABD_Q;

    case 1770:  /* neon_vabdsv8qi */
    case 1771:  /* neon_vabduv8qi */
    case 1774:  /* neon_vabdsv4hi */
    case 1775:  /* neon_vabduv4hi */
    case 1778:  /* neon_vabdsv2si */
    case 1779:  /* neon_vabduv2si */
    case 1783:  /* neon_vabdv4hf */
      return TYPE_NEON_ABD;

    case 1905:  /* neon_vqabsv16qi */
    case 1907:  /* neon_vqabsv8hi */
    case 1909:  /* neon_vqabsv4si */
      return TYPE_NEON_QABS_Q;

    case 1904:  /* neon_vqabsv8qi */
    case 1906:  /* neon_vqabsv4hi */
    case 1908:  /* neon_vqabsv2si */
      return TYPE_NEON_QABS;

    case 1994:  /* neon_vqnegv16qi */
    case 1996:  /* neon_vqnegv8hi */
    case 1998:  /* neon_vqnegv4si */
      return TYPE_NEON_QNEG_Q;

    case 1993:  /* neon_vqnegv8qi */
    case 1995:  /* neon_vqnegv4hi */
    case 1997:  /* neon_vqnegv2si */
      return TYPE_NEON_QNEG;

    case 1973:  /* sdot_prodv16qi */
    case 1974:  /* udot_prodv16qi */
    case 1976:  /* neon_usdotv16qi */
    case 1979:  /* neon_sdot_lanev16qi */
    case 1980:  /* neon_udot_lanev16qi */
    case 1983:  /* neon_sdot_laneqv16qi */
    case 1984:  /* neon_udot_laneqv16qi */
    case 1987:  /* neon_usdot_lanev16qi */
    case 1988:  /* neon_sudot_lanev16qi */
    case 1991:  /* neon_usdot_laneqv16qi */
    case 1992:  /* neon_sudot_laneqv16qi */
    case 2829:  /* neon_vbfdotv4sf */
    case 2831:  /* neon_vbfdot_lanev4bfv4sf */
    case 2833:  /* neon_vbfdot_lanev8bfv4sf */
      return TYPE_NEON_DOT_Q;

    case 1971:  /* sdot_prodv8qi */
    case 1972:  /* udot_prodv8qi */
    case 1975:  /* neon_usdotv8qi */
    case 1977:  /* neon_sdot_lanev8qi */
    case 1978:  /* neon_udot_lanev8qi */
    case 1981:  /* neon_sdot_laneqv8qi */
    case 1982:  /* neon_udot_laneqv8qi */
    case 1985:  /* neon_usdot_lanev8qi */
    case 1986:  /* neon_sudot_lanev8qi */
    case 1989:  /* neon_usdot_laneqv8qi */
    case 1990:  /* neon_sudot_laneqv8qi */
    case 2828:  /* neon_vbfdotv2sf */
    case 2830:  /* neon_vbfdot_lanev4bfv2sf */
    case 2832:  /* neon_vbfdot_lanev8bfv2sf */
      return TYPE_NEON_DOT;

    case 1308:  /* neon_absv8hf2 */
    case 1309:  /* neon_negv8hf2 */
      return TYPE_NEON_ABS_Q;

    case 1310:  /* neon_absv4hf2 */
    case 1311:  /* neon_negv4hf2 */
      return TYPE_NEON_ABS;

    case 1923:  /* neon_vcmla0v4hf */
    case 1924:  /* neon_vcmla90v4hf */
    case 1925:  /* neon_vcmla180v4hf */
    case 1926:  /* neon_vcmla270v4hf */
    case 1927:  /* neon_vcmla0v8hf */
    case 1928:  /* neon_vcmla90v8hf */
    case 1929:  /* neon_vcmla180v8hf */
    case 1930:  /* neon_vcmla270v8hf */
    case 1931:  /* neon_vcmla0v2sf */
    case 1932:  /* neon_vcmla90v2sf */
    case 1933:  /* neon_vcmla180v2sf */
    case 1934:  /* neon_vcmla270v2sf */
    case 1935:  /* neon_vcmla0v4sf */
    case 1936:  /* neon_vcmla90v4sf */
    case 1937:  /* neon_vcmla180v4sf */
    case 1938:  /* neon_vcmla270v4sf */
    case 1939:  /* neon_vcmla_lane0v4hf */
    case 1940:  /* neon_vcmla_lane90v4hf */
    case 1941:  /* neon_vcmla_lane180v4hf */
    case 1942:  /* neon_vcmla_lane270v4hf */
    case 1943:  /* neon_vcmla_lane0v8hf */
    case 1944:  /* neon_vcmla_lane90v8hf */
    case 1945:  /* neon_vcmla_lane180v8hf */
    case 1946:  /* neon_vcmla_lane270v8hf */
    case 1947:  /* neon_vcmla_lane0v2sf */
    case 1948:  /* neon_vcmla_lane90v2sf */
    case 1949:  /* neon_vcmla_lane180v2sf */
    case 1950:  /* neon_vcmla_lane270v2sf */
    case 1951:  /* neon_vcmla_lane0v4sf */
    case 1952:  /* neon_vcmla_lane90v4sf */
    case 1953:  /* neon_vcmla_lane180v4sf */
    case 1954:  /* neon_vcmla_lane270v4sf */
    case 1955:  /* neon_vcmla_laneq0v2sf */
    case 1956:  /* neon_vcmla_laneq90v2sf */
    case 1957:  /* neon_vcmla_laneq180v2sf */
    case 1958:  /* neon_vcmla_laneq270v2sf */
    case 1959:  /* neon_vcmla_laneq0v4hf */
    case 1960:  /* neon_vcmla_laneq90v4hf */
    case 1961:  /* neon_vcmla_laneq180v4hf */
    case 1962:  /* neon_vcmla_laneq270v4hf */
    case 1963:  /* neon_vcmlaq_lane0v8hf */
    case 1964:  /* neon_vcmlaq_lane90v8hf */
    case 1965:  /* neon_vcmlaq_lane180v8hf */
    case 1966:  /* neon_vcmlaq_lane270v8hf */
    case 1967:  /* neon_vcmlaq_lane0v4sf */
    case 1968:  /* neon_vcmlaq_lane90v4sf */
    case 1969:  /* neon_vcmlaq_lane180v4sf */
    case 1970:  /* neon_vcmlaq_lane270v4sf */
      return TYPE_NEON_FCMLA;

    case 1915:  /* neon_vcadd90v4hf */
    case 1916:  /* neon_vcadd270v4hf */
    case 1917:  /* neon_vcadd90v8hf */
    case 1918:  /* neon_vcadd270v8hf */
    case 1919:  /* neon_vcadd90v2sf */
    case 1920:  /* neon_vcadd270v2sf */
    case 1921:  /* neon_vcadd90v4sf */
    case 1922:  /* neon_vcadd270v4sf */
      return TYPE_NEON_FCADD;

    case 1644:  /* neon_vsubhnv8hi */
    case 1645:  /* neon_vrsubhnv8hi */
    case 1646:  /* neon_vsubhnv4si */
    case 1647:  /* neon_vrsubhnv4si */
    case 1648:  /* neon_vsubhnv2di */
    case 1649:  /* neon_vrsubhnv2di */
      return TYPE_NEON_SUB_HALVE_NARROW_Q;

    case 1634:  /* neon_vhsubsv16qi */
    case 1635:  /* neon_vhsubuv16qi */
    case 1638:  /* neon_vhsubsv8hi */
    case 1639:  /* neon_vhsubuv8hi */
    case 1642:  /* neon_vhsubsv4si */
    case 1643:  /* neon_vhsubuv4si */
      return TYPE_NEON_SUB_HALVE_Q;

    case 1632:  /* neon_vhsubsv8qi */
    case 1633:  /* neon_vhsubuv8qi */
    case 1636:  /* neon_vhsubsv4hi */
    case 1637:  /* neon_vhsubuv4hi */
    case 1640:  /* neon_vhsubsv2si */
    case 1641:  /* neon_vhsubuv2si */
      return TYPE_NEON_SUB_HALVE;

    case 1618:  /* neon_vqsubsv16qi */
    case 1619:  /* neon_vqsubuv16qi */
    case 1622:  /* neon_vqsubsv8hi */
    case 1623:  /* neon_vqsubuv8hi */
    case 1626:  /* neon_vqsubsv4si */
    case 1627:  /* neon_vqsubuv4si */
    case 1630:  /* neon_vqsubsv2di */
    case 1631:  /* neon_vqsubuv2di */
      return TYPE_NEON_QSUB_Q;

    case 1445:  /* *ss_subv8qi_neon */
    case 1446:  /* *ss_subv4hi_neon */
    case 1447:  /* *ss_subv2si_neon */
    case 1448:  /* *ss_subv2sf_neon */
    case 1449:  /* *us_subv8qi_neon */
    case 1450:  /* *us_subv4hi_neon */
    case 1451:  /* *us_subv2si_neon */
    case 1452:  /* *us_subv2sf_neon */
    case 1616:  /* neon_vqsubsv8qi */
    case 1617:  /* neon_vqsubuv8qi */
    case 1620:  /* neon_vqsubsv4hi */
    case 1621:  /* neon_vqsubuv4hi */
    case 1624:  /* neon_vqsubsv2si */
    case 1625:  /* neon_vqsubuv2si */
    case 1628:  /* neon_vqsubsdi */
    case 1629:  /* neon_vqsubudi */
      return TYPE_NEON_QSUB;

    case 1604:  /* neon_vsublsv8qi */
    case 1605:  /* neon_vsubluv8qi */
    case 1606:  /* neon_vsublsv4hi */
    case 1607:  /* neon_vsubluv4hi */
    case 1608:  /* neon_vsublsv2si */
    case 1609:  /* neon_vsubluv2si */
      return TYPE_NEON_SUB_LONG;

    case 1610:  /* neon_vsubwsv8qi */
    case 1611:  /* neon_vsubwuv8qi */
    case 1612:  /* neon_vsubwsv4hi */
    case 1613:  /* neon_vsubwuv4hi */
    case 1614:  /* neon_vsubwsv2si */
    case 1615:  /* neon_vsubwuv2si */
      return TYPE_NEON_SUB_WIDEN;

    case 1507:  /* neon_vaddhnv8hi */
    case 1508:  /* neon_vraddhnv8hi */
    case 1509:  /* neon_vaddhnv4si */
    case 1510:  /* neon_vraddhnv4si */
    case 1511:  /* neon_vaddhnv2di */
    case 1512:  /* neon_vraddhnv2di */
      return TYPE_NEON_ADD_HALVE_NARROW_Q;

    case 1467:  /* neon_vrhaddsv8qi */
    case 1468:  /* neon_vrhadduv8qi */
    case 1469:  /* neon_vhaddsv8qi */
    case 1470:  /* neon_vhadduv8qi */
    case 1471:  /* neon_vrhaddsv16qi */
    case 1472:  /* neon_vrhadduv16qi */
    case 1473:  /* neon_vhaddsv16qi */
    case 1474:  /* neon_vhadduv16qi */
    case 1475:  /* neon_vrhaddsv4hi */
    case 1476:  /* neon_vrhadduv4hi */
    case 1477:  /* neon_vhaddsv4hi */
    case 1478:  /* neon_vhadduv4hi */
    case 1479:  /* neon_vrhaddsv8hi */
    case 1480:  /* neon_vrhadduv8hi */
    case 1481:  /* neon_vhaddsv8hi */
    case 1482:  /* neon_vhadduv8hi */
    case 1483:  /* neon_vrhaddsv2si */
    case 1484:  /* neon_vrhadduv2si */
    case 1485:  /* neon_vhaddsv2si */
    case 1486:  /* neon_vhadduv2si */
    case 1487:  /* neon_vrhaddsv4si */
    case 1488:  /* neon_vrhadduv4si */
    case 1489:  /* neon_vhaddsv4si */
    case 1490:  /* neon_vhadduv4si */
      return TYPE_NEON_ADD_HALVE_Q;

    case 1493:  /* neon_vqaddsv16qi */
    case 1494:  /* neon_vqadduv16qi */
    case 1497:  /* neon_vqaddsv8hi */
    case 1498:  /* neon_vqadduv8hi */
    case 1501:  /* neon_vqaddsv4si */
    case 1502:  /* neon_vqadduv4si */
    case 1505:  /* neon_vqaddsv2di */
    case 1506:  /* neon_vqadduv2di */
      return TYPE_NEON_QADD_Q;

    case 1437:  /* *ss_addv8qi_neon */
    case 1438:  /* *ss_addv4hi_neon */
    case 1439:  /* *ss_addv2si_neon */
    case 1440:  /* *ss_addv2sf_neon */
    case 1441:  /* *us_addv8qi_neon */
    case 1442:  /* *us_addv4hi_neon */
    case 1443:  /* *us_addv2si_neon */
    case 1444:  /* *us_addv2sf_neon */
    case 1491:  /* neon_vqaddsv8qi */
    case 1492:  /* neon_vqadduv8qi */
    case 1495:  /* neon_vqaddsv4hi */
    case 1496:  /* neon_vqadduv4hi */
    case 1499:  /* neon_vqaddsv2si */
    case 1500:  /* neon_vqadduv2si */
    case 1503:  /* neon_vqaddsdi */
    case 1504:  /* neon_vqaddudi */
      return TYPE_NEON_QADD;

    case 1455:  /* neon_vaddlsv8qi */
    case 1456:  /* neon_vaddluv8qi */
    case 1457:  /* neon_vaddlsv4hi */
    case 1458:  /* neon_vaddluv4hi */
    case 1459:  /* neon_vaddlsv2si */
    case 1460:  /* neon_vaddluv2si */
      return TYPE_NEON_ADD_LONG;

    case 1381:  /* vec_sel_widen_ssum_lov16qiv8qi3 */
    case 1382:  /* vec_sel_widen_ssum_lov8hiv4hi3 */
    case 1383:  /* vec_sel_widen_ssum_lov4siv2si3 */
    case 1384:  /* vec_sel_widen_ssum_hiv16qiv8qi3 */
    case 1385:  /* vec_sel_widen_ssum_hiv8hiv4hi3 */
    case 1386:  /* vec_sel_widen_ssum_hiv4siv2si3 */
    case 1387:  /* widen_ssumv8qi3 */
    case 1388:  /* widen_ssumv4hi3 */
    case 1389:  /* widen_ssumv2si3 */
    case 1390:  /* vec_sel_widen_usum_lov16qiv8qi3 */
    case 1391:  /* vec_sel_widen_usum_lov8hiv4hi3 */
    case 1392:  /* vec_sel_widen_usum_lov4siv2si3 */
    case 1393:  /* vec_sel_widen_usum_hiv16qiv8qi3 */
    case 1394:  /* vec_sel_widen_usum_hiv8hiv4hi3 */
    case 1395:  /* vec_sel_widen_usum_hiv4siv2si3 */
    case 1396:  /* widen_usumv8qi3 */
    case 1397:  /* widen_usumv4hi3 */
    case 1398:  /* widen_usumv2si3 */
    case 1461:  /* neon_vaddwsv8qi */
    case 1462:  /* neon_vaddwuv8qi */
    case 1463:  /* neon_vaddwsv4hi */
    case 1464:  /* neon_vaddwuv4hi */
    case 1465:  /* neon_vaddwsv2si */
    case 1466:  /* neon_vaddwuv2si */
      return TYPE_NEON_ADD_WIDEN;

    case 1417:  /* arm_reduc_plus_internal_v2di */
      return TYPE_NEON_ADD_Q;

    case 527:  /* iwmmxt_xordi3 */
    case 542:  /* *xorv2si3_iwmmxt */
    case 543:  /* *xorv4hi3_iwmmxt */
    case 544:  /* *xorv8qi3_iwmmxt */
    case 570:  /* iwmmxt_clrdi */
    case 571:  /* iwmmxt_clrv8qi */
    case 572:  /* iwmmxt_clrv4hi */
    case 573:  /* iwmmxt_clrv2si */
    case 6620:  /* *p iwmmxt_xordi3 */
    case 6632:  /* *p *xorv2si3_iwmmxt */
    case 6633:  /* *p *xorv4hi3_iwmmxt */
    case 6634:  /* *p *xorv8qi3_iwmmxt */
    case 6660:  /* *p iwmmxt_clrdi */
    case 6661:  /* *p iwmmxt_clrv8qi */
    case 6662:  /* *p iwmmxt_clrv4hi */
    case 6663:  /* *p iwmmxt_clrv2si */
      return TYPE_WMMX_WXOR;

    case 617:  /* iwmmxt_wunpckilb */
    case 618:  /* iwmmxt_wunpckilh */
    case 619:  /* iwmmxt_wunpckilw */
    case 6707:  /* *p iwmmxt_wunpckilb */
    case 6708:  /* *p iwmmxt_wunpckilh */
    case 6709:  /* *p iwmmxt_wunpckilw */
      return TYPE_WMMX_WUNPCKIL;

    case 614:  /* iwmmxt_wunpckihb */
    case 615:  /* iwmmxt_wunpckihh */
    case 616:  /* iwmmxt_wunpckihw */
    case 6704:  /* *p iwmmxt_wunpckihb */
    case 6705:  /* *p iwmmxt_wunpckihh */
    case 6706:  /* *p iwmmxt_wunpckihw */
      return TYPE_WMMX_WUNPCKIH;

    case 626:  /* iwmmxt_wunpckelub */
    case 627:  /* iwmmxt_wunpckeluh */
    case 628:  /* iwmmxt_wunpckeluw */
    case 629:  /* iwmmxt_wunpckelsb */
    case 630:  /* iwmmxt_wunpckelsh */
    case 631:  /* iwmmxt_wunpckelsw */
    case 6716:  /* *p iwmmxt_wunpckelub */
    case 6717:  /* *p iwmmxt_wunpckeluh */
    case 6718:  /* *p iwmmxt_wunpckeluw */
    case 6719:  /* *p iwmmxt_wunpckelsb */
    case 6720:  /* *p iwmmxt_wunpckelsh */
    case 6721:  /* *p iwmmxt_wunpckelsw */
      return TYPE_WMMX_WUNPCKEL;

    case 620:  /* iwmmxt_wunpckehub */
    case 621:  /* iwmmxt_wunpckehuh */
    case 622:  /* iwmmxt_wunpckehuw */
    case 623:  /* iwmmxt_wunpckehsb */
    case 624:  /* iwmmxt_wunpckehsh */
    case 625:  /* iwmmxt_wunpckehsw */
    case 6710:  /* *p iwmmxt_wunpckehub */
    case 6711:  /* *p iwmmxt_wunpckehuh */
    case 6712:  /* *p iwmmxt_wunpckehuw */
    case 6713:  /* *p iwmmxt_wunpckehsb */
    case 6714:  /* *p iwmmxt_wunpckehsh */
    case 6715:  /* *p iwmmxt_wunpckehsw */
      return TYPE_WMMX_WUNPCKEH;

    case 687:  /* iwmmxt_wsubaddhx */
    case 6777:  /* *p iwmmxt_wsubaddhx */
      return TYPE_WMMX_WSUBADDHX;

    case 554:  /* *subv2si3_iwmmxt */
    case 555:  /* *subv4hi3_iwmmxt */
    case 556:  /* *subv8qi3_iwmmxt */
    case 557:  /* sssubv8qi3 */
    case 558:  /* sssubv4hi3 */
    case 559:  /* sssubv2si3 */
    case 560:  /* ussubv8qi3 */
    case 561:  /* ussubv4hi3 */
    case 562:  /* ussubv2si3 */
    case 6644:  /* *p *subv2si3_iwmmxt */
    case 6645:  /* *p *subv4hi3_iwmmxt */
    case 6646:  /* *p *subv8qi3_iwmmxt */
    case 6647:  /* *p sssubv8qi3 */
    case 6648:  /* *p sssubv4hi3 */
    case 6649:  /* *p sssubv2si3 */
    case 6650:  /* *p ussubv8qi3 */
    case 6651:  /* *p ussubv4hi3 */
    case 6652:  /* *p ussubv2si3 */
      return TYPE_WMMX_WSUB;

    case 638:  /* lshrv4hi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 650:  /* lshrv4hi3_di */
    case 651:  /* lshrv2si3_di */
    case 652:  /* lshrdi3_di */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6740:  /* *p lshrv4hi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6742:  /* *p lshrdi3_di */
      return TYPE_WMMX_WSRL;

    case 635:  /* ashrv4hi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 647:  /* ashrv4hi3_di */
    case 648:  /* ashrv2si3_di */
    case 649:  /* ashrdi3_di */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6737:  /* *p ashrv4hi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6739:  /* *p ashrdi3_di */
      return TYPE_WMMX_WSRA;

    case 641:  /* ashlv4hi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 643:  /* ashldi3_iwmmxt */
    case 653:  /* ashlv4hi3_di */
    case 654:  /* ashlv2si3_di */
    case 655:  /* ashldi3_di */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6743:  /* *p ashlv4hi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6745:  /* *p ashldi3_di */
      return TYPE_WMMX_WSLL;

    case 586:  /* iwmmxt_wshufh */
    case 6676:  /* *p iwmmxt_wshufh */
      return TYPE_WMMX_WSHUFH;

    case 676:  /* iwmmxt_wsadb */
    case 677:  /* iwmmxt_wsadh */
    case 678:  /* iwmmxt_wsadbz */
    case 679:  /* iwmmxt_wsadhz */
    case 6766:  /* *p iwmmxt_wsadb */
    case 6767:  /* *p iwmmxt_wsadh */
    case 6768:  /* *p iwmmxt_wsadbz */
    case 6769:  /* *p iwmmxt_wsadhz */
      return TYPE_WMMX_WSAD;

    case 632:  /* rorv4hi3 */
    case 633:  /* rorv2si3 */
    case 634:  /* rordi3 */
    case 644:  /* rorv4hi3_di */
    case 645:  /* rorv2si3_di */
    case 646:  /* rordi3_di */
    case 6722:  /* *p rorv4hi3 */
    case 6723:  /* *p rorv2si3 */
    case 6724:  /* *p rordi3 */
    case 6734:  /* *p rorv4hi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6736:  /* *p rordi3_di */
      return TYPE_WMMX_WROR;

    case 704:  /* iwmmxt_wqmulwm */
    case 706:  /* iwmmxt_wqmulwmr */
    case 6794:  /* *p iwmmxt_wqmulwm */
    case 6796:  /* *p iwmmxt_wqmulwmr */
      return TYPE_WMMX_WQMULWM;

    case 703:  /* iwmmxt_wqmulm */
    case 705:  /* iwmmxt_wqmulmr */
    case 6793:  /* *p iwmmxt_wqmulm */
    case 6795:  /* *p iwmmxt_wqmulmr */
      return TYPE_WMMX_WQMULM;

    case 709:  /* iwmmxt_wqmiabb */
    case 710:  /* iwmmxt_wqmiabt */
    case 711:  /* iwmmxt_wqmiatb */
    case 712:  /* iwmmxt_wqmiatt */
    case 713:  /* iwmmxt_wqmiabbn */
    case 714:  /* iwmmxt_wqmiabtn */
    case 715:  /* iwmmxt_wqmiatbn */
    case 716:  /* iwmmxt_wqmiattn */
    case 6799:  /* *p iwmmxt_wqmiabb */
    case 6800:  /* *p iwmmxt_wqmiabt */
    case 6801:  /* *p iwmmxt_wqmiatb */
    case 6802:  /* *p iwmmxt_wqmiatt */
    case 6803:  /* *p iwmmxt_wqmiabbn */
    case 6804:  /* *p iwmmxt_wqmiabtn */
    case 6805:  /* *p iwmmxt_wqmiatbn */
    case 6806:  /* *p iwmmxt_wqmiattn */
      return TYPE_WMMX_WQMIAXY;

    case 608:  /* iwmmxt_wpackhss */
    case 609:  /* iwmmxt_wpackwss */
    case 610:  /* iwmmxt_wpackdss */
    case 611:  /* iwmmxt_wpackhus */
    case 612:  /* iwmmxt_wpackwus */
    case 613:  /* iwmmxt_wpackdus */
    case 6698:  /* *p iwmmxt_wpackhss */
    case 6699:  /* *p iwmmxt_wpackwss */
    case 6700:  /* *p iwmmxt_wpackdss */
    case 6701:  /* *p iwmmxt_wpackhus */
    case 6702:  /* *p iwmmxt_wpackwus */
    case 6703:  /* *p iwmmxt_wpackdus */
      return TYPE_WMMX_WPACK;

    case 526:  /* iwmmxt_iordi3 */
    case 539:  /* *iorv2si3_iwmmxt */
    case 540:  /* *iorv4hi3_iwmmxt */
    case 541:  /* *iorv8qi3_iwmmxt */
    case 6619:  /* *p iwmmxt_iordi3 */
    case 6629:  /* *p *iorv2si3_iwmmxt */
    case 6630:  /* *p *iorv4hi3_iwmmxt */
    case 6631:  /* *p *iorv8qi3_iwmmxt */
      return TYPE_WMMX_WOR;

    case 696:  /* iwmmxt_wmulwsm */
    case 697:  /* iwmmxt_wmulwum */
    case 701:  /* iwmmxt_wmulwumr */
    case 702:  /* iwmmxt_wmulwl */
    case 6786:  /* *p iwmmxt_wmulwsm */
    case 6787:  /* *p iwmmxt_wmulwum */
    case 6791:  /* *p iwmmxt_wmulwumr */
    case 6792:  /* *p iwmmxt_wmulwl */
      return TYPE_WMMX_WMULW;

    case 563:  /* *mulv4hi3_iwmmxt */
    case 564:  /* smulv4hi3_highpart */
    case 565:  /* umulv4hi3_highpart */
    case 698:  /* iwmmxt_wmulsmr */
    case 699:  /* iwmmxt_wmulumr */
    case 700:  /* iwmmxt_wmulwsmr */
    case 6653:  /* *p *mulv4hi3_iwmmxt */
    case 6654:  /* *p smulv4hi3_highpart */
    case 6655:  /* *p umulv4hi3_highpart */
    case 6788:  /* *p iwmmxt_wmulsmr */
    case 6789:  /* *p iwmmxt_wmulumr */
    case 6790:  /* *p iwmmxt_wmulwsmr */
      return TYPE_WMMX_WMUL;

    case 602:  /* *sminv2si3_iwmmxt */
    case 603:  /* *sminv4hi3_iwmmxt */
    case 604:  /* *sminv8qi3_iwmmxt */
    case 605:  /* *uminv2si3_iwmmxt */
    case 606:  /* *uminv4hi3_iwmmxt */
    case 607:  /* *uminv8qi3_iwmmxt */
    case 6692:  /* *p *sminv2si3_iwmmxt */
    case 6693:  /* *p *sminv4hi3_iwmmxt */
    case 6694:  /* *p *sminv8qi3_iwmmxt */
    case 6695:  /* *p *uminv2si3_iwmmxt */
    case 6696:  /* *p *uminv4hi3_iwmmxt */
    case 6697:  /* *p *uminv8qi3_iwmmxt */
      return TYPE_WMMX_WMIN;

    case 717:  /* iwmmxt_wmiabb */
    case 718:  /* iwmmxt_wmiabt */
    case 719:  /* iwmmxt_wmiatb */
    case 720:  /* iwmmxt_wmiatt */
    case 721:  /* iwmmxt_wmiabbn */
    case 722:  /* iwmmxt_wmiabtn */
    case 723:  /* iwmmxt_wmiatbn */
    case 724:  /* iwmmxt_wmiattn */
    case 6807:  /* *p iwmmxt_wmiabb */
    case 6808:  /* *p iwmmxt_wmiabt */
    case 6809:  /* *p iwmmxt_wmiatb */
    case 6810:  /* *p iwmmxt_wmiatt */
    case 6811:  /* *p iwmmxt_wmiabbn */
    case 6812:  /* *p iwmmxt_wmiabtn */
    case 6813:  /* *p iwmmxt_wmiatbn */
    case 6814:  /* *p iwmmxt_wmiattn */
      return TYPE_WMMX_WMIAXY;

    case 725:  /* iwmmxt_wmiawbb */
    case 726:  /* iwmmxt_wmiawbt */
    case 727:  /* iwmmxt_wmiawtb */
    case 728:  /* iwmmxt_wmiawtt */
    case 729:  /* iwmmxt_wmiawbbn */
    case 730:  /* iwmmxt_wmiawbtn */
    case 731:  /* iwmmxt_wmiawtbn */
    case 732:  /* iwmmxt_wmiawttn */
    case 6815:  /* *p iwmmxt_wmiawbb */
    case 6816:  /* *p iwmmxt_wmiawbt */
    case 6817:  /* *p iwmmxt_wmiawtb */
    case 6818:  /* *p iwmmxt_wmiawtt */
    case 6819:  /* *p iwmmxt_wmiawbbn */
    case 6820:  /* *p iwmmxt_wmiawbtn */
    case 6821:  /* *p iwmmxt_wmiawtbn */
    case 6822:  /* *p iwmmxt_wmiawttn */
      return TYPE_WMMX_WMIAWXY;

    case 733:  /* iwmmxt_wmerge */
    case 6823:  /* *p iwmmxt_wmerge */
      return TYPE_WMMX_WMERGE;

    case 596:  /* *smaxv2si3_iwmmxt */
    case 597:  /* *smaxv4hi3_iwmmxt */
    case 598:  /* *smaxv8qi3_iwmmxt */
    case 599:  /* *umaxv2si3_iwmmxt */
    case 600:  /* *umaxv4hi3_iwmmxt */
    case 601:  /* *umaxv8qi3_iwmmxt */
    case 6686:  /* *p *smaxv2si3_iwmmxt */
    case 6687:  /* *p *smaxv4hi3_iwmmxt */
    case 6688:  /* *p *smaxv8qi3_iwmmxt */
    case 6689:  /* *p *umaxv2si3_iwmmxt */
    case 6690:  /* *p *umaxv4hi3_iwmmxt */
    case 6691:  /* *p *umaxv8qi3_iwmmxt */
      return TYPE_WMMX_WMAX;

    case 656:  /* iwmmxt_wmadds */
    case 657:  /* iwmmxt_wmaddu */
    case 692:  /* iwmmxt_wmaddsx */
    case 693:  /* iwmmxt_wmaddux */
    case 694:  /* iwmmxt_wmaddsn */
    case 695:  /* iwmmxt_wmaddun */
    case 6746:  /* *p iwmmxt_wmadds */
    case 6747:  /* *p iwmmxt_wmaddu */
    case 6782:  /* *p iwmmxt_wmaddsx */
    case 6783:  /* *p iwmmxt_wmaddux */
    case 6784:  /* *p iwmmxt_wmaddsn */
    case 6785:  /* *p iwmmxt_wmaddun */
      return TYPE_WMMX_WMADD;

    case 566:  /* iwmmxt_wmacs */
    case 567:  /* iwmmxt_wmacsz */
    case 568:  /* iwmmxt_wmacu */
    case 569:  /* iwmmxt_wmacuz */
    case 6656:  /* *p iwmmxt_wmacs */
    case 6657:  /* *p iwmmxt_wmacsz */
    case 6658:  /* *p iwmmxt_wmacu */
    case 6659:  /* *p iwmmxt_wmacuz */
      return TYPE_WMMX_WMAC;

    case 590:  /* gtuv8qi3 */
    case 591:  /* gtuv4hi3 */
    case 592:  /* gtuv2si3 */
    case 593:  /* gtv8qi3 */
    case 594:  /* gtv4hi3 */
    case 595:  /* gtv2si3 */
    case 6680:  /* *p gtuv8qi3 */
    case 6681:  /* *p gtuv4hi3 */
    case 6682:  /* *p gtuv2si3 */
    case 6683:  /* *p gtv8qi3 */
    case 6684:  /* *p gtv4hi3 */
    case 6685:  /* *p gtv2si3 */
      return TYPE_WMMX_WCMPGT;

    case 587:  /* eqv8qi3 */
    case 588:  /* eqv4hi3 */
    case 589:  /* eqv2si3 */
    case 6677:  /* *p eqv8qi3 */
    case 6678:  /* *p eqv4hi3 */
    case 6679:  /* *p eqv2si3 */
      return TYPE_WMMX_WCMPEQ;

    case 690:  /* iwmmxt_avg4 */
    case 691:  /* iwmmxt_avg4r */
    case 6780:  /* *p iwmmxt_avg4 */
    case 6781:  /* *p iwmmxt_avg4r */
      return TYPE_WMMX_WAVG4;

    case 574:  /* iwmmxt_uavgrndv8qi3 */
    case 575:  /* iwmmxt_uavgrndv4hi3 */
    case 576:  /* iwmmxt_uavgv8qi3 */
    case 577:  /* iwmmxt_uavgv4hi3 */
    case 6664:  /* *p iwmmxt_uavgrndv8qi3 */
    case 6665:  /* *p iwmmxt_uavgrndv4hi3 */
    case 6666:  /* *p iwmmxt_uavgv8qi3 */
    case 6667:  /* *p iwmmxt_uavgv4hi3 */
      return TYPE_WMMX_WAVG2;

    case 529:  /* iwmmxt_nanddi3 */
    case 6622:  /* *p iwmmxt_nanddi3 */
      return TYPE_WMMX_WANDN;

    case 528:  /* iwmmxt_anddi3 */
    case 536:  /* *andv2si3_iwmmxt */
    case 537:  /* *andv4hi3_iwmmxt */
    case 538:  /* *andv8qi3_iwmmxt */
    case 6621:  /* *p iwmmxt_anddi3 */
    case 6626:  /* *p *andv2si3_iwmmxt */
    case 6627:  /* *p *andv4hi3_iwmmxt */
    case 6628:  /* *p *andv8qi3_iwmmxt */
      return TYPE_WMMX_WAND;

    case 671:  /* iwmmxt_walignr */
    case 672:  /* iwmmxt_walignr0 */
    case 673:  /* iwmmxt_walignr1 */
    case 674:  /* iwmmxt_walignr2 */
    case 675:  /* iwmmxt_walignr3 */
    case 6761:  /* *p iwmmxt_walignr */
    case 6762:  /* *p iwmmxt_walignr0 */
    case 6763:  /* *p iwmmxt_walignr1 */
    case 6764:  /* *p iwmmxt_walignr2 */
    case 6765:  /* *p iwmmxt_walignr3 */
      return TYPE_WMMX_WALIGNR;

    case 670:  /* iwmmxt_waligni */
    case 6760:  /* *p iwmmxt_waligni */
      return TYPE_WMMX_WALIGNI;

    case 686:  /* iwmmxt_waddsubhx */
    case 6776:  /* *p iwmmxt_waddsubhx */
      return TYPE_WMMX_WADDSUBHX;

    case 707:  /* iwmmxt_waddbhusm */
    case 708:  /* iwmmxt_waddbhusl */
    case 6797:  /* *p iwmmxt_waddbhusm */
    case 6798:  /* *p iwmmxt_waddbhusl */
      return TYPE_WMMX_WADDBHUS;

    case 545:  /* *addv2si3_iwmmxt */
    case 546:  /* *addv4hi3_iwmmxt */
    case 547:  /* *addv8qi3_iwmmxt */
    case 548:  /* ssaddv8qi3 */
    case 549:  /* ssaddv4hi3 */
    case 550:  /* ssaddv2si3 */
    case 551:  /* usaddv8qi3 */
    case 552:  /* usaddv4hi3 */
    case 553:  /* usaddv2si3 */
    case 688:  /* addcv4hi3 */
    case 689:  /* addcv2si3 */
    case 6635:  /* *p *addv2si3_iwmmxt */
    case 6636:  /* *p *addv4hi3_iwmmxt */
    case 6637:  /* *p *addv8qi3_iwmmxt */
    case 6638:  /* *p ssaddv8qi3 */
    case 6639:  /* *p ssaddv4hi3 */
    case 6640:  /* *p ssaddv2si3 */
    case 6641:  /* *p usaddv8qi3 */
    case 6642:  /* *p usaddv4hi3 */
    case 6643:  /* *p usaddv2si3 */
    case 6778:  /* *p addcv4hi3 */
    case 6779:  /* *p addcv2si3 */
      return TYPE_WMMX_WADD;

    case 667:  /* iwmmxt_waccb */
    case 668:  /* iwmmxt_wacch */
    case 669:  /* iwmmxt_waccw */
    case 6757:  /* *p iwmmxt_waccb */
    case 6758:  /* *p iwmmxt_wacch */
    case 6759:  /* *p iwmmxt_waccw */
      return TYPE_WMMX_WACC;

    case 683:  /* iwmmxt_wabsdiffb */
    case 684:  /* iwmmxt_wabsdiffh */
    case 685:  /* iwmmxt_wabsdiffw */
    case 6773:  /* *p iwmmxt_wabsdiffb */
    case 6774:  /* *p iwmmxt_wabsdiffh */
    case 6775:  /* *p iwmmxt_wabsdiffw */
      return TYPE_WMMX_WABSDIFF;

    case 680:  /* iwmmxt_wabsv2si3 */
    case 681:  /* iwmmxt_wabsv4hi3 */
    case 682:  /* iwmmxt_wabsv8qi3 */
    case 6770:  /* *p iwmmxt_wabsv2si3 */
    case 6771:  /* *p iwmmxt_wabsv4hi3 */
    case 6772:  /* *p iwmmxt_wabsv8qi3 */
      return TYPE_WMMX_WABS;

    case 740:  /* iwmmxt_torvscv2si3 */
    case 741:  /* iwmmxt_torvscv4hi3 */
    case 742:  /* iwmmxt_torvscv8qi3 */
    case 6830:  /* *p iwmmxt_torvscv2si3 */
    case 6831:  /* *p iwmmxt_torvscv4hi3 */
    case 6832:  /* *p iwmmxt_torvscv8qi3 */
      return TYPE_WMMX_TORVSC;

    case 737:  /* iwmmxt_torcv2si3 */
    case 738:  /* iwmmxt_torcv4hi3 */
    case 739:  /* iwmmxt_torcv8qi3 */
    case 6827:  /* *p iwmmxt_torcv2si3 */
    case 6828:  /* *p iwmmxt_torcv4hi3 */
    case 6829:  /* *p iwmmxt_torcv8qi3 */
      return TYPE_WMMX_TORC;

    case 664:  /* iwmmxt_tmovmskb */
    case 665:  /* iwmmxt_tmovmskh */
    case 666:  /* iwmmxt_tmovmskw */
    case 6754:  /* *p iwmmxt_tmovmskb */
    case 6755:  /* *p iwmmxt_tmovmskh */
    case 6756:  /* *p iwmmxt_tmovmskw */
      return TYPE_WMMX_TMOVMSK;

    case 660:  /* iwmmxt_tmiabb */
    case 661:  /* iwmmxt_tmiatb */
    case 662:  /* iwmmxt_tmiabt */
    case 663:  /* iwmmxt_tmiatt */
    case 6750:  /* *p iwmmxt_tmiabb */
    case 6751:  /* *p iwmmxt_tmiatb */
    case 6752:  /* *p iwmmxt_tmiabt */
    case 6753:  /* *p iwmmxt_tmiatt */
      return TYPE_WMMX_TMIAXY;

    case 659:  /* iwmmxt_tmiaph */
    case 6749:  /* *p iwmmxt_tmiaph */
      return TYPE_WMMX_TMIAPH;

    case 658:  /* iwmmxt_tmia */
    case 6748:  /* *p iwmmxt_tmia */
      return TYPE_WMMX_TMIA;

    case 578:  /* iwmmxt_tinsrb */
    case 579:  /* iwmmxt_tinsrh */
    case 580:  /* iwmmxt_tinsrw */
    case 6668:  /* *p iwmmxt_tinsrb */
    case 6669:  /* *p iwmmxt_tinsrh */
    case 6670:  /* *p iwmmxt_tinsrw */
      return TYPE_WMMX_TINSR;

    case 581:  /* iwmmxt_textrmub */
    case 582:  /* iwmmxt_textrmsb */
    case 583:  /* iwmmxt_textrmuh */
    case 584:  /* iwmmxt_textrmsh */
    case 585:  /* iwmmxt_textrmw */
    case 6671:  /* *p iwmmxt_textrmub */
    case 6672:  /* *p iwmmxt_textrmsb */
    case 6673:  /* *p iwmmxt_textrmuh */
    case 6674:  /* *p iwmmxt_textrmsh */
    case 6675:  /* *p iwmmxt_textrmw */
      return TYPE_WMMX_TEXTRM;

    case 743:  /* iwmmxt_textrcv2si3 */
    case 744:  /* iwmmxt_textrcv4hi3 */
    case 745:  /* iwmmxt_textrcv8qi3 */
    case 6833:  /* *p iwmmxt_textrcv2si3 */
    case 6834:  /* *p iwmmxt_textrcv4hi3 */
    case 6835:  /* *p iwmmxt_textrcv8qi3 */
      return TYPE_WMMX_TEXTRC;

    case 523:  /* tbcstv8qi */
    case 524:  /* tbcstv4hi */
    case 525:  /* tbcstv2si */
    case 6616:  /* *p tbcstv8qi */
    case 6617:  /* *p tbcstv4hi */
    case 6618:  /* *p tbcstv2si */
      return TYPE_WMMX_TBCST;

    case 734:  /* iwmmxt_tandcv2si3 */
    case 735:  /* iwmmxt_tandcv4hi3 */
    case 736:  /* iwmmxt_tandcv8qi3 */
    case 6824:  /* *p iwmmxt_tandcv2si3 */
    case 6825:  /* *p iwmmxt_tandcv4hi3 */
    case 6826:  /* *p iwmmxt_tandcv8qi3 */
      return TYPE_WMMX_TANDC;

    case 7040:  /* *p mve_sqshll_di */
    case 7039:  /* *p mve_srshrl_di */
    case 7038:  /* *p mve_srshr_si */
    case 7037:  /* *p mve_sqshl_si */
    case 7036:  /* *p mve_urshr_si */
    case 7035:  /* *p mve_uqshl_si */
    case 7034:  /* *p mve_urshrl_di */
    case 7033:  /* *p mve_uqshll_di */
    case 7032:  /* *p mve_sqrshr_si */
    case 7031:  /* *p mve_uqrshl_si */
    case 7030:  /* *p mve_sqrshrl_sat48_di */
    case 7029:  /* *p mve_sqrshrl_sat64_di */
    case 7028:  /* *p mve_uqrshll_sat48_di */
    case 7027:  /* *p mve_uqrshll_sat64_di */
    case 6970:  /* *p arm_store_release_exclusivesi */
    case 6969:  /* *p arm_store_release_exclusivehi */
    case 6968:  /* *p arm_store_release_exclusiveqi */
    case 6967:  /* *p arm_store_release_exclusivedi */
    case 6966:  /* *p arm_store_exclusivedi */
    case 6965:  /* *p arm_store_exclusivesi */
    case 6964:  /* *p arm_store_exclusivehi */
    case 6963:  /* *p arm_store_exclusiveqi */
    case 6962:  /* *p arm_load_acquire_exclusivedi */
    case 6961:  /* *p arm_load_exclusivedi */
    case 6960:  /* *p arm_load_acquire_exclusivesi */
    case 6959:  /* *p arm_load_exclusivesi */
    case 6958:  /* *p arm_load_acquire_exclusivehi */
    case 6957:  /* *p arm_load_acquire_exclusiveqi */
    case 6956:  /* *p arm_load_exclusivehi */
    case 6955:  /* *p arm_load_exclusiveqi */
    case 6954:  /* *p arm_atomic_loaddi2_ldrd */
    case 6953:  /* *p atomic_storesi */
    case 6952:  /* *p atomic_storehi */
    case 6951:  /* *p atomic_storeqi */
    case 6950:  /* *p atomic_loadsi */
    case 6949:  /* *p atomic_loadhi */
    case 6948:  /* *p atomic_loadqi */
    case 6947:  /* *p thumb2_lsrl */
    case 6946:  /* *p thumb2_lsll */
    case 6945:  /* *p thumb2_asrl */
    case 6944:  /* *p *clear_multiple */
    case 6943:  /* *p *clear_apsr */
    case 6615:  /* *p *load_multiple */
    case 6420:  /* *p arm_set_apsr */
    case 6419:  /* *p arm_get_apsr */
    case 4935:  /* mve_sqshll_di */
    case 4934:  /* mve_srshrl_di */
    case 4933:  /* mve_srshr_si */
    case 4932:  /* mve_sqshl_si */
    case 4931:  /* mve_urshr_si */
    case 4930:  /* mve_uqshl_si */
    case 4929:  /* mve_urshrl_di */
    case 4928:  /* mve_uqshll_di */
    case 4927:  /* mve_sqrshr_si */
    case 4926:  /* mve_uqrshl_si */
    case 4925:  /* mve_sqrshrl_sat48_di */
    case 4924:  /* mve_sqrshrl_sat64_di */
    case 4923:  /* mve_uqrshll_sat48_di */
    case 4922:  /* mve_uqrshll_sat64_di */
    case 4903:  /* mve_vld4qv4sf */
    case 4902:  /* mve_vld4qv8hf */
    case 4901:  /* mve_vld4qv4si */
    case 4900:  /* mve_vld4qv8hi */
    case 4899:  /* mve_vld4qv16qi */
    case 4898:  /* mve_vld2qv4sf */
    case 4897:  /* mve_vld2qv8hf */
    case 4896:  /* mve_vld2qv4si */
    case 4895:  /* mve_vld2qv8hi */
    case 4894:  /* mve_vld2qv16qi */
    case 4893:  /* mve_vst2qv4sf */
    case 4892:  /* mve_vst2qv8hf */
    case 4891:  /* mve_vst2qv4si */
    case 4890:  /* mve_vst2qv8hi */
    case 4889:  /* mve_vst2qv16qi */
    case 4872:  /* mve_vldrdq_gather_base_wb_z_uv2di_insn */
    case 4871:  /* mve_vldrdq_gather_base_wb_z_sv2di_insn */
    case 4868:  /* mve_vldrdq_gather_base_wb_uv2di_insn */
    case 4867:  /* mve_vldrdq_gather_base_wb_sv2di_insn */
    case 4866:  /* mve_vldrwq_gather_base_wb_z_fv4sf_insn */
    case 4865:  /* mve_vldrwq_gather_base_wb_fv4sf_insn */
    case 4864:  /* mve_vldrwq_gather_base_wb_z_uv4si_insn */
    case 4863:  /* mve_vldrwq_gather_base_wb_z_sv4si_insn */
    case 4862:  /* mve_vldrwq_gather_base_wb_uv4si_insn */
    case 4861:  /* mve_vldrwq_gather_base_wb_sv4si_insn */
    case 4860:  /* mve_vstrdq_scatter_base_wb_p_uv2di */
    case 4859:  /* mve_vstrdq_scatter_base_wb_p_sv2di */
    case 4858:  /* mve_vstrdq_scatter_base_wb_uv2di */
    case 4857:  /* mve_vstrdq_scatter_base_wb_sv2di */
    case 4856:  /* mve_vstrwq_scatter_base_wb_p_fv4sf */
    case 4855:  /* mve_vstrwq_scatter_base_wb_fv4sf */
    case 4854:  /* mve_vstrwq_scatter_base_wb_p_uv4si */
    case 4853:  /* mve_vstrwq_scatter_base_wb_p_sv4si */
    case 4852:  /* mve_vstrwq_scatter_base_wb_uv4si */
    case 4851:  /* mve_vstrwq_scatter_base_wb_sv4si */
    case 4847:  /* mve_viwdupq_wb_uv4si_insn */
    case 4846:  /* mve_viwdupq_wb_uv8hi_insn */
    case 4845:  /* mve_viwdupq_wb_uv16qi_insn */
    case 4841:  /* mve_vdwdupq_wb_uv4si_insn */
    case 4840:  /* mve_vdwdupq_wb_uv8hi_insn */
    case 4839:  /* mve_vdwdupq_wb_uv16qi_insn */
    case 4838:  /* mve_vddupq_m_wb_uv4si_insn */
    case 4837:  /* mve_vddupq_m_wb_uv8hi_insn */
    case 4836:  /* mve_vddupq_m_wb_uv16qi_insn */
    case 4835:  /* mve_vddupq_uv4si_insn */
    case 4834:  /* mve_vddupq_uv8hi_insn */
    case 4833:  /* mve_vddupq_uv16qi_insn */
    case 4832:  /* mve_vidupq_m_wb_uv4si_insn */
    case 4831:  /* mve_vidupq_m_wb_uv8hi_insn */
    case 4830:  /* mve_vidupq_m_wb_uv16qi_insn */
    case 4829:  /* mve_vidupq_uv4si_insn */
    case 4828:  /* mve_vidupq_uv8hi_insn */
    case 4827:  /* mve_vidupq_uv16qi_insn */
    case 4821:  /* mve_vstrwq_scatter_shifted_offset_uv4si_insn */
    case 4820:  /* mve_vstrwq_scatter_shifted_offset_sv4si_insn */
    case 4819:  /* mve_vstrwq_scatter_shifted_offset_p_uv4si_insn */
    case 4818:  /* mve_vstrwq_scatter_shifted_offset_p_sv4si_insn */
    case 4817:  /* mve_vstrwq_scatter_shifted_offset_p_fv4sf_insn */
    case 4816:  /* mve_vstrwq_scatter_shifted_offset_fv4sf_insn */
    case 4815:  /* mve_vstrwq_scatter_offset_uv4si_insn */
    case 4814:  /* mve_vstrwq_scatter_offset_sv4si_insn */
    case 4813:  /* mve_vstrwq_scatter_offset_p_uv4si_insn */
    case 4812:  /* mve_vstrwq_scatter_offset_p_sv4si_insn */
    case 4811:  /* mve_vstrwq_scatter_offset_p_fv4sf_insn */
    case 4810:  /* mve_vstrwq_scatter_offset_fv4sf_insn */
    case 4809:  /* mve_vstrwq_scatter_base_p_fv4sf */
    case 4808:  /* mve_vstrwq_scatter_base_fv4sf */
    case 4807:  /* mve_vstrhq_scatter_shifted_offset_p_fv8hf_insn */
    case 4806:  /* mve_vstrhq_scatter_shifted_offset_fv8hf_insn */
    case 4805:  /* mve_vstrhq_scatter_offset_p_fv8hf_insn */
    case 4804:  /* mve_vstrhq_scatter_offset_fv8hf_insn */
    case 4803:  /* mve_vstrdq_scatter_shifted_offset_uv2di_insn */
    case 4802:  /* mve_vstrdq_scatter_shifted_offset_sv2di_insn */
    case 4801:  /* mve_vstrdq_scatter_shifted_offset_p_uv2di_insn */
    case 4800:  /* mve_vstrdq_scatter_shifted_offset_p_sv2di_insn */
    case 4799:  /* mve_vstrdq_scatter_offset_uv2di_insn */
    case 4798:  /* mve_vstrdq_scatter_offset_sv2di_insn */
    case 4797:  /* mve_vstrdq_scatter_offset_p_uv2di_insn */
    case 4796:  /* mve_vstrdq_scatter_offset_p_sv2di_insn */
    case 4795:  /* mve_vstrdq_scatter_base_uv2di */
    case 4794:  /* mve_vstrdq_scatter_base_sv2di */
    case 4793:  /* mve_vstrdq_scatter_base_p_uv2di */
    case 4792:  /* mve_vstrdq_scatter_base_p_sv2di */
    case 4791:  /* mve_vstrwq_uv4si */
    case 4790:  /* mve_vstrwq_sv4si */
    case 4789:  /* mve_vstrwq_p_uv4si */
    case 4788:  /* mve_vstrwq_p_sv4si */
    case 4787:  /* mve_vstrwq_p_fv4sf */
    case 4786:  /* mve_vstrwq_fv4sf */
    case 4785:  /* mve_vstrhq_uv4si */
    case 4784:  /* mve_vstrhq_sv4si */
    case 4783:  /* mve_vstrhq_uv8hi */
    case 4782:  /* mve_vstrhq_sv8hi */
    case 4781:  /* mve_vstrhq_scatter_shifted_offset_uv4si_insn */
    case 4780:  /* mve_vstrhq_scatter_shifted_offset_sv4si_insn */
    case 4779:  /* mve_vstrhq_scatter_shifted_offset_uv8hi_insn */
    case 4778:  /* mve_vstrhq_scatter_shifted_offset_sv8hi_insn */
    case 4777:  /* mve_vstrhq_scatter_shifted_offset_p_uv4si_insn */
    case 4776:  /* mve_vstrhq_scatter_shifted_offset_p_sv4si_insn */
    case 4775:  /* mve_vstrhq_scatter_shifted_offset_p_uv8hi_insn */
    case 4774:  /* mve_vstrhq_scatter_shifted_offset_p_sv8hi_insn */
    case 4773:  /* mve_vstrhq_scatter_offset_uv4si_insn */
    case 4772:  /* mve_vstrhq_scatter_offset_sv4si_insn */
    case 4771:  /* mve_vstrhq_scatter_offset_uv8hi_insn */
    case 4770:  /* mve_vstrhq_scatter_offset_sv8hi_insn */
    case 4769:  /* mve_vstrhq_scatter_offset_p_uv4si_insn */
    case 4768:  /* mve_vstrhq_scatter_offset_p_sv4si_insn */
    case 4767:  /* mve_vstrhq_scatter_offset_p_uv8hi_insn */
    case 4766:  /* mve_vstrhq_scatter_offset_p_sv8hi_insn */
    case 4765:  /* mve_vstrhq_p_uv4si */
    case 4764:  /* mve_vstrhq_p_sv4si */
    case 4763:  /* mve_vstrhq_p_uv8hi */
    case 4762:  /* mve_vstrhq_p_sv8hi */
    case 4761:  /* mve_vstrhq_p_fv8hf */
    case 4760:  /* mve_vstrhq_fv8hf */
    case 4759:  /* mve_vldrwq_gather_shifted_offset_z_uv4si */
    case 4758:  /* mve_vldrwq_gather_shifted_offset_z_sv4si */
    case 4757:  /* mve_vldrwq_gather_shifted_offset_z_fv4sf */
    case 4756:  /* mve_vldrwq_gather_shifted_offset_uv4si */
    case 4755:  /* mve_vldrwq_gather_shifted_offset_sv4si */
    case 4754:  /* mve_vldrwq_gather_shifted_offset_fv4sf */
    case 4753:  /* mve_vldrwq_gather_offset_z_uv4si */
    case 4752:  /* mve_vldrwq_gather_offset_z_sv4si */
    case 4751:  /* mve_vldrwq_gather_offset_z_fv4sf */
    case 4750:  /* mve_vldrwq_gather_offset_uv4si */
    case 4749:  /* mve_vldrwq_gather_offset_sv4si */
    case 4748:  /* mve_vldrwq_gather_offset_fv4sf */
    case 4747:  /* mve_vldrwq_gather_base_z_fv4sf */
    case 4746:  /* mve_vldrwq_gather_base_fv4sf */
    case 4745:  /* mve_vldrhq_gather_shifted_offset_z_fv8hf */
    case 4744:  /* mve_vldrhq_gather_shifted_offset_fv8hf */
    case 4743:  /* mve_vldrhq_gather_offset_z_fv8hf */
    case 4742:  /* mve_vldrhq_gather_offset_fv8hf */
    case 4741:  /* mve_vldrdq_gather_shifted_offset_z_uv2di */
    case 4740:  /* mve_vldrdq_gather_shifted_offset_z_sv2di */
    case 4739:  /* mve_vldrdq_gather_shifted_offset_uv2di */
    case 4738:  /* mve_vldrdq_gather_shifted_offset_sv2di */
    case 4737:  /* mve_vldrdq_gather_offset_z_uv2di */
    case 4736:  /* mve_vldrdq_gather_offset_z_sv2di */
    case 4735:  /* mve_vldrdq_gather_offset_uv2di */
    case 4734:  /* mve_vldrdq_gather_offset_sv2di */
    case 4733:  /* mve_vldrdq_gather_base_z_uv2di */
    case 4732:  /* mve_vldrdq_gather_base_z_sv2di */
    case 4731:  /* mve_vldrdq_gather_base_uv2di */
    case 4730:  /* mve_vldrdq_gather_base_sv2di */
    case 4729:  /* mve_vldrwq_z_uv4si */
    case 4728:  /* mve_vldrwq_z_sv4si */
    case 4727:  /* mve_vldrwq_z_fv4sf */
    case 4726:  /* mve_vldrwq_uv4si */
    case 4725:  /* mve_vldrwq_sv4si */
    case 4724:  /* mve_vldrwq_fv4sf */
    case 4723:  /* mve_vldrhq_z_uv4si */
    case 4722:  /* mve_vldrhq_z_sv4si */
    case 4721:  /* mve_vldrhq_z_uv8hi */
    case 4720:  /* mve_vldrhq_z_sv8hi */
    case 4719:  /* mve_vldrhq_z_fv8hf */
    case 4718:  /* mve_vldrhq_uv4si */
    case 4717:  /* mve_vldrhq_sv4si */
    case 4716:  /* mve_vldrhq_uv8hi */
    case 4715:  /* mve_vldrhq_sv8hi */
    case 4714:  /* mve_vldrhq_gather_shifted_offset_z_uv4si */
    case 4713:  /* mve_vldrhq_gather_shifted_offset_z_sv4si */
    case 4712:  /* mve_vldrhq_gather_shifted_offset_z_uv8hi */
    case 4711:  /* mve_vldrhq_gather_shifted_offset_z_sv8hi */
    case 4710:  /* mve_vldrhq_gather_shifted_offset_uv4si */
    case 4709:  /* mve_vldrhq_gather_shifted_offset_sv4si */
    case 4708:  /* mve_vldrhq_gather_shifted_offset_uv8hi */
    case 4707:  /* mve_vldrhq_gather_shifted_offset_sv8hi */
    case 4706:  /* mve_vldrhq_gather_offset_z_uv4si */
    case 4705:  /* mve_vldrhq_gather_offset_z_sv4si */
    case 4704:  /* mve_vldrhq_gather_offset_z_uv8hi */
    case 4703:  /* mve_vldrhq_gather_offset_z_sv8hi */
    case 4702:  /* mve_vldrhq_gather_offset_uv4si */
    case 4701:  /* mve_vldrhq_gather_offset_sv4si */
    case 4700:  /* mve_vldrhq_gather_offset_uv8hi */
    case 4699:  /* mve_vldrhq_gather_offset_sv8hi */
    case 4698:  /* mve_vldrhq_fv8hf */
    case 4697:  /* mve_vldrwq_gather_base_z_uv4si */
    case 4696:  /* mve_vldrwq_gather_base_z_sv4si */
    case 4695:  /* mve_vldrbq_z_uv4si */
    case 4694:  /* mve_vldrbq_z_sv4si */
    case 4693:  /* mve_vldrbq_z_uv8hi */
    case 4692:  /* mve_vldrbq_z_sv8hi */
    case 4691:  /* mve_vldrbq_z_uv16qi */
    case 4690:  /* mve_vldrbq_z_sv16qi */
    case 4689:  /* mve_vldrbq_gather_offset_z_uv4si */
    case 4688:  /* mve_vldrbq_gather_offset_z_sv4si */
    case 4687:  /* mve_vldrbq_gather_offset_z_uv8hi */
    case 4686:  /* mve_vldrbq_gather_offset_z_sv8hi */
    case 4685:  /* mve_vldrbq_gather_offset_z_uv16qi */
    case 4684:  /* mve_vldrbq_gather_offset_z_sv16qi */
    case 4683:  /* mve_vstrbq_p_uv4si */
    case 4682:  /* mve_vstrbq_p_sv4si */
    case 4681:  /* mve_vstrbq_p_uv8hi */
    case 4680:  /* mve_vstrbq_p_sv8hi */
    case 4679:  /* mve_vstrbq_p_uv16qi */
    case 4678:  /* mve_vstrbq_p_sv16qi */
    case 4677:  /* mve_vstrwq_scatter_base_p_uv4si */
    case 4676:  /* mve_vstrwq_scatter_base_p_sv4si */
    case 4675:  /* mve_vstrbq_scatter_offset_p_uv4si_insn */
    case 4674:  /* mve_vstrbq_scatter_offset_p_sv4si_insn */
    case 4673:  /* mve_vstrbq_scatter_offset_p_uv8hi_insn */
    case 4672:  /* mve_vstrbq_scatter_offset_p_sv8hi_insn */
    case 4671:  /* mve_vstrbq_scatter_offset_p_uv16qi_insn */
    case 4670:  /* mve_vstrbq_scatter_offset_p_sv16qi_insn */
    case 4669:  /* mve_vldrwq_gather_base_uv4si */
    case 4668:  /* mve_vldrwq_gather_base_sv4si */
    case 4667:  /* mve_vldrbq_uv4si */
    case 4666:  /* mve_vldrbq_sv4si */
    case 4665:  /* mve_vldrbq_uv8hi */
    case 4664:  /* mve_vldrbq_sv8hi */
    case 4663:  /* mve_vldrbq_uv16qi */
    case 4662:  /* mve_vldrbq_sv16qi */
    case 4661:  /* mve_vldrbq_gather_offset_uv4si */
    case 4660:  /* mve_vldrbq_gather_offset_sv4si */
    case 4659:  /* mve_vldrbq_gather_offset_uv8hi */
    case 4658:  /* mve_vldrbq_gather_offset_sv8hi */
    case 4657:  /* mve_vldrbq_gather_offset_uv16qi */
    case 4656:  /* mve_vldrbq_gather_offset_sv16qi */
    case 4655:  /* mve_vstrwq_scatter_base_uv4si */
    case 4654:  /* mve_vstrwq_scatter_base_sv4si */
    case 4653:  /* mve_vstrbq_scatter_offset_uv4si_insn */
    case 4652:  /* mve_vstrbq_scatter_offset_sv4si_insn */
    case 4651:  /* mve_vstrbq_scatter_offset_uv8hi_insn */
    case 4650:  /* mve_vstrbq_scatter_offset_sv8hi_insn */
    case 4649:  /* mve_vstrbq_scatter_offset_uv16qi_insn */
    case 4648:  /* mve_vstrbq_scatter_offset_sv16qi_insn */
    case 4647:  /* mve_vstrbq_uv4si */
    case 4646:  /* mve_vstrbq_sv4si */
    case 4645:  /* mve_vstrbq_uv8hi */
    case 4644:  /* mve_vstrbq_sv8hi */
    case 4643:  /* mve_vstrbq_uv16qi */
    case 4642:  /* mve_vstrbq_sv16qi */
    case 3722:  /* mve_vshlcq_uv4si */
    case 3721:  /* mve_vshlcq_sv4si */
    case 3720:  /* mve_vshlcq_uv8hi */
    case 3719:  /* mve_vshlcq_sv8hi */
    case 3718:  /* mve_vshlcq_uv16qi */
    case 3717:  /* mve_vshlcq_sv16qi */
    case 3057:  /* mve_vst4qv4sf */
    case 3056:  /* mve_vst4qv8hf */
    case 3055:  /* mve_vst4qv4si */
    case 3054:  /* mve_vst4qv8hi */
    case 3053:  /* mve_vst4qv16qi */
    case 2979:  /* arm_store_release_exclusivesi */
    case 2978:  /* arm_store_release_exclusivehi */
    case 2977:  /* arm_store_release_exclusiveqi */
    case 2976:  /* arm_store_release_exclusivedi */
    case 2975:  /* arm_store_exclusivedi */
    case 2974:  /* arm_store_exclusivesi */
    case 2973:  /* arm_store_exclusivehi */
    case 2972:  /* arm_store_exclusiveqi */
    case 2971:  /* arm_load_acquire_exclusivedi */
    case 2970:  /* arm_load_exclusivedi */
    case 2969:  /* arm_load_acquire_exclusivesi */
    case 2968:  /* arm_load_exclusivesi */
    case 2967:  /* arm_load_acquire_exclusivehi */
    case 2966:  /* arm_load_acquire_exclusiveqi */
    case 2965:  /* arm_load_exclusivehi */
    case 2964:  /* arm_load_exclusiveqi */
    case 2963:  /* atomic_nand_fetchdi */
    case 2962:  /* atomic_nand_fetchsi */
    case 2961:  /* atomic_nand_fetchhi */
    case 2960:  /* atomic_nand_fetchqi */
    case 2959:  /* atomic_and_fetchdi */
    case 2958:  /* atomic_xor_fetchdi */
    case 2957:  /* atomic_or_fetchdi */
    case 2956:  /* atomic_sub_fetchdi */
    case 2955:  /* atomic_add_fetchdi */
    case 2954:  /* atomic_and_fetchsi */
    case 2953:  /* atomic_xor_fetchsi */
    case 2952:  /* atomic_or_fetchsi */
    case 2951:  /* atomic_sub_fetchsi */
    case 2950:  /* atomic_add_fetchsi */
    case 2949:  /* atomic_and_fetchhi */
    case 2948:  /* atomic_xor_fetchhi */
    case 2947:  /* atomic_or_fetchhi */
    case 2946:  /* atomic_sub_fetchhi */
    case 2945:  /* atomic_add_fetchhi */
    case 2944:  /* atomic_and_fetchqi */
    case 2943:  /* atomic_xor_fetchqi */
    case 2942:  /* atomic_or_fetchqi */
    case 2941:  /* atomic_sub_fetchqi */
    case 2940:  /* atomic_add_fetchqi */
    case 2939:  /* atomic_fetch_nanddi */
    case 2938:  /* atomic_fetch_nandsi */
    case 2937:  /* atomic_fetch_nandhi */
    case 2936:  /* atomic_fetch_nandqi */
    case 2935:  /* atomic_fetch_anddi */
    case 2934:  /* atomic_fetch_xordi */
    case 2933:  /* atomic_fetch_ordi */
    case 2932:  /* atomic_fetch_subdi */
    case 2931:  /* atomic_fetch_adddi */
    case 2930:  /* atomic_fetch_andsi */
    case 2929:  /* atomic_fetch_xorsi */
    case 2928:  /* atomic_fetch_orsi */
    case 2927:  /* atomic_fetch_subsi */
    case 2926:  /* atomic_fetch_addsi */
    case 2925:  /* atomic_fetch_andhi */
    case 2924:  /* atomic_fetch_xorhi */
    case 2923:  /* atomic_fetch_orhi */
    case 2922:  /* atomic_fetch_subhi */
    case 2921:  /* atomic_fetch_addhi */
    case 2920:  /* atomic_fetch_andqi */
    case 2919:  /* atomic_fetch_xorqi */
    case 2918:  /* atomic_fetch_orqi */
    case 2917:  /* atomic_fetch_subqi */
    case 2916:  /* atomic_fetch_addqi */
    case 2915:  /* atomic_nanddi */
    case 2914:  /* atomic_nandsi */
    case 2913:  /* atomic_nandhi */
    case 2912:  /* atomic_nandqi */
    case 2911:  /* atomic_anddi */
    case 2910:  /* atomic_xordi */
    case 2909:  /* atomic_ordi */
    case 2908:  /* atomic_subdi */
    case 2907:  /* atomic_adddi */
    case 2906:  /* atomic_andsi */
    case 2905:  /* atomic_xorsi */
    case 2904:  /* atomic_orsi */
    case 2903:  /* atomic_subsi */
    case 2902:  /* atomic_addsi */
    case 2901:  /* atomic_andhi */
    case 2900:  /* atomic_xorhi */
    case 2899:  /* atomic_orhi */
    case 2898:  /* atomic_subhi */
    case 2897:  /* atomic_addhi */
    case 2896:  /* atomic_andqi */
    case 2895:  /* atomic_xorqi */
    case 2894:  /* atomic_orqi */
    case 2893:  /* atomic_subqi */
    case 2892:  /* atomic_addqi */
    case 2891:  /* atomic_exchangedi */
    case 2890:  /* atomic_exchangesi */
    case 2889:  /* atomic_exchangehi */
    case 2888:  /* atomic_exchangeqi */
    case 2887:  /* atomic_compare_and_swapt1di_1 */
    case 2886:  /* atomic_compare_and_swapt1si_1 */
    case 2885:  /* atomic_compare_and_swap32di_1 */
    case 2884:  /* atomic_compare_and_swap32si_1 */
    case 2883:  /* atomic_compare_and_swapt1hi_1 */
    case 2882:  /* atomic_compare_and_swapt1qi_1 */
    case 2881:  /* atomic_compare_and_swap32hi_1 */
    case 2880:  /* atomic_compare_and_swap32qi_1 */
    case 2879:  /* arm_atomic_loaddi2_ldrd */
    case 2878:  /* atomic_storesi */
    case 2877:  /* atomic_storehi */
    case 2876:  /* atomic_storeqi */
    case 2875:  /* atomic_loadsi */
    case 2874:  /* atomic_loadhi */
    case 2873:  /* atomic_loadqi */
    case 2872:  /* *memory_barrier */
    case 2842:  /* neon_vbfcvtbf_cvtmodesf */
    case 2841:  /* neon_vbfcvtbf_cvtmodev2si */
    case 1069:  /* dls_insn */
    case 1067:  /* thumb2_lsrl */
    case 1066:  /* thumb2_lsll */
    case 1065:  /* thumb2_asrl */
    case 1064:  /* *clear_multiple */
    case 1063:  /* *clear_apsr */
    case 1044:  /* thumb2_eh_return */
    case 979:  /* *cstoresi_ne0_thumb1_insn */
    case 921:  /* no_literal_pool_sf_immediate */
    case 920:  /* no_literal_pool_df_immediate */
    case 857:  /* *cmpdf_trap_split_vfp */
    case 856:  /* *cmpdf_split_vfp */
    case 855:  /* *cmpsf_trap_split_vfp */
    case 854:  /* *cmpsf_split_vfp */
    case 509:  /* aut_nop */
    case 508:  /* pacbti_nop */
    case 507:  /* pac_nop */
    case 487:  /* *load_multiple */
    case 404:  /* arm_eh_return */
    case 401:  /* ctzsi2 */
    case 310:  /* *stack_protect_combined_test_insn */
    case 308:  /* *stack_protect_combined_set_insn */
    case 289:  /* restore_pic_register_after_call */
    case 132:  /* arm_set_apsr */
    case 131:  /* arm_get_apsr */
    case 54:  /* subvsi3_borrow */
    case 52:  /* usubvsi3_borrow */
      return TYPE_UNTYPED;

    case 67:  /* smull */
    case 68:  /* umull */
    case 71:  /* *smull_high */
    case 72:  /* *umull_high */
    case 6374:  /* *p smull */
    case 6375:  /* *p umull */
    case 6378:  /* *p *smull_high */
    case 6379:  /* *p *umull_high */
      return TYPE_UMULL;

    case 69:  /* smlal */
    case 70:  /* umlal */
    case 6376:  /* *p smlal */
    case 6377:  /* *p umlal */
      return TYPE_UMLAL;

    case 167:  /* udivsi3 */
    case 6437:  /* *p udivsi3 */
      return TYPE_UDIV;

    case 318:  /* trap */
      return TYPE_TRAP;

    case 384:  /* *push_multi */
    case 434:  /* *stm4_ */
    case 435:  /* *stm4_ia_update */
    case 436:  /* *thumb_stm4_ia_update */
    case 439:  /* *stm4_ib */
    case 440:  /* *stm4_ib_update */
    case 443:  /* *stm4_da */
    case 444:  /* *stm4_da_update */
    case 447:  /* *stm4_db */
    case 448:  /* *stm4_db_update */
    case 6569:  /* *p *stm4_ */
    case 6570:  /* *p *stm4_ia_update */
    case 6573:  /* *p *stm4_ib */
    case 6574:  /* *p *stm4_ib_update */
    case 6577:  /* *p *stm4_da */
    case 6578:  /* *p *stm4_da_update */
    case 6581:  /* *p *stm4_db */
    case 6582:  /* *p *stm4_db_update */
      return TYPE_STORE_16;

    case 453:  /* *stm3_ */
    case 454:  /* *stm3_ia_update */
    case 455:  /* *thumb_stm3_ia_update */
    case 458:  /* *stm3_ib */
    case 459:  /* *stm3_ib_update */
    case 462:  /* *stm3_da */
    case 463:  /* *stm3_da_update */
    case 466:  /* *stm3_db */
    case 467:  /* *stm3_db_update */
    case 965:  /* cpymem12b */
    case 6585:  /* *p *stm3_ */
    case 6586:  /* *p *stm3_ia_update */
    case 6589:  /* *p *stm3_ib */
    case 6590:  /* *p *stm3_ib_update */
    case 6593:  /* *p *stm3_da */
    case 6594:  /* *p *stm3_da_update */
    case 6597:  /* *p *stm3_db */
    case 6598:  /* *p *stm3_db_update */
      return TYPE_STORE_12;

    case 161:  /* unaligned_storedi */
    case 419:  /* *thumb2_strd */
    case 420:  /* *thumb2_strd_base */
    case 421:  /* *thumb2_strd_base_neg */
    case 429:  /* *arm_strd */
    case 472:  /* *stm2_ */
    case 473:  /* *stm2_ia_update */
    case 474:  /* *thumb_stm2_ia_update */
    case 477:  /* *stm2_ib */
    case 478:  /* *stm2_ib_update */
    case 481:  /* *stm2_da */
    case 482:  /* *stm2_da_update */
    case 485:  /* *stm2_db */
    case 486:  /* *stm2_db_update */
    case 966:  /* cpymem8b */
    case 1010:  /* *thumb2_storewb_pairsi */
    case 6562:  /* *p *thumb2_strd */
    case 6563:  /* *p *thumb2_strd_base */
    case 6564:  /* *p *thumb2_strd_base_neg */
    case 6566:  /* *p *arm_strd */
    case 6601:  /* *p *stm2_ */
    case 6602:  /* *p *stm2_ia_update */
    case 6605:  /* *p *stm2_ib */
    case 6606:  /* *p *stm2_ib_update */
    case 6609:  /* *p *stm2_da */
    case 6610:  /* *p *stm2_da_update */
    case 6613:  /* *p *stm2_db */
    case 6614:  /* *p *stm2_db_update */
      return TYPE_STORE_8;

    case 122:  /* *arm_umaxsi3 */
    case 123:  /* *arm_uminsi3 */
    case 124:  /* *store_minmaxsi */
    case 162:  /* unaligned_storesi */
    case 163:  /* unaligned_storehi */
    case 306:  /* probe_stack */
    case 849:  /* push_fpsysreg_insn */
    case 852:  /* lazy_store_multiple_insn */
    case 6432:  /* *p unaligned_storesi */
    case 6433:  /* *p unaligned_storehi */
    case 6535:  /* *p probe_stack */
    case 6904:  /* *p push_fpsysreg_insn */
    case 6907:  /* *p lazy_store_multiple_insn */
      return TYPE_STORE_4;

    case 73:  /* mulhisi3 */
    case 74:  /* *mulhisi3tb */
    case 75:  /* *mulhisi3bt */
    case 76:  /* *mulhisi3tt */
    case 6380:  /* *p mulhisi3 */
    case 6381:  /* *p *mulhisi3tb */
    case 6382:  /* *p *mulhisi3bt */
    case 6383:  /* *p *mulhisi3tt */
      return TYPE_SMULXY;

    case 77:  /* *arm_maddhisi4 */
    case 78:  /* arm_smlabb_setq */
    case 79:  /* maddhisi4tb */
    case 80:  /* arm_smlatb_setq */
    case 81:  /* maddhisi4tt */
    case 82:  /* arm_smlatt_setq */
    case 86:  /* arm_smlawb_insn */
    case 87:  /* arm_smlawb_setq_insn */
    case 88:  /* arm_smlawt_insn */
    case 89:  /* arm_smlawt_setq_insn */
    case 6384:  /* *p *arm_maddhisi4 */
    case 6385:  /* *p arm_smlabb_setq */
    case 6386:  /* *p maddhisi4tb */
    case 6387:  /* *p arm_smlatb_setq */
    case 6388:  /* *p maddhisi4tt */
    case 6389:  /* *p arm_smlatt_setq */
    case 6393:  /* *p arm_smlawb_insn */
    case 6394:  /* *p arm_smlawb_setq_insn */
    case 6395:  /* *p arm_smlawt_insn */
    case 6396:  /* *p arm_smlawt_setq_insn */
      return TYPE_SMLAXY;

    case 83:  /* maddhidi4 */
    case 84:  /* *maddhidi4tb */
    case 85:  /* *maddhidi4tt */
    case 6390:  /* *p maddhidi4 */
    case 6391:  /* *p *maddhidi4tb */
    case 6392:  /* *p *maddhidi4tt */
      return TYPE_SMLALXY;

    case 222:  /* arm_smlald */
    case 223:  /* arm_smlaldx */
    case 224:  /* arm_smlsld */
    case 225:  /* arm_smlsldx */
    case 6487:  /* *p arm_smlald */
    case 6488:  /* *p arm_smlaldx */
    case 6489:  /* *p arm_smlsld */
    case 6490:  /* *p arm_smlsldx */
      return TYPE_SMLALD;

    case 947:  /* *thumb1_rotrsi3 */
      return TYPE_SHIFT_REG;

    case 166:  /* divsi3 */
    case 6436:  /* *p divsi3 */
      return TYPE_SDIV;

    case 411:  /* *arm_rev */
    case 412:  /* *arm_revsh */
    case 413:  /* *arm_rev16 */
    case 414:  /* arm_rev16si2 */
    case 415:  /* arm_rev16si2_alt */
    case 6558:  /* *p *arm_rev */
      return TYPE_REV;

    case 510:  /* bti_nop */
      return TYPE_NOP;

    case 173:  /* *arm_one_cmplsi2 */
    case 174:  /* *notsi_compare0 */
    case 175:  /* *notsi_compare0_scratch */
    case 373:  /* *if_not_arith */
    case 952:  /* *thumb1_one_cmplsi2 */
    case 1059:  /* *thumb2_one_cmplsi2_short */
    case 6441:  /* *p *arm_one_cmplsi2 */
    case 6939:  /* *p *thumb2_one_cmplsi2_short */
      return TYPE_MVN_REG;

    case 94:  /* *ne_zeroextractsi */
    case 95:  /* *ne_zeroextractsi_shifted */
    case 96:  /* *ite_ne_zeroextractsi */
    case 97:  /* *ite_ne_zeroextractsi_shifted */
    case 116:  /* *andsi_iorsi3_notsi */
    case 119:  /* *arm_smax_insn */
    case 121:  /* *arm_smin_insn */
    case 125:  /* *minmax_arithsi */
    case 126:  /* *minmax_arithsi_non_canon */
    case 171:  /* *arm_abssi2 */
    case 172:  /* *arm_neg_abssi2 */
    case 279:  /* *mov_scc */
    case 281:  /* *mov_negscc */
    case 282:  /* *mov_notscc */
    case 304:  /* *check_arch2 */
    case 307:  /* probe_stack_range */
    case 309:  /* *stack_protect_set_insn */
    case 311:  /* arm_stack_protect_test_insn */
    case 312:  /* stack_protect_set_tls */
    case 313:  /* stack_protect_test_tls */
    case 314:  /* *arm_casesi_internal */
    case 334:  /* *and_scc */
    case 336:  /* *compare_scc */
    case 338:  /* *cond_arith */
    case 339:  /* *cond_sub */
    case 340:  /* *cmp_ite0 */
    case 341:  /* *cmp_ite1 */
    case 342:  /* *cmp_and */
    case 343:  /* *cmp_ior */
    case 344:  /* *ior_scc_scc */
    case 345:  /* *ior_scc_scc_cmp */
    case 346:  /* *and_scc_scc */
    case 347:  /* *and_scc_scc_cmp */
    case 348:  /* *and_scc_scc_nodom */
    case 349:  /* *negscc */
    case 350:  /* movcond_addsi */
    case 351:  /* movcond */
    case 352:  /* *ifcompare_plus_move */
    case 354:  /* *ifcompare_move_plus */
    case 356:  /* *ifcompare_arith_arith */
    case 357:  /* *if_arith_arith */
    case 358:  /* *ifcompare_arith_move */
    case 360:  /* *ifcompare_move_arith */
    case 362:  /* *ifcompare_move_not */
    case 364:  /* *ifcompare_not_move */
    case 366:  /* *ifcompare_shift_move */
    case 368:  /* *ifcompare_move_shift */
    case 370:  /* *ifcompare_shift_shift */
    case 372:  /* *ifcompare_not_arith */
    case 374:  /* *ifcompare_arith_not */
    case 375:  /* *if_arith_not */
    case 376:  /* *ifcompare_neg_move */
    case 378:  /* *ifcompare_move_neg */
    case 382:  /* *sign_extract_onebit */
    case 383:  /* *not_signextract_onebit */
    case 934:  /* *thumb1_adddi3 */
    case 936:  /* *thumb_subdi3 */
    case 948:  /* *thumb1_negdi2 */
    case 950:  /* *thumb1_abssi2 */
    case 951:  /* *thumb1_neg_abssi2 */
    case 968:  /* cbranchsi4_insn */
    case 969:  /* cbranchsi4_scratch */
    case 970:  /* *negated_cbranchsi4 */
    case 971:  /* *tbit_cbranch */
    case 972:  /* *tlobits_cbranch */
    case 973:  /* *tstsi3_cbranch */
    case 974:  /* *cbranchne_decr1 */
    case 975:  /* *addsi3_cbranch */
    case 976:  /* *addsi3_cbranch_scratch */
    case 978:  /* *cstoresi_eq0_thumb1_insn */
    case 980:  /* cstoresi_nltu_thumb1 */
    case 981:  /* cstoresi_ltu_thumb1 */
    case 982:  /* thumb1_addsi3_addgeu */
    case 992:  /* thumb1_casesi_dispatch */
    case 994:  /* prologue_thumb1_interwork */
    case 999:  /* thumb1_stack_protect_test_insn */
    case 1000:  /* *thumb2_smaxsi3 */
    case 1001:  /* *thumb2_sminsi3 */
    case 1002:  /* *thumb32_umaxsi3 */
    case 1003:  /* *thumb2_uminsi3 */
    case 1004:  /* *thumb2_abssi2 */
    case 1005:  /* *thumb2_neg_abssi2 */
    case 1008:  /* tls_load_dot_plus_four */
    case 1011:  /* *thumb2_mov_scc */
    case 1012:  /* *thumb2_mov_negscc */
    case 1013:  /* *thumb2_mov_negscc_strict_it */
    case 1014:  /* *thumb2_mov_notscc */
    case 1015:  /* *thumb2_mov_notscc_strict_it */
    case 1017:  /* *thumb2_movsfcc_soft_insn */
    case 1025:  /* *thumb2_and_scc */
    case 1026:  /* *thumb2_ior_scc */
    case 1027:  /* *thumb2_ior_scc_strict_it */
    case 1028:  /* *thumb2_cond_move */
    case 1029:  /* *thumb2_cond_arith */
    case 1030:  /* *thumb2_cond_arith_strict_it */
    case 1031:  /* *thumb2_cond_sub */
    case 1032:  /* *thumb2_negscc */
    case 1036:  /* *thumb2_movcond */
    case 1040:  /* *thumb2_casesi_internal */
    case 1041:  /* *thumb2_casesi_internal_pic */
    case 2053:  /* neon_vdup_nv2di */
    case 2080:  /* neon_vcombinev8qi */
    case 2081:  /* neon_vcombinev4hi */
    case 2082:  /* neon_vcombinev4hf */
    case 2083:  /* neon_vcombinev4bf */
    case 2084:  /* neon_vcombinev2si */
    case 2085:  /* neon_vcombinev2sf */
    case 2086:  /* neon_vcombinedi */
    case 2472:  /* neon_vtbl1v16qi */
    case 2473:  /* neon_vtbl2v16qi */
    case 2474:  /* neon_vcombinev16qi */
    case 2811:  /* vec_pack_trunc_v8hi */
    case 2812:  /* vec_pack_trunc_v4si */
    case 2813:  /* vec_pack_trunc_v2di */
    case 3034:  /* *arm_ssmulsa3 */
    case 3035:  /* *arm_usmulusa3 */
    case 6411:  /* *p *andsi_iorsi3_notsi */
    case 6439:  /* *p *arm_abssi2 */
    case 6440:  /* *p *arm_neg_abssi2 */
    case 6923:  /* *p *thumb2_abssi2 */
    case 6924:  /* *p *thumb2_neg_abssi2 */
      return TYPE_MULTIPLE;

    case 59:  /* *mulsi3_compare0 */
    case 60:  /* *mulsi3_compare0_v6 */
    case 61:  /* *mulsi_compare0_scratch */
    case 62:  /* *mulsi_compare0_scratch_v6 */
    case 938:  /* *thumb_mulsi3 */
    case 939:  /* *thumb_mulsi3_v6 */
    case 1054:  /* *thumb2_mulsi_short */
    case 1055:  /* *thumb2_mulsi_short_compare0 */
    case 1056:  /* *thumb2_mulsi_short_compare0_scratch */
    case 6938:  /* *p *thumb2_mulsi_short */
      return TYPE_MULS;

    case 56:  /* *mul */
    case 6371:  /* *p *mul */
      return TYPE_MUL;

    case 405:  /* load_tp_hard */
    case 406:  /* reload_tp_hard */
    case 918:  /* set_fpscr */
    case 919:  /* get_fpscr */
    case 6556:  /* *p load_tp_hard */
      return TYPE_MRS;

    case 287:  /* *movsfcc_soft_insn */
    case 317:  /* nop */
    case 851:  /* *clear_vfp_multiple */
    case 996:  /* *thumb1_movpc_insn */
    case 998:  /* thumb_eh_return */
    case 6906:  /* *p *clear_vfp_multiple */
      return TYPE_MOV_REG;

    case 1047:  /* *thumb2_movqi_shortim */
    case 1048:  /* *thumb2_movhi_shortim */
    case 1049:  /* *thumb2_movsi_shortim */
    case 6933:  /* *p *thumb2_movqi_shortim */
    case 6934:  /* *p *thumb2_movhi_shortim */
    case 6935:  /* *p *thumb2_movsi_shortim */
      return TYPE_MOV_IMM;

    case 63:  /* *mulsi3addsi_compare0 */
    case 64:  /* *mulsi3addsi_compare0_v6 */
    case 65:  /* *mulsi3addsi_compare0_scratch */
    case 66:  /* *mulsi3addsi_compare0_scratch_v6 */
      return TYPE_MLAS;

    case 57:  /* *mla */
    case 58:  /* *mls */
    case 6372:  /* *p *mla */
    case 6373:  /* *p *mls */
      return TYPE_MLA;

    case 108:  /* *andsi_notsi_si_compare0 */
    case 109:  /* *andsi_notsi_si_compare0_scratch */
      return TYPE_LOGICS_SHIFT_REG;

    case 941:  /* thumb1_bicsi3 */
    case 942:  /* *thumb1_iorsi3_insn */
    case 943:  /* *thumb1_xorsi3_insn */
    case 977:  /* *thumb_cmpdi_zero */
      return TYPE_LOGICS_REG;

    case 93:  /* *zeroextractsi_compare0_scratch */
    case 6398:  /* *p *zeroextractsi_compare0_scratch */
      return TYPE_LOGICS_IMM;

    case 117:  /* *smax_0 */
    case 118:  /* *smax_m1 */
    case 120:  /* *smin_0 */
    case 137:  /* *satsi_smin_shift */
    case 138:  /* *satsi_smax_shift */
    case 6412:  /* *p *smax_0 */
    case 6413:  /* *p *smax_m1 */
    case 6414:  /* *p *smin_0 */
    case 6425:  /* *p *satsi_smin_shift */
    case 6426:  /* *p *satsi_smax_shift */
      return TYPE_LOGIC_SHIFT_REG;

    case 377:  /* *if_neg_move */
    case 379:  /* *if_move_neg */
      return TYPE_LOGIC_SHIFT_IMM;

    case 104:  /* andsi_notsi_si */
    case 1061:  /* *orsi_notsi_si */
    case 6405:  /* *p andsi_notsi_si */
    case 6941:  /* *p *orsi_notsi_si */
      return TYPE_LOGIC_REG;

    case 182:  /* *compareqi_eq0 */
    case 940:  /* *thumb1_andsi3_insn */
    case 6448:  /* *p *compareqi_eq0 */
      return TYPE_LOGIC_IMM;

    case 386:  /* *load_multiple_with_writeback */
    case 387:  /* *pop_multiple_with_writeback_and_return */
    case 388:  /* *pop_multiple_with_return */
    case 390:  /* *vfp_pop_multiple_with_writeback */
    case 430:  /* *ldm4_ */
    case 431:  /* *thumb_ldm4_ia */
    case 432:  /* *ldm4_ia_update */
    case 433:  /* *thumb_ldm4_ia_update */
    case 437:  /* *ldm4_ib */
    case 438:  /* *ldm4_ib_update */
    case 441:  /* *ldm4_da */
    case 442:  /* *ldm4_da_update */
    case 445:  /* *ldm4_db */
    case 446:  /* *ldm4_db_update */
    case 6550:  /* *p *load_multiple_with_writeback */
    case 6551:  /* *p *pop_multiple_with_writeback_and_return */
    case 6552:  /* *p *pop_multiple_with_return */
    case 6567:  /* *p *ldm4_ */
    case 6568:  /* *p *ldm4_ia_update */
    case 6571:  /* *p *ldm4_ib */
    case 6572:  /* *p *ldm4_ib_update */
    case 6575:  /* *p *ldm4_da */
    case 6576:  /* *p *ldm4_da_update */
    case 6579:  /* *p *ldm4_db */
    case 6580:  /* *p *ldm4_db_update */
      return TYPE_LOAD_16;

    case 449:  /* *ldm3_ */
    case 450:  /* *thumb_ldm3_ia */
    case 451:  /* *ldm3_ia_update */
    case 452:  /* *thumb_ldm3_ia_update */
    case 456:  /* *ldm3_ib */
    case 457:  /* *ldm3_ib_update */
    case 460:  /* *ldm3_da */
    case 461:  /* *ldm3_da_update */
    case 464:  /* *ldm3_db */
    case 465:  /* *ldm3_db_update */
    case 6583:  /* *p *ldm3_ */
    case 6584:  /* *p *ldm3_ia_update */
    case 6587:  /* *p *ldm3_ib */
    case 6588:  /* *p *ldm3_ib_update */
    case 6591:  /* *p *ldm3_da */
    case 6592:  /* *p *ldm3_da_update */
    case 6595:  /* *p *ldm3_db */
    case 6596:  /* *p *ldm3_db_update */
      return TYPE_LOAD_12;

    case 157:  /* unaligned_loaddi */
    case 416:  /* *thumb2_ldrd */
    case 417:  /* *thumb2_ldrd_base */
    case 418:  /* *thumb2_ldrd_base_neg */
    case 428:  /* *arm_ldrd */
    case 468:  /* *ldm2_ */
    case 469:  /* *thumb_ldm2_ia */
    case 470:  /* *ldm2_ia_update */
    case 471:  /* *thumb_ldm2_ia_update */
    case 475:  /* *ldm2_ib */
    case 476:  /* *ldm2_ib_update */
    case 479:  /* *ldm2_da */
    case 480:  /* *ldm2_da_update */
    case 483:  /* *ldm2_db */
    case 484:  /* *ldm2_db_update */
    case 6559:  /* *p *thumb2_ldrd */
    case 6560:  /* *p *thumb2_ldrd_base */
    case 6561:  /* *p *thumb2_ldrd_base_neg */
    case 6565:  /* *p *arm_ldrd */
    case 6599:  /* *p *ldm2_ */
    case 6600:  /* *p *ldm2_ia_update */
    case 6603:  /* *p *ldm2_ib */
    case 6604:  /* *p *ldm2_ib_update */
    case 6607:  /* *p *ldm2_da */
    case 6608:  /* *p *ldm2_da_update */
    case 6611:  /* *p *ldm2_db */
    case 6612:  /* *p *ldm2_db_update */
      return TYPE_LOAD_8;

    case 158:  /* unaligned_loadsi */
    case 258:  /* pic_load_addr_unified */
    case 259:  /* pic_load_addr_32bit */
    case 260:  /* pic_load_addr_thumb1 */
    case 263:  /* tls_load_dot_plus_eight */
    case 298:  /* *arm_return */
    case 299:  /* *cond_return */
    case 300:  /* *cond_simple_return */
    case 301:  /* *cond_return_inverted */
    case 302:  /* *cond_simple_return_inverted */
    case 316:  /* *load_indirect_jump */
    case 380:  /* *arith_adjacentmem */
    case 389:  /* *ldr_with_return */
    case 402:  /* prefetch */
    case 850:  /* pop_fpsysreg_insn */
    case 853:  /* lazy_load_multiple_insn */
    case 1006:  /* *thumb2_pop_single */
    case 6429:  /* *p unaligned_loadsi */
    case 6523:  /* *p tls_load_dot_plus_eight */
    case 6533:  /* *p *arm_return */
    case 6537:  /* *p *load_indirect_jump */
    case 6549:  /* *p *arith_adjacentmem */
    case 6553:  /* *p *ldr_with_return */
    case 6905:  /* *p pop_fpsysreg_insn */
    case 6925:  /* *p *thumb2_pop_single */
      return TYPE_LOAD_4;

    case 159:  /* unaligned_loadhis */
    case 160:  /* unaligned_loadhiu */
    case 186:  /* *arm_extendqihi_insn */
    case 6430:  /* *p unaligned_loadhis */
    case 6431:  /* *p unaligned_loadhiu */
    case 6451:  /* *p *arm_extendqihi_insn */
      return TYPE_LOAD_BYTE;

    case 847:  /* *sqrtdf2_vfp */
    case 6903:  /* *p *sqrtdf2_vfp */
      return TYPE_FSQRTD;

    case 844:  /* neon_vsqrthf */
    case 845:  /* neon_vrsqrtshf */
    case 846:  /* *sqrtsf2_vfp */
    case 6902:  /* *p *sqrtsf2_vfp */
      return TYPE_FSQRTS;

    case 797:  /* mulhf3 */
    case 798:  /* *mulsf3_vfp */
    case 800:  /* *mulsf3neghf_vfp */
    case 801:  /* *negmulhf3_vfp */
    case 802:  /* *mulsf3negsf_vfp */
    case 803:  /* *negmulsf3_vfp */
    case 6866:  /* *p *mulsf3_vfp */
    case 6868:  /* *p *mulsf3negsf_vfp */
    case 6869:  /* *p *negmulsf3_vfp */
      return TYPE_FMULS;

    case 799:  /* *muldf3_vfp */
    case 804:  /* *muldf3negdf_vfp */
    case 805:  /* *negmuldf3_vfp */
    case 6867:  /* *p *muldf3_vfp */
    case 6870:  /* *p *muldf3negdf_vfp */
    case 6871:  /* *p *negmuldf3_vfp */
      return TYPE_FMULD;

    case 806:  /* *mulsf3addhf_vfp */
    case 807:  /* *mulsf3addsf_vfp */
    case 809:  /* *mulhf3subhf_vfp */
    case 810:  /* *mulsf3subsf_vfp */
    case 812:  /* *mulhf3neghfaddhf_vfp */
    case 813:  /* *mulsf3negsfaddsf_vfp */
    case 815:  /* *mulhf3neghfsubhf_vfp */
    case 816:  /* *mulsf3negsfsubsf_vfp */
    case 6872:  /* *p *mulsf3addsf_vfp */
    case 6874:  /* *p *mulsf3subsf_vfp */
    case 6876:  /* *p *mulsf3negsfaddsf_vfp */
    case 6878:  /* *p *mulsf3negsfsubsf_vfp */
      return TYPE_FMACS;

    case 808:  /* *muldf3adddf_vfp */
    case 811:  /* *muldf3subdf_vfp */
    case 814:  /* *fmuldf3negdfadddf_vfp */
    case 817:  /* *muldf3negdfsubdf_vfp */
    case 6873:  /* *p *muldf3adddf_vfp */
    case 6875:  /* *p *muldf3subdf_vfp */
    case 6877:  /* *p *fmuldf3negdfadddf_vfp */
    case 6879:  /* *p *muldf3negdfsubdf_vfp */
      return TYPE_FMACD;

    case 818:  /* fmahf4 */
    case 819:  /* fmasf4 */
    case 821:  /* fmsubhf4_fp16 */
    case 822:  /* *fmsubsf4 */
    case 824:  /* *fnmsubhf4 */
    case 825:  /* *fnmsubsf4 */
    case 827:  /* *fnmaddhf4 */
    case 828:  /* *fnmaddsf4 */
    case 6880:  /* *p fmasf4 */
    case 6882:  /* *p *fmsubsf4 */
    case 6884:  /* *p *fnmsubsf4 */
    case 6886:  /* *p *fnmaddsf4 */
      return TYPE_FFMAS;

    case 820:  /* fmadf4 */
    case 823:  /* *fmsubdf4 */
    case 826:  /* *fnmsubdf4 */
    case 829:  /* *fnmadddf4 */
    case 6881:  /* *p fmadf4 */
    case 6883:  /* *p *fmsubdf4 */
    case 6885:  /* *p *fnmsubdf4 */
    case 6887:  /* *p *fnmadddf4 */
      return TYPE_FFMAD;

    case 775:  /* *abssf2_vfp */
    case 777:  /* *negsf2_vfp */
    case 779:  /* abshf2 */
    case 780:  /* neghf2 */
    case 6856:  /* *p *abssf2_vfp */
    case 6858:  /* *p *negsf2_vfp */
      return TYPE_FFARITHS;

    case 776:  /* *absdf2_vfp */
    case 778:  /* *negdf2_vfp */
    case 6857:  /* *p *absdf2_vfp */
    case 6859:  /* *p *negdf2_vfp */
      return TYPE_FFARITHD;

    case 794:  /* divhf3 */
    case 795:  /* *divsf3_vfp */
    case 6864:  /* *p *divsf3_vfp */
      return TYPE_FDIVS;

    case 796:  /* *divdf3_vfp */
    case 6865:  /* *p *divdf3_vfp */
      return TYPE_FDIVD;

    case 283:  /* *cmovsf */
    case 284:  /* *cmovdf */
    case 285:  /* *cmovhf */
      return TYPE_FCSEL;

    case 858:  /* *cmpsf_vfp */
    case 859:  /* *cmpsf_trap_vfp */
    case 6908:  /* *p *cmpsf_vfp */
    case 6909:  /* *p *cmpsf_trap_vfp */
      return TYPE_FCMPS;

    case 860:  /* *cmpdf_vfp */
    case 861:  /* *cmpdf_trap_vfp */
    case 6910:  /* *p *cmpdf_vfp */
    case 6911:  /* *p *cmpdf_trap_vfp */
      return TYPE_FCMPD;

    case 788:  /* addhf3 */
    case 789:  /* *addsf3_vfp */
    case 791:  /* subhf3 */
    case 792:  /* *subsf3_vfp */
    case 6860:  /* *p *addsf3_vfp */
    case 6862:  /* *p *subsf3_vfp */
      return TYPE_FADDS;

    case 790:  /* *adddf3_vfp */
    case 793:  /* *subdf3_vfp */
    case 6861:  /* *p *adddf3_vfp */
    case 6863:  /* *p *subdf3_vfp */
      return TYPE_FADDD;

    case 883:  /* *push_multi_vfp */
      return TYPE_F_STORED;

    case 884:  /* btruncsf2 */
    case 885:  /* ceilsf2 */
    case 886:  /* floorsf2 */
    case 887:  /* nearbyintsf2 */
    case 888:  /* rintsf2 */
    case 889:  /* roundsf2 */
    case 6917:  /* *p btruncsf2 */
    case 6918:  /* *p nearbyintsf2 */
    case 6919:  /* *p rintsf2 */
      return TYPE_F_RINTS;

    case 890:  /* btruncdf2 */
    case 891:  /* ceildf2 */
    case 892:  /* floordf2 */
    case 893:  /* nearbyintdf2 */
    case 894:  /* rintdf2 */
    case 895:  /* rounddf2 */
    case 6920:  /* *p btruncdf2 */
    case 6921:  /* *p nearbyintdf2 */
    case 6922:  /* *p rintdf2 */
      return TYPE_F_RINTD;

    case 908:  /* smaxsf3 */
    case 910:  /* sminsf3 */
    case 912:  /* neon_vmaxnmhf */
    case 913:  /* neon_vminnmhf */
    case 914:  /* fmaxsf3 */
    case 915:  /* fminsf3 */
      return TYPE_F_MINMAXS;

    case 909:  /* smaxdf3 */
    case 911:  /* smindf3 */
    case 916:  /* fmaxdf3 */
    case 917:  /* fmindf3 */
      return TYPE_F_MINMAXD;

    case 848:  /* *movcc_vfp */
      return TYPE_F_FLAG;

    case 840:  /* *floatsisf2_vfp */
    case 841:  /* *floatsidf2_vfp */
    case 842:  /* floatunssisf2 */
    case 843:  /* floatunssidf2 */
    case 862:  /* *combine_vcvt_f32_u32 */
    case 863:  /* *combine_vcvt_f32_s32 */
    case 864:  /* *combine_vcvt_f64_u32 */
    case 865:  /* *combine_vcvt_f64_s32 */
    case 867:  /* neon_vcvthshf */
    case 868:  /* neon_vcvthuhf */
    case 871:  /* neon_vcvths_nhf_unspec */
    case 872:  /* neon_vcvthu_nhf_unspec */
    case 6898:  /* *p *floatsisf2_vfp */
    case 6899:  /* *p *floatsidf2_vfp */
    case 6900:  /* *p floatunssisf2 */
    case 6901:  /* *p floatunssidf2 */
    case 6912:  /* *p *combine_vcvt_f32_u32 */
    case 6913:  /* *p *combine_vcvt_f32_s32 */
    case 6914:  /* *p *combine_vcvt_f64_u32 */
    case 6915:  /* *p *combine_vcvt_f64_s32 */
      return TYPE_F_CVTI2F;

    case 836:  /* *truncsisf2_vfp */
    case 837:  /* *truncsidf2_vfp */
    case 838:  /* fixuns_truncsfsi2 */
    case 839:  /* fixuns_truncdfsi2 */
    case 866:  /* *combine_vcvtf2i */
    case 869:  /* neon_vcvthssi */
    case 870:  /* neon_vcvthusi */
    case 873:  /* neon_vcvths_nsi_unspec */
    case 874:  /* neon_vcvthu_nsi_unspec */
    case 875:  /* neon_vcvtahssi */
    case 876:  /* neon_vcvtahusi */
    case 877:  /* neon_vcvtmhssi */
    case 878:  /* neon_vcvtmhusi */
    case 879:  /* neon_vcvtnhssi */
    case 880:  /* neon_vcvtnhusi */
    case 881:  /* neon_vcvtphssi */
    case 882:  /* neon_vcvtphusi */
    case 896:  /* lceilsfsi2 */
    case 897:  /* lfloorsfsi2 */
    case 898:  /* lroundsfsi2 */
    case 899:  /* lceilusfsi2 */
    case 900:  /* lfloorusfsi2 */
    case 901:  /* lroundusfsi2 */
    case 902:  /* lceildfsi2 */
    case 903:  /* lfloordfsi2 */
    case 904:  /* lrounddfsi2 */
    case 905:  /* lceiludfsi2 */
    case 906:  /* lfloorudfsi2 */
    case 907:  /* lroundudfsi2 */
    case 6894:  /* *p *truncsisf2_vfp */
    case 6895:  /* *p *truncsidf2_vfp */
    case 6896:  /* *p fixuns_truncsfsi2 */
    case 6897:  /* *p fixuns_truncdfsi2 */
    case 6916:  /* *p *combine_vcvtf2i */
      return TYPE_F_CVTF2I;

    case 830:  /* *extendsfdf2_vfp */
    case 831:  /* *truncdfsf2_vfp */
    case 832:  /* extendhfsf2 */
    case 833:  /* *truncdfhf2 */
    case 834:  /* *extendhfdf2 */
    case 835:  /* truncsfhf2 */
    case 2837:  /* neon_vbfcvtsf */
    case 6888:  /* *p *extendsfdf2_vfp */
    case 6889:  /* *p *truncdfsf2_vfp */
    case 6890:  /* *p extendhfsf2 */
    case 6891:  /* *p *truncdfhf2 */
    case 6892:  /* *p *extendhfdf2 */
    case 6893:  /* *p truncsfhf2 */
      return TYPE_F_CVT;

    case 422:  /* arm_crc32b */
    case 423:  /* arm_crc32h */
    case 424:  /* arm_crc32w */
    case 425:  /* arm_crc32cb */
    case 426:  /* arm_crc32ch */
    case 427:  /* arm_crc32cw */
      return TYPE_CRC;

    case 1033:  /* *thumb2_csinv */
    case 1034:  /* *thumb2_csinc */
    case 1035:  /* *thumb2_csneg */
      return TYPE_CSEL;

    case 276:  /* *deleted_compare */
    case 391:  /* align_4 */
    case 392:  /* align_8 */
    case 393:  /* consttable_end */
    case 394:  /* consttable_1 */
    case 395:  /* consttable_2 */
    case 396:  /* consttable_4 */
    case 397:  /* consttable_8 */
    case 398:  /* consttable_16 */
    case 403:  /* force_register_use */
      return TYPE_NO_INSN;

    case 399:  /* clzsi2 */
    case 400:  /* rbitsi2 */
    case 6554:  /* *p clzsi2 */
    case 6555:  /* *p rbitsi2 */
      return TYPE_CLZ;

    case 290:  /* *call_reg_armv5 */
    case 291:  /* *call_reg_arm */
    case 292:  /* *call_value_reg_armv5 */
    case 293:  /* *call_value_reg_arm */
    case 294:  /* *call_symbol */
    case 295:  /* *call_value_symbol */
    case 296:  /* *sibcall_insn */
    case 297:  /* *sibcall_value_insn */
    case 984:  /* *call_reg_thumb1_v5 */
    case 985:  /* *nonsecure_call_reg_thumb1_v5 */
    case 986:  /* *call_reg_thumb1 */
    case 987:  /* *call_value_reg_thumb1_v5 */
    case 988:  /* *nonsecure_call_value_reg_thumb1_v5 */
    case 989:  /* *call_value_reg_thumb1 */
    case 990:  /* *call_insn */
    case 991:  /* *call_value_insn */
    case 1018:  /* *call_reg_thumb2 */
    case 1019:  /* *nonsecure_call_reg_thumb2_fpcxt */
    case 1020:  /* *nonsecure_call_reg_thumb2 */
    case 1021:  /* *call_value_reg_thumb2 */
    case 1022:  /* *nonsecure_call_value_reg_thumb2_fpcxt */
    case 1023:  /* *nonsecure_call_value_reg_thumb2 */
      return TYPE_CALL;

    case 277:  /* arm_cond_branch */
    case 278:  /* *arm_cond_branch_reversed */
    case 288:  /* *arm_jump */
    case 303:  /* *arm_simple_return */
    case 315:  /* *arm_indirect_jump */
    case 407:  /* load_tp_soft_fdpic */
    case 408:  /* load_tp_soft */
    case 409:  /* tlscall */
    case 983:  /* *thumb_jump */
    case 993:  /* *thumb1_indirect_jump */
    case 997:  /* *thumb1_tablejump */
    case 1024:  /* *thumb2_indirect_jump */
    case 1042:  /* *thumb2_return */
    case 1043:  /* *thumb2_cmse_entry_return */
    case 1068:  /* *doloop_end_internal */
    case 6532:  /* *p *arm_jump */
    case 6534:  /* *p *arm_simple_return */
    case 6536:  /* *p *arm_indirect_jump */
      return TYPE_BRANCH;

    case 305:  /* blockage */
    case 385:  /* stack_tie */
    case 506:  /* *speculation_barrier_insn */
    case 995:  /* *epilogue_insns */
      return TYPE_BLOCK;

    case 98:  /* insv_zero */
    case 99:  /* insv_t2 */
    case 100:  /* *bfi */
    case 101:  /* *bfi_alt1 */
    case 102:  /* *bfi_alt2 */
    case 103:  /* *bfi_alt3 */
    case 164:  /* *extv_reg */
    case 165:  /* extzv_t2 */
    case 6399:  /* *p insv_zero */
    case 6400:  /* *p insv_t2 */
    case 6401:  /* *p *bfi */
    case 6402:  /* *p *bfi_alt1 */
    case 6403:  /* *p *bfi_alt2 */
    case 6404:  /* *p *bfi_alt3 */
    case 6434:  /* *p *extv_reg */
    case 6435:  /* *p extzv_t2 */
      return TYPE_BFM;

    case 1:  /* *addsi3_cin_vout_reg_insn */
    case 4:  /* *addsi3_cin_cout_reg_insn */
    case 8:  /* addsi3_compareV_reg */
    case 9:  /* *addsi3_compareV_reg_nosum */
    case 15:  /* *compare_negsi_si */
    case 16:  /* cmpsi2_addneg */
    case 26:  /* subsi3_compare1 */
    case 27:  /* subvsi3 */
    case 937:  /* thumb1_subsi3_insn */
    case 6355:  /* *p *compare_negsi_si */
      return TYPE_ALUS_SREG;

    case 2:  /* *addsi3_cin_vout_imm_insn */
    case 3:  /* *addsi3_cin_vout_0_insn */
    case 5:  /* *addsi3_cin_cout_imm_insn */
    case 6:  /* *addsi3_cin_cout_0_insn */
    case 10:  /* subvsi3_intmin */
    case 11:  /* addsi3_compareV_imm */
    case 12:  /* addsi3_compareV_imm_nosum */
    case 28:  /* subvsi3_imm1 */
    case 48:  /* rsb_imm_compare */
    case 49:  /* rsb_imm_compare_scratch */
    case 50:  /* rscsi3_CC_NVout_scratch */
    case 51:  /* rscsi3_CC_Bout_scratch */
    case 53:  /* usubvsi3_borrow_imm */
    case 55:  /* subvsi3_borrow_imm */
    case 133:  /* satsi_smin */
    case 134:  /* satsi_smin_setq */
    case 135:  /* satsi_smax */
    case 136:  /* satsi_smax_setq */
    case 169:  /* negsi2_0compare */
    case 264:  /* *movsi_compare0 */
    case 6421:  /* *p satsi_smin */
    case 6422:  /* *p satsi_smin_setq */
    case 6423:  /* *p satsi_smax */
    case 6424:  /* *p satsi_smax_setq */
      return TYPE_ALUS_IMM;

    case 127:  /* arm_qadd_insn */
    case 128:  /* arm_qadd_setq_insn */
    case 129:  /* arm_qsub_insn */
    case 130:  /* arm_qsub_setq_insn */
    case 190:  /* arm_sxtb16 */
    case 191:  /* arm_uxtb16 */
    case 192:  /* arm_qadd8 */
    case 193:  /* arm_qsub8 */
    case 194:  /* arm_shadd8 */
    case 195:  /* arm_shsub8 */
    case 196:  /* arm_uhadd8 */
    case 197:  /* arm_uhsub8 */
    case 198:  /* arm_uqadd8 */
    case 199:  /* arm_uqsub8 */
    case 200:  /* arm_qadd16 */
    case 201:  /* arm_qasx */
    case 202:  /* arm_qsax */
    case 203:  /* arm_qsub16 */
    case 204:  /* arm_shadd16 */
    case 205:  /* arm_shasx */
    case 206:  /* arm_shsax */
    case 207:  /* arm_shsub16 */
    case 208:  /* arm_uhadd16 */
    case 209:  /* arm_uhasx */
    case 210:  /* arm_uhsax */
    case 211:  /* arm_uhsub16 */
    case 212:  /* arm_uqadd16 */
    case 213:  /* arm_uqasx */
    case 214:  /* arm_uqsax */
    case 215:  /* arm_uqsub16 */
    case 216:  /* arm_smusd */
    case 217:  /* arm_smusdx */
    case 218:  /* arm_sxtab16 */
    case 219:  /* arm_uxtab16 */
    case 220:  /* arm_usad8 */
    case 221:  /* arm_usada8 */
    case 2990:  /* *arm_addv4qq3 */
    case 2991:  /* *arm_addv2hq3 */
    case 2992:  /* *arm_addv2ha3 */
    case 2993:  /* usaddv4uqq3 */
    case 2994:  /* usaddv2uhq3 */
    case 2995:  /* usadduqq3 */
    case 2996:  /* usadduhq3 */
    case 2997:  /* usaddv2uha3 */
    case 2998:  /* usadduha3 */
    case 2999:  /* *arm_ssaddv4qq3 */
    case 3000:  /* *arm_ssaddv2hq3 */
    case 3001:  /* *arm_ssaddqq3 */
    case 3002:  /* *arm_ssaddhq3 */
    case 3003:  /* *arm_ssaddv2ha3 */
    case 3004:  /* *arm_ssaddha3 */
    case 3005:  /* *arm_ssaddsq3 */
    case 3006:  /* *arm_ssaddsa3 */
    case 3017:  /* *arm_subv4qq3 */
    case 3018:  /* *arm_subv2hq3 */
    case 3019:  /* *arm_subv2ha3 */
    case 3020:  /* ussubv4uqq3 */
    case 3021:  /* ussubv2uhq3 */
    case 3022:  /* ussubuqq3 */
    case 3023:  /* ussubuhq3 */
    case 3024:  /* ussubv2uha3 */
    case 3025:  /* ussubuha3 */
    case 3026:  /* *arm_sssubv4qq3 */
    case 3027:  /* *arm_sssubv2hq3 */
    case 3028:  /* *arm_sssubqq3 */
    case 3029:  /* *arm_sssubhq3 */
    case 3030:  /* *arm_sssubv2ha3 */
    case 3031:  /* *arm_sssubha3 */
    case 3032:  /* *arm_sssubsq3 */
    case 3033:  /* *arm_sssubsa3 */
    case 6415:  /* *p arm_qadd_insn */
    case 6416:  /* *p arm_qadd_setq_insn */
    case 6417:  /* *p arm_qsub_insn */
    case 6418:  /* *p arm_qsub_setq_insn */
    case 6455:  /* *p arm_sxtb16 */
    case 6456:  /* *p arm_uxtb16 */
    case 6457:  /* *p arm_qadd8 */
    case 6458:  /* *p arm_qsub8 */
    case 6459:  /* *p arm_shadd8 */
    case 6460:  /* *p arm_shsub8 */
    case 6461:  /* *p arm_uhadd8 */
    case 6462:  /* *p arm_uhsub8 */
    case 6463:  /* *p arm_uqadd8 */
    case 6464:  /* *p arm_uqsub8 */
    case 6465:  /* *p arm_qadd16 */
    case 6466:  /* *p arm_qasx */
    case 6467:  /* *p arm_qsax */
    case 6468:  /* *p arm_qsub16 */
    case 6469:  /* *p arm_shadd16 */
    case 6470:  /* *p arm_shasx */
    case 6471:  /* *p arm_shsax */
    case 6472:  /* *p arm_shsub16 */
    case 6473:  /* *p arm_uhadd16 */
    case 6474:  /* *p arm_uhasx */
    case 6475:  /* *p arm_uhsax */
    case 6476:  /* *p arm_uhsub16 */
    case 6477:  /* *p arm_uqadd16 */
    case 6478:  /* *p arm_uqasx */
    case 6479:  /* *p arm_uqsax */
    case 6480:  /* *p arm_uqsub16 */
    case 6481:  /* *p arm_smusd */
    case 6482:  /* *p arm_smusdx */
    case 6483:  /* *p arm_sxtab16 */
    case 6484:  /* *p arm_uxtab16 */
    case 6485:  /* *p arm_usad8 */
    case 6486:  /* *p arm_usada8 */
    case 6981:  /* *p *arm_addv4qq3 */
    case 6982:  /* *p *arm_addv2hq3 */
    case 6983:  /* *p *arm_addv2ha3 */
    case 6984:  /* *p usaddv4uqq3 */
    case 6985:  /* *p usaddv2uhq3 */
    case 6986:  /* *p usadduqq3 */
    case 6987:  /* *p usadduhq3 */
    case 6988:  /* *p usaddv2uha3 */
    case 6989:  /* *p usadduha3 */
    case 6990:  /* *p *arm_ssaddv4qq3 */
    case 6991:  /* *p *arm_ssaddv2hq3 */
    case 6992:  /* *p *arm_ssaddqq3 */
    case 6993:  /* *p *arm_ssaddhq3 */
    case 6994:  /* *p *arm_ssaddv2ha3 */
    case 6995:  /* *p *arm_ssaddha3 */
    case 6996:  /* *p *arm_ssaddsq3 */
    case 6997:  /* *p *arm_ssaddsa3 */
    case 7008:  /* *p *arm_subv4qq3 */
    case 7009:  /* *p *arm_subv2hq3 */
    case 7010:  /* *p *arm_subv2ha3 */
    case 7011:  /* *p ussubv4uqq3 */
    case 7012:  /* *p ussubv2uhq3 */
    case 7013:  /* *p ussubuqq3 */
    case 7014:  /* *p ussubuhq3 */
    case 7015:  /* *p ussubv2uha3 */
    case 7016:  /* *p ussubuha3 */
    case 7017:  /* *p *arm_sssubv4qq3 */
    case 7018:  /* *p *arm_sssubv2hq3 */
    case 7019:  /* *p *arm_sssubqq3 */
    case 7020:  /* *p *arm_sssubhq3 */
    case 7021:  /* *p *arm_sssubv2ha3 */
    case 7022:  /* *p *arm_sssubha3 */
    case 7023:  /* *p *arm_sssubsq3 */
    case 7024:  /* *p *arm_sssubsa3 */
      return TYPE_ALU_DSP_REG;

    case 178:  /* *arm_zero_extendhisi2addsi */
    case 181:  /* *arm_zero_extendqisi2addsi */
    case 185:  /* *arm_extendhisi2addsi */
    case 189:  /* *arm_extendqisi2addsi */
    case 6444:  /* *p *arm_zero_extendhisi2addsi */
    case 6447:  /* *p *arm_zero_extendqisi2addsi */
    case 6454:  /* *p *arm_extendqisi2addsi */
      return TYPE_ALU_SHIFT_REG;

    case 226:  /* arm_sadd8 */
    case 227:  /* arm_ssub8 */
    case 228:  /* arm_uadd8 */
    case 229:  /* arm_usub8 */
    case 230:  /* arm_sadd16 */
    case 231:  /* arm_sasx */
    case 232:  /* arm_ssax */
    case 233:  /* arm_ssub16 */
    case 234:  /* arm_uadd16 */
    case 235:  /* arm_uasx */
    case 236:  /* arm_usax */
    case 237:  /* arm_usub16 */
    case 238:  /* arm_smlad_insn */
    case 239:  /* arm_smlad_setq_insn */
    case 240:  /* arm_smladx_insn */
    case 241:  /* arm_smladx_setq_insn */
    case 242:  /* arm_smlsd_insn */
    case 243:  /* arm_smlsd_setq_insn */
    case 244:  /* arm_smlsdx_insn */
    case 245:  /* arm_smlsdx_setq_insn */
    case 246:  /* arm_smuad_insn */
    case 247:  /* arm_smuad_setq_insn */
    case 248:  /* arm_smuadx_insn */
    case 249:  /* arm_smuadx_setq_insn */
    case 250:  /* arm_ssat16_insn */
    case 251:  /* arm_ssat16_setq_insn */
    case 252:  /* arm_usat16_insn */
    case 253:  /* arm_usat16_setq_insn */
    case 254:  /* arm_sel */
    case 256:  /* *arm_movt */
    case 261:  /* pic_add_dot_plus_four */
    case 262:  /* pic_add_dot_plus_eight */
    case 410:  /* *arm_movtas_ze */
    case 1045:  /* *thumb2_alusi3_short */
    case 1051:  /* *thumb2_subsi_short */
    case 1060:  /* *thumb2_negsi2_short */
    case 2980:  /* addqq3 */
    case 2981:  /* addhq3 */
    case 2982:  /* addsq3 */
    case 2983:  /* adduqq3 */
    case 2984:  /* adduhq3 */
    case 2985:  /* addusq3 */
    case 2986:  /* addha3 */
    case 2987:  /* addsa3 */
    case 2988:  /* adduha3 */
    case 2989:  /* addusa3 */
    case 3007:  /* subqq3 */
    case 3008:  /* subhq3 */
    case 3009:  /* subsq3 */
    case 3010:  /* subuqq3 */
    case 3011:  /* subuhq3 */
    case 3012:  /* subusq3 */
    case 3013:  /* subha3 */
    case 3014:  /* subsa3 */
    case 3015:  /* subuha3 */
    case 3016:  /* subusa3 */
    case 6491:  /* *p arm_sadd8 */
    case 6492:  /* *p arm_ssub8 */
    case 6493:  /* *p arm_uadd8 */
    case 6494:  /* *p arm_usub8 */
    case 6495:  /* *p arm_sadd16 */
    case 6496:  /* *p arm_sasx */
    case 6497:  /* *p arm_ssax */
    case 6498:  /* *p arm_ssub16 */
    case 6499:  /* *p arm_uadd16 */
    case 6500:  /* *p arm_uasx */
    case 6501:  /* *p arm_usax */
    case 6502:  /* *p arm_usub16 */
    case 6503:  /* *p arm_smlad_insn */
    case 6504:  /* *p arm_smlad_setq_insn */
    case 6505:  /* *p arm_smladx_insn */
    case 6506:  /* *p arm_smladx_setq_insn */
    case 6507:  /* *p arm_smlsd_insn */
    case 6508:  /* *p arm_smlsd_setq_insn */
    case 6509:  /* *p arm_smlsdx_insn */
    case 6510:  /* *p arm_smlsdx_setq_insn */
    case 6511:  /* *p arm_smuad_insn */
    case 6512:  /* *p arm_smuad_setq_insn */
    case 6513:  /* *p arm_smuadx_insn */
    case 6514:  /* *p arm_smuadx_setq_insn */
    case 6515:  /* *p arm_ssat16_insn */
    case 6516:  /* *p arm_ssat16_setq_insn */
    case 6517:  /* *p arm_usat16_insn */
    case 6518:  /* *p arm_usat16_setq_insn */
    case 6519:  /* *p arm_sel */
    case 6520:  /* *p *arm_movt */
    case 6522:  /* *p pic_add_dot_plus_eight */
    case 6557:  /* *p *arm_movtas_ze */
    case 6931:  /* *p *thumb2_alusi3_short */
    case 6937:  /* *p *thumb2_subsi_short */
    case 6940:  /* *p *thumb2_negsi2_short */
    case 6971:  /* *p addqq3 */
    case 6972:  /* *p addhq3 */
    case 6973:  /* *p addsq3 */
    case 6974:  /* *p adduqq3 */
    case 6975:  /* *p adduhq3 */
    case 6976:  /* *p addusq3 */
    case 6977:  /* *p addha3 */
    case 6978:  /* *p addsa3 */
    case 6979:  /* *p adduha3 */
    case 6980:  /* *p addusa3 */
    case 6998:  /* *p subqq3 */
    case 6999:  /* *p subhq3 */
    case 7000:  /* *p subsq3 */
    case 7001:  /* *p subuqq3 */
    case 7002:  /* *p subuhq3 */
    case 7003:  /* *p subusq3 */
    case 7004:  /* *p subha3 */
    case 7005:  /* *p subsa3 */
    case 7006:  /* *p subuha3 */
    case 7007:  /* *p subusa3 */
      return TYPE_ALU_SREG;

    case 168:  /* *arm_negsi2 */
    case 949:  /* *thumb1_negsi2 */
    case 3037:  /* arm_usatsihi */
    case 6438:  /* *p *arm_negsi2 */
    case 7026:  /* *p arm_usatsihi */
      return TYPE_ALU_IMM;

    case 25:  /* *addsi3_carryin_clobercc */
      return TYPE_ADCS_REG;

    case 33:  /* cmpsi3_carryin_CC_NVout */
    case 34:  /* cmpsi3_carryin_CC_Bout */
    case 280:  /* *negscc_borrow */
      return TYPE_ADC_REG;

    case 22:  /* add0si3_carryin */
    case 30:  /* rsbsi_carryin_reg */
    case 35:  /* cmpsi3_imm_carryin_CC_NVout */
    case 36:  /* cmpsi3_imm_carryin_CC_Bout */
    case 37:  /* cmpsi3_0_carryin_CC_NVout */
    case 38:  /* cmpsi3_0_carryin_CC_Bout */
    case 39:  /* *subsi3_carryin_const */
    case 40:  /* *subsi3_carryin_const0 */
    case 6359:  /* *p add0si3_carryin */
    case 6363:  /* *p rsbsi_carryin_reg */
      return TYPE_ADC_IMM;

    default:
      return TYPE_MVE_MOVE;

    }
}

enum attr_use_literal_pool
get_attr_use_literal_pool (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 6855:  /* *p *movdf_vfp */
    case 770:  /* *thumb2_movdf_vfp */
    case 769:  /* *movdf_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 4) && (
#line 225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(CONSTANT_P (operands[1]))))
        {
	  return USE_LITERAL_POOL_YES;
        }
      else
        {
	  return USE_LITERAL_POOL_NO;
        }

    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 768:  /* *thumb2_movsf_vfp */
    case 767:  /* *movsf_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 3) && (
#line 225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(CONSTANT_P (operands[1]))))
        {
	  return USE_LITERAL_POOL_YES;
        }
      else
        {
	  return USE_LITERAL_POOL_NO;
        }

    case 6850:  /* *p *movdi_vfp */
    case 760:  /* *movdi_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 10) && (
#line 225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(CONSTANT_P (operands[1]))))
        {
	  return USE_LITERAL_POOL_YES;
        }
      else
        {
	  return USE_LITERAL_POOL_NO;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 12) && (
#line 225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(CONSTANT_P (operands[1]))))
        {
	  return USE_LITERAL_POOL_YES;
        }
      else
        {
	  return USE_LITERAL_POOL_NO;
        }

    case 6848:  /* *p *arm_movsi_vfp */
    case 758:  /* *arm_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 9) && (
#line 225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(CONSTANT_P (operands[1]))))
        {
	  return USE_LITERAL_POOL_YES;
        }
      else
        {
	  return USE_LITERAL_POOL_NO;
        }

    case 531:  /* *iwmmxt_movsi_insn */
    case 530:  /* *iwmmxt_arm_movdi */
      extract_constrain_insn_cached (insn);
      if ((which_alternative == 13) && (
#line 225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(CONSTANT_P (operands[1]))))
        {
	  return USE_LITERAL_POOL_YES;
        }
      else
        {
	  return USE_LITERAL_POOL_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      extract_constrain_insn_cached (insn);
      if ((((cached_type = get_attr_type (insn)) == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD)) && (
#line 225 "../../../../../../../work-shared/gcc-13.3.0-r0/gcc-13.3.0/gcc/config/arm/arm.md"
(CONSTANT_P (operands[1]))))
        {
	  return USE_LITERAL_POOL_YES;
        }
      else
        {
	  return USE_LITERAL_POOL_NO;
        }

    default:
      return USE_LITERAL_POOL_NO;

    }
}

enum attr_vqh_mnem
get_attr_vqh_mnem (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case 1401:  /* quad_halves_smaxv4si */
    case 1403:  /* quad_halves_umaxv4si */
    case 1406:  /* quad_halves_smaxv4sf */
    case 1409:  /* quad_halves_smaxv8hi */
    case 1411:  /* quad_halves_umaxv8hi */
    case 1414:  /* quad_halves_smaxv16qi */
    case 1416:  /* quad_halves_umaxv16qi */
      return VQH_MNEM_VMAX;

    case 1400:  /* quad_halves_sminv4si */
    case 1402:  /* quad_halves_uminv4si */
    case 1405:  /* quad_halves_sminv4sf */
    case 1408:  /* quad_halves_sminv8hi */
    case 1410:  /* quad_halves_uminv8hi */
    case 1413:  /* quad_halves_sminv16qi */
    case 1415:  /* quad_halves_uminv16qi */
      return VQH_MNEM_VMIN;

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      return VQH_MNEM_VADD;

    }
}

enum attr_wmmxt_transfer_c3
get_attr_wmmxt_transfer_c3 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_TMIA) || (cached_type == TYPE_WMMX_TMIAPH) || (cached_type == TYPE_WMMX_TMIAXY))
        {
	  return WMMXT_TRANSFER_C3_YES;
        }
      else
        {
	  return WMMXT_TRANSFER_C3_NO;
        }

    case 6753:  /* *p iwmmxt_tmiatt */
    case 6752:  /* *p iwmmxt_tmiabt */
    case 6751:  /* *p iwmmxt_tmiatb */
    case 6750:  /* *p iwmmxt_tmiabb */
    case 6749:  /* *p iwmmxt_tmiaph */
    case 6748:  /* *p iwmmxt_tmia */
    case 663:  /* iwmmxt_tmiatt */
    case 662:  /* iwmmxt_tmiabt */
    case 661:  /* iwmmxt_tmiatb */
    case 660:  /* iwmmxt_tmiabb */
    case 659:  /* iwmmxt_tmiaph */
    case 658:  /* iwmmxt_tmia */
      return WMMXT_TRANSFER_C3_YES;

    default:
      return WMMXT_TRANSFER_C3_NO;

    }
}

enum attr_wmmxt_transfer_c2
get_attr_wmmxt_transfer_c2 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 3)
        {
	  return WMMXT_TRANSFER_C2_YES;
        }
      else
        {
	  return WMMXT_TRANSFER_C2_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_TEXTRM) || (cached_type == TYPE_WMMX_TMOVMSK) || (cached_type == TYPE_WMMX_TMRC) || (cached_type == TYPE_WMMX_TMRRC))
        {
	  return WMMXT_TRANSFER_C2_YES;
        }
      else
        {
	  return WMMXT_TRANSFER_C2_NO;
        }

    case 6756:  /* *p iwmmxt_tmovmskw */
    case 6755:  /* *p iwmmxt_tmovmskh */
    case 6754:  /* *p iwmmxt_tmovmskb */
    case 6675:  /* *p iwmmxt_textrmw */
    case 6674:  /* *p iwmmxt_textrmsh */
    case 6673:  /* *p iwmmxt_textrmuh */
    case 6672:  /* *p iwmmxt_textrmsb */
    case 6671:  /* *p iwmmxt_textrmub */
    case 666:  /* iwmmxt_tmovmskw */
    case 665:  /* iwmmxt_tmovmskh */
    case 664:  /* iwmmxt_tmovmskb */
    case 585:  /* iwmmxt_textrmw */
    case 584:  /* iwmmxt_textrmsh */
    case 583:  /* iwmmxt_textrmuh */
    case 582:  /* iwmmxt_textrmsb */
    case 581:  /* iwmmxt_textrmub */
      return WMMXT_TRANSFER_C2_YES;

    default:
      return WMMXT_TRANSFER_C2_NO;

    }
}

enum attr_wmmxt_transfer_c1
get_attr_wmmxt_transfer_c1 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 4)
        {
	  return WMMXT_TRANSFER_C1_YES;
        }
      else
        {
	  return WMMXT_TRANSFER_C1_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_TBCST) || (cached_type == TYPE_WMMX_TINSR) || (cached_type == TYPE_WMMX_TMCR) || (cached_type == TYPE_WMMX_TMCRR))
        {
	  return WMMXT_TRANSFER_C1_YES;
        }
      else
        {
	  return WMMXT_TRANSFER_C1_NO;
        }

    case 6670:  /* *p iwmmxt_tinsrw */
    case 6669:  /* *p iwmmxt_tinsrh */
    case 6668:  /* *p iwmmxt_tinsrb */
    case 6618:  /* *p tbcstv2si */
    case 6617:  /* *p tbcstv4hi */
    case 6616:  /* *p tbcstv8qi */
    case 580:  /* iwmmxt_tinsrw */
    case 579:  /* iwmmxt_tinsrh */
    case 578:  /* iwmmxt_tinsrb */
    case 525:  /* tbcstv2si */
    case 524:  /* tbcstv4hi */
    case 523:  /* tbcstv8qi */
      return WMMXT_TRANSFER_C1_YES;

    default:
      return WMMXT_TRANSFER_C1_NO;

    }
}

enum attr_wmmxt_alu_c3
get_attr_wmmxt_alu_c3 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (get_attr_type (insn) == TYPE_WMMX_WSAD)
        {
	  return WMMXT_ALU_C3_YES;
        }
      else
        {
	  return WMMXT_ALU_C3_NO;
        }

    case 6769:  /* *p iwmmxt_wsadhz */
    case 6768:  /* *p iwmmxt_wsadbz */
    case 6767:  /* *p iwmmxt_wsadh */
    case 6766:  /* *p iwmmxt_wsadb */
    case 679:  /* iwmmxt_wsadhz */
    case 678:  /* iwmmxt_wsadbz */
    case 677:  /* iwmmxt_wsadh */
    case 676:  /* iwmmxt_wsadb */
      return WMMXT_ALU_C3_YES;

    default:
      return WMMXT_ALU_C3_NO;

    }
}

enum attr_wmmxt_alu_c2
get_attr_wmmxt_alu_c2 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_WACC) || (cached_type == TYPE_WMMX_WADD) || (cached_type == TYPE_WMMX_WADDSUBHX) || (cached_type == TYPE_WMMX_WAVG2) || (cached_type == TYPE_WMMX_WAVG4) || (cached_type == TYPE_WMMX_WCMPEQ) || (cached_type == TYPE_WMMX_WCMPGT) || (cached_type == TYPE_WMMX_WMAX) || (cached_type == TYPE_WMMX_WMIN) || (cached_type == TYPE_WMMX_WSUB) || (cached_type == TYPE_WMMX_WADDBHUS) || (cached_type == TYPE_WMMX_WSUBADDHX))
        {
	  return WMMXT_ALU_C2_YES;
        }
      else
        {
	  return WMMXT_ALU_C2_NO;
        }

    case 6798:  /* *p iwmmxt_waddbhusl */
    case 6797:  /* *p iwmmxt_waddbhusm */
    case 6781:  /* *p iwmmxt_avg4r */
    case 6780:  /* *p iwmmxt_avg4 */
    case 6779:  /* *p addcv2si3 */
    case 6778:  /* *p addcv4hi3 */
    case 6777:  /* *p iwmmxt_wsubaddhx */
    case 6776:  /* *p iwmmxt_waddsubhx */
    case 6759:  /* *p iwmmxt_waccw */
    case 6758:  /* *p iwmmxt_wacch */
    case 6757:  /* *p iwmmxt_waccb */
    case 6697:  /* *p *uminv8qi3_iwmmxt */
    case 6696:  /* *p *uminv4hi3_iwmmxt */
    case 6695:  /* *p *uminv2si3_iwmmxt */
    case 6694:  /* *p *sminv8qi3_iwmmxt */
    case 6693:  /* *p *sminv4hi3_iwmmxt */
    case 6692:  /* *p *sminv2si3_iwmmxt */
    case 6691:  /* *p *umaxv8qi3_iwmmxt */
    case 6690:  /* *p *umaxv4hi3_iwmmxt */
    case 6689:  /* *p *umaxv2si3_iwmmxt */
    case 6688:  /* *p *smaxv8qi3_iwmmxt */
    case 6687:  /* *p *smaxv4hi3_iwmmxt */
    case 6686:  /* *p *smaxv2si3_iwmmxt */
    case 6685:  /* *p gtv2si3 */
    case 6684:  /* *p gtv4hi3 */
    case 6683:  /* *p gtv8qi3 */
    case 6682:  /* *p gtuv2si3 */
    case 6681:  /* *p gtuv4hi3 */
    case 6680:  /* *p gtuv8qi3 */
    case 6679:  /* *p eqv2si3 */
    case 6678:  /* *p eqv4hi3 */
    case 6677:  /* *p eqv8qi3 */
    case 6667:  /* *p iwmmxt_uavgv4hi3 */
    case 6666:  /* *p iwmmxt_uavgv8qi3 */
    case 6665:  /* *p iwmmxt_uavgrndv4hi3 */
    case 6664:  /* *p iwmmxt_uavgrndv8qi3 */
    case 6652:  /* *p ussubv2si3 */
    case 6651:  /* *p ussubv4hi3 */
    case 6650:  /* *p ussubv8qi3 */
    case 6649:  /* *p sssubv2si3 */
    case 6648:  /* *p sssubv4hi3 */
    case 6647:  /* *p sssubv8qi3 */
    case 6646:  /* *p *subv8qi3_iwmmxt */
    case 6645:  /* *p *subv4hi3_iwmmxt */
    case 6644:  /* *p *subv2si3_iwmmxt */
    case 6643:  /* *p usaddv2si3 */
    case 6642:  /* *p usaddv4hi3 */
    case 6641:  /* *p usaddv8qi3 */
    case 6640:  /* *p ssaddv2si3 */
    case 6639:  /* *p ssaddv4hi3 */
    case 6638:  /* *p ssaddv8qi3 */
    case 6637:  /* *p *addv8qi3_iwmmxt */
    case 6636:  /* *p *addv4hi3_iwmmxt */
    case 6635:  /* *p *addv2si3_iwmmxt */
    case 708:  /* iwmmxt_waddbhusl */
    case 707:  /* iwmmxt_waddbhusm */
    case 691:  /* iwmmxt_avg4r */
    case 690:  /* iwmmxt_avg4 */
    case 689:  /* addcv2si3 */
    case 688:  /* addcv4hi3 */
    case 687:  /* iwmmxt_wsubaddhx */
    case 686:  /* iwmmxt_waddsubhx */
    case 669:  /* iwmmxt_waccw */
    case 668:  /* iwmmxt_wacch */
    case 667:  /* iwmmxt_waccb */
    case 607:  /* *uminv8qi3_iwmmxt */
    case 606:  /* *uminv4hi3_iwmmxt */
    case 605:  /* *uminv2si3_iwmmxt */
    case 604:  /* *sminv8qi3_iwmmxt */
    case 603:  /* *sminv4hi3_iwmmxt */
    case 602:  /* *sminv2si3_iwmmxt */
    case 601:  /* *umaxv8qi3_iwmmxt */
    case 600:  /* *umaxv4hi3_iwmmxt */
    case 599:  /* *umaxv2si3_iwmmxt */
    case 598:  /* *smaxv8qi3_iwmmxt */
    case 597:  /* *smaxv4hi3_iwmmxt */
    case 596:  /* *smaxv2si3_iwmmxt */
    case 595:  /* gtv2si3 */
    case 594:  /* gtv4hi3 */
    case 593:  /* gtv8qi3 */
    case 592:  /* gtuv2si3 */
    case 591:  /* gtuv4hi3 */
    case 590:  /* gtuv8qi3 */
    case 589:  /* eqv2si3 */
    case 588:  /* eqv4hi3 */
    case 587:  /* eqv8qi3 */
    case 577:  /* iwmmxt_uavgv4hi3 */
    case 576:  /* iwmmxt_uavgv8qi3 */
    case 575:  /* iwmmxt_uavgrndv4hi3 */
    case 574:  /* iwmmxt_uavgrndv8qi3 */
    case 562:  /* ussubv2si3 */
    case 561:  /* ussubv4hi3 */
    case 560:  /* ussubv8qi3 */
    case 559:  /* sssubv2si3 */
    case 558:  /* sssubv4hi3 */
    case 557:  /* sssubv8qi3 */
    case 556:  /* *subv8qi3_iwmmxt */
    case 555:  /* *subv4hi3_iwmmxt */
    case 554:  /* *subv2si3_iwmmxt */
    case 553:  /* usaddv2si3 */
    case 552:  /* usaddv4hi3 */
    case 551:  /* usaddv8qi3 */
    case 550:  /* ssaddv2si3 */
    case 549:  /* ssaddv4hi3 */
    case 548:  /* ssaddv8qi3 */
    case 547:  /* *addv8qi3_iwmmxt */
    case 546:  /* *addv4hi3_iwmmxt */
    case 545:  /* *addv2si3_iwmmxt */
      return WMMXT_ALU_C2_YES;

    default:
      return WMMXT_ALU_C2_NO;

    }
}

enum attr_wmmxt_alu_c1
get_attr_wmmxt_alu_c1 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return WMMXT_ALU_C1_YES;
        }
      else
        {
	  return WMMXT_ALU_C1_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_WABS) || (cached_type == TYPE_WMMX_WABSDIFF) || (cached_type == TYPE_WMMX_WAND) || (cached_type == TYPE_WMMX_WANDN) || (cached_type == TYPE_WMMX_WMOV) || (cached_type == TYPE_WMMX_WOR) || (cached_type == TYPE_WMMX_WXOR))
        {
	  return WMMXT_ALU_C1_YES;
        }
      else
        {
	  return WMMXT_ALU_C1_NO;
        }

    case 6775:  /* *p iwmmxt_wabsdiffw */
    case 6774:  /* *p iwmmxt_wabsdiffh */
    case 6773:  /* *p iwmmxt_wabsdiffb */
    case 6772:  /* *p iwmmxt_wabsv8qi3 */
    case 6771:  /* *p iwmmxt_wabsv4hi3 */
    case 6770:  /* *p iwmmxt_wabsv2si3 */
    case 6663:  /* *p iwmmxt_clrv2si */
    case 6662:  /* *p iwmmxt_clrv4hi */
    case 6661:  /* *p iwmmxt_clrv8qi */
    case 6660:  /* *p iwmmxt_clrdi */
    case 6634:  /* *p *xorv8qi3_iwmmxt */
    case 6633:  /* *p *xorv4hi3_iwmmxt */
    case 6632:  /* *p *xorv2si3_iwmmxt */
    case 6631:  /* *p *iorv8qi3_iwmmxt */
    case 6630:  /* *p *iorv4hi3_iwmmxt */
    case 6629:  /* *p *iorv2si3_iwmmxt */
    case 6628:  /* *p *andv8qi3_iwmmxt */
    case 6627:  /* *p *andv4hi3_iwmmxt */
    case 6626:  /* *p *andv2si3_iwmmxt */
    case 6622:  /* *p iwmmxt_nanddi3 */
    case 6621:  /* *p iwmmxt_anddi3 */
    case 6620:  /* *p iwmmxt_xordi3 */
    case 6619:  /* *p iwmmxt_iordi3 */
    case 685:  /* iwmmxt_wabsdiffw */
    case 684:  /* iwmmxt_wabsdiffh */
    case 683:  /* iwmmxt_wabsdiffb */
    case 682:  /* iwmmxt_wabsv8qi3 */
    case 681:  /* iwmmxt_wabsv4hi3 */
    case 680:  /* iwmmxt_wabsv2si3 */
    case 573:  /* iwmmxt_clrv2si */
    case 572:  /* iwmmxt_clrv4hi */
    case 571:  /* iwmmxt_clrv8qi */
    case 570:  /* iwmmxt_clrdi */
    case 544:  /* *xorv8qi3_iwmmxt */
    case 543:  /* *xorv4hi3_iwmmxt */
    case 542:  /* *xorv2si3_iwmmxt */
    case 541:  /* *iorv8qi3_iwmmxt */
    case 540:  /* *iorv4hi3_iwmmxt */
    case 539:  /* *iorv2si3_iwmmxt */
    case 538:  /* *andv8qi3_iwmmxt */
    case 537:  /* *andv4hi3_iwmmxt */
    case 536:  /* *andv2si3_iwmmxt */
    case 529:  /* iwmmxt_nanddi3 */
    case 528:  /* iwmmxt_anddi3 */
    case 527:  /* iwmmxt_xordi3 */
    case 526:  /* iwmmxt_iordi3 */
      return WMMXT_ALU_C1_YES;

    default:
      return WMMXT_ALU_C1_NO;

    }
}

enum attr_wmmxt_mult_c2
get_attr_wmmxt_mult_c2 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_WMUL) || (cached_type == TYPE_WMMX_WQMULM))
        {
	  return WMMXT_MULT_C2_YES;
        }
      else
        {
	  return WMMXT_MULT_C2_NO;
        }

    case 6795:  /* *p iwmmxt_wqmulmr */
    case 6793:  /* *p iwmmxt_wqmulm */
    case 6790:  /* *p iwmmxt_wmulwsmr */
    case 6789:  /* *p iwmmxt_wmulumr */
    case 6788:  /* *p iwmmxt_wmulsmr */
    case 6655:  /* *p umulv4hi3_highpart */
    case 6654:  /* *p smulv4hi3_highpart */
    case 6653:  /* *p *mulv4hi3_iwmmxt */
    case 705:  /* iwmmxt_wqmulmr */
    case 703:  /* iwmmxt_wqmulm */
    case 700:  /* iwmmxt_wmulwsmr */
    case 699:  /* iwmmxt_wmulumr */
    case 698:  /* iwmmxt_wmulsmr */
    case 565:  /* umulv4hi3_highpart */
    case 564:  /* smulv4hi3_highpart */
    case 563:  /* *mulv4hi3_iwmmxt */
      return WMMXT_MULT_C2_YES;

    default:
      return WMMXT_MULT_C2_NO;

    }
}

enum attr_wmmxt_mult_c1
get_attr_wmmxt_mult_c1 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_WMAC) || (cached_type == TYPE_WMMX_WMADD) || (cached_type == TYPE_WMMX_WMIAXY) || (cached_type == TYPE_WMMX_WMIAWXY) || (cached_type == TYPE_WMMX_WMULW) || (cached_type == TYPE_WMMX_WQMIAXY) || (cached_type == TYPE_WMMX_WQMULWM))
        {
	  return WMMXT_MULT_C1_YES;
        }
      else
        {
	  return WMMXT_MULT_C1_NO;
        }

    case 6822:  /* *p iwmmxt_wmiawttn */
    case 6821:  /* *p iwmmxt_wmiawtbn */
    case 6820:  /* *p iwmmxt_wmiawbtn */
    case 6819:  /* *p iwmmxt_wmiawbbn */
    case 6818:  /* *p iwmmxt_wmiawtt */
    case 6817:  /* *p iwmmxt_wmiawtb */
    case 6816:  /* *p iwmmxt_wmiawbt */
    case 6815:  /* *p iwmmxt_wmiawbb */
    case 6814:  /* *p iwmmxt_wmiattn */
    case 6813:  /* *p iwmmxt_wmiatbn */
    case 6812:  /* *p iwmmxt_wmiabtn */
    case 6811:  /* *p iwmmxt_wmiabbn */
    case 6810:  /* *p iwmmxt_wmiatt */
    case 6809:  /* *p iwmmxt_wmiatb */
    case 6808:  /* *p iwmmxt_wmiabt */
    case 6807:  /* *p iwmmxt_wmiabb */
    case 6806:  /* *p iwmmxt_wqmiattn */
    case 6805:  /* *p iwmmxt_wqmiatbn */
    case 6804:  /* *p iwmmxt_wqmiabtn */
    case 6803:  /* *p iwmmxt_wqmiabbn */
    case 6802:  /* *p iwmmxt_wqmiatt */
    case 6801:  /* *p iwmmxt_wqmiatb */
    case 6800:  /* *p iwmmxt_wqmiabt */
    case 6799:  /* *p iwmmxt_wqmiabb */
    case 6796:  /* *p iwmmxt_wqmulwmr */
    case 6794:  /* *p iwmmxt_wqmulwm */
    case 6792:  /* *p iwmmxt_wmulwl */
    case 6791:  /* *p iwmmxt_wmulwumr */
    case 6787:  /* *p iwmmxt_wmulwum */
    case 6786:  /* *p iwmmxt_wmulwsm */
    case 6785:  /* *p iwmmxt_wmaddun */
    case 6784:  /* *p iwmmxt_wmaddsn */
    case 6783:  /* *p iwmmxt_wmaddux */
    case 6782:  /* *p iwmmxt_wmaddsx */
    case 6747:  /* *p iwmmxt_wmaddu */
    case 6746:  /* *p iwmmxt_wmadds */
    case 6659:  /* *p iwmmxt_wmacuz */
    case 6658:  /* *p iwmmxt_wmacu */
    case 6657:  /* *p iwmmxt_wmacsz */
    case 6656:  /* *p iwmmxt_wmacs */
    case 732:  /* iwmmxt_wmiawttn */
    case 731:  /* iwmmxt_wmiawtbn */
    case 730:  /* iwmmxt_wmiawbtn */
    case 729:  /* iwmmxt_wmiawbbn */
    case 728:  /* iwmmxt_wmiawtt */
    case 727:  /* iwmmxt_wmiawtb */
    case 726:  /* iwmmxt_wmiawbt */
    case 725:  /* iwmmxt_wmiawbb */
    case 724:  /* iwmmxt_wmiattn */
    case 723:  /* iwmmxt_wmiatbn */
    case 722:  /* iwmmxt_wmiabtn */
    case 721:  /* iwmmxt_wmiabbn */
    case 720:  /* iwmmxt_wmiatt */
    case 719:  /* iwmmxt_wmiatb */
    case 718:  /* iwmmxt_wmiabt */
    case 717:  /* iwmmxt_wmiabb */
    case 716:  /* iwmmxt_wqmiattn */
    case 715:  /* iwmmxt_wqmiatbn */
    case 714:  /* iwmmxt_wqmiabtn */
    case 713:  /* iwmmxt_wqmiabbn */
    case 712:  /* iwmmxt_wqmiatt */
    case 711:  /* iwmmxt_wqmiatb */
    case 710:  /* iwmmxt_wqmiabt */
    case 709:  /* iwmmxt_wqmiabb */
    case 706:  /* iwmmxt_wqmulwmr */
    case 704:  /* iwmmxt_wqmulwm */
    case 702:  /* iwmmxt_wmulwl */
    case 701:  /* iwmmxt_wmulwumr */
    case 697:  /* iwmmxt_wmulwum */
    case 696:  /* iwmmxt_wmulwsm */
    case 695:  /* iwmmxt_wmaddun */
    case 694:  /* iwmmxt_wmaddsn */
    case 693:  /* iwmmxt_wmaddux */
    case 692:  /* iwmmxt_wmaddsx */
    case 657:  /* iwmmxt_wmaddu */
    case 656:  /* iwmmxt_wmadds */
    case 569:  /* iwmmxt_wmacuz */
    case 568:  /* iwmmxt_wmacu */
    case 567:  /* iwmmxt_wmacsz */
    case 566:  /* iwmmxt_wmacs */
      return WMMXT_MULT_C1_YES;

    default:
      return WMMXT_MULT_C1_NO;

    }
}

enum attr_wmmxt_pack
get_attr_wmmxt_pack (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_WALIGNI) || (cached_type == TYPE_WMMX_WALIGNR) || (cached_type == TYPE_WMMX_WMERGE) || (cached_type == TYPE_WMMX_WPACK) || (cached_type == TYPE_WMMX_WSHUFH) || (cached_type == TYPE_WMMX_WUNPCKEH) || (cached_type == TYPE_WMMX_WUNPCKIH) || (cached_type == TYPE_WMMX_WUNPCKEL) || (cached_type == TYPE_WMMX_WUNPCKIL))
        {
	  return WMMXT_PACK_YES;
        }
      else
        {
	  return WMMXT_PACK_NO;
        }

    case 6823:  /* *p iwmmxt_wmerge */
    case 6765:  /* *p iwmmxt_walignr3 */
    case 6764:  /* *p iwmmxt_walignr2 */
    case 6763:  /* *p iwmmxt_walignr1 */
    case 6762:  /* *p iwmmxt_walignr0 */
    case 6761:  /* *p iwmmxt_walignr */
    case 6760:  /* *p iwmmxt_waligni */
    case 6721:  /* *p iwmmxt_wunpckelsw */
    case 6720:  /* *p iwmmxt_wunpckelsh */
    case 6719:  /* *p iwmmxt_wunpckelsb */
    case 6718:  /* *p iwmmxt_wunpckeluw */
    case 6717:  /* *p iwmmxt_wunpckeluh */
    case 6716:  /* *p iwmmxt_wunpckelub */
    case 6715:  /* *p iwmmxt_wunpckehsw */
    case 6714:  /* *p iwmmxt_wunpckehsh */
    case 6713:  /* *p iwmmxt_wunpckehsb */
    case 6712:  /* *p iwmmxt_wunpckehuw */
    case 6711:  /* *p iwmmxt_wunpckehuh */
    case 6710:  /* *p iwmmxt_wunpckehub */
    case 6709:  /* *p iwmmxt_wunpckilw */
    case 6708:  /* *p iwmmxt_wunpckilh */
    case 6707:  /* *p iwmmxt_wunpckilb */
    case 6706:  /* *p iwmmxt_wunpckihw */
    case 6705:  /* *p iwmmxt_wunpckihh */
    case 6704:  /* *p iwmmxt_wunpckihb */
    case 6703:  /* *p iwmmxt_wpackdus */
    case 6702:  /* *p iwmmxt_wpackwus */
    case 6701:  /* *p iwmmxt_wpackhus */
    case 6700:  /* *p iwmmxt_wpackdss */
    case 6699:  /* *p iwmmxt_wpackwss */
    case 6698:  /* *p iwmmxt_wpackhss */
    case 6676:  /* *p iwmmxt_wshufh */
    case 733:  /* iwmmxt_wmerge */
    case 675:  /* iwmmxt_walignr3 */
    case 674:  /* iwmmxt_walignr2 */
    case 673:  /* iwmmxt_walignr1 */
    case 672:  /* iwmmxt_walignr0 */
    case 671:  /* iwmmxt_walignr */
    case 670:  /* iwmmxt_waligni */
    case 631:  /* iwmmxt_wunpckelsw */
    case 630:  /* iwmmxt_wunpckelsh */
    case 629:  /* iwmmxt_wunpckelsb */
    case 628:  /* iwmmxt_wunpckeluw */
    case 627:  /* iwmmxt_wunpckeluh */
    case 626:  /* iwmmxt_wunpckelub */
    case 625:  /* iwmmxt_wunpckehsw */
    case 624:  /* iwmmxt_wunpckehsh */
    case 623:  /* iwmmxt_wunpckehsb */
    case 622:  /* iwmmxt_wunpckehuw */
    case 621:  /* iwmmxt_wunpckehuh */
    case 620:  /* iwmmxt_wunpckehub */
    case 619:  /* iwmmxt_wunpckilw */
    case 618:  /* iwmmxt_wunpckilh */
    case 617:  /* iwmmxt_wunpckilb */
    case 616:  /* iwmmxt_wunpckihw */
    case 615:  /* iwmmxt_wunpckihh */
    case 614:  /* iwmmxt_wunpckihb */
    case 613:  /* iwmmxt_wpackdus */
    case 612:  /* iwmmxt_wpackwus */
    case 611:  /* iwmmxt_wpackhus */
    case 610:  /* iwmmxt_wpackdss */
    case 609:  /* iwmmxt_wpackwss */
    case 608:  /* iwmmxt_wpackhss */
    case 586:  /* iwmmxt_wshufh */
      return WMMXT_PACK_YES;

    default:
      return WMMXT_PACK_NO;

    }
}

enum attr_wmmxt_shift
get_attr_wmmxt_shift (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_WMMX_WROR) || (cached_type == TYPE_WMMX_WSLL) || (cached_type == TYPE_WMMX_WSRA) || (cached_type == TYPE_WMMX_WSRL))
        {
	  return WMMXT_SHIFT_YES;
        }
      else
        {
	  return WMMXT_SHIFT_NO;
        }

    case 6745:  /* *p ashldi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6736:  /* *p rordi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6734:  /* *p rorv4hi3_di */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6724:  /* *p rordi3 */
    case 6723:  /* *p rorv2si3 */
    case 6722:  /* *p rorv4hi3 */
    case 655:  /* ashldi3_di */
    case 654:  /* ashlv2si3_di */
    case 653:  /* ashlv4hi3_di */
    case 652:  /* lshrdi3_di */
    case 651:  /* lshrv2si3_di */
    case 650:  /* lshrv4hi3_di */
    case 649:  /* ashrdi3_di */
    case 648:  /* ashrv2si3_di */
    case 647:  /* ashrv4hi3_di */
    case 646:  /* rordi3_di */
    case 645:  /* rorv2si3_di */
    case 644:  /* rorv4hi3_di */
    case 643:  /* ashldi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 634:  /* rordi3 */
    case 633:  /* rorv2si3 */
    case 632:  /* rorv4hi3 */
      return WMMXT_SHIFT_YES;

    default:
      return WMMXT_SHIFT_NO;

    }
}

enum attr_write_conflict
get_attr_write_conflict (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 6927:  /* *p *thumb2_movhi_insn */
    case 1009:  /* *thumb2_movhi_insn */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0x1fULL))
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 963:  /* *thumb1_movsf_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xaULL))
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 959:  /* *thumb1_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x120ULL))
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6849:  /* *p *thumb2_movsi_vfp */
    case 759:  /* *thumb2_movsi_vfp */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0x60ULL))
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6926:  /* *p *thumb2_movsi_insn */
    case 6854:  /* *p *thumb2_movsf_vfp */
    case 6853:  /* *p *movsf_vfp */
    case 6847:  /* *p *thumb2_movhi_fp16 */
    case 6846:  /* *p *thumb2_movhi_fp16 */
    case 6845:  /* *p *thumb2_movhi_fp16 */
    case 6844:  /* *p *thumb2_movhi_fp16 */
    case 6843:  /* *p *thumb2_movhi_fp16 */
    case 6841:  /* *p *thumb2_movhi_vfp */
    case 6840:  /* *p *thumb2_movhi_vfp */
    case 6839:  /* *p *thumb2_movhi_vfp */
    case 6838:  /* *p *thumb2_movhi_vfp */
    case 6837:  /* *p *thumb2_movhi_vfp */
    case 1007:  /* *thumb2_movsi_insn */
    case 768:  /* *thumb2_movsf_vfp */
    case 767:  /* *movsf_vfp */
    case 757:  /* *thumb2_movhi_fp16 */
    case 756:  /* *thumb2_movhi_fp16 */
    case 755:  /* *thumb2_movhi_fp16 */
    case 754:  /* *thumb2_movhi_fp16 */
    case 753:  /* *thumb2_movhi_fp16 */
    case 751:  /* *thumb2_movhi_vfp */
    case 750:  /* *thumb2_movhi_vfp */
    case 749:  /* *thumb2_movhi_vfp */
    case 748:  /* *thumb2_movhi_vfp */
    case 747:  /* *thumb2_movhi_vfp */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 5)
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6625:  /* *p movv8qi_internal */
    case 6624:  /* *p movv4hi_internal */
    case 6623:  /* *p movv2si_internal */
    case 535:  /* movv8qi_internal */
    case 534:  /* movv4hi_internal */
    case 533:  /* movv2si_internal */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 6)
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 764:  /* *movbf_vfp_neon */
    case 763:  /* *movhf_vfp_neon */
    case 532:  /* *cond_iwmmxt_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 2)
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6529:  /* *p *arm_movsf_soft_insn */
    case 962:  /* *thumb1_movhf */
    case 961:  /* *thumb1_movqi_insn */
    case 960:  /* *thumb1_movhi_insn */
    case 270:  /* *arm_movsf_soft_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 1)
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6852:  /* *p *movbf_vfp_bf16 */
    case 6851:  /* *p *movhf_vfp_hf16 */
    case 6528:  /* *p *arm32_movbf */
    case 6527:  /* *p *arm32_movhf */
    case 766:  /* *movbf_vfp */
    case 765:  /* *movhf_vfp */
    case 762:  /* *movbf_vfp_bf16 */
    case 761:  /* *movhf_vfp_hf16 */
    case 269:  /* *arm32_movbf */
    case 268:  /* *arm32_movhf */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 0)
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6526:  /* *p *arm_movqi_insn */
    case 267:  /* *arm_movqi_insn */
      extract_constrain_insn_cached (insn);
      if (((1ULL << which_alternative) & 0xa0ULL))
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6524:  /* *p *movhi_insn_arch4 */
    case 265:  /* *movhi_insn_arch4 */
      extract_constrain_insn_cached (insn);
      if (!((1ULL << which_alternative) & 0xfULL))
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6848:  /* *p *arm_movsi_vfp */
    case 6842:  /* *p *arm_movhi_fp16 */
    case 6836:  /* *p *arm_movhi_vfp */
    case 6521:  /* *p *arm_movsi_insn */
    case 758:  /* *arm_movsi_vfp */
    case 752:  /* *arm_movhi_fp16 */
    case 746:  /* *arm_movhi_vfp */
    case 531:  /* *iwmmxt_movsi_insn */
    case 257:  /* *arm_movsi_insn */
      extract_constrain_insn_cached (insn);
      if (which_alternative == 4)
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_BLOCK) || (cached_type == TYPE_CALL) || (cached_type == TYPE_LOAD_4))
        {
	  return WRITE_CONFLICT_YES;
        }
      else
        {
	  return WRITE_CONFLICT_NO;
        }

    case 6925:  /* *p *thumb2_pop_single */
    case 6905:  /* *p pop_fpsysreg_insn */
    case 6553:  /* *p *ldr_with_return */
    case 6549:  /* *p *arith_adjacentmem */
    case 6537:  /* *p *load_indirect_jump */
    case 6533:  /* *p *arm_return */
    case 6523:  /* *p tls_load_dot_plus_eight */
    case 6429:  /* *p unaligned_loadsi */
    case 1023:  /* *nonsecure_call_value_reg_thumb2 */
    case 1022:  /* *nonsecure_call_value_reg_thumb2_fpcxt */
    case 1021:  /* *call_value_reg_thumb2 */
    case 1020:  /* *nonsecure_call_reg_thumb2 */
    case 1019:  /* *nonsecure_call_reg_thumb2_fpcxt */
    case 1018:  /* *call_reg_thumb2 */
    case 1006:  /* *thumb2_pop_single */
    case 995:  /* *epilogue_insns */
    case 991:  /* *call_value_insn */
    case 990:  /* *call_insn */
    case 989:  /* *call_value_reg_thumb1 */
    case 988:  /* *nonsecure_call_value_reg_thumb1_v5 */
    case 987:  /* *call_value_reg_thumb1_v5 */
    case 986:  /* *call_reg_thumb1 */
    case 985:  /* *nonsecure_call_reg_thumb1_v5 */
    case 984:  /* *call_reg_thumb1_v5 */
    case 853:  /* lazy_load_multiple_insn */
    case 850:  /* pop_fpsysreg_insn */
    case 506:  /* *speculation_barrier_insn */
    case 402:  /* prefetch */
    case 389:  /* *ldr_with_return */
    case 385:  /* stack_tie */
    case 380:  /* *arith_adjacentmem */
    case 316:  /* *load_indirect_jump */
    case 305:  /* blockage */
    case 302:  /* *cond_simple_return_inverted */
    case 301:  /* *cond_return_inverted */
    case 300:  /* *cond_simple_return */
    case 299:  /* *cond_return */
    case 298:  /* *arm_return */
    case 297:  /* *sibcall_value_insn */
    case 296:  /* *sibcall_insn */
    case 295:  /* *call_value_symbol */
    case 294:  /* *call_symbol */
    case 293:  /* *call_value_reg_arm */
    case 292:  /* *call_value_reg_armv5 */
    case 291:  /* *call_reg_arm */
    case 290:  /* *call_reg_armv5 */
    case 263:  /* tls_load_dot_plus_eight */
    case 260:  /* pic_load_addr_thumb1 */
    case 259:  /* pic_load_addr_32bit */
    case 258:  /* pic_load_addr_unified */
    case 158:  /* unaligned_loadsi */
      return WRITE_CONFLICT_YES;

    default:
      return WRITE_CONFLICT_NO;

    }
}

enum attr_widen_mul64
get_attr_widen_mul64 (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
      if (((cached_type = get_attr_type (insn)) == TYPE_SMLALXY) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMAAL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_UMLALS) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_SMLALS))
        {
	  return WIDEN_MUL64_YES;
        }
      else
        {
	  return WIDEN_MUL64_NO;
        }

    case 6392:  /* *p *maddhidi4tt */
    case 6391:  /* *p *maddhidi4tb */
    case 6390:  /* *p maddhidi4 */
    case 6379:  /* *p *umull_high */
    case 6378:  /* *p *smull_high */
    case 6377:  /* *p umlal */
    case 6376:  /* *p smlal */
    case 6375:  /* *p umull */
    case 6374:  /* *p smull */
    case 85:  /* *maddhidi4tt */
    case 84:  /* *maddhidi4tb */
    case 83:  /* maddhidi4 */
    case 72:  /* *umull_high */
    case 71:  /* *smull_high */
    case 70:  /* umlal */
    case 69:  /* smlal */
    case 68:  /* umull */
    case 67:  /* smull */
      return WIDEN_MUL64_YES;

    default:
      return WIDEN_MUL64_NO;

    }
}

int
eligible_for_delay (rtx_insn *delay_insn ATTRIBUTE_UNUSED, int slot, 
		   rtx_insn *candidate_insn, int flags ATTRIBUTE_UNUSED)
{
  rtx_insn *insn ATTRIBUTE_UNUSED;

  if (num_delay_slots (delay_insn) == 0)
    return 0;
  gcc_assert (slot < 0);

  if (!INSN_P (candidate_insn))
    return 0;

  insn = candidate_insn;
  switch (slot)
    {
    default:
      gcc_unreachable ();
    }
}

int
eligible_for_annul_true (rtx_insn *delay_insn ATTRIBUTE_UNUSED,
    int slot ATTRIBUTE_UNUSED,
    rtx_insn *candidate_insn ATTRIBUTE_UNUSED,
    int flags ATTRIBUTE_UNUSED)
{
  return 0;
}

int
eligible_for_annul_false (rtx_insn *delay_insn ATTRIBUTE_UNUSED,
    int slot ATTRIBUTE_UNUSED,
    rtx_insn *candidate_insn ATTRIBUTE_UNUSED,
    int flags ATTRIBUTE_UNUSED)
{
  return 0;
}

int
const_num_delay_slots (rtx_insn *insn)
{
  switch (recog_memoized (insn))
    {
    default:
      return 1;
    }
}

EXPORTED_CONST int length_unit_log = 0;
